﻿-- encoding: UTF-8
-------------------------------------------------------------------------------
-- 谷歌拼音易五码输入扩展
--
-- 作者：JeffWang<wang_deyu@hotmail.com>
-- 版权：New BSD License
-- 版本：1.0.0.0018
--
-- 简介：易五码输入法，例如iyw10130 -> 王
--
-------------------------------------------------------------------------------

-- 易五码表
local im4c_table = {}
for i = 00000, 99999 do
	im4c_table[i] = {}
end
-- 汉字拼音表
local pinyin_table = {}

-- 通配符用的查找表
local im4c_ext_table = {}

-------------------------------------------------------------------------------

-- 是否合法的参数
function checkInput(args)
	-- 有效参数是2-6个
	if #args < 1 or #args > 5 then
		return false
	end

	-- 参数必须是[0-9|?]字符组成
	for i = 1, 5 do
		if i > #args then break end
		local ch = string.byte(args, i)
		if ch < string.byte("0") or ch > string.byte("9") then
			if ch ~= string.byte("?") then return false end
		end
	end
	-- 如果有第6个参数，必须是"?"
	if #args == 6 then
		local ch = string.byte(args, 6)
		if ch ~= string.byte("?") then return false end
	end

	-- 合法参数
	return true
end

-- 是否有完整易五码
function hasComplete4Code(numbers)
	return #numbers >= 5
		and string.byte(numbers, 1) >= 48 and string.byte(numbers, 1) <= 57
		and string.byte(numbers, 2) >= 48 and string.byte(numbers, 2) <= 57
		and string.byte(numbers, 3) >= 48 and string.byte(numbers, 3) <= 57
		and string.byte(numbers, 4) >= 48 and string.byte(numbers, 4) <= 57
		and string.byte(numbers, 5) >= 48 and string.byte(numbers, 5) <= 57
end

-- 读取参数
-- return id, show_info, show_help
function readArgs(args)
	-- ID信息（数字/字符串）
	-- 如果是完整易五码，则转为数字
	if hasComplete4Code(args) then
		id = assert(tonumber(string.sub(args, 1, 5)))
	else
		-- 还有非数字的类型
		id = string.sub(args, 1, 5)
		-- 不足5字节，用“?”补充
		for i = #args+1, 5 do
			id = (id .. "?")
		end
	end

	-- 是否显示详细信息
	local show_info = false
	if #args > 5 and string.byte(args, 6) == string.byte("?") then
		show_info = true
	end

	-- 只有"?"字符时，显示帮助
	local show_help = args
	for i = 1, #args do
		if string.byte(args, i) ~= string.byte("?") then
			show_help = nil
		end
	end
    
	return id, show_info, show_help
end

-------------------------------------------------------------------------------

-- 查询易五码表
function SearchTableByYiwu(args)
	-- 提示中显示帮助
	local ret = "-- 有效格式：101;1013;101?;?010;1?0?? --"
	if not checkInput(args) then return ret end

	-- 读取参数
	local id, show_info, show_help = readArgs(args)
	
	-- 显示口诀
	if show_help then
		if #show_help == 1 then
			return {
				"易洪川发明易五码",
				"比四角号码重码更少",
				"2005年《易五码检字法》出版",
				"可以输入65160个汉字。",
			}
		elseif #show_help == 2 then
			return {
				"易五码口诀：",
				"一横二垂三捺点，",
				"四托五交六框圈，",
				"七角八人九米小，",
				"特殊笔型零在前。",
			}
		elseif #show_help == 3 then
			return {
				"前三码为外形码",
				"后二码为内质码",
				"外形码参照口诀",
				"内质吗笔画相关",
				"横笔画与交叉数",
			}
		elseif #show_help == 4 then
			return {
				"扩展作者：",
				"JeffWang",
				"<wang_deyu@hotmail.com>",
			}
		else
			return {
				"http://www.yfcompuart.com",
			}
		end
		
	end
	
	-- 可能查找失败（通配符）
	local words = nil
	if type(id) == "number" then
		words = im4c_table[id]
	else
		-- 间接引用查找
		words = im4c_ext_table[id]
	end
	if not words then return {} end

	-- 显示详细信息
	if show_info then
		local info_table = { }
		-- 通配符查找可能失败
		for i = 1, #words do
			-- 使用拼音信息
			local pinyin = pinyin_table[tostring(words[i])]
			if pinyin then
				table.insert(info_table, pinyin)
			else
				table.insert(info_table, tostring(words[i]))
			end
		end
		return info_table
	else
		return words
	end

	-- 不会执行
	return ret
end

-- 注册命令
ime.register_command("yw", "SearchTableByYiwu", "易五码", "alpha", "易五码输入法，例如iyw10131[?] -> 王")

-------------------------------------------------------------------------------

-- 生成通配符查找表
-- 函数需要在基本表初始化之后执行
function generateIm4cExtTable()
	for i = 00000, 99999 do
		-- 只处理有汉字的类型
		if im4c_table[i] then
			-- 解析每个易五码编号
			local x1, x2, x3, x4, x5 = string.byte(string.format("%05d", i), 1, 5)
			-- 生成通配符位置组合
			local keys = {
				-- 1个通配符
				string.format("%s%c%c%c%c", "?", x2 , x3 , x4 , x5 ),
				string.format("%c%s%c%c%c", x1 , "?", x3 , x4 , x5 ),
				string.format("%c%c%s%c%c", x1 , x2 , "?", x4 , x5 ),
				string.format("%c%c%c%s%c", x1 , x2 , x3 , "?", x5 ),
				string.format("%c%c%c%c%s", x1 , x2 , x3 , x4 , "?"),
				-- 2个通配符
				string.format("%s%s%c%c%c", "?", "?", x3 , x4 , x5 ),
				string.format("%s%c%s%c%c", "?", x2 , "?", x4 , x5 ),
				string.format("%s%c%c%s%c", "?", x2 , x3 , "?", x5 ),
				string.format("%s%c%c%c%s", "?", x2 , x3 , x4 , "?"),
				string.format("%c%s%s%c%c", x1 , "?", "?", x4 , x5 ),
				string.format("%c%s%c%s%c", x1 , "?", x3 , "?", x5 ),
				string.format("%c%s%c%c%s", x1 , "?", x3 , x4 , "?"),
				string.format("%c%c%s%s%c", x1 , x2 , "?", "?", x5 ),
				string.format("%c%c%s%c%s", x1 , x2 , "?", x4 , "?"),
				string.format("%c%c%c%s%s", x1 , x2 , x3 , "?", "?"),
			}
			-- 保存汉字到对应的通配符选择中
			for j = 1, #(im4c_table[i]) do
				for k = 1, #keys do
					if im4c_ext_table[keys[k]] then
						table.insert(im4c_ext_table[keys[k]], im4c_table[i][j])	
					else
						im4c_ext_table[keys[k]] = { im4c_table[i][j] }
					end
				end
			end
		end
	end
end

-------------------------------------------------------------------------------

-- 汉字易五码表(共65160字)

do
	local a = im4c_table
	a[00000]={"彳"}
	a[00002]={"蕑","𥳐","𥴥","𦽅","𧀲"}
	a[00005]={"蘭"}
	a[00010]={"宀","簡","闁","门","阝","𥶆","𥶿","𨷮","𨷾"}
	a[00012]={"䉮","䕞","䕡","撊","艹","𢵧","𢸴","𢺄","𧂄"}
	a[00013]={"撋","擱","籣"}
	a[00014]={"藺"}
	a[00015]={"攔"}
	a[00020]={"","𥫗","𨸙"}
	a[00022]={"扌"}
	a[00032]={"扪"}
	a[00060]={"简","門"}
	a[00062]={"鬥"}
	a[00063]={"搁"}
	a[00064]={"蔺"}
	a[00072]={"菛"}
	a[00082]={"㨛","捫","蕄"}
	a[00083]={"䔵"}
	a[00084]={"蔅"}
	a[00090]={"䉍"}
	a[00091]={"簢"}
	a[00092]={"蔄"}
	a[00093]={"𢲾","𢵢"}
	a[00104]={"𨽧"}
	a[00112]={"𥶴"}
	a[00114]={"𥷘","𥷬"}
	a[00116]={"㩲","𧃔"}
	a[00132]={"苎"}
	a[00142]={"𦱇","𦲵"}
	a[00150]={"箜","𨼹"}
	a[00152]={"䓚","控","𦺝"}
	a[00153]={"𦹦"}
	a[00154]={"菈"}
	a[00162]={"萓","𢶅","𦯓","𦷳"}
	a[00164]={"𢬀","𦶏","𦸐"}
	a[00166]={"𦼉"}
	a[00172]={"萱","𢷙","𥲎"}
	a[00173]={"㝫","箍","𢯶","𢲼","𨽈"}
	a[00174]={"薩","𢯽"}
	a[00175]={"蕯"}
	a[00176]={"蓷"}
	a[00180]={"箮","𥳲"}
	a[00182]={"揎","𢲶","𢹑"}
	a[00183]={"𥳌"}
	a[00185]={"簺"}
	a[00187]={"㩙"}
	a[00192]={"𢱱"}
	a[00196]={"𢹵"}
	a[00217]={"𢹱"}
	a[00219]={"𢸳"}
	a[00234]={"莏"}
	a[00242]={"萨","𦴌"}
	a[00244]={"䓆"}
	a[00252]={"䇽","𢶌"}
	a[00260]={"𥰾"}
	a[00262]={"搾"}
	a[00263]={"蓹"}
	a[00264]={"𦿏"}
	a[00271]={"篽","𥷉"}
	a[00292]={"擳"}
	a[00301]={"𥶻"}
	a[00302]={"𢤘"}
	a[00303]={"𢸥"}
	a[00310]={"𨵬"}
	a[00312]={"𧂡"}
	a[00319]={"𢺉"}
	a[00322]={"徔"}
	a[00332]={"䔹"}
	a[00340]={"䉌"}
	a[00342]={"搲","𧁂"}
	a[00350]={"𥲡","𥶼"}
	a[00352]={"䓳","𢱶","𨼿"}
	a[00356]={"𦺦"}
	a[00362]={"攨","蔭"}
	a[00363]={"𧀕"}
	a[00364]={"㩚","𥳺"}
	a[00365]={"藌","𦾖"}
	a[00366]={"㩃"}
	a[00373]={"𢖘"}
	a[00374]={"𢳑"}
	a[00382]={"蘟","𢠶"}
	a[00383]={"䉥","䧮"}
	a[00385]={"藼","𧒣"}
	a[00386]={"攐"}
	a[00393]={"𧁼"}
	a[00395]={"攇"}
	a[00400]={"𨵄"}
	a[00412]={"𧅉"}
	a[00415]={"𥷪"}
	a[00430]={"陀"}
	a[00440]={"𥬌"}
	a[00442]={"宽","拕","𦱆","𦳾"}
	a[00450]={"院","𨹕"}
	a[00451]={"𥭌"}
	a[00452]={"挖","莞","菀","𢰉","𢳙"}
	a[00453]={"挓"}
	a[00454]={"𦰜"}
	a[00460]={"筦","箢"}
	a[00462]={"捖","捥"}
	a[00463]={"𦵤"}
	a[00464]={"𦸅"}
	a[00466]={"㩢"}
	a[00472]={"寛","寬","筢"}
	a[00473]={"蔻"}
	a[00474]={"菢","𢯿"}
	a[00480]={"𨳷","𨳻"}
	a[00481]={"簆"}
	a[00484]={"𦶂"}
	a[00486]={"𨼭"}
	a[00491]={"𨴥"}
	a[00492]={"攛"}
	a[00494]={"𧂛"}
	a[00496]={"𢶊"}
	a[00503]={"䉗"}
	a[00504]={"籜"}
	a[00517]={"𨶱"}
	a[00531]={"𨺦"}
	a[00534]={"荌","𢱇"}
	a[00541]={"𥯴"}
	a[00543]={"䓈","𢯴","𢲷"}
	a[00544]={"按"}
	a[00546]={"𦵭"}
	a[00553]={"䔂","𦵮"}
	a[00554]={"㨓","䔖","𢭂","𦼧"}
	a[00555]={"𢹕"}
	a[00556]={"菝","𦰽"}
	a[00560]={"𦲫"}
	a[00562]={"䉄"}
	a[00563]={"蕧","薇","𦽛"}
	a[00564]={"𢳓"}
	a[00565]={"𦾨"}
	a[00566]={"𦽚"}
	a[00567]={"萚","𡪤"}
	a[00568]={"葎"}
	a[00571]={"䉠","𥳇"}
	a[00572]={"𥷲"}
	a[00574]={"藢","𦸤"}
	a[00575]={"搑","擏","箨"}
	a[00576]={"撺","箻"}
	a[00578]={"𢯰"}
	a[00579]={"撶","𦾙"}
	a[00580]={"𧂜"}
	a[00582]={"𨴣"}
	a[00584]={"𢲻","𢷸","𥵵"}
	a[00585]={"篺","籆"}
	a[00587]={"擭"}
	a[00594]={"𥷐"}
	a[00595]={"䉟","䔱"}
	a[00596]={"蘀"}
	a[00598]={"𢴩"}
	a[00602]={"𧅓","𨶀"}
	a[00603]={"𨵫"}
	a[00604]={"𦾬"}
	a[00613]={"籒"}
	a[00642]={"蓉"}
	a[00650]={"䈶"}
	a[00652]={"搈","菪","𦼑","𨸉","𨻇"}
	a[00655]={"𦴈"}
	a[00661]={"𥯾","𨻴","𨼈"}
	a[00662]={"䔒","筘","蓿","𦵡"}
	a[00663]={"揢","箬","𢴀","𥯶"}
	a[00664]={"搭","萔","𧀯"}
	a[00665]={"掿","描","葀"}
	a[00666]={"菗"}
	a[00670]={"䈹"}
	a[00672]={"摍","撘","𢲹","𥮠","𥶪","𦺼"}
	a[00674]={"𢱁","𢸙"}
	a[00675]={"𦵯"}
	a[00683]={"䔰","𥰶"}
	a[00685]={"㩈","搳","𦼾"}
	a[00686]={"擆"}
	a[00692]={"𥴻"}
	a[00693]={"籀"}
	a[00694]={"簎","𢷷"}
	a[00700]={"簼","𨵌"}
	a[00703]={"𥶽"}
	a[00708]={"㩷"}
	a[00710]={"䦡"}
	a[00714]={"𨷳"}
	a[00715]={"𪇜"}
	a[00732]={"苧","荇"}
	a[00733]={"䓖","𦱖"}
	a[00740]={"䇡","筕"}
	a[00742]={"拧","葕","𢫱"}
	a[00743]={"茡","蔤","𦸇"}
	a[00745]={"㨅","𢰆"}
	a[00749]={"𢺊"}
	a[00750]={"㣷"}
	a[00751]={"䈼","𢕗"}
	a[00752]={"荫","𢯼"}
	a[00753]={"㨸"}
	a[00755]={"捞","𦯙"}
	a[00760]={"𢕋"}
	a[00762]={"菅","薴","𢮍","𦾩"}
	a[00763]={"䕔","𦳉"}
	a[00764]={"䔭"}
	a[00767]={"㩶"}
	a[00770]={"管","𥲋"}
	a[00772]={"䈰","捾","擰","藛","𥳥","𦽜"}
	a[00773]={"㨳","箉"}
	a[00774]={"㨚","㩐","箝","𦽆"}
	a[00775]={"𠟽","𦺧"}
	a[00778]={"蒱","藆"}
	a[00780]={"𥳜","𥴩","𥶘","𨴠"}
	a[00782]={"擶","𢵀"}
	a[00783]={"䔺"}
	a[00784]={"䔾","擖"}
	a[00788]={"𢷘"}
	a[00791]={"𥳔"}
	a[00792]={"藭"}
	a[00793]={"撱"}
	a[00794]={"𦼸"}
	a[00795]={"𧃯"}
	a[00796]={"𢺃"}
	a[00797]={"𢸆","𢹘","𥴮"}
	a[00802]={"𥶐"}
	a[00810]={"𢕩","𨷚"}
	a[00812]={"𩰝"}
	a[00822]={"茓","蓯"}
	a[00830]={"篵"}
	a[00832]={"㧒","摐"}
	a[00833]={"葖"}
	a[00834]={"𡫜"}
	a[00840]={"䧑"}
	a[00841]={"𥯝"}
	a[00842]={"蓰"}
	a[00843]={"揬","𢰃","𢲘"}
	a[00850]={"簁"}
	a[00852]={"掟","摈"}
	a[00853]={"擌"}
	a[00856]={"荴"}
	a[00860]={"𥲗"}
	a[00862]={"𦻀"}
	a[00863]={"寞"}
	a[00864]={"蔩"}
	a[00865]={"𦺕"}
	a[00872]={"薲"}
	a[00873]={"𥱹"}
	a[00875]={"摸"}
	a[00882]={"擯"}
	a[00884]={"䔶"}
	a[00886]={"𧃕"}
	a[00889]={"蓵"}
	a[00892]={"𢷤","𢺅","𥳳"}
	a[00894]={"䦫","藬"}
	a[00896]={"攓"}
	a[00905]={"㩰","𧂈"}
	a[00913]={"攥"}
	a[00915]={"𢺇"}
	a[00930]={"徖"}
	a[00933]={"蒣","𦯕","𦴕"}
	a[00934]={"𢰀"}
	a[00940]={"𥭫"}
	a[00941]={"筞"}
	a[00942]={"萗","𢲺"}
	a[00943]={"㧲","蒢"}
	a[00945]={"搽","𦴇"}
	a[00951]={"篨"}
	a[00955]={"㨲"}
	a[00962]={"䕓"}
	a[00963]={"藔"}
	a[00964]={"㩍"}
	a[00965]={"𦺤"}
	a[00966]={"蔯"}
	a[00972]={"擦"}
	a[00973]={"𢸘"}
	a[00974]={"攃"}
	a[00977]={"㩟","𦾱"}
	a[00978]={"擛","𦽥"}
	a[00983]={"蘌"}
	a[00987]={"𦿕"}
	a[00991]={"籞"}
	a[01020]={"㝉","闩"}
	a[01040]={"𨛱"}
	a[01042]={"𦭭"}
	a[01043]={"䓉"}
	a[01050]={"筇"}
	a[01051]={"𥭕"}
	a[01053]={"捓"}
	a[01060]={"𨜱"}
	a[01061]={"𢔴"}
	a[01063]={"𦳃"}
	a[01064]={"挪"}
	a[01070]={"閂"}
	a[01071]={"𥯘"}
	a[01072]={"𡪅","𨝢"}
	a[01073]={"揶","𡩫","𢰗","𦷽"}
	a[01075]={"𦵼"}
	a[01100]={"𡪏","𥴐"}
	a[01101]={"𨴗"}
	a[01102]={"䨈","籊","薤","𩀈","𩰒"}
	a[01103]={"㩑","𡫿","𥲔","𥵏","𦼩"}
	a[01104]={"擢","薑","𥴑","𧂯"}
	a[01105]={"㩹","𢶣","𧂖"}
	a[01110]={"閸","𨶿"}
	a[01111]={"䉹","𡔂","𨷆"}
	a[01112]={"𡫼","𨶾"}
	a[01113]={"䖅","籗","蘁","闉","𡬀","𡬏","𢶍","𢺰"}
	a[01114]={"㩖","䕬","𢶫"}
	a[01115]={"攉","籱","藿","𧃗","𧅁"}
	a[01116]={"虇"}
	a[01117]={"𧆑"}
	a[01120]={"𢓁","𢓖"}
	a[01130]={"征","径","徑","𡧇","𢓞","𨸖","𨸹"}
	a[01131]={"彺","鿉","𢔉"}
	a[01132]={"苤","莁","𦫽","𦬀"}
	a[01140]={"㿾","竺","笁","筮","闫","阷","陉","陘","𡧡","𡧾","𨹢"}
	a[01141]={"宝","闰","陋","𡏇","𨻐"}
	a[01142]={"䒱","扛","抷","挜","茎","莖","𦭒"}
	a[01143]={"𦬬","𦭯","𦱬"}
	a[01150]={"䇥","䇰","𧯜","𨸧","𨸭","𨹜"}
	a[01151]={"室","𢔔","𨸅"}
	a[01152]={"拯","挳","荳","𢫮","𢭚","𦬚","𦰆"}
	a[01153]={"䓝","扭","抂","荎","𦭍","𦱃"}
	a[01160]={"䇘","䇺","宣","徰","隥","𡪺","𢕬"}
	a[01161]={"䇪","𨹸"}
	a[01162]={"䔲","䕄","荁","𡑫","𢪔","𢪕","𢭃","𢱉","𣦀","𧗆"}
	a[01163]={"䓧","塟","挃","掹","萾","陻","","𡨾","𢬟","𦮊","𦸧","𨬛","𨹡"}
	a[01164]={"𦍟"}
	a[01165]={"䓰"}
	a[01170]={"㝞","簦","𡨈","𡨰","𥵁","𥷟"}
	a[01171]={"𥯰"}
	a[01172]={"䔼","撜","𢬎","𦾞","𧯷"}
	a[01173]={"㨕","𥯑"}
	a[01174]={"𦱪"}
	a[01175]={"摊","蕥","𡩿","𦻍"}
	a[01176]={"菫","𥸀"}
	a[01180]={"𥮳","𨴇","𨴈"}
	a[01181]={"𨻋"}
	a[01182]={"掗","韮","𡫷","𢖈"}
	a[01183]={"𦹠","𧁅"}
	a[01184]={"𢮢","𢲔"}
	a[01186]={"𦸨"}
	a[01190]={"閆","𡩦"}
	a[01191]={"閏","閠","𨳞","𨻼"}
	a[01192]={"𥲓"}
	a[01193]={"𢲖"}
	a[01194]={"䕢","藋"}
	a[01195]={"𢴬"}
	a[01199]={"𩀵"}
	a[01200]={"𨶪"}
	a[01202]={"䰘"}
	a[01210]={"𨵈"}
	a[01212]={"𩰖","𩰚"}
	a[01222]={"节","𦫺"}
	a[01230]={"𡧒","𥬂"}
	a[01232]={"𤼱"}
	a[01240]={"𥫶"}
	a[01242]={"䒡"}
	a[01250]={"䇙","寥","笻"}
	a[01252]={"蓼","𢪉","𦳵"}
	a[01260]={"徘","𥯩"}
	a[01261]={"𥰚"}
	a[01262]={"摎","𦯄"}
	a[01272]={"菲","𦯆"}
	a[01273]={"𦺹"}
	a[01280]={"𡫱","𨳡"}
	a[01281]={"𥲊"}
	a[01282]={"排","𨴸"}
	a[01284]={"䔷"}
	a[01293]={"𦻅"}
	a[01300]={"𢤑","𥲅"}
	a[01301]={"𢥜"}
	a[01303]={"蕓"}
	a[01304]={"摾"}
	a[01306]={"蘸"}
	a[01308]={"𧔩"}
	a[01310]={"𢓻","𩟸"}
	a[01311]={"䉙","𢥛"}
	a[01314]={"𢺭"}
	a[01316]={"𥸢"}
	a[01318]={"䖆"}
	a[01320]={"家"}
	a[01322]={"芐","𦮡","𦱷"}
	a[01330]={"𡩵","𢓎","𥫫"}
	a[01332]={"荵","𢩹","𢭝","𦱻","𦶣"}
	a[01333]={"㧻","菾","𢫺","𢮞"}
	a[01340]={"惩","𨸞"}
	a[01342]={"芸","蒸","𢲀","𦬜","𦰸"}
	a[01343]={"掭","菰","𢔳","𦴉"}
	a[01349]={"𡩚"}
	a[01350]={"宖","篜","𡪹","𥬀","𥮰"}
	a[01351]={"箛","𧙶"}
	a[01352]={"抎","苰","𦮼","𦯡"}
	a[01353]={"𧀙"}
	a[01354]={"蕤","𦷢"}
	a[01355]={"𧊬"}
	a[01360]={"𥭜"}
	a[01362]={"𢭄","𦶐","𨽁"}
	a[01363]={"𢫻","𥰱"}
	a[01364]={"藂","𢳰","𦼈","𧍟"}
	a[01365]={"掻","搔","蔒","𦲶"}
	a[01370]={"閇","𥯱","𨴯","𨼆"}
	a[01371]={"䉁","䦠"}
	a[01372]={"薞","𢱽","𦱁","𦱚"}
	a[01373]={"𢵆","𢸍","𥱄"}
	a[01374]={"䕯","𢳱"}
	a[01375]={"𢮋","𧒚"}
	a[01380]={"𥴳"}
	a[01382]={"蕜","𢮂","𥷌","𦸾","𦺫","𦼇"}
	a[01383]={"蕶"}
	a[01384]={"𢶘","𧏤"}
	a[01390]={"𨵰"}
	a[01392]={"𢳫","𢴾","𢵣","𥳎"}
	a[01393]={"㩕"}
	a[01394]={"蔃"}
	a[01396]={"𧓿"}
	a[01397]={"𢸪"}
	a[01400]={"𨼉","𨼘"}
	a[01402]={"𩘒"}
	a[01405]={"薽","蘵"}
	a[01410]={"䚔","𢒼","𧡢"}
	a[01412]={"籭","𧢖","𩴱"}
	a[01413]={"籈","蘎","𢶉"}
	a[01414]={"䕻","攦"}
	a[01416]={"𧃝","𧅳"}
	a[01422]={"𦫴"}
	a[01430]={"阢","𡧉","𢓆"}
	a[01431]={"阠"}
	a[01432]={"艺","𦬂"}
	a[01433]={"䒖"}
	a[01434]={"𦴧"}
	a[01440]={"完","阮"}
	a[01442]={"扤","芑","芫","苝","𡧿","𢩵","𢫁","𢰫","𦮃"}
	a[01443]={"扟","芜","芤","𦯿"}
	a[01450]={"笎","𡧗","𥫟"}
	a[01451]={"陚","𡨓","𡨥","𥬗","𥰑"}
	a[01452]={"宼","抏","茿","莻","𡩍","𢪁","𢪞","𦭈"}
	a[01453]={"抚","𢕖","𢪑","𢪬","𥱗"}
	a[01456]={"𢮴","𦺐"}
	a[01460]={"筑","𥬑"}
	a[01461]={"寇"}
	a[01462]={"㧚"}
	a[01463]={"𦯍","𦾳"}
	a[01464]={"䉔","戭"}
	a[01470]={"㝟","𥒳"}
	a[01471]={"𥬶","𥭙"}
	a[01472]={"蔬","𥮸"}
	a[01473]={"𢬴","𥱺"}
	a[01474]={"蓜","𦯋","𦸘"}
	a[01475]={"𢳍","𦸊"}
	a[01480]={"𥲁"}
	a[01485]={"㲨","𦶇"}
	a[01490]={"䦎"}
	a[01492]={"𣰨","𦶁"}
	a[01495]={"𡪫"}
	a[01501]={"聞","𥷣"}
	a[01502]={"閮","𨵑"}
	a[01503]={"蘷","𥷱"}
	a[01504]={"䦤","闄","𢷛","𥲝"}
	a[01510]={"𩏧"}
	a[01511]={"𨶜","𨶞"}
	a[01512]={"䦯","闞","𡫳"}
	a[01513]={"𢹎","𢺕","𥷨","𨽦"}
	a[01514]={"鬫"}
	a[01515]={"攝"}
	a[01517]={"㩣","𨵭"}
	a[01518]={"𧅞"}
	a[01521]={"㝊","彶"}
	a[01522]={"𢓄"}
	a[01523]={"芆","𦫿"}
	a[01531]={"闬","𥫢","𨸗","𨸚"}
	a[01532]={"𡧕","𨸦"}
	a[01533]={"䒥","扠","芉","芨","苹","𢼘","𦯘","𦲯"}
	a[01534]={"茾"}
	a[01541]={"竿","笈"}
	a[01542]={"笄"}
	a[01543]={"䓮","扞","扱","抨","𢩲","𢪩","𦭱"}
	a[01544]={"㧐","蕐","","𦯸"}
	a[01545]={"芛"}
	a[01546]={"𦮉"}
	a[01551]={"㝚","闻","𡩅","𢔀","𢕲","𢽉","𥱙"}
	a[01552]={"娿","第","𥰰"}
	a[01553]={"䕜","笋","茸","莚","𦳠"}
	a[01554]={"莛","葬","蒆","𡨤","𢬌","𦮘","𨺝"}
	a[01555]={"择","𢬏","𦺒"}
	a[01556]={"莄","葽"}
	a[01557]={"華"}
	a[01561]={"䇯","䈣","筵","𡨞","𡨦","𢖉","𨺜"}
	a[01562]={"㝡","筓","筳","陬","𢕭","𨺘"}
	a[01563]={"㪦","挕","挻","筭","菷","𢯸","𦯈","𦰨","𨺿"}
	a[01564]={"挺","筻","菆","𢯬","𦮆","𦳙","𦷠"}
	a[01565]={"䔊","拝","挵","𢰰"}
	a[01566]={"挭","掇","𡪚","𢰳","𢱼","𦽬"}
	a[01571]={"箒","𢕶","𢖒","𢾒"}
	a[01572]={"箃","阚","𡩠","𡪯","𡫙","𥯹"}
	a[01573]={"掃","𡫊","𢕯","𢬶","𦷜","𦻋"}
	a[01574]={"㨖","掫"}
	a[01575]={"𢶛"}
	a[01577]={"徤"}
	a[01578]={"𦵲"}
	a[01581]={"閈","閛","𨳛","𨴉"}
	a[01582]={"開","𥴊"}
	a[01583]={"葞","蕟","𦻔","𧀥"}
	a[01584]={"撖","𢱥","𢿩"}
	a[01585]={"摄","蕈","𦹽","𦾹"}
	a[01587]={"𡩌","𨺩"}
	a[01591]={"𣀖","𥰺","𥳊"}
	a[01592]={"𡫉","𥵳","𥷂","𨴂"}
	a[01593]={"撥","擾","簟"}
	a[01595]={"撢","𢶁","𧄏"}
	a[01597]={"𥯦"}
	a[01599]={"揵"}
	a[01600]={"𨵝"}
	a[01602]={"藞","𦥉"}
	a[01603]={"㩅"}
	a[01604]={"蕾"}
	a[01605]={"𧃭"}
	a[01611]={"䦜","𨵩","𨷰"}
	a[01612]={"㩡","簪","𥸐","𨷏"}
	a[01613]={"蘦","𢸲","𢹝"}
	a[01614]={"撍","擂","虂","𢸰"}
	a[01640]={"䧂","宕"}
	a[01642]={"䓏","徆","苕","𡧳"}
	a[01643]={"𦭮"}
	a[01650]={"笤","陌","𡧱"}
	a[01651]={"䇧","𢓲","𢕠","𨹙"}
	a[01652]={"㧵","䇴","䓠","拓","招","𦷦"}
	a[01654]={"茜"}
	a[01660]={"䈋","簭"}
	a[01661]={"𡨂"}
	a[01662]={"㧺","𢫦","𦮑","𦵻","𦸚"}
	a[01663]={"㧷","䓊","䓿","宭"}
	a[01664]={"拪","莤"}
	a[01665]={"莙"}
	a[01670]={"𥰸","𥵼"}
	a[01671]={"富","𥭠","𨸆","𨺤"}
	a[01672]={"搢","𡪄","𥭛","𥵉"}
	a[01673]={"䇹","捂","葍"}
	a[01674]={"藸","𠼆","𢭡","𦴖"}
	a[01675]={"捃"}
	a[01680]={"𨻸"}
	a[01681]={"䈏","𢔲"}
	a[01683]={"揊"}
	a[01690]={"䦒","𥱵"}
	a[01692]={"摺","閪","𢲚","𥴉"}
	a[01694]={"𦸭"}
	a[01695]={"䔯"}
	a[01700]={"㔐","䎙","篛","翧","𪃜"}
	a[01701]={"𥳍","𥷢"}
	a[01702]={"搦","𦺚","𨴭","𩤡"}
	a[01703]={"撏","擩"}
	a[01707]={"鷨"}
	a[01710]={"㣔","䳦","𨶟","𪇕"}
	a[01711]={"闘","𡬂","𨷘","𪆠"}
	a[01712]={"䴐","虉","𢶈","𨽨"}
	a[01713]={"摴","鬪","𨶵"}
	a[01714]={"𧃨"}
	a[01718]={"𢺞"}
	a[01720]={"㝋","䦺","宁","行","𡧘","𨸓"}
	a[01722]={"㣜","艼","芀","𦫼","𦬄"}
	a[01730]={"䦽","陑","𡦺","𡧂","𡧃","𡧊","𡧤","𢔈","𥫙","𧗡","𨸐","𨸑"}
	a[01731]={"䦻","字","宇","宻","陃","𡧝","𨸀"}
	a[01732]={"㧅","䒒","䒓","打","扨","艿","芧","茅","茢","荋","𡧴"}
	a[01733]={"䓣","芋","芓","芽","苪","𢩴","𦬋","𦲸"}
	a[01734]={"荆","荊","","𦬤"}
	a[01735]={"隬"}
	a[01737]={"薾"}
	a[01740]={"宆","崈","闯","阿","𡧁","𡧍","𡧎","𡨴","𥬭","𥬵"}
	a[01741]={"䇤","竽","笌","衎","𡧈","𡨬","𥫞","𥮩"}
	a[01742]={"㧫","扔","扬","抒","挒","挧","芌","芎","苛","茘","菡","𢓶","𢩨","𢩯","𦬛","𦭃","𦭎","𦭢","𦳲","𧗦"}
	a[01743]={"㧎","䒭","扜","抦","掚","𢮳"}
	a[01744]={"苐","𢫊"}
	a[01745]={"籋"}
	a[01747]={"擟"}
	a[01750]={"䈄","寕","笃","笴","衏","鸻","𢔚","𢔸","𥫡","𥬣","𧗪","𨼏"}
	a[01751]={"𧗨","𨸳"}
	a[01752]={"㧈","扝","扫","抲","𢪪","𦭡","𦭳"}
	a[01753]={"荨","菿","葝","𥬁","𦹡"}
	a[01754]={"蓩","𢰱","𦰡"}
	a[01756]={"𠟝"}
	a[01760]={"笥","隔","𠝳","𥬤","𥮺","𨻳"}
	a[01761]={"箌","𠟅","𡪉","𥯙","𧗭"}
	a[01762]={"筩","蒚","蔫","𦯢","𦱘","𦺖","𧗴"}
	a[01763]={"挦","捯","𢕁","𦯗"}
	a[01764]={"捅","𠠕","𦾑"}
	a[01765]={"𧀾"}
	a[01767]={"䕳","𦲅"}
	a[01770]={"䈝","䈪","寡","篶","閅","鴴"}
	a[01771]={"衙","𡪬"}
	a[01772]={"䔅","寚","揟","搹","𡩧","𢭈","𢮔","𢳃","𢷚","𦭲"}
	a[01773]={"𢳬","𦴛","𦸕"}
	a[01774]={"𢰙","𢶏"}
	a[01775]={"䉲","𢰭"}
	a[01777]={"𢴃"}
	a[01780]={"𥰯","𨴎"}
	a[01781]={"閕","𥵇","𨳕","𨳵","𪄋"}
	a[01782]={"揹","篫","薚","鶜","𢬞","𢲿"}
	a[01783]={"㨽","𢖎","𢰕"}
	a[01784]={"𥮢"}
	a[01785]={"䦵","𢷋","𦇂"}
	a[01786]={"𢐯","𥯿"}
	a[01787]={"䔜","𦶈","𩰞"}
	a[01790]={"閜","鵍","𡫰","𢤉","𪅢"}
	a[01791]={"隭","𨼔"}
	a[01792]={"蒻","","𦿆","𧀫","𨳤"}
	a[01793]={"蕁","薷","𡫕","𧄙","𪆴"}
	a[01801]={"𡫟","𪏥"}
	a[01802]={"䕱"}
	a[01805]={"𧃟"}
	a[01810]={"顮","𧹆","𨵪","𨷩","𩕽"}
	a[01811]={"𡫩"}
	a[01812]={"寶","𢸸","𩰗"}
	a[01820]={"𡧆"}
	a[01821]={"𢓍"}
	a[01830]={"定","𡧐","𡧢","𢓙","𨻢"}
	a[01833]={"荬","𦬞"}
	a[01840]={"𡩂","𥱇"}
	a[01841]={"阕","陾"}
	a[01842]={"𢪵"}
	a[01843]={"䓴","葵","𢭅","𦮖","𦷡","𦼓"}
	a[01844]={"𤟓"}
	a[01850]={""}
	a[01851]={"㝙","𡨮","𥯫","𥯬"}
	a[01852]={"寅","蓣","𡨒"}
	a[01853]={"㨎","揆","𢲕","𦵏","𦵸"}
	a[01854]={"颟","𢱾","𦴊"}
	a[01860]={"賓","𡫮","𧵒"}
	a[01862]={"𡪪","𥮅"}
	a[01863]={"摂","𤎟","𥲦"}
	a[01865]={"𦴐"}
	a[01870]={"賨","𡩟","𤍘","𩔧"}
	a[01872]={"䔈","𥵫"}
	a[01874]={"𡫈","𢷗"}
	a[01880]={"篢","顁","𡪛","𡫅","𧶉","𧶎","𨷹"}
	a[01881]={"𥳧","𥴋"}
	a[01882]={"摃","蕷","𦳪","𦺣","𩰜","𩰟"}
	a[01884]={"𢵑","𦸆"}
	a[01891]={"寳","闋"}
	a[01892]={"𢰅","𢴦"}
	a[01895]={"𧃞"}
	a[01896]={"𥵯"}
	a[01901]={"𨶉"}
	a[01903]={"𡫻"}
	a[01906]={"𧅟"}
	a[01907]={"𢸩"}
	a[01920]={"㲾","阫"}
	a[01922]={"芣","𦬭"}
	a[01930]={"宗","际","𥫸"}
	a[01931]={"𡧖","𢔟","𨹃"}
	a[01932]={"䒬","抔","𦭕"}
	a[01933]={"荪","𦬽"}
	a[01942]={"𢫒","𦱨"}
	a[01943]={"葇","𢲇","𦰧"}
	a[01951]={"𥬸"}
	a[01952]={"徱","菉","蒜","𢲉","𦰴"}
	a[01953]={"挅","揉","蓀","𦴃"}
	a[01954]={"𨻗"}
	a[01955]={"䔁"}
	a[01960]={"箓","𥭼","𥮜"}
	a[01961]={"𥱖"}
	a[01962]={"䧣","揼","𢮑"}
	a[01963]={"搎","篥","𦵶"}
	a[01964]={"䔫","蔈","𡩪","𢳗"}
	a[01965]={"搮","𡪧"}
	a[01966]={"搡"}
	a[01970]={"閖","𥯐"}
	a[01971]={"築"}
	a[01972]={"篻"}
	a[01973]={"𢵍"}
	a[01974]={"摽"}
	a[01975]={"𦺵"}
	a[01981]={"𡫗"}
	a[01983]={"䕁","𡫚"}
	a[01988]={"𣟦"}
	a[01990]={"𨶋","𨶺"}
	a[01993]={"𥲒"}
	a[01994]={"𢸹"}
	a[01996]={"𢶳"}
	a[02010]={"䦳"}
	a[02012]={"𦫳","𨟭"}
	a[02032]={"茒"}
	a[02044]={"𦰥"}
	a[02052]={"𨟗"}
	a[02060]={"閁"}
	a[02063]={"𦿇","𨟂"}
	a[02067]={"𦸙"}
	a[02082]={"薌"}
	a[02101]={"𨴘"}
	a[02103]={"摣","𢶐"}
	a[02104]={"蘆","𧄗","𧅽","𧆗"}
	a[02105]={"𧅈"}
	a[02110]={"𨶚"}
	a[02112]={"籚","𢷖"}
	a[02113]={"𢸉","𧂊"}
	a[02114]={"攎","𢹬","𩼻"}
	a[02115]={"𨵮"}
	a[02116]={"寷"}
	a[02118]={"蘴"}
	a[02120]={"𢓊"}
	a[02122]={"𦬆"}
	a[02130]={"宐","阯","𡧧"}
	a[02131]={"𢓩","𢔗","𨺄","𨼦"}
	a[02132]={"䒙","徃","芷","𦮨"}
	a[02133]={"𦬰"}
	a[02140]={"䇛","𡨆","𥬛","𨺾"}
	a[02141]={"𥮍","𥴓"}
	a[02142]={"扯","蓝","𢭊","𦭩"}
	a[02143]={"陞","𢴹","𦱐","𦹨"}
	a[02144]={"苼"}
	a[02145]={"𢔝"}
	a[02150]={"篮"}
	a[02151]={"𥯂","𨺛"}
	a[02152]={"㨫","笙","葒","𡍵","𢷼","𥯁","𦵵"}
	a[02153]={"莊","𢭌","𥂃","𦷺"}
	a[02155]={"陲"}
	a[02157]={"菙"}
	a[02160]={"𡪀","𥭣","𨹶"}
	a[02161]={"墬","陛","𨹿","𨼋"}
	a[02162]={"荭","𢳷","𦯭","𦽁","𨺼"}
	a[02163]={"蒩","隆","𢬆","𢳸","𦱩","𦶆"}
	a[02165]={"㣫","䕌","箠","薶","𦽂"}
	a[02166]={"𦱦"}
	a[02167]={"捶"}
	a[02170]={"𥭱"}
	a[02171]={"𥲤"}
	a[02172]={"蕋","蘊","𥮞"}
	a[02173]={"𢴮","𥂿","𥴢","𥵷"}
	a[02174]={"䔨","𡪂","𦻓"}
	a[02175]={"隀","𤯲","𨼇"}
	a[02177]={"董"}
	a[02180]={"𧯳"}
	a[02181]={"𥲜","𨳝"}
	a[02182]={"藴","𥵻"}
	a[02183]={"𧀽"}
	a[02185]={"箽","𧄰"}
	a[02187]={"揰"}
	a[02192]={"蕴"}
	a[02193]={"蔖","𢳛"}
	a[02194]={"𩁞"}
	a[02203]={"𧅸"}
	a[02204]={"𢺬"}
	a[02210]={"籪","關","𢒾"}
	a[02211]={"𢔜","𥸖"}
	a[02220]={"徏","𥫨"}
	a[02222]={"芕","𦫶"}
	a[02223]={"荞","𦹮"}
	a[02230]={"㝖","陊","陟","","𢕕","𨷿"}
	a[02231]={"𥭇"}
	a[02232]={"㧃","䔋","拶","芗","茤","荹"}
	a[02233]={"挢","𦰎"}
	a[02240]={"𥭋"}
	a[02241]={"𥮾"}
	a[02242]={"扸","拸","捗","蔘","𢪫"}
	a[02243]={"䔟","掺"}
	a[02250]={"篸","𢕱","𨽑"}
	a[02251]={"簃","簖"}
	a[02252]={"摻"}
	a[02253]={"𧂅"}
	a[02262]={"𦱸"}
	a[02280]={"𨳹","𨴢"}
	a[02282]={"㝱"}
	a[02300]={"闗"}
	a[02301]={"𨶢"}
	a[02302]={"𥶌"}
	a[02304]={"攄"}
	a[02306]={"𧅮","𧔂"}
	a[02310]={"𢘯"}
	a[02311]={"㣠","𠗆","𢓘"}
	a[02312]={"𦮤"}
	a[02314]={"𢺳","𨷔"}
	a[02316]={"攭","𢺂"}
	a[02317]={"𧅼"}
	a[02320]={"","𥫪"}
	a[02321]={"㣰","𢓿"}
	a[02322]={"䒦","扑"}
	a[02323]={"苳","𦰍"}
	a[02324]={"𦭊"}
	a[02330]={"𥫛"}
	a[02331]={"笗","𨸻"}
	a[02332]={"䓤","払","抸","𢕆","𢩻","𢫑","𦭌","𦯌"}
	a[02333]={"䔳","𦮺","𦸝"}
	a[02334]={"葱"}
	a[02340]={"䧘","𡩀"}
	a[02341]={"𥳚"}
	a[02342]={"㧾","䈡","拤","蒃","𢩼","𦸷","𦼒","𨹠"}
	a[02343]={"撚","蔠","𢶲","𦺨"}
	a[02344]={"揔","𢯁"}
	a[02350]={"惌","篆","隠","𢇌","𥬷","𥳋","𨼯"}
	a[02351]={"䈺","愙","𢕦","𩝶"}
	a[02352]={"挊","掾","撡","茲","葾","蕵","𢰷","𢰾","𥭥","𦳤","𦾜"}
	a[02353]={"䔡","𡩓","𢖛","𦸈"}
	a[02355]={"𧊮"}
	a[02360]={"䈚","隐","𥵮","𨳖"}
	a[02361]={"𨼫"}
	a[02362]={"𢛑","𢰽","𢴴","𦳌"}
	a[02363]={"憼","搀","𢳶","𦼫","𧄉","𨻦"}
	a[02364]={"蘓","𦺠"}
	a[02365]={"䕴"}
	a[02366]={"薰","𢣋"}
	a[02370]={"隱","𨳿","𨴖"}
	a[02371]={"𥴧"}
	a[02372]={"䉉","䗕","𢷻","𦾻","𧀛"}
	a[02373]={"摅","據","𢶞"}
	a[02375]={"𢡹","𧂩"}
	a[02376]={"𢷠"}
	a[02377]={"薫"}
	a[02381]={"𩸪"}
	a[02382]={"䵫","𢷍"}
	a[02383]={"𥷿"}
	a[02384]={"𧑝"}
	a[02385]={"蟼"}
	a[02386]={"蘕"}
	a[02394]={"藘"}
	a[02400]={"𨴓"}
	a[02401]={"𢖞","𨵃","𨵞"}
	a[02402]={"覾"}
	a[02403]={"隵","𡬃"}
	a[02406]={"𡪣"}
	a[02410]={"","𢒽","𨶙"}
	a[02411]={"䧯","𨵘"}
	a[02413]={"攙","𨷺"}
	a[02415]={"䦰","䰗","𢹍"}
	a[02416]={"蘒","𥳈"}
	a[02417]={"𩰘"}
	a[02418]={"撬"}
	a[02420]={"它","𡦾"}
	a[02421]={"𡧬"}
	a[02422]={"𢪢"}
	a[02430]={"阭","𡧏","𢓗"}
	a[02431]={"宅","𢓠","𥫥"}
	a[02432]={"扎","𦫷","𦬈"}
	a[02433]={"𦬃","𧀔"}
	a[02435]={"萟"}
	a[02436]={"莪"}
	a[02440]={"宛","阰","𨹀"}
	a[02441]={"䉭","宪","𡨷","𡨻"}
	a[02442]={"宒","抁","芘","苑","茈","𡨘","𢕺","𥮿","𨸃"}
	a[02443]={"托","𦭶","𦳽"}
	a[02444]={"芼"}
	a[02446]={"㧴"}
	a[02450]={"笓","陒","𡧭","𥬳","𨹔"}
	a[02451]={"寃","筅","𡨚"}
	a[02452]={"㧗","批","揽","笔","苞","藐","𡩽","𢫎","𢬘","𢮤","𧀨"}
	a[02453]={"㧥","䓙","莬","菟","𢬳","𢮿","𢯀","𢯂","𦯠"}
	a[02454]={"㧌","薉","𢰛","𢳴"}
	a[02455]={"𦳁"}
	a[02460]={"㣧","笣"}
	a[02461]={"𥶢"}
	a[02462]={"㧪","抱","阄","𡩄","𢳢","𢷕","𦸡"}
	a[02463]={"挽","擸","薍"}
	a[02464]={"葂","蒓","𢨝","𢱍","𢴫","𦷘"}
	a[02465]={"𦺬"}
	a[02466]={"𦿐"}
	a[02470]={"㼠","𡩇","𨼎"}
	a[02471]={"䖎","𡪳"}
	a[02472]={"蕝"}
	a[02473]={"萀","𥳏"}
	a[02474]={"莼","𦺷"}
	a[02475]={"𢴰","𦺩"}
	a[02480]={"䙾","𡫁","𥰘","𥳵"}
	a[02481]={"箎"}
	a[02482]={"㨢","撧","𥳱"}
	a[02483]={"𢮎"}
	a[02484]={"藏","𧄕"}
	a[02485]={"㩬"}
	a[02487]={"蘶"}
	a[02490]={"𥷳"}
	a[02491]={"𨴐"}
	a[02492]={"閐","𤮀","𨽊"}
	a[02493]={"𧂫"}
	a[02494]={"𢸗"}
	a[02503]={"䕫"}
	a[02504]={"𧄦"}
	a[02512]={"𢓰","𨵿"}
	a[02513]={"㝲","𡬓","𢺥","𧃰"}
	a[02515]={"𢺲","𧅵"}
	a[02516]={"𪔳"}
	a[02521]={"阡","𢓭","𢔏","𨻾"}
	a[02522]={"㣭","䧌","阩","𢓐"}
	a[02523]={"㣦","䒘","芊","𦭼","𦱿"}
	a[02524]={"荽","𦬱","𦱭"}
	a[02531]={"後","阌","陖"}
	a[02532]={"㣪","牢","𨹓","𨺡"}
	a[02533]={"扦","荍","荾","𢓤","𢪟","𦬥","𦰹"}
	a[02534]={"䒜","䒪","抍","挼","萪","葼","𦭞"}
	a[02535]={"萎"}
	a[02541]={"寂","筛","𢼊","𥭟"}
	a[02542]={"䈖","䈦","笲","𡧷"}
	a[02543]={"捘","授","菽","薆","降","𡪃","𢪊","𦭚","𦯩","𦴅"}
	a[02544]={"㧞","㨑","䕑","拚","拨","荈","萲","𢓱","𢪧","𢱃","𦭷","𦮁"}
	a[02545]={"䔣","捼","𦭺","𦮔","𦮧","𦯨","𦱒","𦴏"}
	a[02551]={"𢔄","𥱦","𥴨"}
	a[02552]={"䈠","𥬫"}
	a[02553]={"䇨","拠","掓","敬","荜","葘","𡨣","𢱄","𦳡"}
	a[02554]={"援","蕣","𡨛","𢬓","𢳻","𦰙"}
	a[02555]={"蕛","薐","𢭎","𢳽","𦳋","𦺙"}
	a[02556]={"莑"}
	a[02561]={"筚","𢕛"}
	a[02562]={"𢾏"}
	a[02563]={"䈛","䓬","𢯳","𢲩","𥲖","𦴁","𧃸","𨺮"}
	a[02564]={"藧","𥭗","𦼼"}
	a[02565]={"㢣","蔛","𦴂","𦼡"}
	a[02566]={"挿","捀","薭"}
	a[02571]={"䈇","𡫠"}
	a[02572]={"𥶍"}
	a[02573]={"䈸","掉","𥶝"}
	a[02574]={"㨜","𢖆","𢯯","𦸟"}
	a[02575]={"㩂"}
	a[02577]={"𦳞"}
	a[02581]={"寢","閿","𨳟"}
	a[02582]={"閞","𥳼","𨳯"}
	a[02583]={"簰","藑","𡫺","𧃍","𨵋"}
	a[02584]={"𡫽","𥶈","𨼬"}
	a[02585]={"蘚","𥯟"}
	a[02586]={"薢"}
	a[02588]={"𢵜"}
	a[02591]={"𥵤"}
	a[02592]={"𡫒","𥱿","𥷦","𨴍"}
	a[02593]={"䉳","蘰","𢴼","𧁰","𧃜"}
	a[02594]={"㨿","䉏"}
	a[02595]={"藓","𢸌","𢹛"}
	a[02596]={"䉊","𢶷"}
	a[02598]={"撪","𧃒"}
	a[02601]={"䦭","𨴬"}
	a[02603]={"撸"}
	a[02610]={"䦲","𡫧","𧮐"}
	a[02611]={"𡫔","𡬋","𨷀"}
	a[02612]={"𡬌","𧆏"}
	a[02613]={"𡬑","𡬚"}
	a[02630]={"𢓕"}
	a[02631]={"𢓜"}
	a[02640]={"阽","𨺻"}
	a[02641]={"䧄","客","阁","𡩨"}
	a[02642]={"苔","苫","茗"}
	a[02643]={"䒷","䓘","茖","菑","萂","蓾"}
	a[02644]={"𢭣"}
	a[02650]={"笘","笞","陥"}
	a[02651]={"笿","筈","𡨟","𥮑","𥱾"}
	a[02652]={"審","抬","拈","陹","𥷠","𦮂"}
	a[02653]={"括","挌","萫","𢲸","𦮽","𦷕","𦷙"}
	a[02654]={"蕃"}
	a[02660]={"𡪁","𢔡"}
	a[02661]={"筶"}
	a[02662]={"䉒","指","𢵾","𥮂","𦹄"}
	a[02663]={"捁","揝","𦸖"}
	a[02664]={"播"}
	a[02670]={"階","𡩩","𡪗","𢕻","𨼧"}
	a[02672]={"蒈","𡩒","𡪞"}
	a[02673]={"𢲏","𦺢"}
	a[02674]={"㨧","𢳏"}
	a[02675]={"𦿀"}
	a[02680]={"寣","𨼮"}
	a[02681]={"寤","𥰷"}
	a[02682]={"㨱","揩","薝","𡫥"}
	a[02683]={"𤲸","𧀦"}
	a[02684]={"𦿁","𦿊","𧀈","𧁃"}
	a[02690]={"䦓","簷","𥰀","𨵻","𩈱"}
	a[02691]={"䦚","閣","𥶇"}
	a[02692]={"擔"}
	a[02693]={"䃧","擼","蘠","𦽌"}
	a[02700]={"𨴌","𨶒"}
	a[02702]={"𪇭"}
	a[02703]={"䦛","","𪆆"}
	a[02705]={"擄"}
	a[02710]={"彴","閻"}
	a[02711]={"𪈣"}
	a[02712]={"𡬙","𢹴","𢺯","𪇔","𪈅"}
	a[02714]={"䖂","𧀴"}
	a[02716]={"𪈧"}
	a[02720]={"𢓈","𥫘"}
	a[02721]={"𡨖"}
	a[02722]={"芍","芴","𠚶","𠞝","𦱝"}
	a[02723]={"苸","莉"}
	a[02724]={"茐"}
	a[02730]={"㣘","䇖","笏","𢕷","𥫩","𥬼"}
	a[02731]={"徭","筣","陱","𡥜","𡧸","𢓵","𥬏","𥭐","𧗤","𨹴","𨺭"}
	a[02732]={"㧄","扚","抣","芶","𢩶","𦭘","𦰵","𦷝"}
	a[02733]={"捋","莩","菊","菞","𢪣","𢱹","𦱑","𦱜","𦴙"}
	a[02734]={"𢪤"}
	a[02735]={"𢫍"}
	a[02740]={"㝍","䧁","䧦","剜","寪","徇","笉","𥬉"}
	a[02741]={"䇟","筟","𡩴","𢔇","𥮗","𨻅"}
	a[02742]={"䒛","抅","苟","葯","蒶","蔿","𢔖","𥬄","𦬿","𦭙","𦾓"}
	a[02743]={"䔄","捊","掬","苭","莠","葤","蒳","𢫤","𢰔","𦮍"}
	a[02744]={"抙"}
	a[02745]={"𦱊"}
	a[02746]={"𦻎"}
	a[02750]={"䈧","䧟","笱","箹","𡩹","𥬜","𥬿","𥭔","𨹆"}
	a[02751]={"䈙","䈫","寎","陶","𡩭","𢔣","𢔬","𥫷","𥬓","𥲛","𧗽","𨹋"}
	a[02752]={"抝","拘","撝","荀","药","蓞","𢭓","𢰹","𦮌","𦺃","𧀤","𨺚"}
	a[02753]={"㝢","㨥","㩊","䓒","䦶","拗","揺","摇","箏","荮","萄","蔣","蕱","薊","","𢭆","𢰏","𦮒","𦮿"}
	a[02754]={"葪","蒭","𢱳","𦷱","𦽧"}
	a[02755]={"掙","萭","𢮓","𨺪"}
	a[02757]={"䕝"}
	a[02760]={"䈱","筍","阎","陷","骘","𢔮","𥬠","𥭩"}
	a[02761]={"䉃","𠢙","𡩸","𢕪","𢖍","𥮽","𥳓","𨺃"}
	a[02762]={"㧦","䇶","䚘","搯","篘","萏","","𢮘","𦱫","𦱳","𨻲"}
	a[02763]={"㔤","掏","搖","摪","筝","蓟","𡫘","𢯃","𢵏","𥯔","𧘀"}
	a[02764]={"捔","搊","𦵳"}
	a[02765]={"挣","藊","𢯺","𦹣","𩣻"}
	a[02766]={"㩀","葡","𦸵"}
	a[02770]={"衟","鹓","𡪝","𥮛"}
	a[02771]={"㝯","𡪷","𥯥","𥳭"}
	a[02772]={"掐","掯","衡","𢰠","𢲍","𥰬","𥲉","𦲭","𦻖","𦽭","𦾭","𧗻","𨽥"}
	a[02773]={"䈥","孶","插","蕎","藒","𦿟","𧗾","𪁾"}
	a[02774]={"掳","揷","摢","𢰵","𦽃","𦽑"}
	a[02775]={"擎"}
	a[02777]={"蘍"}
	a[02780]={"𡫂","𥮪","𥰴"}
	a[02781]={"箰","簥","𡭑","𧘄","𨴫","𪀥"}
	a[02782]={"䦐","揈","𢯇","𪁔"}
	a[02783]={"撟","蔔","𢐧","𩤩"}
	a[02784]={"蘅"}
	a[02785]={"衝"}
	a[02787]={"𢰄"}
	a[02790]={"䦱","鵷","𨷒","𪂦"}
	a[02791]={"𡫦","𥷮","𪃭","𪇢"}
	a[02793]={"㩱","𥲾","𧀷"}
	a[02795]={"驚"}
	a[02798]={"𢳾"}
	a[02802]={"𥸞"}
	a[02804]={"𧄑"}
	a[02806]={"𧃢"}
	a[02810]={"𢓑","𢔩","𨻌"}
	a[02812]={"籫"}
	a[02814]={"㩵","攢","𧄽"}
	a[02816]={"𨷥"}
	a[02820]={"㝌","𤇵","𨹾"}
	a[02821]={"宎","𡧠","𢓽","𨺹"}
	a[02822]={"芡","苡"}
	a[02823]={"芺","萩"}
	a[02830]={"䇜","徙","笖","𡪶","𢓺"}
	a[02831]={"徯","笑","篍","𢓪"}
	a[02832]={"扻","拟"}
	a[02833]={"扷","揪","𢪺","𦳫"}
	a[02834]={"苵"}
	a[02840]={"𨺗"}
	a[02841]={"寏","𡨡"}
	a[02842]={"𢖃","𥬘"}
	a[02843]={"蒵","蓗","𢭠","𢯉","𦮐","𦮸"}
	a[02844]={"抶"}
	a[02850]={"𢔤","𨻨"}
	a[02851]={"𣣟","𥰥"}
	a[02852]={"","𢳜"}
	a[02853]={"㨙","挨","换","換","𢲛"}
	a[02854]={"𢰼","𦼣"}
	a[02860]={"寊","𨺟"}
	a[02861]={"额"}
	a[02862]={"萯","蕦","𧂀","𨻘"}
	a[02863]={"𡙠","𢮸","𦳣","𧀚"}
	a[02870]={"𥯗","𥳗"}
	a[02871]={"寲","簴","籎","𡪓"}
	a[02872]={"揁","𡬖","𢰺","𦻁"}
	a[02873]={"㨗","捑","薿","蘔","𢳵","𧀖"}
	a[02876]={"𢹀"}
	a[02880]={"𨻺","𨽗","𩒂"}
	a[02882]={"䔛","蘋","𦺱","𦺲","𧀠","𨳺"}
	a[02883]={"擬","𡬊"}
	a[02884]={"𦿙"}
	a[02890]={"𥷎","𥸛","𥸟"}
	a[02891]={"額","𨴱"}
	a[02892]={"㩩","㩪","蘏","𢹟","𥵂"}
	a[02893]={"蘈","𢶦","𢹃","𥴶"}
	a[02894]={"攒","𦾚"}
	a[02895]={"𧂐"}
	a[02900]={"𨶫"}
	a[02902]={"𧄶"}
	a[02903]={"擽","𧅂"}
	a[02910]={"𨷴","𨷻"}
	a[02911]={"𨷱"}
	a[02912]={"𢺈"}
	a[02913]={"虊","𡬒"}
	a[02921]={"宷","寀"}
	a[02923]={"䒩","菜"}
	a[02930]={"𡧯","𥬞"}
	a[02932]={"㧠","䒺","茮","𢫢","𦯝","𦷲"}
	a[02933]={"採","𦰔"}
	a[02934]={"䔉","䔧","茱","𦰏","𦸸"}
	a[02940]={"𨻩"}
	a[02941]={"㝥","𡪘"}
	a[02942]={"䇬","筿","𢬡","𢭁","𥲧"}
	a[02943]={"藜","𢮥","𦶝","𧀊"}
	a[02944]={"㧣","蔾","𦺪"}
	a[02950]={"察","際"}
	a[02951]={"䉫","𢖟","𨹼"}
	a[02952]={"寐","紥","蔡","蕬"}
	a[02953]={"䓱","葈","隟","𡩣","𦶖"}
	a[02954]={"薒"}
	a[02955]={"𦵴","𦸛"}
	a[02957]={"𦱮"}
	a[02961]={"䈢"}
	a[02962]={"䔝","摖","𥴷","𥶗"}
	a[02963]={"䵈","蘨","𥲀"}
	a[02964]={"檠","蘇","𦸺","𦺯"}
	a[02965]={"搩","摷"}
	a[02967]={"㨀"}
	a[02970]={"𥲕","𥳮","𥵹","𨳴"}
	a[02971]={"䧰","檃","𥰿","𨽌"}
	a[02972]={"𢴱","𥷃","𦾯"}
	a[02974]={"𢸫"}
	a[02976]={"䕈","𣟶"}
	a[02980]={"𨵆"}
	a[02981]={"寱","櫽"}
	a[02982]={"𡬄","𡬇"}
	a[02983]={"蘃","𡬍","𣛳"}
	a[02992]={"𧄎"}
	a[02993]={"藥"}
	a[03062]={"蔀"}
	a[03070]={"篰"}
	a[03083]={"㨯"}
	a[03093]={"𢷢"}
	a[03101]={"䦞","𥴀"}
	a[03102]={"䕊"}
	a[03103]={"𥴁"}
	a[03104]={"籬","𧀣"}
	a[03106]={"攡"}
	a[03110]={"䉡","𨷇"}
	a[03111]={"𥷛"}
	a[03112]={"擅","虀"}
	a[03113]={"𨶻"}
	a[03114]={"𨷙"}
	a[03120]={"𢓔"}
	a[03130]={"𡦽","𢔆","𨸁"}
	a[03131]={"往"}
	a[03132]={"芒","苙","𦲷"}
	a[03133]={"荘"}
	a[03140]={"寍","笀","笠","𡩬","𥱒"}
	a[03141]={"䀄","宔","𡪖"}
	a[03142]={"拉","茫","茳","蒞","鿊",""}
	a[03150]={"𥬮"}
	a[03151]={"䇠","埅","𨹛"}
	a[03152]={"㧟","薀","𦱣","𦶜"}
	a[03153]={"拄","𢱮"}
	a[03160]={"𡩉"}
	a[03162]={"菃","菹","𥲱"}
	a[03163]={"𡎊","𦽘"}
	a[03164]={"𡒎","𦸰"}
	a[03170]={"䈌","𡪕","𥶎"}
	a[03171]={"𥱆","𥲠"}
	a[03172]={"簅","蕰","𥰁"}
	a[03173]={"徸","𦶄"}
	a[03174]={"摌","𧄻"}
	a[03175]={"䕹"}
	a[03180]={"閚","𨳑"}
	a[03181]={"篞"}
	a[03182]={"𦼬","𧗎","𩀩"}
	a[03183]={"𥷩"}
	a[03184]={"蕹"}
	a[03185]={"蕫","𢹼"}
	a[03190]={"㣶","𥶞","𨴤","𨵨"}
	a[03191]={"𨳳"}
	a[03192]={"蘫","蘯","𥵭","𩁔"}
	a[03193]={"𥳘"}
	a[03194]={"擁"}
	a[03195]={"撞"}
	a[03196]={"蘺"}
	a[03200]={"𢓟"}
	a[03212]={"𦭴","𦺅","𧅱","𧆌"}
	a[03221]={""}
	a[03222]={"莎","𢫧"}
	a[03223]={"荠"}
	a[03232]={"䓅","挱"}
	a[03233]={"挤"}
	a[03240]={"䇵"}
	a[03243]={"萕"}
	a[03253]={"㨈","薪"}
	a[03260]={"隮"}
	a[03262]={"薺","𦾷"}
	a[03270]={"閯"}
	a[03272]={"擠","𢹓"}
	a[03282]={"𦸪"}
	a[03287]={"𦾶"}
	a[03301]={"䦢"}
	a[03306]={"蘘"}
	a[03310]={"𨶗","𨶡"}
	a[03312]={"𦯹"}
	a[03314]={"䉴","𡬛"}
	a[03316]={"攘"}
	a[03320]={"闷"}
	a[03321]={"宓","𨸼"}
	a[03322]={"芯","苄","𡨜","𦮰"}
	a[03323]={"苾"}
	a[03324]={"𦯂"}
	a[03330]={"䧇","愆","笇","阏","𡫇"}
	a[03331]={"𢛬"}
	a[03332]={"䒾","抃","抋","莣","菸","蒎","𦮋","𦶧"}
	a[03333]={"㧙"}
	a[03340]={"箊","𥯠","𨸫"}
	a[03341]={"𤌊"}
	a[03342]={"挔","蓘","蕊","𢮁","𢮯","𢰜","𦬾","𦶍"}
	a[03343]={"𦿞"}
	a[03350]={"𥳝"}
	a[03352]={"㨰","蔉","𢫔","𦯫","𦹭"}
	a[03353]={"蜜"}
	a[03355]={"𦸞"}
	a[03360]={"䧫","𥰠"}
	a[03362]={"簔","蒗","𢴒","𦻂","𧍢"}
	a[03364]={"蓑","𦳶","𧀡"}
	a[03370]={"悶","籇","𥵆","𨳲","𩜾"}
	a[03371]={"閟","𢡥"}
	a[03372]={"㩝","簑","薏","𢸬","𦽤","𧃥","𨽖","𩰍"}
	a[03374]={"𧂋","𧍙"}
	a[03379]={"𢶧"}
	a[03380]={"閼"}
	a[03381]={"𢡻"}
	a[03382]={"𢶶"}
	a[03384]={"𢴶","𢸣","𧒧"}
	a[03385]={"𧓫"}
	a[03390]={"𨴋"}
	a[03394]={"忀","𧕝"}
	a[03401]={"𥷵"}
	a[03402]={"𧂎"}
	a[03404]={"虃"}
	a[03410]={"寵","徿","籠","籯","隴"}
	a[03411]={"𨶃"}
	a[03412]={"攏","籝","蘢","𢺆","𥷶","𥸏","𥸗","𧅋"}
	a[03413]={"𥷰","𨶝"}
	a[03414]={"䕦","攍","𢺑","𢺧","𧄹","𧄿"}
	a[03415]={"𥸔","𧆂"}
	a[03416]={"𡬕"}
	a[03417]={"𧆃"}
	a[03420]={"𢓝"}
	a[03430]={"宨"}
	a[03432]={"𦴢"}
	a[03440]={"筄","闶","阬","𡧽"}
	a[03442]={"挑","苀","范","茺","荒","萒","萢"}
	a[03443]={"䓋","䓜","莐"}
	a[03446]={"䔐"}
	a[03450]={"笐","笵","𥬱","𨺥"}
	a[03452]={"㧤","㧧","抗","筂","蓅","𦯇","𦰫","𦳆","𦴪","𦹲"}
	a[03460]={"𥰤"}
	a[03461]={"箲","𡪆"}
	a[03462]={"𢯻","𦶉"}
	a[03464]={"葹","𦸮","𦺘","𦺿"}
	a[03470]={"𡪥"}
	a[03471]={"𥲬","𥳛","𨼨"}
	a[03472]={"䔔","箷","𥳒","𩗧"}
	a[03473]={"㩆"}
	a[03474]={"揓","𡫹","𢴠"}
	a[03480]={"𨴡"}
	a[03482]={"㲰","㼹","摬","篭","薧","𣯱"}
	a[03484]={"藱","𦹾","𦺑","𦽡","𦿅"}
	a[03486]={"𢷉"}
	a[03490]={"閌"}
	a[03491]={"寴"}
	a[03492]={"䓽"}
	a[03493]={"藽"}
	a[03494]={"𢴅","𦿗","𧂕","𧂪"}
	a[03504]={"𢸻"}
	a[03505]={"𢹸"}
	a[03512]={"䉸"}
	a[03513]={"𥸘"}
	a[03515]={"䕶"}
	a[03517]={"𧅰"}
	a[03521]={"㝔","闵","阧","𢔙"}
	a[03523]={"芠","茭","𦯻"}
	a[03524]={"𦯽","𦷪"}
	a[03531]={"㝕","筊","闹","𡨧","𢓫","𥫾"}
	a[03533]={"抆","抖","挍","萃","𦺌"}
	a[03534]={"䓾","𢳼","𦭰","𦯺"}
	a[03535]={"𦯊"}
	a[03541]={"宰","箤","𡧵"}
	a[03543]={"捽","掖","莘","萍","蒂","𢬪"}
	a[03544]={"䓑","菠","菨","蓱","𢪴"}
	a[03551]={"𢕑","𥭴"}
	a[03552]={"䈉","箥","𥮓","𥰅","𨼻"}
	a[03553]={"揥","莈","蔋","𢕎"}
	a[03554]={"接","蓤","蔆","𢬵"}
	a[03556]={"蔢"}
	a[03561]={"徹","𢕒","𢕔"}
	a[03562]={"𢕹","𥲂","𨻕"}
	a[03563]={"䔞","藙"}
	a[03565]={"𦴝"}
	a[03571]={"䉨","寖","寝","閔","閗","障","𡩻","𥴃"}
	a[03572]={"𣪮","𨽘"}
	a[03573]={"摔","蓡","蔁","鬦","𥱼","𦼻"}
	a[03574]={"䔻","𧁱"}
	a[03577]={"𦻈"}
	a[03578]={"葏","𦻄"}
	a[03581]={"閙"}
	a[03582]={"𡫏","𥵪"}
	a[03583]={"䔓","䕕","撤","鬧"}
	a[03584]={"䕪","撴","薓","𢖜","𢸑","𧄘"}
	a[03585]={"撁"}
	a[03591]={"𨴲"}
	a[03593]={"蔎","𥷁"}
	a[03594]={"蘐"}
	a[03595]={"䕺","藫"}
	a[03600]={"䦣","𨵍"}
	a[03601]={"闊"}
	a[03610]={"誾","闇"}
	a[03611]={"𥶅","𨶖"}
	a[03612]={"𧅠"}
	a[03614]={"藷"}
	a[03642]={"𦰪","𦳸"}
	a[03650]={"陪"}
	a[03651]={"阔","𢕮"}
	a[03652]={"菩","菬","菭","萡","𦹃"}
	a[03653]={"落","萿"}
	a[03654]={"𦶡"}
	a[03660]={"㝘","䈃","箁","箈","箔","訚","隌","𡩘","𡫍","𥭚","𥮒","𨻓"}
	a[03661]={"䁇","𥯛","𥵄"}
	a[03662]={"䓂","掊","萻","𢫾","𢱆","𦯾"}
	a[03664]={"藩"}
	a[03670]={"䇾"}
	a[03672]={"揞","籓","𦱋","𦴒"}
	a[03673]={"蓄","𢴨"}
	a[03674]={"𦵩","𦺳"}
	a[03680]={"䈍","䈞"}
	a[03683]={"搐"}
	a[03691]={"𡫸"}
	a[03695]={"𧃫"}
	a[03700]={"鸋","𨵎"}
	a[03702]={"𢖊","𥴰","𧀎","𪆢"}
	a[03703]={"𧃈"}
	a[03704]={"𧅯"}
	a[03711]={"𥶏"}
	a[03712]={"藹"}
	a[03720]={"彷","𧗠"}
	a[03721]={"𡨑"}
	a[03722]={"𦭑"}
	a[03730]={"㝑","寜","衍","防","𨸂"}
	a[03731]={"密"}
	a[03732]={"芳","𦰛"}
	a[03733]={"㧑","𦰷","𦷰"}
	a[03740]={"徬","𡨪","𥫳"}
	a[03742]={"㧍","䓷","荡","","𢮰","𦲂"}
	a[03743]={"蒋","蒍"}
	a[03744]={"𡩋"}
	a[03750]={"䘕","䧛","寧","衒"}
	a[03751]={"𥰆","𥰛","𧗶"}
	a[03752]={"甯","菏","蒡","蔏","𠟌","𦴥","𦵑","𦵿","𦶒","𦷟"}
	a[03754]={"蓠"}
	a[03755]={"寗","𦷫"}
	a[03760]={"篣","𥯽","𥰵","𥲌"}
	a[03761]={"䧐","𢕚","𦑸","𧗵"}
	a[03762]={"㧸","䕍","搒","篱","葶","蒟","蕍","𢳣","𦱀","𦺍","𦾸"}
	a[03763]={"蔐","𥵥","𦳧","𧁄"}
	a[03764]={"摛","薱"}
	a[03766]={"蒲"}
	a[03770]={"䈮","䧚","𥯢","𥳷","𥵣","𧗳","𧗹"}
	a[03771]={"𥯞","𥱀","𧗿","𪂁"}
	a[03772]={"䔽","勶","揨","蒿","蕩","𥵢","𧂙"}
	a[03773]={"㨃","摘","𢰧","𦶌"}
	a[03774]={"䈬","𢷮","𦶊"}
	a[03775]={"蕅"}
	a[03777]={"薄"}
	a[03779]={"𦺇"}
	a[03780]={"篙","簜","閍","𥲮","𪁢"}
	a[03781]={"𪅮"}
	a[03782]={"搞","薃"}
	a[03784]={"蔳"}
	a[03785]={"簿","𥳻"}
	a[03790]={"鷑"}
	a[03792]={"𢷒","𦺞","𧂧"}
	a[03793]={"𢷔","𧘂"}
	a[03794]={"𢴆","𦽴"}
	a[03800]={"𩕳"}
	a[03801]={"𥷼"}
	a[03803]={"𧆈"}
	a[03810]={"𢓌"}
	a[03812]={"𥸡","𦮟"}
	a[03813]={"𥸜"}
	a[03814]={"𧄢","𧆐"}
	a[03820]={"宍"}
	a[03821]={"实"}
	a[03822]={"𦬩","𦮛","𦸁"}
	a[03830]={"阂","陔","𥫰","𥲄"}
	a[03832]={"茨","荄"}
	a[03833]={"𦮮","𦰚"}
	a[03842]={"㧡"}
	a[03844]={"葓"}
	a[03850]={"𢕐"}
	a[03852]={"䧤","篊","𢰍"}
	a[03853]={"蒺","𦺾","𧃉"}
	a[03861]={"𡫃","𧶡"}
	a[03862]={"蔙"}
	a[03863]={"蔟"}
	a[03864]={"撲"}
	a[03865]={"𧀌"}
	a[03866]={"𦳂"}
	a[03871]={"簇"}
	a[03872]={"薋","𢳄"}
	a[03873]={"䕛","𢳇","𧂨"}
	a[03880]={"閡"}
	a[03882]={"簱","藃","𧅙"}
	a[03883]={"𢸈"}
	a[03890]={"𥸊"}
	a[03892]={"籏"}
	a[03902]={"𩕋"}
	a[03911]={"𥸉"}
	a[03922]={"𡩎"}
	a[03933]={"莯","𦮞","𦱈","𦷞","𦸼"}
	a[03934]={"蒅"}
	a[03940]={"𥲰"}
	a[03941]={"𡩁"}
	a[03942]={"㣸"}
	a[03943]={"蒤","𦯧","𦸂"}
	a[03944]={"𦺁","𧀝"}
	a[03951]={"簗","𥮧"}
	a[03952]={"䧨","掠","𡪔","𥴽","𧀉"}
	a[03953]={"薬","蘂","𢮕","𢱨","𨼙"}
	a[03954]={"𦸯"}
	a[03960]={"𥲚"}
	a[03961]={"𡫵","𥯲"}
	a[03962]={"𢱊","𥴼","𧄜"}
	a[03963]={"𧀪"}
	a[03964]={"擈"}
	a[03965]={"薻"}
	a[03973]={"蕖","𦼹"}
	a[03974]={"薸","𧃡"}
	a[03982]={"𦻑"}
	a[03983]={"藁","藳"}
	a[03993]={"藻"}
	a[04040]={"𨽛"}
	a[04053]={"𢰓"}
	a[04062]={"蓈"}
	a[04106]={"𢷹"}
	a[04110]={"䉱"}
	a[04113]={"𨷭"}
	a[04114]={"𢺠","𨷠"}
	a[04132]={"䒸"}
	a[04142]={"𢬔"}
	a[04143]={"蓙"}
	a[04153]={"𢬂"}
	a[04161]={"徨"}
	a[04162]={"䔃"}
	a[04171]={"隍","𥳁"}
	a[04172]={"𢵊"}
	a[04173]={"葟"}
	a[04174]={"㩁"}
	a[04176]={"𢱅"}
	a[04180]={"䦗"}
	a[04181]={"篁"}
	a[04183]={"揘"}
	a[04184]={"𢸔","𢹋"}
	a[04195]={"薼"}
	a[04202]={"𢵞"}
	a[04203]={"擤"}
	a[04204]={"蘼"}
	a[04214]={"攠"}
	a[04220]={"𨸘"}
	a[04232]={"扩","芦"}
	a[04242]={"护","摉"}
	a[04252]={"𦵬"}
	a[04270]={"𥵬"}
	a[04290]={"𥵸"}
	a[04292]={"𢖥"}
	a[04293]={"䕗"}
	a[04300]={"籩","閬","𥸅"}
	a[04301]={"𨶐"}
	a[04302]={"𢹞"}
	a[04303]={"䉦"}
	a[04304]={"𢸦","𧂍"}
	a[04311]={"闧"}
	a[04312]={"𥶷"}
	a[04313]={"闥"}
	a[04315]={"𧕏"}
	a[04320]={"㝎"}
	a[04322]={"芝"}
	a[04330]={"隧"}
	a[04331]={"闼"}
	a[04332]={"菦","蓫","𢳦","𦼯"}
	a[04333]={"荙","蒁","蒾"}
	a[04340]={"篴","𥴦"}
	a[04341]={"笾"}
	a[04342]={"䓕","拡","𢳤","𢷊","𥳤","𦷷","𦿚"}
	a[04343]={"挝","挞","𦳭","𦷴"}
	a[04344]={"蔗","𦳺"}
	a[04350]={"㝗","阆"}
	a[04351]={"𥱻","𥲽"}
	a[04352]={"㣹","䉀","䕂","莨","𦴚","𦾽"}
	a[04353]={"蔥","𢱤","𦾾"}
	a[04354]={"摭","𢕝","𦰭","𧀋","𧀹","𧅊"}
	a[04355]={"䔎","莲"}
	a[04360]={"筤","𥯧","𨻁"}
	a[04361]={"随","𥳿"}
	a[04362]={"蒠","𢖐","𢭗","𢲙"}
	a[04363]={"㣵","䔏","䕖","摠","薳","𦳰","𦹢","𧂏"}
	a[04364]={"䔌","蓪","𦶅","𦻗","𦽟"}
	a[04365]={"藗","𢳪","𧁽"}
	a[04366]={"蓬"}
	a[04369]={"薕"}
	a[04370]={"𥰝"}
	a[04371]={"簉","𥱃","𥷊"}
	a[04372]={"搥","薖","𢱸","𥲆","𥳟","𦷿"}
	a[04373]={"藡","蘧","𢳥","𢷫"}
	a[04374]={"篷","藨","𢳟","𧲛 "}
	a[04375]={"薘"}
	a[04376]={"摓"}
	a[04377]={"簾","蓮"}
	a[04380]={"簻","𦾼","𨷃"}
	a[04381]={"籧"}
	a[04382]={"撾","𢳘","𥳪","𥶔"}
	a[04383]={"擿","𥴪"}
	a[04384]={"㩠","𧄟"}
	a[04385]={"撻"}
	a[04387]={"摙"}
	a[04391]={"𥳠"}
	a[04392]={"𢶑","𦽙","𨽟"}
	a[04393]={"蕸"}
	a[04394]={"𢸷","𧂠"}
	a[04396]={"𢹗"}
	a[04397]={"𢶂"}
	a[04410]={"𨶳"}
	a[04415]={"鬮"}
	a[04418]={"𧆓"}
	a[04432]={"莵"}
	a[04433]={"𢭔"}
	a[04441]={"𨹖"}
	a[04442]={"抭","𢬉","𢭕","𦯜"}
	a[04443]={"菧"}
	a[04450]={"阸","𡨇"}
	a[04452]={"𢲁"}
	a[04453]={"掋","蔲","𢕽","𦶢"}
	a[04460]={"𥭨"}
	a[04461]={"𡨗","𥲃","𨻀"}
	a[04462]={"㧖","隗","𢭖"}
	a[04463]={"蓖"}
	a[04464]={"蒐"}
	a[04470]={"𥰗"}
	a[04471]={"篦"}
	a[04472]={"䈭","葩"}
	a[04473]={"𢱧","𦶃"}
	a[04474]={"䕇","蔍"}
	a[04475]={"𢷪"}
	a[04476]={"蓭"}
	a[04481]={"𥲇"}
	a[04482]={"簏","蔰","𥴯","𦳓","𦼍","𦽏"}
	a[04484]={"摝","𢸎"}
	a[04490]={"簄"}
	a[04492]={"㨭"}
	a[04501]={"䉬"}
	a[04505]={"𪎃"}
	a[04534]={"𢔃"}
	a[04543]={"䧪","𡣀","𢔌","𢯱"}
	a[04552]={"𥭲"}
	a[04553]={"蘬","陴","𢯪","𦯑","𦰬"}
	a[04554]={"䔗"}
	a[04555]={"萆","蓆","𢰘","𦳔"}
	a[04556]={"𦳅"}
	a[04561]={"徼","𢔾","𨹺"}
	a[04562]={"𡫎"}
	a[04563]={"箄","𥯖","𦰺"}
	a[04564]={"蒰","𥯯","𦻉"}
	a[04565]={"捭","𢮽","𢱋","𢱰","𦸣"}
	a[04571]={"𡫀","𨼍"}
	a[04572]={"䈲"}
	a[04573]={"蒒","薂","𢮒","𦺆"}
	a[04574]={"㨩","搬"}
	a[04575]={"𢱻","𢳋"}
	a[04576]={"𦽮","𧂑"}
	a[04581]={"篩","𥵩"}
	a[04583]={"撽","薛"}
	a[04585]={"𥴣","𦾦"}
	a[04593]={"䕠","𢶓"}
	a[04595]={"㜸"}
	a[04601]={"𥶕"}
	a[04602]={"藠"}
	a[04611]={"闙"}
	a[04614]={"𨶈"}
	a[04615]={"攟"}
	a[04617]={"𢹲"}
	a[04632]={"𦬲","𦭾"}
	a[04642]={"苩"}
	a[04643]={"𢫥","𢭇","𦯎"}
	a[04650]={"𥬝"}
	a[04652]={"拍","𦤅"}
	a[04653]={"𦴦"}
	a[04661]={"𥰋"}
	a[04662]={"掂"}
	a[04674]={"䧜","蘑"}
	a[04676]={"蓎"}
	a[04682]={"䔤"}
	a[04683]={"䕐"}
	a[04684]={"篖","𧂉"}
	a[04686]={"搪"}
	a[04693]={"𥴿"}
	a[04700]={"𨶇"}
	a[04701]={"𨉖"}
	a[04704]={"孽"}
	a[04710]={"𨶠 "}
	a[04712]={"𨷓"}
	a[04713]={"𪈟"}
	a[04714]={"𧆆"}
	a[04720]={"㣗"}
	a[04733]={""}
	a[04734]={"𦭸"}
	a[04740]={"𥫿","𨹘"}
	a[04741]={"𥮙"}
	a[04742]={"徧","茑","𦯅"}
	a[04743]={"捬","荢","𢪼","𢬇"}
	a[04750]={"隖","𡧺","𥭈","𨹅"}
	a[04752]={"捣","菂","𢖇","𦲄","𦶀"}
	a[04754]={"萹"}
	a[04755]={"𦼎"}
	a[04760]={"隝","𢕨","𥱳"}
	a[04762]={"摀","篇","菺","蔦","𢯊","𢲲"}
	a[04763]={"㧶","𥱊"}
	a[04764]={"揙","薦"}
	a[04766]={"藦"}
	a[04770]={"䉆","鵆"}
	a[04771]={"𥱈"}
	a[04772]={"㨶","䕣","掮","蘤","𥴱","𦶋"}
	a[04773]={"𢲌","𢷈"}
	a[04776]={"擵"}
	a[04780]={"㝰","𡫛","𥰢"}
	a[04782]={"搗","搧","蓢","蔼"}
	a[04783]={"𢲐"}
	a[04786]={"𢳹","𢺦"}
	a[04787]={"䧡"}
	a[04790]={"𥵨","𥶧"}
	a[04792]={"𢸐"}
	a[04793]={"㔑"}
	a[04794]={"𠣅"}
	a[04811]={"𨶑"}
	a[04813]={"躠","𢹷","𢹻"}
	a[04814]={"𧅤"}
	a[04821]={"𡨿"}
	a[04830]={"𤑾"}
	a[04842]={"萣","隩","𡪿"}
	a[04843]={"䓞"}
	a[04844]={"薁"}
	a[04851]={"䈆"}
	a[04852]={"䉛"}
	a[04853]={"捩"}
	a[04854]={"擙"}
	a[04855]={"𢲎"}
	a[04856]={"菮"}
	a[04863]={"𦺮"}
	a[04866]={"掶"}
	a[04872]={"𢳡"}
	a[04873]={"搝"}
	a[04874]={"𨽏"}
	a[04882]={"𦿜"}
	a[04883]={"𢵐"}
	a[04886]={"擴"}
	a[04887]={"𢳿"}
	a[04895]={"𧁐"}
	a[04900]={"闎"}
	a[04911]={"闑"}
	a[04920]={"𢔻"}
	a[04932]={"𢱑","𦭔","𪎓"}
	a[04940]={"𡨫","𥴎"}
	a[04942]={"𢫕","𢬠"}
	a[04943]={"𢭩"}
	a[04944]={"蔴"}
	a[04950]={"𥮵"}
	a[04951]={"𡩕"}
	a[04952]={"葲","𢮱"}
	a[04953]={"𢮄"}
	a[04954]={"𢳀"}
	a[04955]={"𧃲"}
	a[04961]={"𨻄"}
	a[04962]={"𦽎"}
	a[04964]={"㝩","䕷","𨻷"}
	a[04965]={"𡪼"}
	a[04966]={"𢳧"}
	a[04970]={"簶"}
	a[04971]={"𥶣"}
	a[04973]={"𦾰"}
	a[04974]={"𢶱"}
	a[04983]={"𢳚"}
	a[04985]={"蘪"}
	a[04992]={"䕲"}
	a[04994]={"糵","蘖","𧃧"}
	a[04995]={"攈","攗"}
	a[05013]={"艾"}
	a[05021]={"䦹","𥫜"}
	a[05023]={"𢩩","𦬁"}
	a[05032]={"䢿"}
	a[05053]={"鄀"}
	a[05054]={"𦵟"}
	a[05065]={"挷","𦳻"}
	a[05073]={"𨞨"}
	a[05074]={"𦺥"}
	a[05082]={"𥳉"}
	a[05084]={"𨝨"}
	a[05102]={"閨"}
	a[05103]={"藲"}
	a[05104]={"薹","𢹹","𥷈"}
	a[05105]={"𧃦"}
	a[05108]={"蘳","𧄚","𧅀"}
	a[05110]={"䕼","攤"}
	a[05111]={"䉩","闔","𨶮"}
	a[05112]={"籉"}
	a[05113]={"𨵯","𩀶"}
	a[05114]={"擡","𨽮","𩁌"}
	a[05115]={"𧄧"}
	a[05116]={"𨶬"}
	a[05117]={"𩁳"}
	a[05118]={"㩇"}
	a[05121]={"𢓂"}
	a[05131]={"𥁗"}
	a[05132]={"𢓯"}
	a[05133]={"芏",""}
	a[05141]={"𥫦"}
	a[05142]={"䀂","徍","𡋩","𡎶","𢔺","𢕙","𨻊"}
	a[05143]={"㝧","扗","葢","𡋅","𢔷"}
	a[05144]={"茬","荰","莥"}
	a[05145]={"𦭓"}
	a[05151]={"𥬢","𥮹"}
	a[05152]={"闺","陸","𡧩","𥰎"}
	a[05153]={"笹"}
	a[05154]={"茥","𢬋","𦵔"}
	a[05155]={"垫","抴","𨿆"}
	a[05156]={"𦾟"}
	a[05161]={"徝","阖","𡨵","𥱝"}
	a[05162]={"筀","篐","𥯸","𥲵"}
	a[05163]={"蓋","𥱔","𦳏","𦳘"}
	a[05164]={"挂","葚","𢯅","𥵃","𦍮","𨾶"}
	a[05165]={"塞","蓕"}
	a[05166]={"䔆"}
	a[05171]={"篕"}
	a[05172]={"堕","隓","𡫝","𥯓"}
	a[05173]={"揸","搕","𡪈","𦶙"}
	a[05174]={"揕","𦽯"}
	a[05175]={"㨒","𦸀"}
	a[05176]={"藎","𦻌"}
	a[05177]={"𦱥","𦾗"}
	a[05181]={"䦌","𥮖","𨸌"}
	a[05182]={"𥱜"}
	a[05183]={"㨁","簊","𨿭"}
	a[05184]={"簠","𥵧"}
	a[05185]={"𡪸","𡫑","𡫓","𢷞"}
	a[05186]={"塦"}
	a[05188]={"蓳","𢳩"}
	a[05191]={"𥵈","𨵵"}
	a[05192]={"墮"}
	a[05193]={"撎","𥂯","𦺟","𨼰"}
	a[05196]={"䈽"}
	a[05197]={"蘣"}
	a[05198]={"㨷"}
	a[05205]={"簫"}
	a[05206]={"䖇"}
	a[05207]={"㩋"}
	a[05216]={"𢺴"}
	a[05223]={"䓄"}
	a[05224]={"𦯷"}
	a[05231]={"𡨨","𥭦"}
	a[05232]={"𢔘","𥭝"}
	a[05233]={"菥"}
	a[05241]={"𥭃","𥭄","𥮥"}
	a[05242]={"𡪎","𢓦"}
	a[05244]={"𢮻","𦰀","𦰄","𦾘"}
	a[05246]={"萧"}
	a[05251]={"𥯻"}
	a[05253]={"𦬝"}
	a[05254]={"箫"}
	a[05257]={"䔥"}
	a[05261]={"𥶠"}
	a[05262]={"𥲲"}
	a[05263]={"𡮞","𥲪"}
	a[05264]={"䔮"}
	a[05265]={"簘","𢳮"}
	a[05272]={"簛"}
	a[05273]={"𢵓"}
	a[05274]={"撕","𣃈"}
	a[05277]={"蔪"}
	a[05282]={"𣃑"}
	a[05284]={"𣃄"}
	a[05287]={"摲"}
	a[05297]={"蕭"}
	a[05298]={"𧁲"}
	a[05302]={"𨵗"}
	a[05307]={"蠚","𧒡"}
	a[05310]={"䖄"}
	a[05311]={"㣖","𡬜","𧆒","𧖡"}
	a[05312]={"𢥰"}
	a[05313]={"𧲝","𩼏"}
	a[05316]={"𥶙","𥶬"}
	a[05317]={"𢖧","𧆔"}
	a[05318]={"㩨","𢺐","𧅪"}
	a[05319]={"攮","𢺨","𧅺","𧕷"}
	a[05321]={"𢔋","𢚠"}
	a[05323]={"𦱄"}
	a[05331]={"宏","闳","𡧫","𡨁","𡨭","𥫵"}
	a[05333]={"䓇","苌","菘","𢕉","𦽲"}
	a[05334]={"热","苯","𦴣"}
	a[05341]={"徳","阹","𥯆"}
	a[05342]={"笨"}
	a[05343]={"䒧","䓌","捇","𢝨","𥵅","𦺛"}
	a[05344]={"寒","𢞝","𢫆","𢫿"}
	a[05346]={"𢶰","𦶟"}
	a[05351]={"德","𥬔","𥭡","𥱉","𧱞"}
	a[05352]={"𡨲"}
	a[05353]={"惹","抾","𦵧","𦶠","𦷓"}
	a[05354]={"㥶","抟","𢰯"}
	a[05355]={"𧊝"}
	a[05361]={"㝨","𡪍","𢕞"}
	a[05363]={"㨬","𥲘","𦸉"}
	a[05364]={"㧼","掛","褰","𢷓","𦵢"}
	a[05365]={"藮"}
	a[05366]={"爇","蛰"}
	a[05371]={"隳","𥰟"}
	a[05372]={"𥱕"}
	a[05373]={"憲","摦","𢞩","𥮔"}
	a[05374]={"䧥","寭"}
	a[05375]={"𢮨","𦶮","𧍷"}
	a[05376]={"䗙","蕙","𢮛","𢸺","𧃳"}
	a[05377]={"𢳎","𧀱"}
	a[05381]={"䦝","閎","隨","𢡢"}
	a[05382]={"𢢠","𨽞","𩷷"}
	a[05383]={"蘾","𥶥","𩛬"}
	a[05384]={"𢡳"}
	a[05385]={"䉖","𢰁","𩺁"}
	a[05386]={"𢴥"}
	a[05387]={"𢳨"}
	a[05392]={"𥷀","𧲔"}
	a[05396]={"藝"}
	a[05400]={"𢶪"}
	a[05402]={"閾"}
	a[05403]={"𨽐"}
	a[05404]={"㨴","𧅜","𩰓"}
	a[05405]={"撓","𦽞","𩙃"}
	a[05406]={"𧁉"}
	a[05411]={"𢓀","𥵽","𥸚"}
	a[05412]={"闀","闚","𢓃"}
	a[05413]={"籖","𨷁","𨼡"}
	a[05414]={"閹"}
	a[05415]={"㩥","𥶸","𧄍"}
	a[05416]={"𡬁","𧁳"}
	a[05421]={"𡧞"}
	a[05422]={"彵","𡧀","𡧄"}
	a[05423]={"㣝","芅","𦬍"}
	a[05424]={"㣤","𦬎","𦬗"}
	a[05431]={"宄","𥫝","𨸒"}
	a[05432]={"䇝","宠","笂","阤","陇"}
	a[05433]={"艽","𠒌","𢩮","𦬓"}
	a[05434]={"䧖","执","找","芄","茏","莸","萙","𦱍"}
	a[05435]={"茙"}
	a[05436]={"菚"}
	a[05441]={"𨸪"}
	a[05442]={"竾","笼","𡨳","𢔹","𥫬"}
	a[05443]={"扏","扰","笺","𢓧","𥬪"}
	a[05444]={"扡","扥","拋","拢","箋","芚","荖","荛","𦭋","𦲁"}
	a[05445]={"䒲","𢫨","𦳨"}
	a[05446]={"䓼","𢬿","𢯆","𦯏"}
	a[05448]={"𦶥"}
	a[05451]={"𥰜"}
	a[05452]={"䇭","䧕","阈","𡧪","𥫱","𨺖"}
	a[05453]={"拭","𢕂","𢭪","𦮹"}
	a[05454]={"㧯","䇳","扽","抛","挠","𡩯","𡪐","𢔂","𦱂","𦹅"}
	a[05455]={"䓐","𥴈","𦯮","𦳦","𦳹"}
	a[05456]={"𦰖"}
	a[05461]={"𥮕"}
	a[05462]={"䈅"}
	a[05463]={"𢬐","𢭜","𥭯","𥯒","𦰮"}
	a[05464]={"㝪","寋","掝","阉","𦰾"}
	a[05466]={"菴","蓺","蓻","𢲅"}
	a[05467]={"𣯬"}
	a[05471]={"𡩖","𡩮","𨳍"}
	a[05472]={"𡪨","𥬻","𥮼","𨳮"}
	a[05474]={"䉅","𢬹","𥯃","𩰎"}
	a[05475]={"䒎","𢳌","𦸴"}
	a[05476]={"掩","𢳊","𢴇"}
	a[05477]={"䕙"}
	a[05478]={"𢶤"}
	a[05481]={"𨳊"}
	a[05483]={"徺","𡪩"}
	a[05484]={"𡪰","𢵖","𨵊"}
	a[05485]={"𥱍","𥵞"}
	a[05486]={"撠","𦼺","𧄥"}
	a[05487]={"擮","𢮊","𥰳"}
	a[05488]={"𦳛"}
	a[05492]={"𨳘","𨴛"}
	a[05493]={"隢","𢴧"}
	a[05494]={"摫","𢶭"}
	a[05495]={"範","蕘","𣰛","𦿖"}
	a[05496]={"𢶋"}
	a[05497]={"𢶩"}
	a[05502]={"𨵉"}
	a[05504]={"𧂔"}
	a[05505]={"𤜂"}
	a[05508]={"𦼷"}
	a[05511]={"攆","𢷦","𢺩"}
	a[05512]={"𥷆","𨵾"}
	a[05513]={"闈","𨷂"}
	a[05514]={"䒝","𧲞"}
	a[05515]={"閳","𢆈","𥷯","𩰛"}
	a[05516]={"𩏓"}
	a[05517]={"𦮙","𧃙"}
	a[05518]={"𦿓"}
	a[05519]={"𧁍"}
	a[05522]={"安","笅","𡧅"}
	a[05523]={"𢓬"}
	a[05524]={"𦬇"}
	a[05525]={"𦬢"}
	a[05526]={"𡪋"}
	a[05532]={"𡨔","𢔁","𥫠","𥫭","𨸲","𨸽","𨺶"}
	a[05533]={"𡟨","𨻤"}
	a[05534]={"宑","扙","芰","芾","苃","茇","阱","𦬒","𦬠","𦭄","𦱏","𦲲"}
	a[05535]={"莃","莽","𦬻"}
	a[05536]={"彿"}
	a[05542]={"陵","𡧌","𢔛","𥫲","𥫴","𥬒"}
	a[05543]={"笯","闱","阵","𥭘","𥮎"}
	a[05544]={"㧊","技","抜","抪","拔","菱","𢕡","𥬆","𦬡"}
	a[05545]={"䒠","䓩","苇","蓛","𢫓","𢬾","𦰃","𦴡","𦶞","𦺋"}
	a[05546]={"莾","𢪝"}
	a[05548]={"茀","葌"}
	a[05552]={"䈊","𡨊","𡪌"}
	a[05553]={"𢕟","𥰡","𨹧"}
	a[05554]={"掕","𢪄","𢲳","𥴟","𦱾"}
	a[05555]={"蔱","𢄏","𢔓","𢪋","𢫇","𢲆","𢽁","𦵪","𦼊"}
	a[05556]={"䔩","律","捹","笰","𦰗"}
	a[05557]={"䓸"}
	a[05558]={"拂"}
	a[05563]={"徫","隞","𢕴","𢿸","𥮁","𥴍"}
	a[05564]={"𥷭","𦹫"}
	a[05565]={"摋","敶","蔜","陣","𢱂","𢴻","𥬬","𦾡"}
	a[05566]={"𢕣","𢳯","𨹷"}
	a[05567]={"莗","菶","蔕","𢱭","𦳴"}
	a[05568]={"茟","萋","𦳳"}
	a[05569]={"𢰎"}
	a[05572]={"𢕿","𨳐"}
	a[05573]={"𨼣"}
	a[05574]={"𢱕","𥲷","𥴖"}
	a[05575]={"葦","蕔","𡫪","𢳆","𥰏","𥲯","𦸱","𦺻"}
	a[05576]={"䕅","筆"}
	a[05577]={"捙","捧","摕","鞌","𢯹","𢰟"}
	a[05578]={"捿","𢫫","𦽨"}
	a[05582]={"𡫄"}
	a[05583]={"䉈","𡡙","𥯤","𥴆"}
	a[05584]={"㪡","簸"}
	a[05585]={"撒","薣","𡫣","𢯷","𢻜","𦺔","𦼮","𦾫"}
	a[05586]={"𥴇","𦼆"}
	a[05587]={"𢶬","𧀮"}
	a[05588]={"蓒"}
	a[05593]={"簳","𥳴","𥵠"}
	a[05594]={"㲅","𢱷","𥶜"}
	a[05595]={"擀","𧂣"}
	a[05596]={"𢵕"}
	a[05597]={"㩤","𥲶","𦼽"}
	a[05598]={"搟"}
	a[05599]={"撵"}
	a[05601]={"䦖"}
	a[05605]={"籍","𢸓"}
	a[05606]={"䉐","簵"}
	a[05610]={"𧅝"}
	a[05612]={"讏","闍"}
	a[05613]={"䦮","讆","𨶶"}
	a[05615]={"𧅥"}
	a[05619]={"䖃"}
	a[05641]={"㝒","㣟","𡧣","𡧶"}
	a[05643]={"㣨","若","苦","茄","莕"}
	a[05644]={"茹"}
	a[05651]={"䇢","䧊","笳","𥬡","𥰫","𨹞"}
	a[05652]={"徣","筎","𢔪"}
	a[05653]={"䓀","拁","𢫈"}
	a[05654]={"𦰯"}
	a[05655]={"菇"}
	a[05661]={"𥭅"}
	a[05662]={"㝜","䈷","阇","陼","𡩛","𡩜","𥭻","𥱓"}
	a[05663]={"害","拮","葙","𥱛"}
	a[05664]={"著","𠹟"}
	a[05665]={"蕏","蕕"}
	a[05666]={"𢵝"}
	a[05671]={"箱","𡫆","𥳖"}
	a[05672]={"箸"}
	a[05673]={"蔷","薔","𡩐","𥴕","𦹷"}
	a[05674]={"㨋","措","萅","蓍","𢲃"}
	a[05675]={"萶","𢳭"}
	a[05676]={"𧀗"}
	a[05681]={"䉢","𥲴"}
	a[05682]={"籕","𥲐","𥶫"}
	a[05683]={"箺","豁","𥳯","𥷸","𦸻","𧨅"}
	a[05684]={"搘","𥈽","𦴀"}
	a[05685]={"撦","𢰦","𢴯"}
	a[05688]={"蓸"}
	a[05691]={"𧨧","𨳾"}
	a[05692]={"䉋"}
	a[05694]={"䕒","簮","謇"}
	a[05696]={"𥲍"}
	a[05697]={"䕋","藉","𦶕"}
	a[05698]={"𢲵"}
	a[05701]={"𧘅","𨴜","𩩜"}
	a[05702]={"隯","𨵴","𨽋","𪇙"}
	a[05703]={"䕵","𢖡","𥶤","𨴒","𩰑","𩽘"}
	a[05704]={"䘙","薵","𢴿","𧃓","𨴪","𨴹"}
	a[05705]={"𧅹"}
	a[05707]={"𧂮"}
	a[05708]={"蔧"}
	a[05711]={"鷴","𪅿"}
	a[05712]={"籌","𠝨","𥷚","𥷤","𪈁","𪈓"}
	a[05713]={"苅","鶷","𥷴"}
	a[05714]={"擣","蘛","𦮓","𪈢"}
	a[05715]={"𥶹"}
	a[05716]={"篲","𧃠"}
	a[05717]={"𧄛","𩍸"}
	a[05718]={"㨹","䕿","𢷬","𧅻","𧆖"}
	a[05721]={"守","闭","阞"}
	a[05723]={"艻","苏","𠞦","𦬌"}
	a[05724]={"䓭"}
	a[05731]={"彻","竻","術"}
	a[05732]={"待"}
	a[05733]={"扐","苆","𠡓","𢔯","𢩭","𢩱","𦯪"}
	a[05734]={"莿","𠞁","𦬵"}
	a[05741]={"徛","𢓢","𧗝","𧗢"}
	a[05742]={"㣮","箣","衖","陆","𧗫","𨺞"}
	a[05743]={"𦮢"}
	a[05744]={"䓁","苷","荐","𠠀","𢫉","𦰁","𦰳","𦱰","𧗸"}
	a[05745]={"䒵","䓶","荔","𦮾"}
	a[05751]={"宥","寄","陏","陓","陭","鹇","𥭀","𥮻","𨺈","𨺕"}
	a[05752]={"䇞","等"}
	a[05753]={"䒴","䓫","䔠","荂","荺","𢪃","𥰍","𥲈"}
	a[05754]={"宯","拑","拵","持","荸","萳","陠","𡺶","𢮷","𦰰","𦸒"}
	a[05755]={"㨺","拹","揦","𢭛","𢵗","𦯞","𦴑"}
	a[05756]={"䓓","䓔","挚","莆"}
	a[05758]={"𦰓"}
	a[05759]={"𢹜"}
	a[05761]={"䈾","筠","𡺆","𢔵","𢕥","𥭺"}
	a[05762]={"䈒","街","𥬯"}
	a[05763]={"䈤","䕆","挎","掎","鴱","𢭙","𢰒","𦰅","𦰶","𧂦"}
	a[05764]={"拷","挬","揇","筹","𢬱","𢯎","𥮉","𦴆"}
	a[05765]={"葑","葧","𥲭"}
	a[05766]={"䔦","捕","搴","蒘","𢭦","𦶦"}
	a[05767]={"蒪","𢲊"}
	a[05770]={"𦵷"}
	a[05771]={"閉","隋","𢕳"}
	a[05772]={"䉇","䘘","寈","鴳","𢕵"}
	a[05773]={"篈","葫","𡩝","𡫭","𦼰","𦼴","𦿂","𩱀"}
	a[05774]={"弿","菁","骞","𠢆","𡩱","𡫌","𢏪","𢮌","𥰪","𦞫"}
	a[05775]={"䕮","䡓","䧠","薅","𢵘","𦷵","𦹤","𧁿"}
	a[05776]={"𢲄","𧅩"}
	a[05777]={"䓯","搏","蓴","𦏡"}
	a[05778]={"㝤","𢮇","𦼭"}
	a[05779]={"𢺏"}
	a[05780]={"搆","𥱏"}
	a[05781]={"嶞","箶","衚","衠","𥰮","𥲙","𥴭","𥵰"}
	a[05782]={"箐","衞","𡪙","𡽃","𥵍","𨴺","𪃝"}
	a[05783]={"㨊","衛","𢰮","𢱪","𥶶"}
	a[05784]={"掅","𢖁","𢖋","𥵱","𪙐"}
	a[05785]={"搚","篿"}
	a[05786]={"簕","簙","騫","𧂭","𧅆"}
	a[05787]={"摶","𢐱","𢲞","𢶯","𥱎"}
	a[05788]={"篝","蘜","𢳝"}
	a[05792]={"䦙","𨳼","𨴆","𨼢","𪅋"}
	a[05793]={"𥲳","𦿋"}
	a[05794]={"鶱","𦢽","𦺓"}
	a[05795]={"摏","𧂇","𩼥"}
	a[05796]={"𡫢","𥴾","𥷥"}
	a[05798]={"藕"}
	a[05799]={"𥵡"}
	a[05801]={"𥶦"}
	a[05803]={"籟","𢷺","𧀺"}
	a[05805]={"攋","𧂬"}
	a[05806]={"攅"}
	a[05807]={"𢶝","𧃤"}
	a[05808]={"𤑒"}
	a[05810]={"𧆋"}
	a[05811]={"㣕","㣣","闐","𡬅"}
	a[05812]={"躛"}
	a[05813]={"擷","攧","荻","𧄺","𩕭"}
	a[05814]={"䦬","𢺗","𨶰"}
	a[05821]={"宊","陜","陝","𥭳"}
	a[05823]={"芖","莢","𦬫","𦭹"}
	a[05824]={"获"}
	a[05827]={"䔪"}
	a[05831]={"徒","筴","𥬇"}
	a[05832]={"䦼","䧆","陕","𤑖"}
	a[05833]={"㧋","拻","挾","𢪂","𦍚","𦰻"}
	a[05834]={"芙","芵","荚","𦮎","𦰂"}
	a[05835]={"𥱶"}
	a[05837]={"摤"}
	a[05841]={"陡"}
	a[05842]={"䇲","𥬹","𥯺"}
	a[05843]={"実","羐","莰","𡨏","𡪱","𢷇"}
	a[05844]={"扶","抉","拱","挟","𡨄","𢓡","𣣐","𦳿"}
	a[05845]={"䔸","𦶓"}
	a[05847]={"𧀭"}
	a[05851]={"𢕫"}
	a[05852]={"𤎇","𥲩","𨼪"}
	a[05853]={"𥬟","𦲃"}
	a[05854]={"㣴","䕭","䧅","萁","赛","𦶗","𧂞"}
	a[05855]={"徢","蔌","𢂒"}
	a[05856]={"荑","𢰶","𦳒"}
	a[05857]={"𢸅"}
	a[05861]={"𡪡","𢕤","𥵐","𧵿"}
	a[05862]={"箕","箦","篏","𥱩"}
	a[05863]={"䕀","簌"}
	a[05864]={"㝣","掑","𢰴","𢸱","𥯪","𦽕","𧃬","𨼤"}
	a[05865]={"寁","摗","𢕢","𦸦","𦺀","𦻊"}
	a[05866]={"挗","葜","𤑔"}
	a[05867]={"萐"}
	a[05871]={"䫅","寘","阗","𢖂"}
	a[05872]={"㣱","頞","𥳽"}
	a[05873]={"簯","籁","蒖","隫","𢴪","𣣶"}
	a[05874]={"簧","蹇","𦸬","𦼙","𧃩"}
	a[05875]={"䞿","擜","箑","蕡"}
	a[05876]={"揍","揳","撗","𢱿"}
	a[05877]={"捷"}
	a[05881]={"䈯","𢖏","𩓘"}
	a[05882]={"䦑","閧","𥴹"}
	a[05883]={"搷","撷","𢵒","𢸋","𥳡","𦽢"}
	a[05884]={"蔶","賽","鬨","𢖑"}
	a[05885]={"㝬","簐","𢴢"}
	a[05888]={"𢴁"}
	a[05891]={"𨽍","𨽤"}
	a[05892]={"簀","籡"}
	a[05893]={"藚"}
	a[05894]={"𢶄","𢷐","𢷟","𦼿","𧀶"}
	a[05895]={"藾"}
	a[05898]={"㩌","擹"}
	a[05904]={"䦨"}
	a[05905]={"𥶾"}
	a[05906]={"𢸨","𥷕"}
	a[05907]={"𢸀"}
	a[05911]={"徠"}
	a[05915]={"𧆙"}
	a[05918]={"蘻"}
	a[05921]={"䧒","宋","闲"}
	a[05922]={"㣩","徕","𢓣","𥟲"}
	a[05923]={"㭉","萊","𦬸"}
	a[05931]={"箂","𡨃"}
	a[05932]={"㝝","陈","陎"}
	a[05933]={"䅁","徚","案","莍","𦸓"}
	a[05934]={"苿","茉","茦","莱","菻","𢫬","𢬺","𢭒"}
	a[05935]={"𦰕"}
	a[05941]={"𥭑"}
	a[05942]={"策","箖","𥬎","𦀀"}
	a[05943]={"捄","萘","阑","𣑄","𦳐"}
	a[05944]={"㨆","抹","抺","拺","𢔅","𦮇"}
	a[05945]={"䒹","萰","𢬗","𢵛"}
	a[05946]={"𦮵","𦳀"}
	a[05951]={"寮","𡩡"}
	a[05952]={"𥮮","𥱘"}
	a[05953]={"䇿","捺","筙","𦵫","𦼔"}
	a[05954]={"絷","陳","𦷸","𦹂","𦼪","𦽔","𦽩"}
	a[05955]={"寨","拣","捒","揀","𢵙","𦳑"}
	a[05956]={"菄","葉","蓁","蕀","𦹁","𧀃"}
	a[05961]={"䉘","簝","𥰼"}
	a[05962]={"𨻰"}
	a[05963]={"撩","𢱢","𥽧","𦼋"}
	a[05964]={"㩒","䈎","䕩","蕠","𢱌","𥮤","𥱧"}
	a[05965]={"𦻆"}
	a[05966]={"㨂","捸","揲","搸","𢱴"}
	a[05967]={"𢰬","𦿒"}
	a[05971]={"閑"}
	a[05972]={"𡩼","𥱨"}
	a[05974]={"㨞","䉓","藄","𧁒"}
	a[05975]={"𢵇","𢵎","𦾮"}
	a[05977]={"𢱠","𧁈"}
	a[05982]={"㯐","䦥"}
	a[05985]={"𢴲","𥱂","𧁀"}
	a[05987]={"𨽬"}
	a[05988]={"𢷜","𧀵"}
	a[05990]={"𧄠"}
	a[05993]={"闌","𥶭","𥶺","𨴨"}
	a[05994]={"𢷌"}
	a[05995]={"𥷗"}
	a[05999]={"𢺌"}
	a[06002]={"攌"}
	a[06003]={"𥴞"}
	a[06004]={"酄"}
	a[06005]={"䕤","鄿"}
	a[06007]={"㩛"}
	a[06011]={"𧆘"}
	a[06030]={"问"}
	a[06031]={"𢓨"}
	a[06032]={"㣙","苬","𦬅","𦭝","𦯯","𦸠"}
	a[06033]={"𦭤","𦳊"}
	a[06040]={"徊","间","阳"}
	a[06041]={"䧃","阃"}
	a[06042]={"䒤","宙","扣","莔","𦵣"}
	a[06043]={"苗","茵","菌","𦭁"}
	a[06044]={"苖","𢪠","𦭖","𦮗"}
	a[06046]={"䒼"}
	a[06050]={"𡧟","𥭮"}
	a[06051]={"䇱","笝","筃","箘","𥮦"}
	a[06052]={"㨡","抇","笛","苜","茴","𢪏","𢪾","𦮄"}
	a[06053]={"㧢","捆","𢮖","𦭉","𦱵"}
	a[06054]={"抽","筁"}
	a[06056]={"𢬑"}
	a[06060]={"𥬥","𨜳"}
	a[06062]={"鄸","𢪷","𢰋","𥲢","𦳬","𦴄","𨝥"}
	a[06063]={"䓢","鄚"}
	a[06064]={"𦯁"}
	a[06070]={"𥳙"}
	a[06071]={"箇"}
	a[06072]={"𥭒","𨞛","𨟁"}
	a[06073]={"㧽","掴","薗","𢬻","𦳩"}
	a[06074]={"蔨","蔮","𢬼"}
	a[06080]={"問"}
	a[06082]={"簂","𥱽"}
	a[06083]={"𧀇","𨞼"}
	a[06084]={"摑"}
	a[06087]={"𧅲","𧆕"}
	a[06090]={"間"}
	a[06091]={"閫","𨳸"}
	a[06092]={"𨟔"}
	a[06100]={"䦔"}
	a[06101]={"䥌"}
	a[06102]={"擝","籮"}
	a[06104]={"攞"}
	a[06107]={"虄"}
	a[06110]={"𨵷"}
	a[06111]={"𡬔","𥶊","𥷍","𨶴"}
	a[06112]={"忂"}
	a[06113]={"𨴻","𨷅","𩐍"}
	a[06114]={"㩴","闦","𧄒"}
	a[06115]={"㩸"}
	a[06116]={"蘲","𢹮"}
	a[06117]={"𩁩"}
	a[06151]={"徎"}
	a[06152]={"蒕","𡧹","𦬹"}
	a[06160]={"笪","𥭷","𨻥"}
	a[06161]={"陧","𥮭"}
	a[06162]={"担","搵","蒀"}
	a[06163]={"䧉","𦯖"}
	a[06165]={"荲","𦰌"}
	a[06171]={"䇸","𥭧"}
	a[06172]={"揾","𡩳","𢱫"}
	a[06173]={"挰","捏"}
	a[06174]={"墓","蓶","𥭤"}
	a[06175]={"捚"}
	a[06182]={"篂","𧀆"}
	a[06184]={"𡫋","𦻒","𨼷"}
	a[06185]={"𦷗"}
	a[06186]={"𩁝"}
	a[06192]={"𧄼"}
	a[06193]={"𥱐"}
	a[06194]={"蘿","雚","𥴡"}
	a[06197]={"𧒨"}
	a[06202]={"𢶀"}
	a[06205]={"蘄"}
	a[06213]={"𥷋"}
	a[06241]={"𨺬"}
	a[06242]={"荶","萝",""}
	a[06250]={"箩","𣃇"}
	a[06252]={"夢","𦳥"}
	a[06260]={"篎","𨺸"}
	a[06261]={"箅"}
	a[06263]={"𡖶","𢮧"}
	a[06270]={"𥲣"}
	a[06272]={"葃"}
	a[06273]={"㱳"}
	a[06280]={"𥯭","𥶩"}
	a[06282]={"𣃍","𦽍"}
	a[06292]={"薡"}
	a[06300]={"𥷾"}
	a[06301]={"䉵"}
	a[06302]={"𧁊","𨶯"}
	a[06306]={"𧔃"}
	a[06307]={"𧓵"}
	a[06308]={"𧔴"}
	a[06310]={"闤","𥶉"}
	a[06311]={"籑","𨷤"}
	a[06313]={"䵵"}
	a[06314]={"𢤎","𢦉","𢺱"}
	a[06315]={"䖁"}
	a[06316]={"𢺖","𨷷"}
	a[06319]={"䘍"}
	a[06330]={"𡩑"}
	a[06332]={"𦵺"}
	a[06340]={"𡩲"}
	a[06342]={"闽","𨹁"}
	a[06344]={"茧"}
	a[06350]={"𢜇"}
	a[06351]={"𨺯"}
	a[06352]={"𢰌"}
	a[06353]={"慕","葸","蒽"}
	a[06354]={"𡪊","𢫼","𦸽"}
	a[06356]={"𦴜"}
	a[06360]={"𡪭","𢕼"}
	a[06361]={"隈","𢖚","𥯨","𥲸"}
	a[06362]={"𥳬","𧲎"}
	a[06363]={"揌","摁","葨","𢟽"}
	a[06364]={"㩏"}
	a[06365]={"𦽳"}
	a[06370]={"寰","阛","𡫖"}
	a[06371]={"𥯜"}
	a[06373]={"揋","摆","𡪾"}
	a[06375]={"𧍣"}
	a[06376]={"𧏊"}
	a[06380]={"隰","𥶟","𧁾"}
	a[06381]={"篡","簒"}
	a[06382]={"擐","𢡗","𦿌"}
	a[06385]={"蟇"}
	a[06386]={"蕽"}
	a[06390]={"𨴽"}
	a[06392]={"閩","𢵃","𢷑","𧄾"}
	a[06393]={"𢸃","𥴵","𦿉","𧃊"}
	a[06395]={"𧅌"}
	a[06396]={"擃","𧁁"}
	a[06397]={"蠆"}
	a[06400]={"𥶓"}
	a[06401]={"𥲻"}
	a[06402]={"擺","𨞯"}
	a[06404]={"𣰚","𩴲"}
	a[06407]={"𧂁"}
	a[06410]={"覸","𥸙","𨴼"}
	a[06412]={"䒐","𨵜"}
	a[06413]={"𥌱"}
	a[06414]={"觀","𧢰"}
	a[06416]={"飌","𣰻","𩙣","𩙤"}
	a[06434]={"𦰋"}
	a[06442]={"𦬺"}
	a[06444]={"蔑"}
	a[06446]={"䒶"}
	a[06450]={"宺","𡧮","𢓼","𥰕"}
	a[06451]={"𥱢"}
	a[06452]={"拀","篾","萈","𢬒","𥱡"}
	a[06453]={"𦼤"}
	a[06454]={"䇩","薎","𦸑"}
	a[06455]={"𧀅"}
	a[06456]={"拽"}
	a[06460]={"䧋","𨹝","𨹨"}
	a[06462]={"䓃","莧","𢮺","𥴸","𦵽"}
	a[06463]={"簚","𦸿"}
	a[06466]={"𦴍","𦾒"}
	a[06470]={"䇼","筧"}
	a[06472]={"㨪","挸","挹","菎","薨"}
	a[06473]={"𣬍","𦳈"}
	a[06475]={"蕺","𦽒"}
	a[06480]={"箟"}
	a[06481]={"篹","𥯡"}
	a[06482]={"掍","甍"}
	a[06483]={"𦷖 "}
	a[06485]={"擑"}
	a[06490]={"䉚"}
	a[06492]={"藣","𥲨","𦫰","𦺊"}
	a[06494]={"𣰌","𣰖","𦼵","𧂝"}
	a[06496]={"𦺽"}
	a[06501]={"閺","𡫤","𨴝"}
	a[06502]={"𡕹","𨵒"}
	a[06503]={"簞","𣫑"}
	a[06504]={"撮","蘡","𧃱","𨵓"}
	a[06505]={"撣","𦾛"}
	a[06511]={"䦩","闅","闝","𥸂","𥸇"}
	a[06512]={"䉷","䦴","𨶁"}
	a[06513]={"籰","闡","𢖦"}
	a[06514]={"䕾","攖","𢺘"}
	a[06515]={"攫","𧅚"}
	a[06516]={"𢸶","𨏉"}
	a[06534]={"𦬕"}
	a[06541]={"𢓴"}
	a[06542]={"闸","𥫯","𨸺"}
	a[06543]={"审","𢔼","𦱟","𨸬"}
	a[06546]={"茰"}
	a[06552]={"宴","笚","𢔕","𥱅"}
	a[06553]={"草","𥬐","𦴋"}
	a[06554]={"押","𥬽","𦰇","𦱤"}
	a[06555]={"抻","𢅓","𦱓"}
	a[06561]={"㣬"}
	a[06562]={"𡩷","𢔠","𨻂"}
	a[06563]={"䓍","𢫵","𥭆","𦱛"}
	a[06564]={"幕","萛","𢮆","𢱩","𦺏"}
	a[06565]={"𡠜","𢬽","𢮅","𦳕"}
	a[06566]={"捜"}
	a[06567]={"𢕏"}
	a[06570]={"蔞"}
	a[06571]={"筸","𢕃","𢾮"}
	a[06572]={"算","𨼸"}
	a[06573]={"捍","葺","蔓"}
	a[06574]={"䕉","𢲋","𦳱","𦸫","𧀧","𧃣"}
	a[06578]={"寠","𨻻"}
	a[06579]={"蓽"}
	a[06580]={"摟","𦸩"}
	a[06581]={"箿","藪","𣪯"}
	a[06583]={"揖","摱","𧀰"}
	a[06584]={"擇"}
	a[06585]={"𢖢"}
	a[06587]={"篳"}
	a[06588]={"簍"}
	a[06589]={"𢳂"}
	a[06590]={"擻"}
	a[06592]={"閘","𢖠","𥲺","𨼥"}
	a[06593]={"蘉","𣀔","𥲏","𦸋","𧁎","𨴁","𨼒"}
	a[06594]={"蕞",""}
	a[06595]={"蕇"}
	a[06598]={"𥴂"}
	a[06599]={"籔"}
	a[06600]={"閭","𨼗"}
	a[06601]={"𥲹"}
	a[06602]={"蕌"}
	a[06603]={"謩","𥷫"}
	a[06605]={"藟"}
	a[06610]={"閶","闆"}
	a[06611]={"𥷇"}
	a[06612]={"䖀","虈","𥸑","𥸣","𧄤","𨷄"}
	a[06613]={"䉪","䕎","𧄯"}
	a[06614]={"𥍊"}
	a[06615]={"攂"}
	a[06650]={"宫","宮","闾"}
	a[06652]={"莒"}
	a[06660]={"筥","𢔒"}
	a[06662]={"捛"}
	a[06664]={"𥭾"}
	a[06670]={"阊"}
	a[06672]={"䓵","菖","𣊔","𥕗","𦿛"}
	a[06673]={"𠻚","𧁌","𧅡"}
	a[06675]={"𦵰"}
	a[06680]={"𥰔","𥱟"}
	a[06681]={"𥰻","𥱠"}
	a[06682]={"瞢","𢮵","𨽉"}
	a[06683]={"暮","蕗","𦽖"}
	a[06684]={"撂","薯","𥋚","𦸜"}
	a[06691]={"簬"}
	a[06692]={"𢵚","𥲞","𥵟"}
	a[06695]={"䕸"}
	a[06702]={"蕚","𢹡","𧄞","𪇓"}
	a[06703]={"𧃐"}
	a[06704]={"𪈛"}
	a[06705]={"勸"}
	a[06710]={"䦪","闒","鷼","𦟲","𧃛","𨵛","𨵶"}
	a[06711]={"𧘆","𨵏"}
	a[06712]={"衢","𪆰","𪈆","𪈘"}
	a[06713]={"𧅖","𧅿"}
	a[06714]={"䕽","鸛","鹳"}
	a[06715]={"𡿉"}
	a[06740]={"𥶖"}
	a[06742]={"蘮","𡧥","𦮶"}
	a[06743]={"莂","莴"}
	a[06750]={"𥷙","𧗧"}
	a[06751]={"䇷","得"}
	a[06752]={"䓪","萴","𢓳","𧊔"}
	a[06753]={"拐","捌","莳","𢬢","𦮣"}
	a[06754]={"莮"}
	a[06760]={"䈟","䧎","陽","𠟬","𥮀","𥮬"}
	a[06761]={"𢔥","𢔶"}
	a[06762]={"掦","葛","𢔽","𢪶","𢯩","𢱦","𦮻","𦰉","𦱕","𦳝"}
	a[06763]={"䦸","寓","隅","𢰐","𦴗","𦷤"}
	a[06764]={"募","𠢓","𦰝"}
	a[06765]={"萬"}
	a[06770]={"䈓","𥭞","𥯕","𨺷"}
	a[06772]={"㔍","捐","掲","揚","揭","萌","𥭢","𦷹","𦹩"}
	a[06773]={"㧹","鹋","𢰊","𦰲","𦳢"}
	a[06774]={"蒔","薥"}
	a[06775]={"摹","𦸎"}
	a[06776]={"勱"}
	a[06777]={"𡭆"}
	a[06780]={"阘","𠢽","𧘃","𨺨"}
	a[06782]={"萼","藅","𢴄","𦶑","𦶔","𦷣","𦽦","𧅅"}
	a[06783]={"蓦","𢯮","𦲰"}
	a[06784]={"擉"}
	a[06790]={"䈳","𡪑","𡫞","𥯳","𥵀","𥵑"}
	a[06791]={"𨴾"}
	a[06792]={"搨","𢶔","𥶨","𧀩","𪅇"}
	a[06793]={"鶓","𧀄"}
	a[06794]={"𦽊","𪇴"}
	a[06795]={"驀","𦿄"}
	a[06800]={"閴","𢖤"}
	a[06802]={"顭"}
	a[06803]={"𩔷"}
	a[06810]={"𥶛"}
	a[06811]={"闃"}
	a[06812]={"闠","𢺫","𩖉"}
	a[06814]={"顴","颧"}
	a[06822]={"𡧑"}
	a[06832]={"𤋂","𦭜"}
	a[06840]={"陨","𡨶"}
	a[06842]={"抧","莡"}
	a[06843]={"𦮥"}
	a[06850]={"㝠","徥","筼","𡨕","𥭽"}
	a[06852]={"捉","损","阓","𤊾","𦮷","𦽉"}
	a[06853]={"茣","莫","𦹪"}
	a[06854]={"蒉"}
	a[06860]={"寔","筫","隄"}
	a[06861]={"筽","阒","𨺆"}
	a[06862]={"篑","𦳚"}
	a[06863]={"𢫸","𢮚"}
	a[06864]={"𦴤"}
	a[06865]={"䔬","掼"}
	a[06870]={"䈕","隕"}
	a[06871]={""}
	a[06872]={"䠢","提","蒷","蕒"}
	a[06880]={"篔","簤"}
	a[06882]={"損","隤","𡪲","𢶆"}
	a[06883]={"實","藈"}
	a[06884]={"蕢","𢯵","𧃏"}
	a[06892]={"簣"}
	a[06893]={"㩎"}
	a[06894]={"撌"}
	a[06895]={"摜","躉","𧄌"}
	a[06903]={"𨵚"}
	a[06913]={"𥸕"}
	a[06914]={"𧆉"}
	a[06915]={"虆","𢺢"}
	a[06916]={"蘽"}
	a[06941]={"宲"}
	a[06953]={"菒","𨺁"}
	a[06954]={"菋"}
	a[06955]={"菓"}
	a[06961]={"𡩈","𨻽"}
	a[06962]={"𢖔","𢲗"}
	a[06963]={"蔂","蔝","𦳮"}
	a[06964]={"𥡡"}
	a[06965]={"捰"}
	a[06971]={"䉂"}
	a[06972]={"忁"}
	a[06973]={"摞"}
	a[06974]={"𥢞"}
	a[06981]={"𥴠"}
	a[06982]={"撔","𥣚","𥴌"}
	a[06983]={"繤"}
	a[06984]={"㩧"}
	a[06988]={"𥽚"}
	a[06991]={"纂","𥵺"}
	a[06993]={"操"}
	a[06995]={"𢹯"}
	a[06996]={"𧀢"}
	a[07033]={""}
	a[07045]={"𢪡"}
	a[07050]={"𥬅"}
	a[07052]={"𨞫"}
	a[07053]={"𥬦"}
	a[07060]={"𨛯","𨜌"}
	a[07071]={"𨳙"}
	a[07100]={"篚","𥱸","𨳽","𨻉"}
	a[07102]={"摳","𢹳"}
	a[07104]={"䕚"}
	a[07110]={"𡬐"}
	a[07111]={"𨴑","𨷽"}
	a[07112]={"籄","𧄸","𨷦"}
	a[07132]={"茊"}
	a[07140]={"徂","笽"}
	a[07141]={"陿"}
	a[07142]={"拞","苉","𡋴"}
	a[07143]={"抠","茔"}
	a[07150]={"宜","宦","宧"}
	a[07151]={"篋","𡩊","𨹟"}
	a[07152]={"垼","苣","苴","茝","茞","𢖙"}
	a[07153]={"㧜","埑","莹","蓥"}
	a[07154]={"𦼦"}
	a[07160]={"䇫","笡","笸","𥬙"}
	a[07161]={"𢕀"}
	a[07162]={"抯","拒","挋","箧","𡫯","𦱯"}
	a[07163]={"䒰","銴","𢭘","𨧦"}
	a[07164]={"藶","鋬","𢹠"}
	a[07165]={"蒮"}
	a[07170]={"隉"}
	a[07171]={"筐","筺","𥮶","𥱚"}
	a[07172]={"筪","隁","𦹧","𦾐"}
	a[07173]={"篧","𥮟","𦱙","𦵐","𨿒"}
	a[07174]={"捱","攊"}
	a[07175]={"搉"}
	a[07180]={"簋","𢕓","𨻭"}
	a[07181]={"箼"}
	a[07182]={"揑","藍","𦳎","𦼘"}
	a[07183]={"握","𦷔"}
	a[07184]={"㨤","揠","𢴂","𦸃"}
	a[07190]={"䧢","籃","𡩾","𨻃"}
	a[07192]={"㩜","蓲"}
	a[07194]={"摼","擓"}
	a[07195]={"𩀔"}
	a[07210]={"𨷖","𨷵"}
	a[07212]={"鬬","鬭"}
	a[07220]={"𢓋"}
	a[07222]={"芹",""}
	a[07230]={"𡧙"}
	a[07232]={"䒢","折","茆"}
	a[07240]={"笷","𥭹"}
	a[07242]={"㧕","抑","茚","𢫲"}
	a[07252]={"𢬃","𦰼"}
	a[07262]={"莭"}
	a[07263]={"𦸔"}
	a[07270]={"節","𨳜"}
	a[07271]={"簓"}
	a[07272]={"揤","葄"}
	a[07300]={"䦘"}
	a[07302]={"蠞"}
	a[07312]={"𢺪","𦬔"}
	a[07313]={"𧃚"}
	a[07320]={"笊","𨸯"}
	a[07322]={"抓","苽","𢸖","𦭐"}
	a[07330]={"寙","笟"}
	a[07332]={"㧓","挀","焎","荩","蓏"}
	a[07334]={"𦰈"}
	a[07340]={"很"}
	a[07342]={"悊","蒙"}
	a[07350]={"宸","限","陙","𨸄"}
	a[07352]={"茛","莀","裚","𤎗","𦮈","𦳍"}
	a[07354]={"萤"}
	a[07360]={"䈨","悹","𨳉"}
	a[07362]={"拫","振","萇","𦷚","𦻕","𩜔"}
	a[07364]={"蜇","𢷾","𦽫"}
	a[07371]={"𥮱"}
	a[07372]={"䉞","䕃","䭁","掁","𢤷"}
	a[07373]={"藯"}
	a[07374]={"搌","撼","𢷭"}
	a[07382]={"𢸊","𥴲"}
	a[07396]={"𢷝"}
	a[07401]={"𨳶"}
	a[07402]={"闏"}
	a[07405]={"𡫴"}
	a[07410]={"䦧","覵","𥵒"}
	a[07412]={"攬","鬩"}
	a[07414]={"攪"}
	a[07420]={"𢒿"}
	a[07421]={"彽"}
	a[07422]={"𢩰","𦫾","𨹒"}
	a[07424]={"茂","荗"}
	a[07430]={"宂","𡦻","𢓚","𨸔"}
	a[07431]={"阺","𨸝"}
	a[07432]={"䒮","宬","芁","芃","苋","𡦿","𢪚","𢪦","𦬊","𨹚","𨻒"}
	a[07433]={"䒞","芪","茋"}
	a[07434]={"㧔","䒯","荿","蒇","𦮠"}
	a[07440]={"竼","笕","阨"}
	a[07441]={"𥫹","𥫽","𥰒"}
	a[07442]={"筬","芭","苊","苨","𢩫","𢪨","𥯣","𦬮","𦯵"}
	a[07443]={"扺","抌","抵","茕","𢩺","𥰓","𦰘"}
	a[07444]={"搣","隇","𦭂","𦸗"}
	a[07446]={"葳"}
	a[07450]={"笆","𥫺"}
	a[07451]={"𡨉","𥭿","𨸰"}
	a[07452]={"乴","扼","把","抳","萞","𢫷","𢮉","𦴓","𦶤","𨺢"}
	a[07453]={"㧩","苠"}
	a[07454]={"䓻","摵","葴","葻","蒧"}
	a[07456]={"揻"}
	a[07457]={"𢳒"}
	a[07460]={"箆","阋","𨹣","𨺙"}
	a[07461]={"笢"}
	a[07462]={"箴","萖","𢬯","𦱼","𦲳"}
	a[07463]={"抿","蒄","蒬","𦴞"}
	a[07464]={"㨔","捤","荱","蔵","蕆"}
	a[07466]={"㲟"}
	a[07470]={"𤬽","𥬾","𥮄"}
	a[07471]={"𥭬","𨻆"}
	a[07472]={"䇻","掜","萉","𢭨","𦱉","𦱔","𦸍"}
	a[07474]={"氋"}
	a[07476]={"𩘕"}
	a[07480]={"䈈","𨳋"}
	a[07481]={"篪"}
	a[07482]={"蔸","𦸌"}
	a[07483]={"搋","蔇"}
	a[07484]={"䚆"}
	a[07490]={"篼"}
	a[07492]={"㨮"}
	a[07493]={"摡"}
	a[07501]={"𥳣"}
	a[07502]={"𥵓","𥶵"}
	a[07504]={"𢶙","𦽐"}
	a[07511]={"闢","𢓉","𥳨","𨵐","𨵟","𨷕"}
	a[07512]={"𨵹","𨶘"}
	a[07513]={"𢹚","𥸃","𦗿"}
	a[07514]={"攑","𦘃"}
	a[07517]={"𥴤"}
	a[07518]={"蕼","𢺟"}
	a[07519]={"𦽇"}
	a[07520]={"鿈"}
	a[07521]={"阪"}
	a[07522]={"彼","𢓹"}
	a[07523]={"芇","𦬐"}
	a[07524]={"𦬷"}
	a[07531]={"役"}
	a[07532]={"笫","陂"}
	a[07533]={"㧆","扳","拆","𦮜","𦰑"}
	a[07534]={"𦯛"}
	a[07541]={"𡧔","𢔭","𨸜"}
	a[07542]={"𢔧","𤿤"}
	a[07543]={"报","芟","𢂼","𥫻","𦯼"}
	a[07544]={"娎","披","荦"}
	a[07551]={"𢕌","𥬖","𥯼"}
	a[07552]={"徲","𢔦","𦭀"}
	a[07553]={"投","𢫳","𢼺"}
	a[07554]={"㿱","撄","𦸳"}
	a[07555]={"荤","𢫽","𦳟"}
	a[07561]={"𡨯","𥰹"}
	a[07562]={"箳","𥰦"}
	a[07563]={"菔","菣","𢾠","𦵥"}
	a[07564]={"摒","蓃","𢲈","𢳲","𦱱","𦼗","𧂌"}
	a[07565]={"挥"}
	a[07566]={"𢱺"}
	a[07571]={"徦","箙","𢕧","𢕾","𢖓"}
	a[07572]={"𥰞","𨺣"}
	a[07573]={"搱"}
	a[07574]={"搜","摨","葮","𢲽","𦴎"}
	a[07576]={"𢶚"}
	a[07577]={"葷"}
	a[07581]={"隦","𥲑","𥴄","𨐝","𨺽"}
	a[07582]={"簈","𥰩"}
	a[07583]={"䕧","葭","蒑","薜"}
	a[07584]={"𢯫","𢱲"}
	a[07585]={"𣀸","𦽄"}
	a[07587]={"揮"}
	a[07591]={"䈔","䉰","𥴬"}
	a[07592]={"𨵂"}
	a[07593]={"擗","簲","𢱈","𥴫"}
	a[07595]={"㩔"}
	a[07596]={"𥀹"}
	a[07603]={"𦾕"}
	a[07610]={"𥷷"}
	a[07611]={"閽","𨵽"}
	a[07614]={"𧂢"}
	a[07636]={"鿀"}
	a[07640]={"𡧻"}
	a[07642]={"茩"}
	a[07651]={"循","𢕍"}
	a[07652]={"㧨","哲","𦯰"}
	a[07653]={"萜","𢬷","𦯚"}
	a[07660]={"𢔰"}
	a[07661]={"阍","𡨢","𡨩","𨺠","𨻧"}
	a[07662]={"晢","硩","营"}
	a[07663]={"蒥","𡪒","𢬸","𦱅"}
	a[07664]={"蒏"}
	a[07670]={"𡩏"}
	a[07671]={"𥆛","𥰣"}
	a[07672]={"䀸","葿"}
	a[07673]={"㨨","捪","据","揗","𥶋"}
	a[07680]={"篃"}
	a[07682]={"萺","誓","𢰲","𦺎","𨼑"}
	a[07683]={"𦳜","𦽪"}
	a[07685]={"𥵶"}
	a[07692]={"𢯾"}
	a[07693]={"㨉"}
	a[07695]={"𥶚"}
	a[07700]={"閰","𥵦","𨴏","𨼖"}
	a[07701]={"𨵡"}
	a[07702]={"蕳","闖"}
	a[07703]={"𪃔"}
	a[07704]={"𥷑","𥷽"}
	a[07705]={"㩭","𢵔"}
	a[07706]={"虅"}
	a[07708]={"𨴕"}
	a[07710]={"鷳","𥳑","𨵧","𪇧"}
	a[07711]={"𢓇","𨵠"}
	a[07712]={"䳲","𢹶","𧄷","𪈭"}
	a[07713]={"䴁","𥷝","𪆨"}
	a[07714]={"㩮","蘙","虋","𢺡","𥸎","𧅢"}
	a[07721]={"𨹌"}
	a[07722]={"荝","𦮦","𦺶"}
	a[07723]={"芮"}
	a[07724]={"䒽"}
	a[07730]={"𥫚","𥵲"}
	a[07731]={"笍","𥭊"}
	a[07732]={"𦬪","𨙰"}
	a[07733]={"㧏","劳","抐","苈","𢫭","𦬣","𦭬"}
	a[07734]={"䒟","𠝟","𢓏","𢓒"}
	a[07740]={"㣚","阴","𡧓","𨹽"}
	a[07741]={"𥮫"}
	a[07742]={"㧇","苘","𢫏","𥫼","𦮏","𦮯","𦯶","𦱌","𨸱"}
	a[07743]={"𦭨","𦰊"}
	a[07744]={"苚","𨸨"}
	a[07745]={"苺"}
	a[07746]={"䒣","苒"}
	a[07750]={"㣯","官"}
	a[07751]={"徟","𢔨"}
	a[07752]={"䒿","䧞","抈","捳","掆","苢","茼","莺","菵","𢪜","𢮼","𦭻","𦺄"}
	a[07753]={"䓛","䓨","荕","𢯍","𦸢"}
	a[07754]={"䈀","䔍","拥","笧","𥬕"}
	a[07755]={"拇"}
	a[07756]={"抩","𢪈"}
	a[07758]={"𥬰","𥮚"}
	a[07760]={"寫","筒","衐","衕","𡨅","𥭖"}
	a[07761]={"䧓","筋","𡬮","𥮝"}
	a[07762]={"㧮","挏","篤","萵","蕮","𠟗","𢏨","𢫋","𦯃","𦵱"}
	a[07763]={"䓟","掘","莇","蓐","蔚","藰"}
	a[07764]={"鸷"}
	a[07766]={"𦱲"}
	a[07770]={"䈑","䉣","𨹹"}
	a[07771]={"䉧","筯","𥮐","𥰐","𥳀","𥳩","𨳠"}
	a[07772]={"㨝","挶","萠","葋","蒯","蓇","𢰚","𢰸","𪘔"}
	a[07773]={"㨄","搙","𢭟","𢵁","𢶵","𢷶","𦯟"}
	a[07774]={"繭","𧣯"}
	a[07775]={"蕂"}
	a[07776]={"𩤯"}
	a[07780]={"𥯷"}
	a[07781]={"䢇","𪁛"}
	a[07782]={"䔚","掤","搰","𢰻","𪁊"}
	a[07783]={"𪂛","𪃖"}
	a[07784]={"鶧","𥳫","𪃳"}
	a[07786]={"䔕"}
	a[07790]={"閒","𨴀"}
	a[07792]={"鸏","﨟","𢲰","𦼳","𦿃"}
	a[07794]={"䈻"}
	a[07795]={"𢴡"}
	a[07800]={"籅","𧸹","𨽠","𩓧"}
	a[07802]={"簨","𢸂","𧂟"}
	a[07803]={"擫","藖","𢸯","𢹰"}
	a[07804]={"撰"}
	a[07810]={"𨵙"}
	a[07811]={"䉯","𨷪"}
	a[07812]={"䕟","𢸾","𩕕"}
	a[07813]={"𢸒"}
	a[07815]={"𥷔"}
	a[07822]={"荧"}
	a[07830]={"宾"}
	a[07832]={"烲","𦬨","𦲽"}
	a[07834]={"英"}
	a[07841]={"𥬺"}
	a[07842]={"䇦","択","捠","掀"}
	a[07843]={"𡘭","𢬍","𦯴"}
	a[07844]={"抰","𨹻"}
	a[07846]={"䓦"}
	a[07850]={"𡨋"}
	a[07851]={"𨺺"}
	a[07852]={"𥷅","𦱽"}
	a[07853]={"萸","蕨"}
	a[07854]={"𥮏"}
	a[07856]={"捵"}
	a[07861]={"𡩔","𥯮","𥰽","𥱁"}
	a[07862]={"蓂","踅"}
	a[07863]={"撅"}
	a[07870]={"䈿","賔"}
	a[07872]={"㨠","𡩶"}
	a[07873]={"𢲂"}
	a[07880]={"𥷞","𨴴"}
	a[07881]={"𢖣"}
	a[07882]={"㩫"}
	a[07884]={"蕻","𢵟"}
	a[07891]={"𨽀"}
	a[07892]={"藇","𨽯","𩕱"}
	a[07893]={"擨","𧄖"}
	a[07894]={"𢷧","𦺈"}
	a[07904]={"𢷽","𢹐"}
	a[07913]={"𥸋"}
	a[07915]={"𧅾"}
	a[07932]={"荥"}
	a[07933]={"㧰","䒳","荣"}
	a[07941]={"𨹄"}
	a[07942]={"萦","𢵌","𥮣"}
	a[07943]={"探","梊"}
	a[07944]={"𦼖"}
	a[07950]={"𨻣"}
	a[07951]={"𥬲","𥭰"}
	a[07952]={"䋢","蒝","𢰂","𥱥"}
	a[07953]={"挆"}
	a[07963]={"𧀬"}
	a[07974]={"藤"}
	a[07976]={"𢴟"}
	a[07982]={"籐"}
	a[07984]={"䕨"}
	a[07986]={"𦼶"}
	a[07992]={"籘"}
	a[07994]={"蘗"}
	a[07996]={"𧀳"}
	a[08010]={"穴","闪","队","","𡦼"}
	a[08012]={"䒔","𦫸","𦫻"}
	a[08022]={"扒","扖"}
	a[08031]={"𨜛"}
	a[08041]={"𥦢"}
	a[08044]={"䣐","𨝒"}
	a[08051]={"𥦅"}
	a[08053]={"掷"}
	a[08060]={"閃","閄","𥧫"}
	a[08064]={"𨞂"}
	a[08085]={"𧀿"}
	a[08095]={"擲"}
	a[08100]={"𨵀","𨽭"}
	a[08102]={"閵"}
	a[08103]={"𧂚","𧗘"}
	a[08111]={"𥩔","𨶩"}
	a[08112]={"𢸿","𢺙"}
	a[08114]={"𧃘"}
	a[08116]={"籦","𢺚","𩁮","𩁲"}
	a[08130]={"䆝","空","险","𥤩","𥥊"}
	a[08131]={"䦷","坠","","𡨠","𥤧","𥦊","𨹫"}
	a[08132]={"芢","莅","莶","𦭆","𦮳"}
	a[08133]={"茌","荏","莝"}
	a[08140]={"䆙","签","隘","𥤫","𥥻"}
	a[08141]={"䇮","墜","𥥲","𥦨","𥧧","𥭭"}
	a[08142]={"捡","掽","葐","𢬕","𢬖","𦶩"}
	a[08143]={"拰","挫","荃","菳","𢬝","𥧚","𦯀"}
	a[08150]={"䆠","𡩞","𥥐","𥥷","𥦐","𥦰","𥬚"}
	a[08151]={"窒","筌","鐆","𥦠","𥮃","𥯀"}
	a[08152]={"寉","拦","搤","窐","葅","陮","𡨱","𢭢","𦯣","𦯱","𩀰"}
	a[08153]={"拴","捦"}
	a[08154]={"萑","龿","𦻃"}
	a[08160]={"䆸","𥥣","𥦪","𥨰"}
	a[08161]={"𨻹"}
	a[08162]={"窪","𥨁","𥨻","𥯄"}
	a[08163]={"𢭉","𩀆"}
	a[08164]={"推","蒫"}
	a[08170]={"𥦯","𥦳","𥧍","𥧘","𥲥","𨽙"}
	a[08171]={"𥧊","𥨠"}
	a[08172]={"𥨕","𥰭","𦿘"}
	a[08173]={"窿"}
	a[08174]={"搓"}
	a[08175]={"薙"}
	a[08180]={"䆾"}
	a[08181]={"䦟",""}
	a[08182]={"𢴈","𥧬"}
	a[08183]={"䆹","䉜","䔘","𢵦"}
	a[08185]={"𧆀"}
	a[08190]={"䆰","𥩌","𨴃","𨶂","𩐌"}
	a[08191]={"䦦"}
	a[08193]={"𩰔"}
	a[08194]={"𥨮"}
	a[08210]={"㝏","阶"}
	a[08212]={"芥","𦭏"}
	a[08220]={"穸","𥨡"}
	a[08222]={"扴","抮","芩","𦮬"}
	a[08223]={"蓚"}
	a[08230]={"彮","窌","笒","𢓓","𢔱"}
	a[08231]={"𢓷","𥱤"}
	a[08232]={"扲","𦯒","𦰿"}
	a[08233]={"𢯋"}
	a[08240]={"䆗","宱","窄","阼"}
	a[08242]={"苲","莋"}
	a[08250]={"笮","筰","𥧯"}
	a[08251]={"御","𢕜"}
	a[08252]={"拃"}
	a[08260]={"䦏","𥥹","𥮡"}
	a[08265]={"蕲"}
	a[08270]={"𥥺"}
	a[08271]={"窷"}
	a[08280]={"𩈁"}
	a[08290]={"𨴰"}
	a[08302]={"𨶲"}
	a[08310]={"彸","彾","𥥁"}
	a[08312]={"𦬙","𦮕"}
	a[08320]={"㝐","䆥","䇚","慫","窆","窊","阾","隊","𡩙","𥤲","𥥋","𥥬","𨼾","𨽎"}
	a[08321]={"𢚐"}
	a[08322]={"扵","苓","𢪗","𦬘","𦮩","𦰐","𦲤"}
	a[08330]={"䆳","䇗","䧔","窓","窳","笭","𥥴","𥦫","𥧁"}
	a[08331]={"䆖","窸","𢡣","𥮴"}
	a[08332]={"䆫","䓗","拎","菍","𢪌","𥥑"}
	a[08334]={"㣳"}
	a[08340]={"𥦗","𥮘","𥮨"}
	a[08341]={"窯"}
	a[08342]={"捴","捻","荟","𢚅","𢬜","𢮈","𥥢","𧉴"}
	a[08343]={"蓔","𥦾"}
	a[08344]={"𨼊"}
	a[08346]={"蕪"}
	a[08350]={"䆡","䆣","陰","𥥈","𥧉","𥧛","𥨞","𥭉","𩞐"}
	a[08351]={"窻","𥧳","𥴏"}
	a[08352]={"䆶","䓹","搃","搇","𥦛","𨸋"}
	a[08354]={"䉑","蕉"}
	a[08356]={"撫"}
	a[08357]={"隒"}
	a[08359]={"蒹"}
	a[08360]={"篒","隂","𥦷","𨳢"}
	a[08361]={"䆽","𥧰","𥨽"}
	a[08362]={"𢶕","𥧟","𥨭"}
	a[08363]={"藵","𢶎"}
	a[08364]={"撨"}
	a[08367]={"䈴"}
	a[08369]={"搛"}
	a[08370]={"䆼","䈘","閝","𨳗","𨴧"}
	a[08372]={"𢰩"}
	a[08376]={"𧁋","𧁓"}
	a[08380]={"𢡙","𥴺","𨴮"}
	a[08381]={"𩝓"}
	a[08382]={"𢶴"}
	a[08383]={"𩸻"}
	a[08384]={"𥵴"}
	a[08391]={"𨴿","𨶅","𩝩"}
	a[08392]={"𥨀","𥶑"}
	a[08394]={"攁","𨶭"}
	a[08400]={"𥨪","𥨫"}
	a[08401]={"𧡧"}
	a[08402]={"籤"}
	a[08404]={"攕","𥷜"}
	a[08406]={"竁"}
	a[08410]={"竉"}
	a[08411]={"竈","𥨬","𥩋"}
	a[08412]={"𢺮"}
	a[08413]={"𪚨","𪛔"}
	a[08414]={"𢹖"}
	a[08416]={"𡬎","𥩊"}
	a[08420]={"㣞"}
	a[08421]={"𡧜","𥥇"}
	a[08422]={"阀","𥥰","𦬳","𦲮"}
	a[08423]={"䒫","花","芲","𦬴"}
	a[08424]={"茷"}
	a[08430]={"䆓","穵","窕","𥤤","𥥕"}
	a[08431]={"究","笩","𥤥","𥤷"}
	a[08432]={"䆒","抡","窚","筏","苍","𢬁","𥤭","𦮀"}
	a[08433]={"蒊","𢪎","𦬖"}
	a[08434]={"𢫌","𦭟"}
	a[08440]={"阅","阣","𥤶","𥤸","𥤻","𥥱","𥦒","𨹪"}
	a[08441]={"𢔫","𥥅","𥦥","𥦱","𥦻"}
	a[08442]={"䒗","䓲","抢","挩","窀","窛","芞","莌","陁","𣯨","𥥧","𦯲"}
	a[08443]={"𥥗"}
	a[08444]={"𦭥"}
	a[08450]={"㼻","䆞","窇","𥥟","𥥠","𥧕","𨸛"}
	a[08451]={"䆛","𥦙","𥦲","𥧔"}
	a[08452]={"㗡","㧉","扢","捝","窢","窥","𢔞","𢮾"}
	a[08454]={"拖"}
	a[08460]={"𥦀","𥨥","𥰖","𦫪"}
	a[08461]={"𥦣"}
	a[08462]={"𥱑"}
	a[08463]={"𢮲","𦾺"}
	a[08464]={"𥦩"}
	a[08465]={"䧧"}
	a[08467]={"䕏","𧂂"}
	a[08470]={"㼸","窤","竄","𥨟"}
	a[08472]={"閥"}
	a[08474]={"篯","𣯈"}
	a[08475]={"䉝","籛"}
	a[08477]={"㩘"}
	a[08480]={"閱"}
	a[08481]={"𡪽","𥨖"}
	a[08482]={"窺","𢖝"}
	a[08483]={"𥧢"}
	a[08484]={"𥨔"}
	a[08485]={"䆴"}
	a[08486]={"𢸤"}
	a[08490]={"䦍","竀","閲","𥳸"}
	a[08491]={"𥨾"}
	a[08492]={"𥨼"}
	a[08493]={"𢵅"}
	a[08494]={"𣩾","𧃖"}
	a[08496]={"竃"}
	a[08501]={"𣫢"}
	a[08504]={"𨵸"}
	a[08506]={"䇀","𥨳"}
	a[08510]={"𧃑"}
	a[08512]={"𥤹"}
	a[08513]={"𧅄","𨶔","𪛒"}
	a[08515]={"䉶","𢹺"}
	a[08516]={"𥸌"}
	a[08517]={"㩳","","𧄐"}
	a[08521]={"帘","窔","","𥤦"}
	a[08522]={"𥤨","𥤰"}
	a[08523]={"莜","𦬯","𦭛","𦮫","𦶎"}
	a[08531]={"窣","筱","𥤱","𥨝"}
	a[08532]={"㣢","㹐","䆔","徉","窂","窲","𥤴","𥥏","𥥛","𥥜","𥦑","𥧇","𨹗"}
	a[08533]={"䆧","窭","葰","𢪛","𢫹","𦰞","𦲴"}
	a[08534]={"穽","茽","荓","𦯳"}
	a[08535]={"䔀","𦲱"}
	a[08541]={"䈗","𢕈","𥦖"}
	a[08542]={"䆘","䈂","筗","𢔿","𥤿","𥥞","𥥤","𥥵","𥨅","𥭪","𥭸"}
	a[08543]={"蔹","𦵦","𦹿"}
	a[08544]={"䔑","拼","蓌","𣁙","𥥥","𦭵","𦯔"}
	a[08545]={"𦭽"}
	a[08551]={"復","聳","𢽦","𥥯","𥦄","𥦵"}
	a[08552]={"𥥫","𥥶","𥦍","𥦭","𥧋","𥧞","𥬴"}
	a[08553]={"阐","𥦌","𥧿","𥨺"}
	a[08554]={"挮","窜","窡","葊","𢮡","𨸇"}
	a[08555]={"葁"}
	a[08556]={"𦳄"}
	a[08561]={"㲁","䧗","寑","窧","𥦞","𥦦","𥦸","𥨂","𥨇","𥨍","𥨢"}
	a[08562]={"𡪵","𥦡","𥨒","𥲼"}
	a[08563]={"箪","葠","𥦆","𥨆","𥨓"}
	a[08564]={"揜","箯","𥨦","𥩂"}
	a[08565]={"掸","蒦"}
	a[08566]={"䆯"}
	a[08571]={"䆮","䈜","竅","𥧜","𥧭","𥧲","𥨃","𥨄","𥨈"}
	a[08572]={"䆻","𡪢","𤛝"}
	a[08573]={"篗","蘞"}
	a[08574]={"𦺭"}
	a[08575]={"㔼","㨦","𢲜"}
	a[08576]={"𢳺"}
	a[08578]={"窶"}
	a[08581]={"籢","𥨊","𥨿","𨳰"}
	a[08582]={"䦕"}
	a[08583]={"䇁","𢷩","𥧖","𥨎"}
	a[08584]={"𥀥","𥨗"}
	a[08586]={"䆭"}
	a[08592]={"𥨶","𨴞"}
	a[08594]={"𢵂","𥩎","𥩑"}
	a[08595]={"𢸕","𢸽"}
	a[08606]={"𧂤"}
	a[08610]={"𨶆"}
	a[08614]={"𧄔"}
	a[08620]={"𢓾"}
	a[08622]={"㣡"}
	a[08630]={"㣛","䧍","容","𨸮"}
	a[08640]={"㝓","䆟","","𡧼","𥥔"}
	a[08641]={"㝛","窗","𢔊","𥥖","𥦬"}
	a[08642]={"荅","莟","𥥉","𦯉","𦯐","𦰒"}
	a[08650]={"宿","窅","答","筨","𥦇","𧯉"}
	a[08651]={"窖","𥥭","𥦿","𥧦"}
	a[08652]={"䆺","拾","蓓","𢵄"}
	a[08653]={"䓡"}
	a[08660]={"䆵","徻","窨","𡪠"}
	a[08661]={"𥧝","𥧥","𥧸","𥮷"}
	a[08662]={"蒼","𡩤","𥧏","𥧠","𥧶","𦴩","𦼏","𨺧"}
	a[08663]={"捨","窘"}
	a[08664]={"𦳷"}
	a[08665]={"𦴨"}
	a[08670]={"䉕","篬","𥴔"}
	a[08672]={"搶","摿","薈","𢰈","𢰢","𢴣"}
	a[08673]={"𦸥"}
	a[08674]={"揂","𠿡"}
	a[08680]={"𥨉","𥵊"}
	a[08681]={"窹","𥧺"}
	a[08682]={"𢶒","𧀻"}
	a[08684]={"𢵈","𦾔"}
	a[08690]={"竆","閤","𨵁"}
	a[08691]={"𥨌"}
	a[08692]={"𨢛"}
	a[08694]={"撯"}
	a[08700]={"𥨵","𨵦","𨶨"}
	a[08702]={"𢸄","𥩏","𨸎"}
	a[08703]={"𥩄"}
	a[08704]={"蘥","𧆇"}
	a[08710]={"闟"}
	a[08712]={"籥","𨷲","𩰙"}
	a[08715]={"𧅘","𪇡"}
	a[08720]={"䆑","𡧋","𥤣","𥤽","𥥄","𥥒","𥦋","𧗞","𧗟"}
	a[08721]={"穷","附","𡧛","𡨙","𥦉"}
	a[08722]={"芬","苮","𦬉","𦮪"}
	a[08723]={"苻","𠝐"}
	a[08727]={"䕥"}
	a[08730]={"衑","𢔍","𥥎","𥬍"}
	a[08731]={"穻","穿","窉","窋","符","𠞀","𠞾","𥤪","𥦘","𥦧"}
	a[08732]={"㣥","扮","芿","𢪅","𥤺","𥥚","𥥳"}
	a[08733]={"拊","𦭿"}
	a[08740]={"䈩","穹","窎","𢔢","𥤵","𥥃","𥥆","𥥩","𥧂","𧗺"}
	a[08741]={"窃","窈","窏","窑","窝","窰","𡧰","𥥙","𥦂"}
	a[08742]={"䔢","剳","荷","陯","𢪆","𥥝","𦻏"}
	a[08743]={"𢭧"}
	a[08744]={"菕","𦱎"}
	a[08745]={"𥷄"}
	a[08749]={"𥥼"}
	a[08750]={"䆚","劄","窍","窬","箚","隃","𡩗"}
	a[08751]={"䆜","䆤","䘖","窟","銜","𠟶","𥦹","𥧃"}
	a[08752]={"䈁","萮","葥","𢬲","𥦁","𥧓","𦸄"}
	a[08753]={"䔙","蓨"}
	a[08754]={"掄","窙","𢯌"}
	a[08755]={"莓"}
	a[08757]={"𢺣"}
	a[08760]={"䆷","䳷","窞","窩","窵","箭","鴪","𡩥","𥥾","𥦮","𥧈","𥧹","𥨙","𥨚","𥴝"}
	a[08761]={"竊","衔","衘","𠢡","𥧮","𥰧","𥲟","𥳾"}
	a[08762]={"掵","揃","揄","蓊","𥧗"}
	a[08763]={"蒴","𢕰","𥧆","𥧼"}
	a[08764]={"擒"}
	a[08765]={"劐","挴","𥧀","𥧻","𦸲"}
	a[08767]={"𦺉"}
	a[08770]={"䈵","衜","𠠖","𥥨","𥦜","𥨐","𥲫","𥵌","𨳚","𨻔"}
	a[08771]={"籂","鶟","𥩈"}
	a[08772]={"㝦","㨣","㨵","𢰖","𢳔","𢶠","𥨲","𦷛","𦾝","𧂆","𩰏"}
	a[08773]={"搠","𦺗","𦽋"}
	a[08774]={"蒨","𢲡","𧅇"}
	a[08775]={"䔿"}
	a[08778]={"𥧒"}
	a[08780]={"窮","鵼","𥨷","𨳣","𪃾"}
	a[08781]={"𥳕","𥴴"}
	a[08782]={"寯","摥","篟","𥨛","𥨣","𥩅"}
	a[08783]={"鷋","𥳰"}
	a[08784]={"携","𥵋","𦼱","𦿈"}
	a[08785]={"撙","𨷬"}
	a[08787]={"𥧱"}
	a[08790]={"𨵅"}
	a[08792]={"㩉","𥷏"}
	a[08793]={"𥨸","𥩓","𧂗"}
	a[08794]={"㩦","擕","舊","𢸼"}
	a[08796]={"𢷨","𥨱"}
	a[08800]={"𢓅"}
	a[08801]={"𥩐"}
	a[08802]={"𨶕"}
	a[08810]={"䆦","從","熧","𢕇","𥩆","𨹈","𨹊","𩕤"}
	a[08812]={"籲","苁","𥸤","𩕹"}
	a[08813]={"𨶏"}
	a[08820]={"䆱","従","𤎩","𥤯","𥤳","𥥀","𥥿","𥬈"}
	a[08821]={"穾","突","𥤮","𥥍","𥥦"}
	a[08822]={"𤞮"}
	a[08823]={"茯","𦹬"}
	a[08831]={"𡧦"}
	a[08832]={"㧿","䆕","𥥂","𥥌","𥥡"}
	a[08833]={"䒨","𢫯"}
	a[08841]={"窽","笶","阙","𥦔","𥦕","𥦺"}
	a[08842]={"窦","𥨩","𥮯","𨹩"}
	a[08843]={"𢬈"}
	a[08844]={"𥦟"}
	a[08850]={"𥦎","𥦴","𥧅","𥧾","𥱣"}
	a[08851]={"𥦏","𥧤","𥨤","𨼌"}
	a[08852]={"𢭀","𨽂"}
	a[08853]={"葔","𢰇","𢲑"}
	a[08854]={"䆢","䓺","𦿍"}
	a[08860]={"閦","險","𡪴","𥦽","𥧑","𨴟"}
	a[08861]={"䆨","䆩","窾","篌","𤡿","𥱌"}
	a[08862]={"薟","𢰑","𢶨","𥰉","𥵜"}
	a[08863]={"撳","𢰡","𥨴","𨸊"}
	a[08864]={"窫","𢷏","𤍐"}
	a[08865]={"蒛","𦾲"}
	a[08870]={"䆬","簽","𥧡","𥧨","𥱷"}
	a[08871]={"窴"}
	a[08872]={"䕘","撿","蘝","𡫬","𢶖","𥩁"}
	a[08873]={"揿"}
	a[08874]={"𥩒"}
	a[08875]={"𣤨","𦽈"}
	a[08880]={"籨","𥳹","𥵝","𩔜"}
	a[08881]={"関","𥵎","𨴊"}
	a[08883]={"𥳢","𦽀"}
	a[08891]={"竇","闕"}
	a[08892]={"𧂃"}
	a[08895]={"𢹢"}
	a[08903]={"𥩃"}
	a[08912]={"苶"}
	a[08920]={"䇣","𥤼","𨹉"}
	a[08921]={"徐","穼","𥥪","𥦓"}
	a[08922]={"𦬼","𦮭"}
	a[08923]={"茠","茶"}
	a[08930]={"𥥓","𥥮"}
	a[08931]={"梥","除","𥥸","𥥽"}
	a[08932]={"窱","𡩢","𥥘","𥦝","𦯬"}
	a[08933]={"棻","荼","𢫩","𥧣"}
	a[08934]={"蓧"}
	a[08940]={"𣘏"}
	a[08941]={"㮤","筡","𥦃","𥨹"}
	a[08942]={"篠"}
	a[08943]={"捈","葆","𥦈","𥧽","𥨑","𦺰"}
	a[08950]={"𥧴"}
	a[08951]={"竂","𣘿","𥦼"}
	a[08952]={"𥧌"}
	a[08953]={"㨐","窠","窼","𥧵"}
	a[08954]={"𥦤","𥧙","𧀸"}
	a[08962]={"𩰐"}
	a[08963]={"𥧷","𦽝"}
	a[08964]={"䆲"}
	a[08965]={"𦺴"}
	a[08971]={"禦"}
	a[08973]={"㨾","𦆫"}
	a[08975]={"𥨘","𦾴"}
	a[08978]={"𢸮"}
	a[08980]={"𨵺"}
	a[08981]={"䆿","𨴩"}
	a[08985]={"蘩"}
	a[08991]={"籙"}
	a[08994]={"𥩀"}
	a[08995]={"㩯"}
	a[08996]={"𧄡"}
	a[09012]={"䒕"}
	a[09060]={"𨳒"}
	a[09061]={"𨝔"}
	a[09072]={"𨟃"}
	a[09105]={"𧅛"}
	a[09110]={"闓","𨷐"}
	a[09111]={"闛"}
	a[09132]={"𦮝"}
	a[09140]={"𡩃"}
	a[09141]={"𢔎"}
	a[09142]={"𢓸","𦵕"}
	a[09152]={"揯","𢕘"}
	a[09160]={"隑"}
	a[09161]={"隚"}
	a[09162]={"䔇","𨻵"}
	a[09163]={"𧁆"}
	a[09164]={"𢳖","𦸏"}
	a[09172]={"㝭","㨟","搄"}
	a[09173]={"摚"}
	a[09174]={"摧"}
	a[09212]={"䒚"}
	a[09220]={"𡨝","𥬃"}
	a[09222]={"抄"}
	a[09242]={"𢭞"}
	a[09244]={"𦶘"}
	a[09250]={"𥳦"}
	a[09252]={"𦼢"}
	a[09261]={"𨼺"}
	a[09320]={"䧙"}
	a[09321]={"𢝱"}
	a[09322]={"𢪍"}
	a[09332]={"𦮚"}
	a[09350]={"𥰌"}
	a[09352]={"蘹"}
	a[09354]={"𧂒"}
	a[09360]={"𢛩"}
	a[09363]={"䧝"}
	a[09365]={"𧄝"}
	a[09373]={"㩄"}
	a[09374]={"𧅃"}
	a[09375]={"𢱟","𧆊"}
	a[09384]={"𧅗"}
	a[09392]={"𥸈"}
	a[09394]={"攩"}
	a[09401]={"𧢒","𧢓"}
	a[09402]={"闂"}
	a[09403]={"𥷖"}
	a[09410]={"𢓥"}
	a[09414]={"虌"}
	a[09430]={"𥭂","𨹂"}
	a[09432]={"茪"}
	a[09441]={"𥱞"}
	a[09442]={"挄","𢔑","𢖌","𦺺"}
	a[09443]={"𦽓"}
	a[09444]={"毮"}
	a[09450]={"闿",""}
	a[09452]={"䒻","搅","𨹵"}
	a[09453]={"𢶇","𣮸"}
	a[09454]={"菤"}
	a[09462]={"箞"}
	a[09464]={"捲"}
	a[09470]={"𨽰"}
	a[09476]={"𢷿"}
	a[09482]={"撹"}
	a[09509]={"𢸏"}
	a[09521]={"叜",""}
	a[09522]={"徶"}
	a[09531]={""}
	a[09532]={"𢻟"}
	a[09534]={"蔽","𢬰","𦷥"}
	a[09535]={"蒌"}
	a[09541]={"𢕄","𨻎"}
	a[09542]={"幑","𢾐","𥳆","𨽃"}
	a[09543]={"篓"}
	a[09544]={"拌","撇","蕿","𦽗"}
	a[09545]={"搂","𢅷"}
	a[09546]={"薮","𦿔"}
	a[09551]={"㣲","微","徽"}
	a[09552]={"徴","𥶒"}
	a[09553]={"隣","𢖄","𢭍","𦵨"}
	a[09554]={"䉤"}
	a[09555]={"𢯭","𦺸","𧃮"}
	a[09556]={"擞"}
	a[09561]={"𥰙"}
	a[09562]={"㝮","徵"}
	a[09563]={"蔊","𢮹","𥳞","𦻐"}
	a[09564]={"䔴","𦽠","𦿎"}
	a[09565]={"撛","𡫾"}
	a[09571]={"徾"}
	a[09572]={"鰴"}
	a[09573]={"黴"}
	a[09576]={"𢹄"}
	a[09577]={"𢷎"}
	a[09582]={"𨴔"}
	a[09583]={"𢹒"}
	a[09594]={"𧀼"}
	a[09600]={"𨵥"}
	a[09611]={"闣"}
	a[09630]={"𡨐"}
	a[09642]={"𦲀"}
	a[09643]={"𦳇"}
	a[09650]={"𡨽"}
	a[09651]={"𥯚"}
	a[09652]={"𦳗","𦴔"}
	a[09654]={"䕰"}
	a[09660]={"箵","𡪟"}
	a[09661]={"𡩺"}
	a[09662]={"㨘"}
	a[09663]={"𥴅","𦱗"}
	a[09664]={"𢰪"}
	a[09672]={"攚","𢹙"}
	a[09673]={"𦼲"}
	a[09681]={"簹"}
	a[09683]={"擋"}
	a[09692]={"𡬆"}
	a[09704]={"攜","𢹂"}
	a[09712]={"𦵹"}
	a[09720]={"𥰨"}
	a[09721]={"𠝬","𡨎"}
	a[09722]={"䓎","𡷺","𦭣"}
	a[09723]={"𦬏"}
	a[09730]={"徜","𢓮","𥭓","𧗣"}
	a[09731]={"𡧚","𡧨","𧗰","𧗱"}
	a[09732]={"𢩳"}
	a[09733]={"挘","茁","𦳼","𦶚","𦺜"}
	a[09740]={"宵","陗"}
	a[09741]={"笜","簩"}
	a[09742]={"莦","萷","𦰱","𦵓"}
	a[09743]={"拙","撈"}
	a[09745]={"𦿝"}
	a[09750]={"筜","筲","箾","篅","𢕅","𧗼"}
	a[09752]={"挡","捎","揣","隲","𢮐","𢳐","𦵾"}
	a[09755]={"𢮙"}
	a[09756]={"𦱞"}
	a[09760]={"䘗","𧗬"}
	a[09761]={"𧗲"}
	a[09762]={"𢱣","𢳕"}
	a[09764]={"𢳳","𦸹","𦺡"}
	a[09766]={"搼","𢯈"}
	a[09770]={"閊"}
	a[09772]={"𥳶"}
	a[09773]={"撐"}
	a[09774]={"撑","𢶮"}
	a[09780]={"𢖅","𨻱"}
	a[09785]={"𦾿"}
	a[09794]={"㩗"}
	a[09810]={"灾","阦","𡨼"}
	a[09812]={"苂","菼","𦼐"}
	a[09822]={"掞","藀","𢫐","𢴵","𤆎","𦭗"}
	a[09831]={"䈐"}
	a[09842]={"筷","𥰲"}
	a[09843]={"㨏"}
	a[09850]={"𨻈"}
	a[09853]={"𢮶"}
	a[09860]={"焛"}
	a[09862]={"薠","𢱡"}
	a[09870]={"𥷡"}
	a[09872]={"𢶃"}
	a[09879]={"𢷥"}
	a[09884]={"蘱","𧀘"}
	a[09886]={"𢹔"}
	a[09912]={"𦭅"}
	a[09921]={"宩"}
	a[09923]={"𦵒"}
	a[09931]={"𥭁","𥰂"}
	a[09933]={"𢪹","𢬊","𦾵"}
	a[09940]={"隙","𨻶"}
	a[09943]={"㩞","𢫂"}
	a[09951]={"𨻍"}
	a[09953]={"𦼕"}
	a[09960]={"𨵼"}
	a[09961]={"䉎"}
	a[09963]={"𢴤"}
	a[10000]={"𨝶"}
	a[10001]={"鄠"}
	a[10002]={"䣟","𦗒"}
	a[10003]={"𣩼"}
	a[10010]={"一","磵","礀","𣩞","𨞵"}
	a[10011]={"酃","𤩬","𨟥","𨟪","𨟯","𩅇"}
	a[10012]={"酈","霩","𥗮","𦘍","𨟕","𨣇","𨣉","𨤄","𨶄"}
	a[10013]={"䃹","𨟢"}
	a[10014]={"瓓","𨟫"}
	a[10015]={"𥗺"}
	a[10016]={"𧖔"}
	a[10020]={"邒","𨛤"}
	a[10021]={"邓","𨙳"}
	a[10030]={"邛","邳","𨚌"}
	a[10031]={"邗","邘","邪","邴","𨜄"}
	a[10032]={"邢"}
	a[10040]={"䂙","䢵","䣆","邧","邵","郦","𨙬","𨙱","𨚏","𨚑","𨚣","𨚩","𨚱","𨛔"}
	a[10041]={"鄈","𤘊","𨙺","𨚨","𨜙"}
	a[10042]={"那"}
	a[10050]={"䣁","邶","邷","郖","鄝","𨚎","��","𨛑"}
	a[10051]={"耶","郅","郔",""}
	a[10052]={"𣨳","𨚾","𨛠","𨜦"}
	a[10053]={"𨛓","𨜼"}
	a[10054]={"郠"}
	a[10060]={"䣓","鄑","鄢","鄧","𨜃","𨜧"}
	a[10061]={"郚","𨛄","𨜏"}
	a[10062]={"琊","郰","鄹","𤥸","𨜥","𨝓","𨟰"}
	a[10063]={"郡","鄄"}
	a[10070]={"鄁","𨛃","𨝆"}
	a[10071]={"𤧢"}
	a[10072]={"𤧡","𨜈"}
	a[10073]={"𨝮"}
	a[10074]={""}
	a[10080]={"𤌎","𨳌","𨳏"}
	a[10081]={"瑯","鄾","𧲃","𨞈","𨞖"}
	a[10082]={"瑘"}
	a[10083]={"𨝸"}
	a[10091]={"鄩","𣩝","𥕖","𨝻","𨟘"}
	a[10092]={"𨞩"}
	a[10095]={"𨞗"}
	a[10100]={"𠁏","𠄾","𩈭"}
	a[10102]={"䣾","霔","𨢠","𩆅"}
	a[10103]={"霍","𨢃"}
	a[10104]={"䝔"}
	a[10106]={"𩃒"}
	a[10110]={"𡂧"}
	a[10111]={"噩","霯","靈","𡂤","𡔈","𩄅","𩄕","𩄟","𩐄"}
	a[10112]={"礷","𤫊","𨣮","𩄇","𩄌","𩅵","𩆜"}
	a[10113]={"䨟","䨢","霮","靂","靋","𦥏","𩄆","𩄝","𩆄","𩆸","𩇎"}
	a[10114]={"礶","霳","霾","","𢑆","𤫧","𥗪","𥘁"}
	a[10115]={"䨪","瓘","靃"}
	a[10116]={"𩆔"}
	a[10117]={"靊"}
	a[10120]={"丕","二","亚","工","巫","𠀜","𠄞","𠄟","𠄠","𢒄","𢒅"}
	a[10121]={"𠄡","𢀓"}
	a[10130]={"㠪","䀃","三","亙","巠","正","盃","𠀀","𠀝","𠄣","𠄨","𢀑","𣥄","𧖯"}
	a[10131]={"五","坙","玉","玊","王","","","𡉊","𡉤","𡍂","𡿱","𤣩","𨤏"}
	a[10140]={"㱏","互","亖","歪","豆","𠀕","𣥒","𥁁","𧱡"}
	a[10141]={"㿻","垩","盂","至","𡉐","𡉝","𡋻","𤣪","𥁆"}
	a[10142]={"㿼","𠄭","𡊞","𤯔","𤯚","𧟠"}
	a[10144]={"亜"}
	a[10146]={"壐"}
	a[10150]={"䜳","亘","","𠀥","𠄢","𢀚","𣅯","𣥔","𥩠","𧖬"}
	a[10151]={"㘸","坖","𡊵","𤰱","𥁄"}
	a[10152]={"𡉙","𡌯","𥒴","𦤳","𧟬"}
	a[10153]={"垔","𡊹"}
	a[10156]={"璽","𨮪"}
	a[10160]={"亞","硿","𠄮","𠄱"}
	a[10161]={"","𠄹","𡊝","𡎄","𨥴"}
	a[10162]={"硭"}
	a[10163]={"𧟴"}
	a[10170]={"𠄸","𥁶"}
	a[10171]={"聜","𠁆","𡋲","𡌥"}
	a[10173]={"𣄱","𧟪"}
	a[10174]={"䙵","𧟼"}
	a[10180]={"𠄵","𥕅"}
	a[10181]={"堊","雴","𩂳"}
	a[10182]={"䃊"}
	a[10183]={"𣩱"}
	a[10184]={"𧟿"}
	a[10185]={"𤨛"}
	a[10190]={"碹"}
	a[10191]={"䪞","琧","瑄","霊","𩁿","𩃜"}
	a[10192]={"䏄","䨙","畺","霪"}
	a[10193]={"礚","𨣘"}
	a[10194]={"瓂"}
	a[10195]={"醛","霻"}
	a[10201]={"𩃛","𩃞","𩃟","𩃬"}
	a[10203]={"𩃑"}
	a[10210]={"丅","丆","丌","𠀦","𠀰","𢀰"}
	a[10211]={"䨶","霏","霽","𩄼","𩅶","𩆆","𩆹"}
	a[10212]={"𩅎"}
	a[10213]={"𩅰","𩆽","𩇁"}
	a[10217]={"𢑁"}
	a[10220]={"㔿","严","亓","歹","𢀘","𣦶"}
	a[10221]={"𡗤"}
	a[10230]={"𢨥"}
	a[10231]={"𩂋"}
	a[10232]={"襾"}
	a[10242]={"𨠩"}
	a[10250]={"㪽","丣","","𢀞"}
	a[10251]={"𢒣"}
	a[10261]={"奡","𩁺"}
	a[10262]={"𧲍"}
	a[10271]={"𩂇","𩂙"}
	a[10272]={"霁"}
	a[10281]={"䨿","𩂞"}
	a[10282]={"䨛","𥗀"}
	a[10283]={"霦","𩃋"}
	a[10291]={"霠","𩂖"}
	a[10292]={"醡"}
	a[10301]={"䨎","震","霢","𩃚","𩄈","𩸖"}
	a[10302]={"𩄫","𩅔"}
	a[10303]={"䨤","靀","𨣼","𩆝"}
	a[10308]={"𩄡"}
	a[10310]={"㶨","下","豕","","","","𤉄","𧰧"}
	a[10311]={"䨨","䨸","豖","霐","𩄮","𩅣","𩆖","𩆼"}
	a[10312]={"𩅆","𩇀"}
	a[10313]={"䨺"}
	a[10314]={"䨹","蠠","𧒜"}
	a[10315]={"𧓑","𩃘","𩅽","𩆶"}
	a[10316]={"𢤏"}
	a[10317]={"䘉"}
	a[10318]={"𩆌"}
	a[10320]={"忑","","𠫔","𢗫","𧰬"}
	a[10321]={"⻗","忝","𩄂"}
	a[10325]={"𢣭"}
	a[10330]={"云","忈","恧","恶","𢆰","𢖶","𢗏","𢘫","𥘖"}
	a[10331]={"㤁","炁","霗","𢗬","𩂱","𩃯"}
	a[10340]={"𠀾","𧰳"}
	a[10341]={"㤅","丟","忢","𤈅"}
	a[10342]={"覂","𢘑","𢙣","𣨠","𧋠"}
	a[10343]={"𧟧"}
	a[10346]={"𠪕"}
	a[10350]={"㤪","䬩","𢙯","𢡵","𧙑"}
	a[10351]={"𤍱","𤨎"}
	a[10352]={"虿","𤍟","𧈫"}
	a[10353]={"蚕"}
	a[10354]={"悪"}
	a[10357]={"蠒"}
	a[10360]={"㥑","𢚧","𢜊","𢝊","𢞘","𨱥"}
	a[10361]={"硡","𩂢"}
	a[10362]={"𧉗","𧊡","𧋔"}
	a[10363]={"䵡"}
	a[10364]={"䵤"}
	a[10370]={"惡","慐","𠁛"}
	a[10371]={"雫","零","𩂈","𩂡","𩵶"}
	a[10372]={"礞","𢛤","𦕹","𨑇","𩂓"}
	a[10373]={"𣩷"}
	a[10374]={"蟸"}
	a[10375]={"𩅛"}
	a[10380]={"𨱼"}
	a[10381]={"䨚","𡚑","𢟜","𤪪","𩃍","𩅥","𩅧"}
	a[10382]={"𩃭","𩅲"}
	a[10384]={"𤧠","𨣭"}
	a[10385]={"䗞"}
	a[10391]={"䨧","雲","霥","𢡰","𩄖","𩆰"}
	a[10392]={"蝁","𨗒"}
	a[10393]={"𧌙"}
	a[10394]={"䤓"}
	a[10401]={"雹","𩂒","𩂷","𩂸"}
	a[10403]={"電","𩃰"}
	a[10410]={"黿","兀","𢀯","𪓣","𪕢"}
	a[10411]={"䨘","䨳","霓","靇","龗","𤮮","𩂵","𩃓","𩆈","𩇑"}
	a[10412]={"𡬘","𦒨","𩄬","𩆣","𩇊"}
	a[10413]={"𩃾","𩅄","𩅐","𩆷","𩇌","𩇏","𩳧","𩵂"}
	a[10414]={"霵","𡰞","𤮳","𩆙","𩆧","𩆭","𩆱","𪛈"}
	a[10415]={"𩂬","𩃗","𩄀","𩅀","𩅯","𩅱","𪓿"}
	a[10416]={"𨤃"}
	a[10417]={"𩇇","𪚦"}
	a[10420]={"㐉","乤","兀","𠀂","𥘅"}
	a[10421]={"𢍼"}
	a[10422]={"𢦌"}
	a[10430]={"元","死","𠑺","𠘶","𢀒"}
	a[10431]={"无","旡","𠀺","𡯊","𣄭","𦓑"}
	a[10433]={"𩃢"}
	a[10435]={"𩃄"}
	a[10440]={"㐓","乭","瓦","𠀘","𠀢","𢙂","𣨀"}
	a[10441]={"㐏","𠀡"}
	a[10442]={"𠀣","𧟣"}
	a[10450]={"㐙","砣","驼","𠘲","𠙁","𢆺"}
	a[10451]={"𠁈","𦔮"}
	a[10452]={"颪","𩃥","𩖲"}
	a[10460]={"㱧","覔","𢀢","𩑋"}
	a[10461]={"㐚","𠀸"}
	a[10462]={"戛","戞"}
	a[10463]={"𠄲"}
	a[10464]={"𠁘"}
	a[10470]={"碗","𠒞"}
	a[10471]={"琬","𣦂","𣱉"}
	a[10472]={"䴡","酡","𥔾","𧟽","𩂻"}
	a[10473]={"䙴","𠀻","𩂅","𩃔","𩄱","𩆉","𩳮"}
	a[10474]={"礣","𩗏"}
	a[10480]={"豌"}
	a[10481]={"䨔","雿","𠁉"}
	a[10482]={"䨋","䰟","𥗥","𩃐"}
	a[10483]={"䬠"}
	a[10490]={"䩊","𥎣"}
	a[10491]={"䨌","𤭗","𩃱","𩆇"}
	a[10492]={"霃"}
	a[10493]={"雮","鼋","𩂄","𩳝"}
	a[10494]={"䩏"}
	a[10496]={"𨣱"}
	a[10502]={"𩃀"}
	a[10503]={"霆","𧠂","𩄸"}
	a[10504]={"𩂽"}
	a[10505]={"䤊","鞷","𩂼","𩄦"}
	a[10506]={"𩈽"}
	a[10507]={"㻶"}
	a[10509]={"𨣄"}
	a[10511]={"夒","𠀱","𡕿"}
	a[10512]={"䨱","霞","霹","霺","𡕾","𩄊","𩅈","𩅍","𩅓","𩅕","𩅢","𩆓"}
	a[10513]={"孁","聶","𡖃","𣁨"}
	a[10514]={"䨥","䨩","䨵","䨷","霰","𩄺","𩄿","𩅦","𩆀","𩆑","𩆥","𩆵","𩇋"}
	a[10515]={"𠮕","𩆕"}
	a[10516]={"䨣","䨰","彠","𩄛","𩅴","𩆿"}
	a[10517]={"霋","𩇈"}
	a[10518]={"𧠄"}
	a[10519]={"𩄽"}
	a[10521]={"㔻","帀","干","平","","𠦓","𡕢","𢁓"}
	a[10522]={"开"}
	a[10523]={"𧰿"}
	a[10531]={"𢁳","𢂇","𢆓"}
	a[10532]={"耍","","𡚬","𡛎","𤘔","𤘮"}
	a[10533]={"𡛌"}
	a[10535]={"𤬧"}
	a[10541]={"耳","𢀣","𢁴"}
	a[10542]={"㪅","𡛍","𡛵","𢍈"}
	a[10543]={"弄","砹","","𠬷","𡕠","𢍗"}
	a[10544]={"更","要","𧟤","𧟥","𧟨"}
	a[10551]={"𠀼","𥔑","𧱮"}
	a[10552]={"㸴","𢄉","𢙴","𥒇"}
	a[10554]={"嫑"}
	a[10561]={"㱰","夏"}
	a[10562]={"𢍐","𢍦","𥒪","𦕪","𧱯","𩂎"}
	a[10563]={"聂","𣄳","𩅅"}
	a[10564]={"𢄀","𩄐"}
	a[10571]={"憂"}
	a[10572]={"雯","𠭍","𢍮"}
	a[10573]={"覃","𠙚","𢍞","𥎂","𦕵","𨡻","𩁻"}
	a[10574]={"𩀝"}
	a[10581]={"𠮎","𩈞"}
	a[10582]={"䏁","雭"}
	a[10583]={"䨫","覆","𧟱","𧟵","𩂔","𩂦","𩂫","𩃝","𩄧"}
	a[10584]={"𢐖","𩂝"}
	a[10585]={"䨍"}
	a[10588]={"璍"}
	a[10591]={"𣦞"}
	a[10592]={"霚","𩂹","𩃁","𩃃"}
	a[10593]={"覈","霈","霎","𧟹","𩂘","𩕂"}
	a[10594]={"𩃂","𩅤"}
	a[10595]={"𥖪"}
	a[10596]={"瓁","𩅁","𩆨"}
	a[10597]={"𩂕"}
	a[10600]={"𩈲"}
	a[10601]={"䨓","霑","𩂩"}
	a[10602]={"𥗁","𨣏"}
	a[10603]={"𠄿"}
	a[10610]={"𡈧","𤾩","𧭳","𩉖"}
	a[10611]={"霅","霝","霫","𩄉","𩄯","𩄷","𩅟","𩆁","𩇄"}
	a[10612]={"霜","霤","露","霿","𩄙","𩄭","𩅑","𩅗","𩅪","𩅸","𩆎","𩆒","𩆞","𩆮","𩆻","𩉆"}
	a[10613]={"𩄣","𩅨","𩆗"}
	a[10614]={"靁","𩂿","𩄄"}
	a[10615]={"𩅮","𩆘","𩇓"}
	a[10616]={"靐"}
	a[10630]={"䂖","否","石","","𠮛","𠮴"}
	a[10631]={"㐁","𠀬","𠀮"}
	a[10632]={"覀"}
	a[10640]={"㫘","百","𠀯","𠄰","𠳄","𠴅","𢀛","𣄼","𣅆"}
	a[10641]={"吞","","𤰺"}
	a[10642]={"西"}
	a[10650]={"晋","面","靣","𣆇","𥄓","𦣻"}
	a[10651]={"吾","昋","𣄮"}
	a[10652]={"酉","𤰳"}
	a[10653]={"𩂰"}
	a[10654]={"𢆍"}
	a[10661]={"瑢","畐","𣅨","𤘉"}
	a[10662]={"𣆛"}
	a[10663]={"𠰶"}
	a[10670]={"晉","𠁞","𣩐","𧥽","𧨈","𧵔"}
	a[10671]={"碦","𥄪","𥔡","𦗋"}
	a[10672]={"𥔽"}
	a[10673]={"𠺞","𤨑"}
	a[10680]={"䃔"}
	a[10681]={"畱","𤲇","𤾄"}
	a[10682]={"𠵥"}
	a[10683]={"𥎆","𦖿"}
	a[10690]={"磊","𡈯","𣇩","𣈆","𣉩","𣍌"}
	a[10691]={"䨐","雼","𤲢","𦗧"}
	a[10692]={"雷","𩂣","𩂥"}
	a[10693]={"磍"}
	a[10694]={"𥖛"}
	a[10695]={"𨡱"}
	a[10700]={"𠁐","𩈬"}
	a[10701]={"䨒","䨦","𡂦","𩃮","𩃼"}
	a[10702]={"䨖","𩆍"}
	a[10703]={"霧"}
	a[10704]={"䨞","霉"}
	a[10707]={"礴"}
	a[10710]={"丁","","𩖔"}
	a[10711]={"䨜","䨠","霘","霛","霭","霱","霶","霷","靄","𠠢","𩃴","𩃿","𩄘","𩅳"}
	a[10712]={"霌","霨","靎","𦉣","𩂾","𩅒","𩅡","𩆫"}
	a[10713]={"䨝","䨴","靍","𩄤","𩅠","𩆚","𩆤","𩆩","𩇐"}
	a[10714]={"靏","𢑇"}
	a[10716]={"霸","𩅂","𩅿"}
	a[10717]={"䨮","覇","𩆺"}
	a[10718]={"覉"}
	a[10719]={"覊","𩄢"}
	a[10720]={"丂","万","亍","而"}
	a[10721]={"丙","于","兩","牙","雨","","𠀅","𢀝","𦙂"}
	a[10722]={"㸦","两"}
	a[10725]={"爾"}
	a[10730]={"丏","丐","丽","亏","可","戸","𠀒","𢀔","𣃙","𧗩"}
	a[10731]={"両","亐","𠀑","𠙻","𠚇","𡗙","𡗣"}
	a[10732]={"𠀛"}
	a[10740]={"𠚃","𠚈","𡶪","𣍡","𦓔"}
	a[10741]={"𢀪","𤣫","𤣶"}
	a[10742]={"甭","𠕂","𥍰"}
	a[10743]={"孬"}
	a[10744]={"再","𠕅"}
	a[10750]={"㫄","焉","鬲","","𠀹","𠣣","𣃟"}
	a[10751]={"画"}
	a[10752]={"㧭","𠀷","𩂧"}
	a[10753]={"𡥟","𤮻"}
	a[10755]={"𠁅"}
	a[10760]={"哥","𠚑","𠸲","𣅰","𦏺","𩾏"}
	a[10761]={"聍","","𠁌","𠢊","𠢨","𤘈","𦘼"}
	a[10762]={"瑏","𠱩","𣃪","𧟩","𩃤"}
	a[10763]={"𥕾"}
	a[10764]={"𣫱"}
	a[10766]={"𠄙"}
	a[10767]={"𢐶"}
	a[10770]={"䲶","𡹅","𣈇","𥓰","𦝽","𩫇"}
	a[10771]={"雰","鴌","𤘍","𩁷","𩂂","𩃡"}
	a[10772]={"雽","𠢘","𩰬"}
	a[10773]={"酧"}
	a[10774]={"璓","𥓨","𦝫"}
	a[10776]={"𤰊","𧟲"}
	a[10780]={"𦟆","𨴙"}
	a[10781]={"奣","琯","雱","雺","需","𥖚","𧦸"}
	a[10782]={"䨗","雳","𩁹","𩂗","𩃹","𩃻"}
	a[10783]={"雾","𩂤"}
	a[10784]={"𧟳","𧟶"}
	a[10790]={"𠾳","𥖽","𨳔"}
	a[10791]={"䨡","聹","雩","雪","霄","𦗰","𧲗","𩂪","𩃎","𩄋","𩄥"}
	a[10792]={"䨕","礍","𨡗","𩄗","𩆲"}
	a[10793]={"雸","𤩲","𨢧"}
	a[10799]={"𩂨"}
	a[10800]={"𥖶"}
	a[10805]={"𨢢"}
	a[10810]={"㶪","灭","","","𠆣","𩖏"}
	a[10811]={"霣","𤴤","𩅼","𩆃","𩆯"}
	a[10812]={"靌","𤫞","𩃺","𩄚","𩅌","𩅏"}
	a[10813]={"𩃙","𩄾"}
	a[10814]={"霬","𩄪","𩄻"}
	a[10815]={"䨑","𩇒"}
	a[10816]={"𩃖"}
	a[10820]={"䎡","页","","𠀔","𠇬","𤴓"}
	a[10821]={"㶣","㶮","天","奀","𤆱"}
	a[10822]={"烎"}
	a[10830]={"贡","𤇈","𤴕"}
	a[10831]={"兲","耎"}
	a[10832]={"䙳","𩄍"}
	a[10840]={"𠁓","𠔐","𤴖","𥑫","𧾸"}
	a[10841]={"𡘀","𩅉"}
	a[10842]={"㶾","㺯","贾","𤊆","𤧦"}
	a[10843]={"䙲","覄","𣨘"}
	a[10850]={"㱨","殡","趸","頁",""}
	a[10851]={"𤈨"}
	a[10852]={"㻠","𠁍","𤧪"}
	a[10854]={"𥍼"}
	a[10860]={"碇","貢","𤊗","𨀂"}
	a[10861]={"琔","瑸","𧶪"}
	a[10863]={"𡙎"}
	a[10864]={"碤"}
	a[10865]={"瑛"}
	a[10870]={"𧴳","𧵲","𧶏"}
	a[10871]={"𠁒"}
	a[10872]={"殥","賈","𠔬"}
	a[10873]={"𣩎"}
	a[10880]={"殯"}
	a[10881]={"䨏"}
	a[10882]={"𩂉"}
	a[10883]={"璌","雵","𥕓","𩂃"}
	a[10884]={"𧷋"}
	a[10885]={"𧲌"}
	a[10890]={"礗","𧶝"}
	a[10891]={"璸","𩃏"}
	a[10893]={"霟"}
	a[10895]={"霙","𢐛"}
	a[10900]={"𩉐"}
	a[10901]={"𩅃"}
	a[10902]={"𩄜"}
	a[10903]={"𣡷","𩃵"}
	a[10910]={"不","","","𡭕","𣎴"}
	a[10911]={"霡"}
	a[10914]={"𣠞","𥤋"}
	a[10915]={"䨯"}
	a[10920]={"⺬","𠀚","𣱳","𣲮"}
	a[10921]={"","𡗘"}
	a[10930]={"汞","𡭚"}
	a[10931]={"沗","𣑘","𧱍"}
	a[10932]={"𩂯"}
	a[10940]={"䝋","泵","𥾟"}
	a[10941]={"䂞","𣐂","𣸞","𥓜","𥞱"}
	a[10942]={"𣳳"}
	a[10943]={"䅇","栗","粟","𠁃"}
	a[10951]={"孮","𥒬"}
	a[10952]={"票"}
	a[10953]={"𦓩"}
	a[10954]={"𠁋","𤨓"}
	a[10955]={"𢆚","𣑨"}
	a[10960]={"碂","綤"}
	a[10961]={"琮"}
	a[10962]={"𨠊"}
	a[10963]={"𣩣"}
	a[10964]={"瑹","𨡸"}
	a[10971]={"𩂆","𩂍"}
	a[10972]={"雬","𩃲"}
	a[10974]={"𤨷"}
	a[10976]={"𣩨"}
	a[10980]={"䃰"}
	a[10982]={"礤","霂"}
	a[10983]={"霖","𩂴","𩄞"}
	a[10985]={"𨢬"}
	a[10991]={"聺"}
	a[10992]={"𩃕"}
	a[10993]={"䨬","𩅩"}
	a[10994]={"𩂺"}
	a[11012]={"𤩟"}
	a[11100]={"𣩛","𩰵"}
	a[11101]={"𦖕","𦗮"}
	a[11103]={"𦖧"}
	a[11104]={"𨣷"}
	a[11110]={"彄","𥕥","𧰛"}
	a[11111]={"𣍒","𥕑","𥘃","𦗛","𧰁","𧰓"}
	a[11112]={"㱺","彊","殭","礓","醧","𢐸","𤩩","𤫩","𤮵","𥎛","𥗅"}
	a[11113]={"瓐","疆","礭","𤳾","𥗃","𨤍","𨯞"}
	a[11117]={"𨌥"}
	a[11130]={"㐀","𠀌"}
	a[11140]={"","𣥠","𣧐"}
	a[11150]={"殌","矼","砋","","𥐵","𥑜"}
	a[11151]={"㺽","玒","驱","","𥐰"}
	a[11160]={"弳","硜","羾","豇","","𢏉","𥔂","𧱂"}
	a[11161]={"砡","砸","耻","𣨂","𤤃","𥐳","𦔸"}
	a[11162]={"玨","珏","班","雈","𤤴","𨠙"}
	a[11170]={"弡","弫","弬","韭","𢎸","𥑗","𧯬","𧱖"}
	a[11171]={"㺿","㻹","聇","𥒓"}
	a[11172]={"㱹","𡍳","𤤻","𤥇","𤦦","𥒑"}
	a[11173]={"斑","𤥷"}
	a[11176]={"𡓭","𢑃","𥜬"}
	a[11180]={"㠭","臦","𩈡","𩰹"}
	a[11181]={"孲","𡌦","𡏵","𥓟","𥕇","𥕰"}
	a[11182]={"礰","臸","𥍻","𨠸","𨾢"}
	a[11183]={"㢾","䃌","瓑","𤦐","𩧾"}
	a[11184]={"𤧕"}
	a[11186]={"㣆","䥸","瓕"}
	a[11190]={"䃁","𥖋","𩐁"}
	a[11191]={"㻗","𤦅","𤦩","𧇘","𨪱"}
	a[11192]={"䣰","𥔌","𨠂"}
	a[11193]={"䣿","𤦵","𦘊","𨡖","𨨖"}
	a[11194]={"𤪾"}
	a[11202]={"𩇽"}
	a[11210]={"⻀","顨"}
	a[11213]={"𨤌"}
	a[11220]={"卝"}
	a[11240]={"㱛","𠁬","𩇧"}
	a[11250]={"","𥐫","𥒼"}
	a[11251]={"㻉"}
	a[11260]={"戼","非"}
	a[11262]={"𤦠"}
	a[11270]={"𣨇"}
	a[11272]={"琴","酽"}
	a[11281]={"𤥗"}
	a[11290]={""}
	a[11291]={"琲","臩","𦕼"}
	a[11300]={"餥","𢐘","𧝣","𩜕"}
	a[11301]={"𥖟","𩻊"}
	a[11303]={"醵","𧓐"}
	a[11304]={"璱"}
	a[11312]={"𥖼","𩼭"}
	a[11313]={"𧞙","𨣖"}
	a[11314]={"𧓊","𧕜","𧲟","𩇔"}
	a[11316]={"蠶","蠺","𧕿","𧖑"}
	a[11318]={"𧕽"}
	a[11320]={"豩"}
	a[11330]={"𧲏"}
	a[11331]={"𧰪"}
	a[11340]={"𠧥"}
	a[11341]={"硺","𤥨"}
	a[11342]={"琢"}
	a[11350]={"㤍"}
	a[11354]={"𧱝"}
	a[11360]={"𢏁","𢏾","𥐯","𥐺","𥔕"}
	a[11361]={"𤤈","𧲋"}
	a[11362]={"𢜈","𥎔"}
	a[11370]={"悲"}
	a[11371]={"耺","𦕇","𦗂"}
	a[11372]={"𤧂","𧊪"}
	a[11373]={"瑟","𤨝"}
	a[11374]={"蝅"}
	a[11380]={"䂻","張","裴","𣩤","𩇻"}
	a[11381]={"𢣓","𥖅"}
	a[11382]={"璩","酝","𨠀"}
	a[11384]={"𤧆"}
	a[11391]={"𧞕"}
	a[11392]={"蜚","𥗗"}
	a[11393]={"𤩙","𤪴"}
	a[11394]={"𧌩"}
	a[11400]={"翫"}
	a[11401]={"𤭻"}
	a[11402]={"虣","麗","𥖬"}
	a[11404]={"𪋘"}
	a[11405]={"𥕠"}
	a[11410]={"礲","𢐝","𧲖","𨛬","𪓔","𪚗"}
	a[11411]={"䏊","瓏","𤮹","𪓯","𪚒"}
	a[11412]={"㽌","䶬","𤩭","𤫣","𤮔","𤮚","𤮷","𤮸"}
	a[11413]={"𤫟","𤮱","𦘐","𨣙","𨣬"}
	a[11414]={"釃"}
	a[11416]={"䩁"}
	a[11430]={"㒮","豗",""}
	a[11440]={"","𡯝"}
	a[11442]={"兓"}
	a[11450]={"㼗","矹","𤬭"}
	a[11451]={"㒬","尫","𣄰"}
	a[11452]={"𠒓","𤤞"}
	a[11460]={"瓨","瓸","砈","𤭃","𤮁","𥑣","𦓓"}
	a[11461]={"㼞","玩"}
	a[11462]={"㼛","酛","𣩪","𤤍"}
	a[11470]={"㐟","砙","𢏍","𤬮","𤭓"}
	a[11471]={"㼲","珁","𣄹","𥓚"}
	a[11472]={"𢧖"}
	a[11480]={"㼣","𧱠"}
	a[11481]={"𤭎"}
	a[11482]={"㼧","𢧻","𦖖"}
	a[11483]={"甅","𤭾"}
	a[11484]={"麉","𤦖"}
	a[11490]={"㽅","䨽","䰛","𩇯"}
	a[11491]={"䎎","𢏯","𤭑"}
	a[11492]={"㼼","琥","琵","琶","靟","𤧰","𤧲"}
	a[11493]={"甄","𠮔"}
	a[11501]={"𢾲"}
	a[11502]={"㪪","㹕","瓇","𦥍"}
	a[11503]={"㪬","磹"}
	a[11504]={"㻼"}
	a[11511]={"虁","𢿟"}
	a[11512]={"㪮","𡖂","𡡜","𢍳","𤫕","𤫘","𪚟"}
	a[11513]={"䝕","𣀀","𣀷","𤫑"}
	a[11514]={"𦗡"}
	a[11515]={"輩","醰","𣀄","𩍻"}
	a[11517]={"𨣌"}
	a[11532]={"豜","𢽚"}
	a[11541]={"⺸","㢟","𢼗","𣧏","𣧒"}
	a[11542]={"幵","羋","芈","𦍋"}
	a[11546]={"𣀑"}
	a[11551]={"㢨","㢭","㪃","矸","砰","𢌛","𢏊","𢻽","𢾧","𧱰"}
	a[11552]={"㚽","㺰","㺳","婯","玕","玶","研","豣","𤥙"}
	a[11553]={"𤣿"}
	a[11554]={"𡠈","𧱩"}
	a[11561]={"㪖","䜴","𣧹","𦏹"}
	a[11562]={"𤽩","𦔼","𦤺"}
	a[11563]={"㪌","廼","𢽄","𢿚","𤧋","𨠃"}
	a[11564]={"𢆛"}
	a[11565]={"敠","𢾪"}
	a[11567]={"㜷"}
	a[11571]={"弭","斐","𢌧","𢾿","𢿤","𥒔","𥔈","𩇪","𩈅"}
	a[11572]={"婓","珥","硏","𢆖","𢏘","𢽖","𢽪","𢾸","𦖩"}
	a[11573]={"硦","酐","𢾵","𢿏","𣀒","𨠟"}
	a[11574]={"㪊","硬","𢌩","𥔖"}
	a[11575]={"𤧄"}
	a[11581]={"䂽","𢌨","𢼿","𩇱"}
	a[11582]={"㹃","琸","聑","𢾇","𥔮"}
	a[11591]={"𢌫","𥔹"}
	a[11592]={"瑡","𢍴","𤧶"}
	a[11593]={"䣵","䯅","辈"}
	a[11595]={"𢿺"}
	a[11600]={"𢐈","𥇖","𩈳"}
	a[11601]={"璿","𦑞","𩇸"}
	a[11602]={"䤄","𤪻","𤪽","𨡞","𩇼","𩈀"}
	a[11607]={"𨣾"}
	a[11610]={"𢐤","𥗉"}
	a[11611]={"𧲙"}
	a[11612]={"㣅","㬜","㽬","䃡","璢","疈","礌","礵","骦","𠠦","𣩳","𤩾","𥎑"}
	a[11613]={"㻸","醽","𤫢"}
	a[11614]={"䤐"}
	a[11618]={"䨻"}
	a[11651]={"𤘇","𪉝"}
	a[11660]={"砧","砳","𥄕","𦤄"}
	a[11661]={"玷","硵","磠","𤤟"}
	a[11670]={"㢶","𥔨"}
	a[11671]={"𡦌","𣗁","𤤿","𥕝","𦕒"}
	a[11672]={"硒"}
	a[11673]={"𤥒","𦕩"}
	a[11680]={"䩇","皕"}
	a[11681]={"瑨","𤨁","𤩅","𥒾"}
	a[11682]={"珸","酟","𥅝"}
	a[11690]={"䛒"}
	a[11691]={"𢐀","𢐜","𣩚","𥔁","𩇵","𩧿"}
	a[11692]={"䎸","朁","𢐡","𥕉"}
	a[11693]={"𨠧"}
	a[11694]={"𠁖"}
	a[11700]={"磭","翡","𩱇"}
	a[11701]={"𥎘"}
	a[11702]={"孺","𨢌","𨴚"}
	a[11703]={"𤫄"}
	a[11705]={"礪"}
	a[11706]={"𤪲"}
	a[11710]={"𢐓","𪂏"}
	a[11711]={"礝"}
	a[11712]={"㻬","瓀","鬵","𢑋","𦠮","𪂫"}
	a[11713]={"醹","𠣃","𤨹"}
	a[11714]={"䤏","𤫗"}
	a[11716]={"䃻"}
	a[11717]={"𤫦","𩧕"}
	a[11720]={"𧰩"}
	a[11731]={"𢆊"}
	a[11740]={"㱙","巧","矴","𠀙","𠀩","𡵽"}
	a[11741]={"玎","𡥢","𣦿","𣧰"}
	a[11742]={"𢃻","𤘆"}
	a[11745]={"𥎖","𦒤"}
	a[11750]={"茍","𠙿","𣧁","𣧤","𥐡"}
	a[11751]={"弙","珩","砑","耵","𤤾","𤦷"}
	a[11752]={"玗","玡","𤤝"}
	a[11755]={"彌"}
	a[11756]={"𤪙"}
	a[11760]={"㢪","砢","砺","骊","𧯫","𨳇"}
	a[11761]={"㺮","玙","珂","聏","","𡦘","𢎰","𥒀","𦔲"}
	a[11762]={"酊","𠄥","𡭃","𤰈","𦕆"}
	a[11763]={"𢬫","𩡵"}
	a[11770]={"𣩙","𥒿","𥓠","𥕷","𥗊","𩇴","𩰴"}
	a[11771]={"𢐰","𤪷"}
	a[11772]={"碼","𢏗","𦓠"}
	a[11773]={"瑪","酑"}
	a[11774]={"揅"}
	a[11775]={"𤥆"}
	a[11777]={"𦘎"}
	a[11780]={"㣂","䃒","","𧱽","𩈔"}
	a[11781]={"𤩋","𤩡","𩇫"}
	a[11782]={"酠","酾","𡭋","𥕕","𨟺","𩇮","𩢳"}
	a[11783]={"㻯"}
	a[11784]={"𤨇"}
	a[11785]={"𤩁"}
	a[11790]={"䲾","彁","𥊄","𦒃","𩈎"}
	a[11791]={"𦖂"}
	a[11792]={"𨢾","𩤤"}
	a[11794]={"𤨍"}
	a[11800]={"䩀","𧶻","𩒢","𩓑","𩔁","𩔊"}
	a[11801]={"颥","𩒸","𩒾","𩔞"}
	a[11802]={"顠"}
	a[11803]={"頵","𩔘","𩔛"}
	a[11810]={"䫍","𥊾","𩓩","𩕧"}
	a[11811]={"䫮","䫷","顬","𣪀","𩕸","𩖈","𩖊"}
	a[11812]={"䫬","𧹁","𨢣","𩅖","𩔮"}
	a[11813]={"顳"}
	a[11814]={"𧷩"}
	a[11820]={"燹"}
	a[11830]={"㱜","顶"}
	a[11831]={"𧱾"}
	a[11840]={"项","预"}
	a[11841]={"顸"}
	a[11842]={"颒"}
	a[11850]={"硕","顽","颈"}
	a[11851]={"顼","𢎾"}
	a[11852]={"𤤇"}
	a[11860]={"䂵","頂","𥓢","𩇭","𩑢"}
	a[11861]={"碝","𤥩","𩑌"}
	a[11862]={"珡","瑌","颋","𦔿"}
	a[11864]={"颡"}
	a[11870]={"䪲","䪹","項","預","𥎀","𩱊"}
	a[11871]={"䪵","奜","猆","頇","𤐱","𥕲","𩑓","𩑳"}
	a[11872]={"頮","𤦣"}
	a[11880]={"䪱","䫊","燛","碩","碵","頑","頙","頸","顄","𩑠","𩑸","𩒴"}
	a[11881]={"頊","𤦹","𩑕","𩑙","𩑧","𩑬","𩒍","𩒤","𩔆","𩱄"}
	a[11882]={"頚","𧵭"}
	a[11883]={"䪳","颞"}
	a[11884]={"𡚌"}
	a[11890]={"䫱","碽","頨","頭","顟","𩒔","𩓪"}
	a[11891]={"𦖦","𩒐","𩒞"}
	a[11892]={"頲","𩒖","𩒼"}
	a[11893]={"𦗩","𨅪"}
	a[11894]={"䫎","顙","𤦡"}
	a[11900]={"𢑽"}
	a[11904]={"醥"}
	a[11906]={"𤩘"}
	a[11940]={"祘","𥐴"}
	a[11941]={"环"}
	a[11950]={"豲",""}
	a[11951]={"𦤹"}
	a[11953]={"栞","𣓁","𣓢"}
	a[11961]={"𦕝"}
	a[11962]={"𣕓","𨟷"}
	a[11963]={"䊙"}
	a[11971]={"棐","𥺟","𦕷"}
	a[11972]={"𤦗","𤩰"}
	a[11973]={"琹","𣗜"}
	a[11974]={"瑮","𤩗"}
	a[11975]={"𢆞"}
	a[11981]={"𥓼"}
	a[11982]={"磦","骠","𢐕","𣝚","𤦲"}
	a[11983]={"𤨧"}
	a[11991]={"㣄","磲"}
	a[11992]={"璖"}
	a[11993]={"䏇","𩇹"}
	a[12020]={"","𢀙"}
	a[12030]={"引","驯","","𥐣","𥒁"}
	a[12031]={"玔","𤥅","𩰊"}
	a[12041]={"㺩"}
	a[12050]={"𢒥"}
	a[12052]={"酬"}
	a[12060]={"𢏄"}
	a[12080]={"𢏮"}
	a[12100]={"𣩶"}
	a[12116]={"𥗦","𩅞"}
	a[12120]={"𣱲"}
	a[12130]={"泴"}
	a[12131]={"卍","坔"}
	a[12140]={"丠","𠀓","𢎞","𣧭","𥁟"}
	a[12143]={"型","𡌑"}
	a[12150]={"䂡","登","𠤢"}
	a[12151]={"㘳","銐","𤤘","𥓕","𥖌"}
	a[12160]={"𥓱"}
	a[12161]={"𡋭","𤧏","𤪩","𦕖","𦕭"}
	a[12162]={"𦔽","𨾸"}
	a[12170]={"𣩟","𥎇"}
	a[12171]={"𣹛","𥕬","𦣮"}
	a[12173]={"𡒐"}
	a[12175]={"硾","𢏴"}
	a[12176]={"㻔"}
	a[12180]={"磴"}
	a[12181]={"璒","𣇇"}
	a[12182]={"𥃄","𦥊","𨡬"}
	a[12184]={"𡏸"}
	a[12185]={"𥍽"}
	a[12186]={"𡥿","𦖋"}
	a[12190]={"𧰐"}
	a[12201]={"聯"}
	a[12202]={"彲"}
	a[12211]={"𢒔"}
	a[12220]={"㣉","耏","𢒁","𣂘"}
	a[12221]={"𣂡"}
	a[12222]={"形"}
	a[12230]={"彨","歽","𣂕","𥍧"}
	a[12232]={"𣂖"}
	a[12240]={"㪼","斫","𢏂","𢒓","𦓘"}
	a[12241]={"㱤","硚","骄","𤤆"}
	a[12250]={"𢎺","𧯞","𩑘"}
	a[12251]={"𦕄"}
	a[12252]={"彯","𣨋","𥍭","𥒱"}
	a[12253]={"㝂"}
	a[12260]={"𣃆"}
	a[12261]={"𢒴"}
	a[12262]={"𣨊","𨠇"}
	a[12270]={"𣂪","𣂱"}
	a[12271]={"㱶"}
	a[12272]={"𣩠"}
	a[12273]={"𦕶"}
	a[12281]={"𥕱"}
	a[12282]={"𥕶"}
	a[12283]={"𤩐"}
	a[12295]={"𥕌"}
	a[12303]={"𢐩"}
	a[12305]={"䗺"}
	a[12306]={"醺"}
	a[12310]={"𢗨"}
	a[12315]={"𩉒"}
	a[12320]={"烈","𠚦","𣲉"}
	a[12322]={"𢝵"}
	a[12323]={"𢞵"}
	a[12330]={"㤠"}
	a[12331]={"孤","𤣺"}
	a[12340]={"弘","弧","砭","裂","𢘠","𥑔","𥒗","𥒩"}
	a[12341]={"㺨","𤣵","𤬉"}
	a[12342]={"𤼭"}
	a[12343]={"𥢝"}
	a[12351]={"张","愻"}
	a[12352]={"𧊿"}
	a[12360]={"𢙰","𥒛","𥕈","𩈕","𩈛"}
	a[12361]={"鮤","𦔷"}
	a[12362]={"瓢","𧉥","𨠋"}
	a[12363]={"𠭺"}
	a[12370]={"𩚾"}
	a[12373]={"蜑"}
	a[12381]={"聮"}
	a[12382]={"𢡲"}
	a[12383]={"𧎕"}
	a[12384]={"𧒈"}
	a[12385]={"𤪠","𧏄"}
	a[12390]={"𥖵"}
	a[12391]={"𢥍"}
	a[12394]={"𧑧"}
	a[12402]={"𣯮"}
	a[12405]={"䤒"}
	a[12410]={"飞","𣴝"}
	a[12412]={"𨡦","𨢂"}
	a[12413]={"𤪫"}
	a[12414]={"㼄","𣰿"}
	a[12415]={"㲲"}
	a[12416]={"𥕹"}
	a[12417]={"𦗨"}
	a[12420]={"礼","𠃞","𠃧","𠚯","𢒇"}
	a[12421]={"𧱓"}
	a[12422]={"飛"}
	a[12430]={"北","氹","𠃖","𠃡","𠫕","𢀗","𣧇","𣱻","𣲯","𤼥","𤼫"}
	a[12431]={"孔","𣱊","𩙱"}
	a[12432]={"発"}
	a[12440]={"䝈","𠤥","𥐕","𥑉"}
	a[12441]={"玌","𣧃","𥦚"}
	a[12442]={"瓱","𡥑"}
	a[12443]={"𡥊"}
	a[12450]={"䂪","𦏳","𦫔","𧱒"}
	a[12451]={"䝓","弤","珧","瓩","瓪","矺","砥","耴","𠤜"}
	a[12452]={"㼃","𣬾","𣭅","𤣯"}
	a[12455]={"𣱌"}
	a[12460]={"䂣","砒","𠤦","𥑽","𦐭","𧱻","𩑍"}
	a[12461]={"玭","玼","聎","𣄺","𣱇","𥎲","𦐊","𦐠","𧯝"}
	a[12462]={"䣥","𣬸","𥐽","𦕑"}
	a[12463]={"𣮪"}
	a[12466]={"飝"}
	a[12470]={"兠","凳","𠙩","𥧐"}
	a[12471]={"䂷","䃳","𩨐","𩰷"}
	a[12472]={"毭","𣰄"}
	a[12473]={"䣴","毦","𤦄","𨟾","𨠏"}
	a[12474]={"醗","𣭲","𤧜"}
	a[12475]={"𣯼"}
	a[12476]={"毲"}
	a[12480]={"㼱","䩃","𣬏","𦒦"}
	a[12482]={"㲪","氄","𢑮","𣮿","𨟵","𨠐"}
	a[12483]={"磯"}
	a[12484]={"璣","酕"}
	a[12485]={"𡰁"}
	a[12491]={"磃","𢐋"}
	a[12492]={"𣯰","𦕿"}
	a[12511]={"𥜹"}
	a[12512]={"靉"}
	a[12513]={"醱"}
	a[12514]={"𨤊"}
	a[12521]={"廵","𢌘","𤼦"}
	a[12531]={"㡂","歼","癷","𠦞","𣧶","𤼧"}
	a[12532]={"㱣","姴","𢌙","𤼪","𧱭"}
	a[12541]={"䂨","延","癹","𤼬"}
	a[12542]={"廷","珳","𠤖","𤣳","𤤐","𥍺"}
	a[12543]={"𢌜","𣨙"}
	a[12551]={"𢂖","𤼲","𥖦"}
	a[12552]={"𤘿","𥀅","𥓻"}
	a[12553]={"㢻","𤤣","𤪀","𤼳","𤼴","𥓔"}
	a[12561]={"𠭼","𡕶","𤼹","𤼼","𥨏"}
	a[12562]={"叆","璦","翪","𤼷","𥔛","𥔺"}
	a[12563]={"瑗","瑷","𦖸"}
	a[12564]={"𤤵"}
	a[12565]={"𨋉"}
	a[12571]={"發","硟"}
	a[12572]={"鬷","𤥻","𦑛","𩱛"}
	a[12573]={"珽","𤩥","𦖵"}
	a[12575]={"𨡌"}
	a[12581]={"𤼺"}
	a[12582]={"𦐿","𦕣"}
	a[12585]={"軰"}
	a[12592]={"𤪞"}
	a[12593]={"聨","𨡩"}
	a[12602]={"𢑵"}
	a[12610]={"𧫯"}
	a[12612]={"䪤"}
	a[12630]={"呇","𣳉"}
	a[12640]={"沓","沯"}
	a[12641]={"畓","𣳖"}
	a[12650]={"㴅","𥔠"}
	a[12651]={"㽝","碯"}
	a[12652]={"瑙"}
	a[12660]={"𥅮","𥒖","𧥿"}
	a[12661]={"㻈"}
	a[12662]={"𤘏","𨠆"}
	a[12670]={"䂿","𤼰"}
	a[12671]={"殙","𤦊","𥍿","𥓬","𥔜","𦧥"}
	a[12672]={"磻","聒","𢐠","𤧘","𩨏"}
	a[12673]={"璠"}
	a[12680]={"䎓","𥍾"}
	a[12681]={"碈","碷","𤩣","𩈙"}
	a[12682]={"琘","𦕾"}
	a[12683]={"䣶","𣝭"}
	a[12690]={"䃈"}
	a[12691]={"瑎"}
	a[12692]={"䎽","酯","𨡍"}
	a[12701]={"𦒓"}
	a[12702]={"酳","𠠫"}
	a[12703]={"𠠛"}
	a[12710]={"𠚥","𠛂","𠛖","𪚀"}
	a[12711]={"剢","𠚫","𠠱","𪚁"}
	a[12713]={"釂","𠠨"}
	a[12715]={"𠠰"}
	a[12720]={"㓚","列","𠚧","𠝃","𠝌","𥍪","𦓎"}
	a[12721]={"刊","𠚵","𠛥","𡥁"}
	a[12722]={"刑","𠚿","𠛚"}
	a[12730]={"刓","刟","刭","剄","矵","𠜉","𠜝","𣧽","𤼮"}
	a[12731]={"㓴","㺫","刴","劽","𣧑","𣧯","𣨅"}
	a[12740]={"㓦","剅","剥","剹","𠛙","𠝙","𠞨","𡶳","𣧿","𣨸","𥒤","𧲄"}
	a[12741]={"䂰","到","刵","殍","𡵾","𤤼"}
	a[12742]={"琍","𠛬","𣧙","𥓑"}
	a[12743]={"㔄","𠞉","𣳗"}
	a[12744]={"剟"}
	a[12750]={"㔁","㳫","䴕","刯","劀","","𡷒","𣨡","𤼻","𥒂","𩧮"}
	a[12751]={"𠜘","𠟙","𥒫"}
	a[12752]={"㓰","㔌","剽","琈","硎","𠟵"}
	a[12753]={"濷"}
	a[12760]={"䃣","䶛","剕","背","𠜲","𠞖"}
	a[12761]={"副","磘","𤼶","𥒻"}
	a[12762]={"琇","瑶","𠢛","𦖀","𩢾"}
	a[12763]={"㻑","酗","酹","𠟕","𩨉"}
	a[12764]={"㻝","𡥶","𤘐"}
	a[12770]={"䃗","鴷","𥔿"}
	a[12771]={"㔇","瑫","𠞐","𠟨","𥓫"}
	a[12773]={"酻","𠟦"}
	a[12774]={"䎺","䏀","瑀"}
	a[12781]={"𠟢","𠟺","𥓾"}
	a[12784]={"聥","𠮐"}
	a[12785]={"𨡘"}
	a[12790]={"㔏"}
	a[12791]={"礄","𠞯","𡦀","𢐟","𦑣"}
	a[12792]={"㔆","𤩝","𨢝"}
	a[12794]={"𨢙"}
	a[12802]={"𤪵"}
	a[12810]={"氼","癶","","𣱸","𣶷","𤆲"}
	a[12813]={"骥"}
	a[12820]={"烮"}
	a[12831]={"殀","癸","𤼩"}
	a[12840]={"𤼯"}
	a[12841]={"豯","𤥍","𥎨","𥤾"}
	a[12850]={"𧵜"}
	a[12851]={"㻄"}
	a[12852]={"𦕯"}
	a[12860]={"𩒆"}
	a[12861]={"磎","骙","𤼵"}
	a[12862]={"𤨊"}
	a[12870]={"𣺪"}
	a[12871]={"𢐏","𤨏","𩄠"}
	a[12872]={"聧"}
	a[12873]={"璞","𤪟","𤳓"}
	a[12875]={"𩙺"}
	a[12880]={"𥕫","𧶙","𧶢"}
	a[12881]={"𥗢"}
	a[12883]={"䤆","冀"}
	a[12890]={"礩"}
	a[12891]={"瓆"}
	a[12892]={"聫"}
	a[12894]={"醭"}
	a[12904]={"𨣺"}
	a[12910]={"水","𢑈"}
	a[12911]={"礫"}
	a[12912]={"瓅","𦘈"}
	a[12913]={"䤕"}
	a[12920]={"沝",""}
	a[12921]={"𤼨"}
	a[12930]={"㴇","淼","𥙊"}
	a[12931]={"𣷘","𥞥"}
	a[12940]={"㵘","砅","砯","𣨒","𣻣"}
	a[12941]={"䉾","孫","砾","𣛁"}
	a[12942]={"","𣔽","𤤤"}
	a[12950]={"𢏛","𣸐","𣻤","𥒜","𥒶"}
	a[12951]={"𣹳"}
	a[12952]={"𥕆","𥡰"}
	a[12953]={"𣕰"}
	a[12961]={"𢑲","𦄳","𦕱"}
	a[12962]={"𣩫","𤧮"}
	a[12963]={"酥","𣩓"}
	a[12970]={"𧩁"}
	a[12971]={"䃯","𥓽"}
	a[12972]={"礏"}
	a[12973]={"𤩶","𥕘"}
	a[12974]={"璅","𥔝"}
	a[12976]={"𤦋"}
	a[12981]={"䏈","𢑄"}
	a[12984]={"𦗔"}
	a[12995]={"𨢪"}
	a[13010]={"刅"}
	a[13030]={"𠧙","𢎡","𢎬","𥐚"}
	a[13031]={"㺪"}
	a[13041]={"𤤫"}
	a[13042]={"珌"}
	a[13051]={"恥"}
	a[13052]={"䎵"}
	a[13053]={"𠧬"}
	a[13102]={"醯","𨣓","𨿉"}
	a[13103]={"䃥"}
	a[13104]={"𤩔"}
	a[13110]={"䃪","𩉊"}
	a[13111]={"璮"}
	a[13112]={"𨣚","𩀦"}
	a[13113]={"𩁎"}
	a[13114]={"𩀿"}
	a[13115]={"𤫚","𨣒","𩀽"}
	a[13140]={"㱐","㱞"}
	a[13150]={"砬","𥐞","𩧧"}
	a[13151]={"𤤔"}
	a[13153]={"难"}
	a[13160]={"翋"}
	a[13161]={"砫","驻"}
	a[13162]={"𣨫","𤤛","𨾆","𨾊","𨾣","𨾿","𨿏"}
	a[13163]={"䧲","雅","𨾌","𨾐"}
	a[13164]={"雃","𥂫"}
	a[13167]={"𩁖"}
	a[13172]={"碓","骓","𦗃","𨾖","𨿋"}
	a[13173]={"琟","𨫣","𩀁","𩀋"}
	a[13180]={"𥓗"}
	a[13182]={"雡","𦑏","𨾫","𩁃"}
	a[13183]={"䝑","䤉","𨾽","𨿊"}
	a[13186]={"𨿷","𩀄"}
	a[13192]={"𩀢"}
	a[13193]={"䂌","𥗭"}
	a[13194]={"醀","𡦜"}
	a[13195]={"䊲","𣠁"}
	a[13202]={"𨣧"}
	a[13230]={"𧱱"}
	a[13240]={"𣨹"}
	a[13251]={"碜","骖"}
	a[13260]={"磣","𥔪"}
	a[13261]={"𤨵"}
	a[13263]={"𨠨"}
	a[13270]={"𥖭"}
	a[13280]={"𩈼"}
	a[13281]={"璾"}
	a[13282]={"醦"}
	a[13303]={"𤪿"}
	a[13306]={"醸"}
	a[13312]={"醷"}
	a[13314]={"骧","𢐿","𣩽","𥗝"}
	a[13315]={"瓖"}
	a[13316]={"釀"}
	a[13340]={"硛"}
	a[13341]={"玣","𤥂"}
	a[13350]={"𥑴"}
	a[13360]={"弦","磙","𣩹","𥕃","𥕦","𥕺"}
	a[13361]={"玹","𤩨","𦗐"}
	a[13363]={"𨠔"}
	a[13370]={"𢛆"}
	a[13371]={"𩉄"}
	a[13372]={"強","礁"}
	a[13374]={"𤨚"}
	a[13380]={"䃶"}
	a[13381]={"瓌","𩱘"}
	a[13382]={"䃭","𦘄","𨣔"}
	a[13383]={"璡","𦗠"}
	a[13391]={"𥖾","𦖶","𩱝"}
	a[13392]={"䃵","䩌","瓋","𨢶"}
	a[13394]={"醮"}
	a[13402]={"殲","𩃷"}
	a[13403]={"殱","𧲘"}
	a[13404]={"𨣝"}
	a[13412]={"㱻","䃷","䃸","𥗯","𩉔"}
	a[13413]={"䃱"}
	a[13414]={"䤘"}
	a[13415]={"𨣲"}
	a[13423]={"戏","𢧈"}
	a[13431]={"𢎁","𣧆","𧰰"}
	a[13432]={"𢦧","𣧌","𥍥"}
	a[13433]={"𢎊","𢦐","𢧏","𧱦"}
	a[13440]={"𥐸"}
	a[13441]={"弐","武","𡯼","𢎄","𣧗","𥐶"}
	a[13442]={"䂝","玳","𢏌","𢦪","𢦰","𣧡","𣧵"}
	a[13443]={"㦱","戣","残"}
	a[13444]={"殘"}
	a[13451]={"玧","𦏵"}
	a[13452]={"䎀","䎉","戮","硥","𢦱","𦐂","𩧪"}
	a[13453]={"珑","珬","珹","聀","𣕥","𥑳","𨠄","𩧩"}
	a[13454]={"㦷","硪","碊"}
	a[13455]={"珴","琖"}
	a[13456]={"𢧱"}
	a[13460]={"兘","巯","巰","疏","砊","硫","𢏭","𥒝"}
	a[13461]={"珫","琉","貮"}
	a[13462]={"戬","磩","𢨌","𢨙","𣨤","𥎕","𩰭"}
	a[13463]={"䣧","戤","臹","𢧎","𤨟","𦖎","𧻂","𨠍 "}
	a[13464]={"䎒","䣬","䣹","𣦏","𥔃","𦕧"}
	a[13465]={"𢧃","𢧙","𤥟"}
	a[13466]={"𣜽"}
	a[13471]={"殧","碔","𣄷","𥓛","𩈊"}
	a[13472]={"㢦","䂸","戨","珷","碱","𥜆"}
	a[13473]={"琙","瑊"}
	a[13475]={"𨠤"}
	a[13476]={"醆"}
	a[13480]={"𣩜","𩐘"}
	a[13481]={"𤦻"}
	a[13482]={"㦻","戩","酼","𦑌","𧯱","𨟼"}
	a[13483]={"聝"}
	a[13484]={"𦖱"}
	a[13491]={"璄"}
	a[13493]={"職","𥖙"}
	a[13494]={"戳","醎","𤪝","𤮌","𥖘"}
	a[13496]={"𤪚"}
	a[13501]={"礔"}
	a[13511]={"𢐻"}
	a[13513]={"𨣳","𨣶 ","𩃶"}
	a[13515]={"䝄","𨣪"}
	a[13516]={"𧰤"}
	a[13531]={"𠅗"}
	a[13532]={"𡥡"}
	a[13541]={"䂭","砇","𣨛","𣨜","𥍬","𦑁"}
	a[13542]={"玟","珓","𣧧","𧱙"}
	a[13551]={"碎","骏","𢏤"}
	a[13552]={"㻐","琗","𤥥","𤥿","𥑕","𩧯"}
	a[13553]={"㺹","𤤒"}
	a[13561]={"㢹","䰚","碲","骍","𨐓"}
	a[13562]={"㢺","𤧛","𦐗","𦖒"}
	a[13563]={"𤥡","𨠦"}
	a[13564]={"酦","𡦉"}
	a[13565]={"𢌠"}
	a[13571]={"𦐹","𧥡","𩈥","𩰺","𩰼"}
	a[13572]={"婱"}
	a[13573]={"酸","醉","𡦍","𤨘","𦥀","𧲀","𨠪"}
	a[13574]={"䣮","䣲"}
	a[13581]={"𧲉"}
	a[13582]={"㻭","𥕁","𩰽"}
	a[13583]={"礮"}
	a[13591]={"㱸","𥕞","𨐕"}
	a[13592]={"璋","𤨼"}
	a[13600]={"𩈴"}
	a[13601]={"𤲾"}
	a[13602]={"䤃","𨡄"}
	a[13611]={"𥗲"}
	a[13612]={"醕"}
	a[13650]={"殆"}
	a[13651]={"孡"}
	a[13660]={"殕","骀"}
	a[13661]={"珆"}
	a[13662]={"𠷠"}
	a[13670]={"碚","𣨌"}
	a[13671]={"琣","𡥪","𤦮"}
	a[13680]={"䂴"}
	a[13681]={"琂"}
	a[13682]={"𨡥"}
	a[13690]={"䜾"}
	a[13691]={"𦖢"}
	a[13692]={"醅"}
	a[13693]={"𨡤"}
	a[13702]={"𨢓"}
	a[13703]={"㻽","醇"}
	a[13704]={"𦑷"}
	a[13712]={"𨢺"}
	a[13714]={"𢑎"}
	a[13750]={"𢎷"}
	a[13751]={"𢏟","𤤁"}
	a[13754]={"豧","𥙳"}
	a[13760]={"𣨉"}
	a[13761]={"豴"}
	a[13762]={"𤧿"}
	a[13764]={"𣨈"}
	a[13765]={"𧱹"}
	a[13770]={"磅","𢐊","𥓯"}
	a[13771]={"㻆","𤦺","𤧭"}
	a[13772]={"𥕮"}
	a[13773]={"璃","𨠯"}
	a[13774]={"𥒰"}
	a[13780]={"碠","𣩅","𩨆"}
	a[13781]={"㻙","弴","𤧟","𥕐","𦗍"}
	a[13782]={"𤨬"}
	a[13784]={"䎍","𦒊"}
	a[13785]={"磗"}
	a[13786]={"𤧵"}
	a[13790]={"碻","𩱐"}
	a[13791]={"聤","𤧼"}
	a[13792]={"𦗑","𨢐"}
	a[13793]={"㻪"}
	a[13794]={"䩉","醨","鬴"}
	a[13795]={"䎔"}
	a[13796]={"酺"}
	a[13804]={"𤣉"}
	a[13811]={"𩉇"}
	a[13812]={"𤫓"}
	a[13813]={"瓛","𥎥"}
	a[13814]={"𤣅"}
	a[13830]={"豥"}
	a[13841]={"孩"}
	a[13842]={"㺴"}
	a[13850]={"硋","骇"}
	a[13851]={"𢏓"}
	a[13853]={"䣭"}
	a[13861]={"𢏦","𥒲"}
	a[13870]={"𩰶"}
	a[13871]={"𦓢"}
	a[13881]={"䝾","𤡾"}
	a[13882]={"𤐦"}
	a[13884]={"𤩽"}
	a[13892]={"𩉈"}
	a[13940]={"㢱"}
	a[13941]={"殏","𥑡","𥒸"}
	a[13942]={"㺷"}
	a[13950]={"𣨣"}
	a[13951]={"𣨚"}
	a[13952]={"球"}
	a[13960]={"䃄","弶","𢏸"}
	a[13961]={"琼","𢏲","𣄴"}
	a[13970]={"翞"}
	a[13971]={"𩰻"}
	a[13973]={"㱷"}
	a[13981]={"𤪗"}
	a[13982]={"䣼","𦥅"}
	a[13983]={"磼"}
	a[14101]={"𦑠"}
	a[14115]={"𤪮"}
	a[14140]={"殈"}
	a[14141]={"𡥠"}
	a[14150]={"𥒌"}
	a[14160]={"𠁇"}
	a[14161]={"䂯","𥒹"}
	a[14162]={"𤥦"}
	a[14170]={"𣨩"}
	a[14181]={"𤦌"}
	a[14191]={"𤧺","𦖑"}
	a[14192]={"瑝","𤧥"}
	a[14202]={"𪖕"}
	a[14212]={"䃺","䶍","𩉚"}
	a[14214]={"釄"}
	a[14240]={"矿"}
	a[14250]={"驴"}
	a[14302]={"𩉌"}
	a[14311]={"𢦋"}
	a[14350]={"砿"}
	a[14351]={"𤨌"}
	a[14360]={"㱢","𥍫"}
	a[14361]={"𥎋"}
	a[14362]={"𤥠"}
	a[14370]={"硠",""}
	a[14371]={"琅","骢"}
	a[14372]={"璁","聰"}
	a[14374]={"𤨫"}
	a[14380]={"磓"}
	a[14381]={"𤧫"}
	a[14382]={"𥗡"}
	a[14383]={"𤩻"}
	a[14387]={"𥖝"}
	a[14392]={"酿"}
	a[14393]={"𨢨"}
	a[14401]={"𤨖"}
	a[14402]={"𩴢"}
	a[14403]={"𢑻","𦗓"}
	a[14404]={"醜","𤮂"}
	a[14413]={"䰰","䰱","𩵀"}
	a[14414]={"𨢷"}
	a[14440]={"𢏋","𥐥","𥐲"}
	a[14450]={"豟","𩧻"}
	a[14451]={"𥒈"}
	a[14460]={"𣨆"}
	a[14461]={"琓"}
	a[14462]={"𩲚","𩲡"}
	a[14463]={"𩳥"}
	a[14470]={"䲫","砨","𠒜"}
	a[14471]={"𤥰"}
	a[14472]={"㱱","𩱽"}
	a[14473]={"𤨞"}
	a[14480]={"𦑀"}
	a[14481]={"磇"}
	a[14482]={"磈","魂","𣩏"}
	a[14483]={"瑰"}
	a[14492]={"䃙","䰭"}
	a[14493]={"聭","𢑶"}
	a[14541]={"𠄛"}
	a[14551]={"廹","𥔉"}
	a[14552]={"𤧯"}
	a[14553]={"𤥃","𤥱"}
	a[14562]={"𦖪"}
	a[14563]={"䤇","𣨲","𤦑"}
	a[14571]={"䃇"}
	a[14573]={"碑"}
	a[14574]={"琕"}
	a[14581]={"𥓭"}
	a[14582]={"𤦞"}
	a[14583]={"豍","𤧻"}
	a[14584]={"聛"}
	a[14591]={"𣍙"}
	a[14592]={"𤩢"}
	a[14593]={"𥖂"}
	a[14595]={"𨡕"}
	a[14616]={"醣"}
	a[14650]={"𣨔","𥍡"}
	a[14651]={"硇"}
	a[14660]={"砶"}
	a[14661]={"珀","𥓁"}
	a[14670]={"𥒕","𦐚"}
	a[14672]={"𦕻"}
	a[14674]={"㻘","𧱵"}
	a[14680]={"𥕯"}
	a[14682]={"𨠘"}
	a[14683]={"𤪺"}
	a[14691]={"碧","𤩷","𤪓"}
	a[14692]={"礳","𥕒"}
	a[14694]={"磄"}
	a[14695]={"瑭"}
	a[14700]={"䳾","鷊","鷸","𩿮"}
	a[14701]={"𪁙","𪂪"}
	a[14702]={"鹴","𦘂","𪅃","𪇯"}
	a[14703]={"鵘","𪃋","𪄃"}
	a[14704]={"𩉑"}
	a[14708]={"𤨭"}
	a[14710]={"鵶","鶸","𪀫","𪂞","𪃿","𪄌","𪄶","𪅴","𪆇"}
	a[14711]={"䴇","䴒","鶝","𪄂","𪄮","𪅳","𪅷","𪆚","𪈑","𪈝"}
	a[14712]={"鸐","鸘","鸝","𪄕","𪅽","𪆲","𪆼","𪇾"}
	a[14713]={"䴑","鷣","鸖","𪄷"}
	a[14714]={"𪈹"}
	a[14740]={"𥑚"}
	a[14741]={"鸡","𥑨"}
	a[14750]={"鸸","鹀","","𥑈","𩿎"}
	a[14751]={"䴓","鸦","","𠭬","𤦓","𥑩"}
	a[14752]={"𤤱","𥑸","𩧳"}
	a[14753]={"珘"}
	a[14760]={"鳭","鴀","鹂","𧱚","𩾚","𩾼","𪁥","𪉂"}
	a[14761]={"珦","鳮"}
	a[14762]={"𣩀","𦐩"}
	a[14764]={"𦐷"}
	a[14770]={"䃖","䲨","䲹","殦","鴯","鵐","鹨","𥑵","𩾗","𩿗","𩿷"}
	a[14771]={"䲯","瑦","鳱","鳵","鳾","鴉","鹉","𤤷","𤪥","𪂕"}
	a[14772]={"碥","骗","鳽","𢐃","𤦝","𪁁"}
	a[14773]={"㻞","𥔷"}
	a[14775]={"鸍"}
	a[14780]={"䲮","䲰","䲽","䳂","鴊","鵋","鵛","鹝","鹬","𩾠","𩿒","𪀉","𪂐"}
	a[14781]={"䳫","鳿","鶔","𣄋","𩿑","𪃉"}
	a[14782]={"𤨥","𦑮","𦕮","𦖓"}
	a[14784]={"𥗂"}
	a[14787]={"𧱿"}
	a[14790]={"翵","骟","鷚","𥔱","𩈜","𩈺","𩿍","𩿸","𩿺","𩿻","𪁞","𪂌"}
	a[14791]={"鵄","鵈","鵡"}
	a[14792]={"𦖛","𪀹","𪄏","𪉒"}
	a[14793]={"鷅"}
	a[14794]={"䳩","鵽","𪂍"}
	a[14801]={"𩈸"}
	a[14805]={"𦘅"}
	a[14813]={"𤫖"}
	a[14851]={"䃐"}
	a[14860]={"𢏹"}
	a[14861]={"𥓎"}
	a[14862]={"礇"}
	a[14870]={"𤭍"}
	a[14871]={"殠","聢"}
	a[14876]={"𣡉"}
	a[14890]={"𣩵"}
	a[14894]={"彍","礦"}
	a[14895]={"㼅"}
	a[14904]={"醿"}
	a[14915]={"𨣿"}
	a[14951]={"𤤯"}
	a[14952]={"𤥤"}
	a[14960]={"骔"}
	a[14962]={"𤥾"}
	a[14963]={"𤪒"}
	a[14970]={"𩈗"}
	a[14971]={"瑔","𥔟"}
	a[14972]={"𨠕"}
	a[14973]={"𢑀"}
	a[14982]={"䩋","𨡹"}
	a[14984]={"𥕎"}
	a[14995]={"醾"}
	a[15021]={"𠦇"}
	a[15031]={"𠦁","𣁬","𥐟"}
	a[15041]={"㪴","𠦊","𥐿"}
	a[15042]={"㺶"}
	a[15043]={"𨟳"}
	a[15051]={"㪶","㪷"}
	a[15052]={"𣁳"}
	a[15061]={"𩰮"}
	a[15063]={"酙"}
	a[15102]={"𢑫"}
	a[15103]={"醘","醢","𥂧","𥂰"}
	a[15104]={"䤁"}
	a[15106]={"𤩖"}
	a[15107]={"瑾"}
	a[15113]={"𥂹","𩅷","𩅾","𩐔"}
	a[15119]={"𡂬"}
	a[15131]={"䝅","𡉹"}
	a[15141]={"𣧅"}
	a[15142]={"𣒮"}
	a[15151]={"𢎳"}
	a[15152]={"殅","𤣰"}
	a[15161]={"𥑰","𥔐"}
	a[15162]={"𥑥","𥒒"}
	a[15163]={"珄","𡎂"}
	a[15164]={"玴","𤤙"}
	a[15171]={"𣩄"}
	a[15172]={"硅","𥓪","𥪻"}
	a[15173]={"珪","𤥧","𦐕"}
	a[15181]={"殖","碴","磕","豷"}
	a[15182]={"碪","𡥰"}
	a[15183]={"㻣","𤩌"}
	a[15184]={"","𤧊","𨠠"}
	a[15185]={"𣩲","𥎚"}
	a[15191]={"殪","𢏶"}
	a[15192]={"𩰳"}
	a[15193]={"𥕛","𨡝","𨡿"}
	a[15194]={"璂"}
	a[15196]={"殣","𣞵","𤪣","𥎊"}
	a[15214]={"𥘄"}
	a[15261]={"䃎"}
	a[15302]={"聼","𤩼"}
	a[15305]={"翴"}
	a[15306]={"𨣂"}
	a[15308]={"𤪼"}
	a[15312]={"瓍","聽"}
	a[15313]={"瓙"}
	a[15314]={"醼"}
	a[15316]={"䎚"}
	a[15317]={"𤪳","𥗾"}
	a[15331]={"𥑖","𧰯","𧹚"}
	a[15332]={"怼"}
	a[15341]={""}
	a[15342]={"甤"}
	a[15351]={"㢬","硳","","𥐪","𥒺"}
	a[15352]={"砵","𤋕","𤣾","𤥴","𥔸"}
	a[15353]={"𤦧","𤧍","𤧴"}
	a[15355]={"𤩿"}
	a[15361]={"砝","𠳊","𦐌"}
	a[15362]={"珐","砖","耾"}
	a[15363]={"酞","𥎢"}
	a[15364]={"𤍰"}
	a[15365]={"琎"}
	a[15372]={"琺"}
	a[15373]={"𦑐"}
	a[15374]={"琏"}
	a[15381]={"𧲈"}
	a[15382]={"聴","𤨂","𥔵"}
	a[15383]={"𤐿","𧐵"}
	a[15384]={"𤪶"}
	a[15385]={"璤","𢤔"}
	a[15392]={"𥗕","𦗟"}
	a[15393]={"䃮","𤫇"}
	a[15394]={"㼀","𦒎"}
	a[15395]={"䃛"}
	a[15396]={"璉"}
	a[15397]={"𤫃"}
	a[15402]={"𩈷"}
	a[15403]={"𣦥","𣩦"}
	a[15404]={"𩈯"}
	a[15405]={"𢆮","𤮍"}
	a[15406]={"醃"}
	a[15413]={"磽","霕","𦒒","𩃌"}
	a[15414]={"𤩊"}
	a[15415]={"𩅝","𩈿"}
	a[15431]={"瓧"}
	a[15432]={"𠬜","𧰭"}
	a[15441]={"㝴","䂗","𣦾","𧱀"}
	a[15442]={"瓲","豘"}
	a[15443]={"硴"}
	a[15444]={"𤦙"}
	a[15451]={"㱡"}
	a[15453]={"𤤀"}
	a[15461]={"殑","","𥑻"}
	a[15462]={"珗","砘","硓","硗","骁","","𤥣","𥔙"}
	a[15463]={"珯","𤤜","𤧌"}
	a[15465]={"𤧳"}
	a[15471]={"𥑄"}
	a[15472]={"𥕜"}
	a[15473]={"𤧈"}
	a[15474]={"䣨","殗"}
	a[15483]={"酰","𤨰","𥖈"}
	a[15484]={"䣩","硽","𨠬"}
	a[15485]={"𦗆"}
	a[15492]={"𩇖"}
	a[15493]={"𦖅"}
	a[15494]={"𦑎"}
	a[15495]={"𦖈"}
	a[15505]={"𩎳"}
	a[15506]={"彟"}
	a[15519]={"𥗇"}
	a[15532]={"䂚","驳","𢌗","𣲰"}
	a[15533]={"豨","𡥃"}
	a[15542]={"妀","𢑒","𣧘","𣧦"}
	a[15543]={"𡚽","𤣷","𤣸"}
	a[15552]={"㱥","骅","𡠢","𢎼","𥑢"}
	a[15553]={"𥑾"}
	a[15554]={"琋","𣨼","𥐹","𨟿"}
	a[15562]={"碐","翄","豉"}
	a[15563]={"䂜","砗","𡞒","𤦫"}
	a[15564]={"玤","玮","𥓈","𨠓","𨣑","𩧼"}
	a[15565]={"䎴"}
	a[15566]={"𢻚"}
	a[15572]={"䰙","𩰫"}
	a[15573]={"𢻊"}
	a[15574]={"䣪","䣫","礟","𢻍","𤯳"}
	a[15575]={"殢","𣨞","𨡂"}
	a[15576]={"甦"}
	a[15583]={"𩈈"}
	a[15585]={"硨"}
	a[15586]={"䃀","琫","𤥭"}
	a[15588]={"𦗉"}
	a[15601]={"礂"}
	a[15602]={"𤩠"}
	a[15604]={"醋","醏"}
	a[15606]={"𥕢"}
	a[15610]={"𨤇"}
	a[15612]={"䃴"}
	a[15613]={"𤪘"}
	a[15614]={"𨢍"}
	a[15615]={"𨣍"}
	a[15617]={"䏆","𩆦"}
	a[15618]={"醩"}
	a[15651]={"㱠"}
	a[15661]={"𢏆","𣨓","𥍱","𥑛","𥑮"}
	a[15662]={"豬"}
	a[15671]={"硈","硞","𥔇","𩧵"}
	a[15672]={"矠","𤥐"}
	a[15673]={"𤥢","𤦘","𤪜"}
	a[15674]={"𠷱"}
	a[15681]={"𥓩","𩰯"}
	a[15682]={"碏","聐","聕","𢑳"}
	a[15683]={"琽","酤","𤨃"}
	a[15685]={"䤀"}
	a[15692]={"㝆","䜺","𥔴","𥕙"}
	a[15693]={"酷","","𩨁"}
	a[15694]={"瑃"}
	a[15696]={"𣩒"}
	a[15702]={"𥖰","𦑊"}
	a[15703]={"聙"}
	a[15704]={"𤨸"}
	a[15712]={"𥖲"}
	a[15713]={"璹","𤫨","𨢗"}
	a[15714]={"醻"}
	a[15716]={"𦒄"}
	a[15717]={"㻰"}
	a[15722]={"对"}
	a[15731]={"耐"}
	a[15732]={"𣧨"}
	a[15741]={"䂤","弣","驸"}
	a[15742]={"𤤕"}
	a[15743]={"𧱼"}
	a[15751]={"𡭁"}
	a[15752]={"𠭑"}
	a[15753]={"㺻","𤦈"}
	a[15754]={"㻳","𡦖","𤥉","𧱐"}
	a[15757]={"𢐳"}
	a[15761]={"㱦","𩈃"}
	a[15762]={"𤘌","𥑠"}
	a[15763]={"玵","珔","酎","𡬽"}
	a[15764]={"璊","𡬵","𦖁"}
	a[15771]={"碕","骑","𥑹","𥑿","𧱫"}
	a[15772]={"珛","琦","𡻧"}
	a[15773]={"㻤","臶","𤨦","𦕐"}
	a[15774]={"硣","𦗫"}
	a[15775]={"𡦗","𤥝","𥕧","𨡆"}
	a[15776]={"𤨮"}
	a[15781]={"䝐"}
	a[15782]={"𦖊","𦖔"}
	a[15783]={"𤨀"}
	a[15784]={"㣁","酣"}
	a[15785]={"䤍","𣩘","𥕪","𥗘"}
	a[15786]={"𡦕","𨢀"}
	a[15787]={"𤨳"}
	a[15791]={"𥓿"}
	a[15792]={"㻟","碃","靕","𤨯","𥗔"}
	a[15793]={"酭","𤦭","𤨅"}
	a[15794]={"𨡯"}
	a[15795]={"碡","磚","𥖣"}
	a[15796]={"瑇","瑼","酵"}
	a[15797]={"礡"}
	a[15798]={"䃓"}
	a[15801]={"殰"}
	a[15802]={"磧","𠓕","𦗀","𧶷"}
	a[15803]={"瓒","𦏙"}
	a[15804]={"𥎞"}
	a[15806]={"䤑","𦒅"}
	a[15811]={"𥖿"}
	a[15812]={"䂎","瓄","礸","𢑊","𣪁","𤩵","𤪬"}
	a[15813]={"瓚"}
	a[15814]={"𨢦","𨣜","𨤆"}
	a[15815]={"瓉"}
	a[15816]={"𨣵"}
	a[15821]={"𧱉"}
	a[15831]={"殎","𣧂"}
	a[15841]={"硤","驮"}
	a[15842]={"𣧞","𤥵"}
	a[15843]={"豮"}
	a[15845]={"磢"}
	a[15852]={"㱩","砆","硔","硖","聗","𥑇","𩧭"}
	a[15853]={"玞","珙"}
	a[15854]={"𣨽","𧱅"}
	a[15862]={"翐"}
	a[15863]={"𦔾","𦕠","𨠿"}
	a[15864]={"𧱪"}
	a[15865]={"䝊"}
	a[15872]={"䃆","碛","礎","骐","𤪃","𥕩"}
	a[15873]={"琪","璴","豶"}
	a[15874]={"酜","𤩸"}
	a[15882]={"𣩬","𥗈","𧯯"}
	a[15883]={"㱵"}
	a[15884]={"彉","磺"}
	a[15885]={"璜","𢏵","𥓐"}
	a[15888]={"㯩"}
	a[15891]={"㣀","磌","𩨋"}
	a[15892]={"㱴","瑱","𥎍","𥎝"}
	a[15893]={"璳","𥖀"}
	a[15894]={"𤩳"}
	a[15895]={"𦑈","𦥇"}
	a[15897]={"𤨢"}
	a[15931]={"𣐫","𦐔"}
	a[15932]={"𠀶","𧲒"}
	a[15941]={"䂾"}
	a[15942]={"殊","琜","𣧣","𣨁"}
	a[15943]={"𡥛"}
	a[15951]={"𧯲"}
	a[15952]={"砞","硃","碄","𣥵","𥑘"}
	a[15953]={"㱫","殐","珠","琳","𣓺","𤤥","𤤹","𤨶"}
	a[15961]={"𣩢"}
	a[15962]={"𦐣"}
	a[15963]={"䎷","疎","","𢏼","𣦚","𣨴","𣩊","𥑶","𦕜"}
	a[15964]={"㻋","殜","殝","瑓","𢐇","𣖦"}
	a[15967]={"𣜿"}
	a[15971]={"𢑬","𥕴"}
	a[15972]={"璙","𥖜","𩈐"}
	a[15973]={"䜹","櫫","磔","𤧉","𤪑"}
	a[15974]={"㻧","䣷","弽","碟","醂","𤧀","𥓝","𥔫","𨠹"}
	a[15975]={"㻡","㻷","瑧","𤦪"}
	a[15981]={"𧰉","𩈫","𩈶"}
	a[15983]={"𤨄","𩓸"}
	a[15984]={"𤩒"}
	a[15985]={"臻"}
	a[15986]={"𥖢"}
	a[15991]={"䩍"}
	a[15993]={"𢑧","𤪌","𧷱","𨣀"}
	a[15995]={"䤂"}
	a[16032]={"𠁨"}
	a[16040]={"𣧝"}
	a[16041]={"𤰓"}
	a[16050]={"𥔆"}
	a[16060]={"驲","驷","𢏎"}
	a[16061]={"䂩","硱","碅","骃","𥑆","𦔻"}
	a[16062]={"㻒","珈","珚","𤤦","𥑤","𩧨"}
	a[16063]={"𤤧"}
	a[16070]={"硘"}
	a[16071]={"㺺","㻁","𤤨"}
	a[16075]={"𤥪"}
	a[16080]={"𢐑"}
	a[16081]={"𩧽"}
	a[16082]={"𤧇"}
	a[16091]={"𥎙"}
	a[16092]={"𢐚","𥕏"}
	a[16102]={"醖","𣩿"}
	a[16103]={"酲","𦖤"}
	a[16112]={"𣌃","𥎡","𥗫","𥗴","𩉗","𩉙"}
	a[16113]={"㼈","䥒"}
	a[16114]={"醒","𥗬"}
	a[16116]={"醴"}
	a[16160]={"豱"}
	a[16170]={"殟","𥑲"}
	a[16180]={"𥔋"}
	a[16181]={"瑥"}
	a[16182]={"珵","醞","𣨾","𨠚"}
	a[16183]={"𩧹"}
	a[16184]={"理"}
	a[16190]={"𩈍"}
	a[16192]={"䃏","聖","𤨱"}
	a[16193]={"瑆","𤩏"}
	a[16194]={"𤪯","𥎓","𦕸","𨡵"}
	a[16261]={"𥔅"}
	a[16262]={"琾","𠁩"}
	a[16300]={"礘"}
	a[16302]={"𤪹"}
	a[16304]={"䃩","𢐪"}
	a[16310]={"䝃","𤄥"}
	a[16311]={"䏉","𤫛","𦗻"}
	a[16312]={"䃨","𢐵"}
	a[16313]={"𦌺"}
	a[16315]={"𦗳"}
	a[16316]={"醲","𧖓"}
	a[16350]={"𢙢"}
	a[16352]={"䂈","𧈬"}
	a[16353]={"𣨃"}
	a[16361]={"𧱨"}
	a[16362]={"𤨒"}
	a[16370]={"𦒠"}
	a[16371]={"㱬"}
	a[16380]={"𥔯"}
	a[16381]={"碨","𤨔"}
	a[16382]={"强","融","𤧖"}
	a[16383]={"𦗣"}
	a[16390]={"彋","𣩯"}
	a[16391]={"環","𤫐"}
	a[16400]={"覴","靦"}
	a[16402]={"𧢄","𨛿","𨞮","𨡁"}
	a[16403]={"䚈","覠","𨛦"}
	a[16405]={"𤪄"}
	a[16411]={"䚖","𥗒","𧢥"}
	a[16412]={"䚕","醌","𣩴"}
	a[16413]={"䚓"}
	a[16414]={"𧢮","𩴒"}
	a[16440]={"𠮞","𣄽","𥘱"}
	a[16450]={"况"}
	a[16451]={"乪"}
	a[16452]={"虺"}
	a[16454]={"𦓕"}
	a[16460]={"𧱗","𨛛"}
	a[16461]={"覌"}
	a[16465]={"𤤺"}
	a[16470]={"覡","𧠣","𧱟"}
	a[16471]={"覝","𤨆","𧠍"}
	a[16472]={"䙹","𧠸"}
	a[16473]={"瓼"}
	a[16474]={"䎈"}
	a[16475]={"覼"}
	a[16480]={"䙼","硯","𥒵","𥓀","𥓣"}
	a[16481]={"現","𦖃","𧡫"}
	a[16490]={"䃂","䚄","覗","𧡀","𧢇","𧢋"}
	a[16491]={"琨","𢎔","𤥛","𧠫"}
	a[16492]={"𠒺"}
	a[16494]={"𧡏"}
	a[16503]={"殫"}
	a[16504]={"犟","𨣠"}
	a[16507]={"𧰆"}
	a[16508]={"𧰃"}
	a[16512]={"礹"}
	a[16513]={"孾","彈","彏","瓔","矡","磾","𤩛","𤫠","𨢥","𩉁"}
	a[16514]={"醳","釅","𤩧","𨣅"}
	a[16515]={"𨢿"}
	a[16519]={"𨢡"}
	a[16543]={"𥙍"}
	a[16551]={"𣅄"}
	a[16553]={"廸","驶","𥑏","𧈰"}
	a[16554]={"𤤭"}
	a[16561]={"廻","廽"}
	a[16562]={"翀","𥑐"}
	a[16563]={"玾","砷","𦕏"}
	a[16564]={"珅","𥒏"}
	a[16565]={"㻀"}
	a[16571]={"𣨨"}
	a[16572]={"琝","𢌥","𥓓"}
	a[16573]={"𡞺"}
	a[16574]={"䎶","𦕽"}
	a[16578]={"䝏"}
	a[16581]={"𢌪","𢏥"}
	a[16582]={"殬","𤥚"}
	a[16592]={"㻴","礋","𤪛"}
	a[16593]={"𡠝"}
	a[16594]={"𡠥"}
	a[16595]={"𨡟"}
	a[16597]={"彃"}
	a[16598]={"㻫","𥕍"}
	a[16599]={"㻲"}
	a[16600]={"𥖊"}
	a[16611]={"𤩜"}
	a[16612]={"謽","𥗟"}
	a[16613]={"礧"}
	a[16614]={"瓃"}
	a[16690]={"𥓥"}
	a[16691]={"琩"}
	a[16700]={"𥔲","𩨌"}
	a[16702]={"䣺"}
	a[16710]={"𧰂","𪇚"}
	a[16712]={"𤫡","𦉦","𨡠"}
	a[16714]={"𤫝"}
	a[16715]={"𤫥"}
	a[16760]={"𣨟","𥍣","𥍴"}
	a[16761]={"䯄"}
	a[16770]={"𣨵","𥓘"}
	a[16771]={"㻛"}
	a[16773]={"𦕊"}
	a[16780]={"弲","碣","碭","𩨀"}
	a[16781]={"琄","瑒","碍","𥕣"}
	a[16782]={"骋"}
	a[16783]={"𥔘"}
	a[16784]={"㻦"}
	a[16791]={"𤦛","𩨅"}
	a[16792]={"𥖠"}
	a[16793]={"㻿","勥","聘"}
	a[16800]={"𦑰"}
	a[16801]={"𢅦"}
	a[16802]={"醍"}
	a[16803]={"璝","𥖏"}
	a[16804]={"瑻"}
	a[16812]={"靧"}
	a[16813]={"聵"}
	a[16814]={"𨣈"}
	a[16850]={"殒"}
	a[16853]={"𣧴"}
	a[16860]={"𥒭","𦐖"}
	a[16861]={"孭","珿","职"}
	a[16862]={"㠬","㱮",""}
	a[16863]={"𥑷","𥛴"}
	a[16870]={"䎌","𧯩"}
	a[16871]={"珼"}
	a[16872]={"㻍"}
	a[16880]={"殞","碮","𢐂","𣩥","𩈤"}
	a[16881]={"瑅","𧵼"}
	a[16882]={"𧲆"}
	a[16883]={"聩","𩨎"}
	a[16890]={"䜻","磒","𦑧"}
	a[16892]={"殨"}
	a[16893]={"𣩔","𦒖"}
	a[16894]={"𨡺"}
	a[16901]={"𥖨"}
	a[16902]={"璪","𢑾"}
	a[16912]={"𦗵"}
	a[16913]={"𥗼"}
	a[16914]={"䤖","𤫤","𥽹"}
	a[16940]={"𥎅"}
	a[16951]={"𥞣"}
	a[16953]={"𥚌"}
	a[16960]={"𦑶"}
	a[16962]={"𤥯","𤦸"}
	a[16963]={"𣨪"}
	a[16970]={"𤃄"}
	a[16971]={"𥓖"}
	a[16972]={"𧲐"}
	a[16973]={"䂺","骒"}
	a[16981]={"磥","骡","𤪁"}
	a[16982]={"䂍","𤨴"}
	a[16984]={"𦖍"}
	a[16990]={"𥖉"}
	a[16991]={"璟"}
	a[16992]={"𥗋"}
	a[17000]={"𦑟"}
	a[17001]={"𦑭","𩈮"}
	a[17002]={"𩃠"}
	a[17003]={"𨡑"}
	a[17010]={"刀","刃","","","𦒆"}
	a[17011]={"𤩎","𦗬"}
	a[17012]={"刄","𠣋","𥖆","𦘁"}
	a[17013]={"醐","𠣀","𠣊","𦒧","𦘑"}
	a[17016]={"𥗠"}
	a[17020]={"习","刁","","𠚪","𡰣","𦏲"}
	a[17021]={"𠨏","𥸥"}
	a[17022]={"劝"}
	a[17030]={"㓛","䂆","彐","歾","𢀕","𢆱","𣧀","𥍞","𧰴"}
	a[17031]={"功","劢","","𠃠","𣦺","𣧍","𣧻"}
	a[17032]={"㔝","","𠡁"}
	a[17040]={"㢩","司","羽","豞","𣍤","𣧔","𥐛","𥐝","𥔰","𧰶"}
	a[17041]={"㱝","动","劭","劯","劲","勁","玓","𤤅","𤥊","𥐻","𥒙"}
	a[17042]={"玏","𠡕","𥍲","𥐷"}
	a[17043]={"𠡅","𠡍","𧰷"}
	a[17044]={"𣧱"}
	a[17050]={"㱚","𣍣","𣧬","𤬱","𥐩","𥐾","𥒉","𧱁"}
	a[17051]={"䑒","勠","𠢜","𠢯","𠨔","𣧥","𤤡","𤥋","𥐼","𥑪 ","𥒚","𦕅","𧱊"}
	a[17052]={"勐","砃","𦔳"}
	a[17053]={"勈","玬","𤤢"}
	a[17054]={"覅","𡥓","𣧺"}
	a[17056]={"𦐘"}
	a[17058]={"𧱆"}
	a[17060]={"殉","碙","驹","","𠣫","𢑪","𣩃","𥑎","𦏼","𧥝","𩈄"}
	a[17061]={"㺾","勔","玥","玽","砌","𠡳","𤣽","𤦇","𥑑","𧱑"}
	a[17062]={"䍾","砽","酌","𠢢","𤤬","𦕋","𨟸"}
	a[17063]={"䣦","勡","砪","𤤪","𦕃"}
	a[17064]={"𥑬","𩧬"}
	a[17065]={"珃","珊"}
	a[17070]={"䃃","䎄","硐","翑","𢏕","𥒘","𦐸","𩧲"}
	a[17071]={"䎳","珝","珣","𥓮","𦕙"}
	a[17072]={"䂶","聈","𡥱","𦐃","𦕀","𨟴"}
	a[17073]={"𦕘","𨠮"}
	a[17075]={"耼","聃"}
	a[17080]={"𣨥","𦐥","𦑇"}
	a[17081]={"碉","𦖉","𩈏"}
	a[17082]={"䣱","琱"}
	a[17083]={"𦒘"}
	a[17090]={"弸","硼","翮","𥔀","𦒑","𧯠"}
	a[17091]={"㻚","𤨡","𥔓"}
	a[17092]={"䎻","䣳","瑚","翲","酮","𠻸"}
	a[17093]={"磡","醄","𨡒"}
	a[17096]={"𤦳"}
	a[17097]={"𤨕"}
	a[17101]={"𡎳","𩐆"}
	a[17102]={"䃘","䃲","𣩰"}
	a[17103]={"𡔀","𢥀"}
	a[17105]={"𨢜"}
	a[17110]={"𩰸"}
	a[17112]={"𩱂"}
	a[17113]={"𢐽"}
	a[17114]={"𣦪","𦏚"}
	a[17117]={"𤪡"}
	a[17120]={"卫","","𠀄"}
	a[17121]={"丒"}
	a[17130]={"⼹","丞","","","𢀖","𥁀","𥍝"}
	a[17131]={"丑","𡉔","𡔛","𡤽"}
	a[17132]={"圣","𥸨"}
	a[17140]={"㿿","弖","盁","𠄪","𠯉","𥁛","𥁝","𥁪"}
	a[17141]={"孟","𠬴","𥁂"}
	a[17142]={"𢎮"}
	a[17150]={"豠","𥁏","𥂂","𥘲","𦏶"}
	a[17151]={"䂇","亟","盈","𣧊","𦑕"}
	a[17152]={"盄","𥁜","𦤵"}
	a[17160]={"弪","歰","殂","疍","盝","硁","翌","𢏞","𥁥","𥂔","𥒡","𦐀","𧯢"}
	a[17161]={"𡊼","𢟄","𤤶","𦑄"}
	a[17162]={"㺲","𢏩","𥍳","𥑋"}
	a[17164]={"𥻫"}
	a[17165]={"𡌭"}
	a[17170]={"砠","驵","𠃬"}
	a[17171]={"䍿","殛","珇","銎","𤦀","𨥲","𨧮"}
	a[17172]={"𤦕","𨣕"}
	a[17173]={"䥐","埾","𡒍","𨤣"}
	a[17175]={"𡏍"}
	a[17180]={"𩰰"}
	a[17181]={"𩈇"}
	a[17182]={"翟","𧰈"}
	a[17183]={"叠","確","𤦟","𤧬"}
	a[17184]={"𤦶"}
	a[17185]={"孻"}
	a[17190]={"𥂨","𥛠"}
	a[17191]={"𥔄","𥔊"}
	a[17192]={"䣯","𥪷","𨡇","𩐂"}
	a[17193]={"醓","𥂘","𨧎"}
	a[17194]={"醠","𡐲"}
	a[17195]={"璶"}
	a[17200]={"鼐"}
	a[17210]={"乛","","𠃍"}
	a[17211]={"𠨦"}
	a[17212]={"𨣯"}
	a[17215]={"䃤","彇"}
	a[17216]={"璛"}
	a[17230]={"卭"}
	a[17231]={"𠬯"}
	a[17240]={"㚉","卲","夛","矽","翏","𢎙","𣥛"}
	a[17250]={"𢏜"}
	a[17251]={"珋","𤥀"}
	a[17253]={"𢂫"}
	a[17260]={"𢇊","𣩍","𧯨"}
	a[17261]={"聊","𤤑"}
	a[17264]={"骕"}
	a[17270]={"磟"}
	a[17271]={"璆","𦕔"}
	a[17280]={"𡖩"}
	a[17281]={"𢐫","𦗖"}
	a[17286]={"𤧎"}
	a[17291]={"𥕡"}
	a[17292]={"醪","𦖐"}
	a[17300]={"𢢧"}
	a[17301]={"𩸇"}
	a[17306]={"璭","𧒢"}
	a[17310]={"乁","","𤆕","𥗷"}
	a[17311]={"𥗰","𥗸"}
	a[17312]={"𢦀","𤑜"}
	a[17313]={"𨤉"}
	a[17314]={"𨣰"}
	a[17315]={"靆"}
	a[17316]={"䤙","𧕑"}
	a[17318]={"𧔨"}
	a[17320]={"忍","𢖫","𤆔","𤇏"}
	a[17321]={"𠬟"}
	a[17330]={"烝","𢘅"}
	a[17331]={"㤂","孞","𣧩"}
	a[17340]={"忌","𢗂","𤆨","𦓖","𧱢"}
	a[17341]={"䂢","焏","𡥧","𢚣","𢜍","𤦏"}
	a[17342]={"𠄘","𢙎","𢚥","𤉋","𤤮","𥍷"}
	a[17343]={"䙶","蚤","𧈡"}
	a[17350]={"䎆","恐","豤","𣨶"}
	a[17351]={"䂊","艰","豫","𠬾","𢏐","𤊅"}
	a[17352]={"䖥","恿","焣","聚","蛋","𧈦"}
	a[17353]={"承","焄","𠹩","𢚫","𤧚","𧈲"}
	a[17360]={"𢐄","𢡆","𣧾","𤈗","𤎘"}
	a[17361]={"㸧","瑑","𤎂","𦖆","𦖟"}
	a[17362]={"䝒","𢙷","𢝭","𤩪","𥒣"}
	a[17363]={"聦","𧝚","𨠌"}
	a[17364]={"𧋳"}
	a[17370]={"硍","𩈢"}
	a[17371]={"䬸","珢","𢐗","𤫈","𦕨","𦖹"}
	a[17372]={"蛩","𧉨"}
	a[17373]={"裠","骚","","𤧷"}
	a[17374]={"瑵","𥎌","𧌣","𧎻","𨡮"}
	a[17375]={"𧎮"}
	a[17380]={"𧙭"}
	a[17382]={"碾","骤","𥕨","𨢊","𩨍"}
	a[17384]={"叇","蟊","𪑤"}
	a[17385]={"㻱","蝨"}
	a[17390]={"𢞔","𥎒","𥖤"}
	a[17392]={"𩜒"}
	a[17393]={"𨢭"}
	a[17401]={"𤪧"}
	a[17406]={"𤰏"}
	a[17410]={"","𪓥","𪓦","𪓱"}
	a[17411]={"","𪕡"}
	a[17412]={"䨲","璏","飁","","𨐾"}
	a[17413]={"𠣉","𤫅","𦒏","𧢱"}
	a[17414]={"𩥡","𪓭"}
	a[17415]={"𦢱","𩙝"}
	a[17416]={"𧖛"}
	a[17420]={"乙","","𠁽"}
	a[17421]={"卂","","𡯅","𥸦"}
	a[17430]={"己","已"}
	a[17431]={"观","𡈾"}
	a[17432]={"丮","","𠃥","𠃨","𠬭","𢦝","𢩦"}
	a[17440]={"㐒","卼","巩","觋","豝","𠃐","𠃮","𠑻","𣦽"}
	a[17441]={"厾","砜","𢁁","𥐜"}
	a[17442]={"虱","𥐠"}
	a[17450]={"卺","矶","矾","砚","𢀷","𢎪","𣧜","𥐗","𥐱"}
	a[17451]={"㺬","䎲","玑","现","𠒢","𢎩","𢎫","𣱏","𣳣","𤣱","𤤌","𤤗","𥑀"}
	a[17452]={"弛","驰","𢀜","𢑟","𣬻","𤣲","𦏸","𧟢"}
	a[17460]={"䩄","巶","巹","弝","𢀵","𢀶","𢀿","𣧼","𤬨","𤭀","𤭆","𥍨","𥑁","𥒍"}
	a[17461]={"孢","玘","珟","𠒉","𢁄","𣧟","𤬫","𦔶","𧠈"}
	a[17462]={"㝃","珮","耽","𠖙","𢟃","𤦍","𥑯","𧱎"}
	a[17463]={"𤱡","𧱧"}
	a[17464]={"𠙞","𠭋"}
	a[17467]={"𠭌"}
	a[17470]={"砲","硊","𠙛","𦐆","𦐙","𨚡"}
	a[17471]={"㢯","䂥","玸","𣄲","𤤲","𤥕","𥔒","𦕍","𦤽","𩈉"}
	a[17472]={"㻊","毣","珉","碸","𢀾","𤭿","𦕛","𩆊"}
	a[17473]={"酖","飘","𠭚","𢁇","𢬬","𤦥","𤧑","𤧔"}
	a[17474]={"酏","𦐪"}
	a[17480]={"㼦","䎂","𡰅","𢏱","𤬳","𥓋","𦫣","𩈆","𩈌"}
	a[17481]={"聣","𢃳","𢑝","𤦤","𤧾"}
	a[17482]={"配","𥒮","𨠁","𩘷","𩘸"}
	a[17483]={"𦫠"}
	a[17485]={"𥏰"}
	a[17490]={"靤","𦫥"}
	a[17491]={"𤩑","𩈦"}
	a[17492]={"䜸","𤭡","𨠖","𨠥","𨠶","𩙄","𩙅","𩲧"}
	a[17494]={"飄"}
	a[17495]={"𤩃"}
	a[17501]={"碬","磤","","𠭵","𣪐","𧲕"}
	a[17502]={"瑕","瓊","𢅜","𣩡"}
	a[17503]={"𤪨","𥀫"}
	a[17504]={"醙","𢥙","𤩴","𦗇"}
	a[17505]={"翬","𦑩"}
	a[17510]={"𪏬"}
	a[17511]={"㕚","又","叉","𣪾","𣫟"}
	a[17512]={"𥕸","𦖲"}
	a[17516]={"𤩚","𤩮"}
	a[17517]={"𤪆","𤪢","𨡫","𩃸","𩊳","𩨃","𩱃"}
	a[17518]={"𤧣"}
	a[17519]={"𣍛"}
	a[17521]={"及","廴","","𠬛"}
	a[17522]={"㕛","双"}
	a[17523]={"𡚩"}
	a[17531]={"𡕡","𦐐","𧰱"}
	a[17532]={"弔","𠡀","𡛺","𢌼","𢎨","𦐒","𧰸"}
	a[17533]={"叒","尹","𠬤"}
	a[17534]={"𡛒"}
	a[17541]={"䂘","歿","豛","驭","𠦕","𢄮","𢌟","𢎤","𢎭","𣧉","𦐏","𦐜","𧱕"}
	a[17542]={"㱟","𦐓"}
	a[17543]={"𡜹","𤿊","𧰵"}
	a[17544]={"叕","𠬺","𢁨","𤿐"}
	a[17551]={"㢠","帚","殁","砐","","𠦘","𠦦","𠬶","𢌡","𢎽","𣪃","𥍟","𧱣"}
	a[17552]={"㢰","取","破","羿","𡝠","𤣭","𤣻","𦔹","𦤶"}
	a[17553]={"玻","𤦾","𥑌"}
	a[17554]={"㜈","䝌","𤿢"}
	a[17555]={"𠡣"}
	a[17561]={"砓","翠","𠭈","𢌞","𣪅","𣪣","𥑊","𦐅"}
	a[17562]={"䜵","琡","砕","翇","翍","𢆙","𢑖","𤤄","𤥞","𤿴","𤿽","𦐧","𧱛"}
	a[17563]={"䂫","彛","璎","驿","𤥘"}
	a[17564]={"娶","帬","𠭱","𠭾","𢃆","𤣹","𤤏","𥍮","𪍫"}
	a[17565]={"𢌢","𢑺"}
	a[17566]={"砩","𠄴","𠮇","𡱉","𤿵","𧱇"}
	a[17571]={"聓","𣪌","𥍯","𥖮"}
	a[17572]={"䩅","翆","翣","𠭿","𢀤","𤩞"}
	a[17573]={"䜶","彞","𠮆","𤧅","𤾋","𩧰"}
	a[17574]={"珲","𤚉","𦏃","𨠈"}
	a[17575]={"䝍","琒"}
	a[17576]={"肂"}
	a[17577]={"建"}
	a[17581]={"豭","骎","𦕓","𩈑","𩈝"}
	a[17582]={"㱭","䃑","𠭪","𡕪","𢍟","𤥜","𤿻","𩨄"}
	a[17583]={"㻓","翚","酘","𤩆","𨠡"}
	a[17584]={"酔","𤿿","𥀘"}
	a[17585]={"羣","𣨿","𨋬"}
	a[17586]={"硉"}
	a[17587]={"珒","𤦯"}
	a[17591]={"䜷","𣆸","𣪏"}
	a[17592]={"璻","碫","𥕋","𦖚"}
	a[17593]={"䏂","瑖","𥔬"}
	a[17594]={"瑋","𤪍","𥎎"}
	a[17595]={"䡗","鞏","𢄥","𨋑"}
	a[17596]={"琿","醊","𣍇","𦘞","𨡃"}
	a[17597]={"𥍹"}
	a[17600]={"䃫","磖","𡃭","𣇶","𦐮"}
	a[17601]={"䃉","瑁","鬸","𥗆","𦗯"}
	a[17602]={"瑉","璐","𤳕","𦗎","𧩞"}
	a[17603]={"𨢇"}
	a[17610]={"𥗵","𥗻","𦑾"}
	a[17611]={"聸","𤩇","𥖷","𦗗"}
	a[17612]={"𡅡"}
	a[17616]={"𦥌"}
	a[17630]={"召","叾"}
	a[17631]={"𠮢"}
	a[17640]={"𠮸"}
	a[17641]={"𡥄"}
	a[17650]={"𠮯","𣆁"}
	a[17651]={"呄","圅","𣧳"}
	a[17653]={"君","𠭀"}
	a[17660]={"弨","𡇶","𥑱","𥒊"}
	a[17661]={"唘","玿","硌","骆","𠶱","𤥁","𤦿","𥑙"}
	a[17662]={"珞","𠭎"}
	a[17670]={"䂬","習","𠝽","𥔩"}
	a[17671]={"𤦱","𥅐","𥓆","𦐦"}
	a[17672]={"臵","𡥨","𣊃"}
	a[17680]={"𦐲"}
	a[17681]={"䀾","磂","骝","𧦪"}
	a[17682]={"琚","瑠","酩","𥉠","𥒽"}
	a[17683]={"酪","𥎈"}
	a[17684]={"珺"}
	a[17690]={"䛐","𡃠","𥕔","𧦬"}
	a[17691]={"㱪","䝀","瑂","𤪅","𦐯"}
	a[17692]={"𦑥"}
	a[17693]={"孴","𡦏"}
	a[17700]={"弼","翯","𢐆","𤾊","𦐱"}
	a[17701]={"㢽","𠼡","𠾉","𢐉","𢐾","𦖙","𦖳","𦖼"}
	a[17702]={"䤎","醑","𢐨","𢐮","𢐲","𦑖"}
	a[17704]={"𡦰"}
	a[17710]={"㣃","䰜","了","","","𢐬","𢐷","𢐹","𢑰","𦑼","𦒛","𦒞","𩈟","𩰲","𩱜","𩱡","𩱥","𩱭","𩱳","𪈊"}
	a[17711]={"孓","鬻","𤩈","𤩉","𥖇","𦒇","𦒫","𦒯","𩱌","𩱍","𩱓","𩱧","𩱨","𩱪","𩱮","𩱯","𪆀"}
	a[17712]={"䰞","璕","𢐼","𥜞","𨢫","𨣊","𩱆","𩱗","𩱚","𩱠","𩱦","𩱰","𩱲"}
	a[17713]={"骣","𢑌","𥗙","𩱖","𩱞","𩱟","𩱫","𩱱","𩱶"}
	a[17714]={"㻵","𢑍"}
	a[17715]={"𢐺","𩱷"}
	a[17716]={"𡦪","𡦷","𩱎","𩱣"}
	a[17717]={"𩱤"}
	a[17720]={"乃","予","孒","矛","","","𠃓","𠄎","𠙶","𡤼","𡭘","𡴻","𡵑","𢎘","𢒀","𨚀"}
	a[17721]={"子","孑"}
	a[17722]={"𠂐","𦘬"}
	a[17730]={"㞯","㞼","函","刕","弓","沀","邔","马","","","𠄕","𡶕","𢎗","𢎚","𢎛","𢎜","𢎟","𢎠","𢎱","𢐴","𨚸"}
	a[17731]={"夃","𡕔","𡬢","𦏽","𦚇","𨚁"}
	a[17733]={""}
	a[17740]={"㐨","㞪","㢧","𠀵","𠂏","𠃚","𠱛","𡖈","𢎝","𣧓","𥍤"}
	a[17741]={"㜿","孕","寻","𡤾","𡬞","𦛆"}
	a[17742]={"務","孖","甬","𡥆","𡰧","𢪻","𢬙","𤘅","𤰄"}
	a[17743]={"𡥅","𡥍"}
	a[17750]={"䂛","矞","砀","胥","𠄝","𢎥","𢎧","𢎻","𥓞","𥯵","𦏻","𦥖","𧱶"}
	a[17751]={"凾","玚","矷","","𠜦","𡥗","𤤂","𤤊","𤥌"}
	a[17752]={"㢴","㺭","郉","𠭽","𡻒","𤤚"}
	a[17753]={"勇"}
	a[17754]={"𣫮"}
	a[17755]={"𠭂"}
	a[17760]={"弜","码","脀","脋","𠚔","𠚚","𠨓","𠯶","𢐅","𢑑","𥍩","𥒢"}
	a[17761]={"孠","玛","𣨢","𣩗","𦏴","𦕬"}
	a[17762]={"㧬","𢑕","𣨍","𤥈"}
	a[17763]={"孨","𠭞","𡥦","𡦅","𨝍"}
	a[17764]={"珕"}
	a[17767]={"𤤖"}
	a[17770]={"驺","𠰟","𢏈","𢏖","𢏚","𢑔","𣨱"}
	a[17771]={"粥","𡥾","𢏷","𢑜","𤧨","𥕟","𦈩","𦛯"}
	a[17772]={"㻕","瑤","硧","确","","𢏧","𤨿","𦖯","𩢗"}
	a[17773]={"㝷","碀","𡍯","𢏰","𤥶","𥒷","𨟓"}
	a[17774]={"琤","","𠮀","𢭤","𢮝","𨜉"}
	a[17777]={"𦕚"}
	a[17780]={"弱","碢","碿","磶","𢐁","𢐐","𣨺","𥓒","𥓦","𦐟","𩧺","𩫉"}
	a[17781]={"尋","璚","𡬶","𢏺","𣄸","𤦆","𤧗","𦖄","𪀛"}
	a[17782]={"𤘎","𤧱","𨞝"}
	a[17783]={"𢱵","𣩌","𤧓","𩢽"}
	a[17784]={"𧐘","𩥦"}
	a[17785]={"𦩧"}
	a[17790]={"磆","骉","","𠝧","𠷎","𢏝","𦒔","𧯰","𪙲"}
	a[17791]={"弻","𢐥","𨞉"}
	a[17792]={"䳱","𥎠","𦞋","𩱈","𪘸"}
	a[17793]={"𢐌"}
	a[17794]={"𠮌","𦦖","𨠱"}
	a[17800]={"𥎗","𩈹"}
	a[17802]={"𤑵","𤮤","𨢎"}
	a[17806]={"歠"}
	a[17810]={"礖","","𥗄"}
	a[17811]={"璵","礥","𣤲","𣤻","𤆆","𤫂","𦘋","𩉏","𩉓"}
	a[17812]={"𤑨","𤫋","𨣦"}
	a[17813]={"㱋","㱌","𤩄","𥎤","𥗓"}
	a[17814]={"瓎"}
	a[17816]={"𤫌"}
	a[17817]={"靅"}
	a[17820]={"疋","𤆄","𧰫"}
	a[17821]={"买","欢","𠛇"}
	a[17830]={"灵","𢏅","𣢈","𣣖","𣧋","𣶙"}
	a[17832]={"㰢"}
	a[17840]={"㰤","䂹","弞","欩","砍","𣢇","𣣁","𣤬","𣧸"}
	a[17841]={"㚑","㺵","玖","","𢎴","𣢕","𤉎","𥎫"}
	a[17842]={"殃","熃","𣧎"}
	a[17850]={"㰯","㰷","𣣂"}
	a[17851]={"㺼","翜","𣢯","𣢶","𥒧","𦤷","𧻬"}
	a[17852]={"㠫","㷅","巬","砄","𢎹","𥑞","𩧫"}
	a[17853]={"奦","巭","玦","𤤠"}
	a[17854]={"欼","𤉅"}
	a[17855]={"𠭨"}
	a[17860]={"𣣌","𧱴"}
	a[17861]={"㻏","䂉","𣣄","𣣻","𥍶"}
	a[17862]={"瑍","𠔣","𢁉","𢑱","𢑴","𤥺","𦐍"}
	a[17863]={"歅"}
	a[17864]={"碘"}
	a[17865]={"琠","𣤜"}
	a[17870]={"㢲","㰳","歌","跫","𣣬","𣩆"}
	a[17871]={"㢿","䃢","𡥼","𣣺","𥎉","𥔢"}
	a[17872]={"㠱","𤧙","𤧝","𨄝"}
	a[17874]={"𣤌","𨠗"}
	a[17875]={"𦖌"}
	a[17880]={"𣤊"}
	a[17881]={"㱊","翭","𣤪","𤦚","𦑚","𩆂"}
	a[17882]={"𤪦"}
	a[17884]={"碶","𣤕"}
	a[17885]={"𤧃"}
	a[17886]={"𦗘","𨡏"}
	a[17890]={"翨","𤎧"}
	a[17891]={"䏃","礙"}
	a[17892]={"𣤩","𦘀"}
	a[17893]={"翼"}
	a[17894]={"𦑯"}
	a[17905]={"𦇚"}
	a[17910]={"","𡭖"}
	a[17913]={"𤃻"}
	a[17915]={"霴","𢑿"}
	a[17920]={"尕","氶"}
	a[17921]={"𡥀","𣎼","𣏉"}
	a[17930]={"𢑗","𣧢"}
	a[17931]={"朶","柔","𠬹","𣏗","𣏻","𣐱"}
	a[17932]={"𣏍"}
	a[17940]={"䂧","弥","录"}
	a[17941]={"珎","𣧷"}
	a[17942]={"㭆","𥹏"}
	a[17944]={"桑","𠬽"}
	a[17950]={"𢑙","𥑝"}
	a[17951]={"䅃","䊄","𠭫","𢑘","𣑦","𣓔"}
	a[17952]={"琛","𣒊","𣵳","𤨺","𥓃"}
	a[17953]={"𣖶"}
	a[17961]={"𢐣","𤧽","𥔔","𦀧"}
	a[17962]={"殩","瑈","瓈","𢑯","𣷗","𤤸","𤦰","𤧁","𦃤 ","𦕰"}
	a[17963]={"棸","𡦞"}
	a[17964]={"殔"}
	a[17970]={"碌","磜"}
	a[17971]={"㻮","琭","𣕡"}
	a[17972]={"𦁫"}
	a[17973]={"璨","𢑤","𤨪"}
	a[17974]={"磉","𥓏","𦑿"}
	a[17975]={"㻖"}
	a[17980]={"䎑","𢑨"}
	a[17981]={"䎼","䏅","𣕠"}
	a[17983]={"彚"}
	a[17985]={"𦖰"}
	a[17992]={"醁","𨢵"}
	a[17994]={"𤩦"}
	a[17996]={"𨢆"}
	a[18010]={"𣱺"}
	a[18020]={"𣦹"}
	a[18021]={"𡤿"}
	a[18030]={"𠇌","𢎢","𥐙"}
	a[18031]={"玐","𤤳"}
	a[18100]={"礛"}
	a[18101]={"璼"}
	a[18102]={"𨢴"}
	a[18103]={"𨢸"}
	a[18104]={"醝"}
	a[18112]={"𨣨"}
	a[18113]={"𨣎","𨤎"}
	a[18114]={"𠕱"}
	a[18131]={"𣴳"}
	a[18140]={"殓","𢎲"}
	a[18141]={"𣨎"}
	a[18150]={"㱲","砼","硷","碰","验"}
	a[18151]={"䂳","𢏬"}
	a[18152]={"堥"}
	a[18160]={"𥔞"}
	a[18161]={"硂","碒","𤧒","𥪛","𦕫","𩧴"}
	a[18162]={"㻇","琻","鍪"}
	a[18171]={"䜼","𤦴 ","𤨜"}
	a[18172]={"𣩈","𤥖"}
	a[18173]={"䨁","𡍶"}
	a[18181]={"𥕤","𦖬"}
	a[18182]={"磋","𨢘","𩱉"}
	a[18183]={"瑳","酫","𨣣"}
	a[18192]={"䤈","𦒁"}
	a[18194]={"𤨩"}
	a[18195]={"𨤲"}
	a[18201]={"霒"}
	a[18220]={"殄"}
	a[18221]={"㜾"}
	a[18230]={"䂦","矜","砎","𩧦"}
	a[18231]={"玠","珍"}
	a[18240]={"砛"}
	a[18241]={"玪","聄"}
	a[18242]={"𤥬"}
	a[18250]={"䪾","𣧫","𣨐","𩈋"}
	a[18251]={"耹","𤨤"}
	a[18260]={"䩂","砟"}
	a[18261]={"𤨋"}
	a[18262]={"𤪱","𨟹"}
	a[18270]={"𣩋","𧯤"}
	a[18280]={"䩆"}
	a[18282]={"酢"}
	a[18302]={"饏"}
	a[18310]={"𩉋"}
	a[18320]={"𧰻"}
	a[18330]={"矝","𥒨","𧰾"}
	a[18331]={"𢚢","𤤽"}
	a[18340]={"㥤","䃍","砱","𢏀","𣨝","𥍵"}
	a[18341]={"愗","玜","玲","𤦬"}
	a[18342]={"㤵"}
	a[18350]={"㢳","䂼","礈","𩨂"}
	a[18351]={"璲","硹","聆","𢾘","𤥼","𤥽"}
	a[18360]={"飱","餮","𩈖"}
	a[18361]={"㻅","磀","聡"}
	a[18362]={"𨠎"}
	a[18363]={"蝥"}
	a[18364]={"𥕻"}
	a[18365]={"璑"}
	a[18370]={"𠾥"}
	a[18371]={"聪","𢢭","𤪂","𩝕"}
	a[18372]={"䱯","憨","𦗄","𨡎","𨣢"}
	a[18374]={"𪑢"}
	a[18377]={"磏","𢐎"}
	a[18378]={"㻩"}
	a[18380]={"磁"}
	a[18381]={"𤧹"}
	a[18387]={"豏"}
	a[18388]={"𦖾"}
	a[18390]={"礠"}
	a[18391]={"𦖺"}
	a[18392]={"礢","𨢁"}
	a[18399]={"𨢑"}
	a[18404]={"𨡪"}
	a[18407]={"𨣞"}
	a[18410]={"𠄋","𡯓"}
	a[18412]={"霼","𨟮","𨣸","𨤋"}
	a[18430]={"瓰"}
	a[18440]={"𠚮"}
	a[18441]={""}
	a[18442]={"𤭅"}
	a[18450]={"","𤬯","𤬻"}
	a[18451]={"玱","𧱲"}
	a[18452]={"𥍢"}
	a[18454]={"𣮖"}
	a[18460]={"䂱","矻"}
	a[18461]={"𤣮","𥎃","𥑅"}
	a[18462]={"㢮","砤","𡦎"}
	a[18463]={"𤤩"}
	a[18470]={"𠃺","𠒻","𤭙","𥐬"}
	a[18472]={"𥍸","𥓌","𥔶"}
	a[18473]={"㻢","琷"}
	a[18474]={"𠮄","𣯛"}
	a[18480]={"𠄄"}
	a[18483]={"𦗅"}
	a[18484]={"𨠑"}
	a[18485]={"礒"}
	a[18486]={"㼁","𤩺"}
	a[18490]={"尶"}
	a[18492]={"𢑠"}
	a[18503]={"𦗪","𦘇"}
	a[18506]={"璷"}
	a[18509]={"𥖻"}
	a[18514]={"𣀳"}
	a[18521]={"𢌝"}
	a[18522]={"𢽴"}
	a[18531]={"攷","攻","敄","𣷜"}
	a[18532]={"㪀","孜","攼","𤉺"}
	a[18533]={"𢼅","𤊮"}
	a[18541]={"改","政","𢎿","𢼔","𥍦"}
	a[18542]={"㡔","玫","𠭕","𡝡"}
	a[18543]={"婺"}
	a[18551]={"𢌣","𥐭","𥑺"}
	a[18552]={"玝","硑","致","骈","𢏳","𦍙"}
	a[18553]={"㻂","𡥩","𢌦","𢼷","𪍓"}
	a[18554]={"𡠉"}
	a[18555]={"敪"}
	a[18561]={"𦒚"}
	a[18562]={"敔","敢","𢏙","𢽰","𥒞","𦒐"}
	a[18563]={"殚","珜","珶","聠","𢿖","𦎦"}
	a[18564]={"𢽏","𤛆"}
	a[18571]={"㢸","𢐍"}
	a[18572]={"𠵦","𢽤","𤨉","𧯪","𩈚"}
	a[18573]={"䃅","弹","𥔣"}
	a[18574]={"㬲"}
	a[18576]={"𣜹"}
	a[18582]={"𣀋","𤪖","𦗈","𦗸"}
	a[18583]={"磝"}
	a[18584]={"璈","璥"}
	a[18585]={"䃝","群","𤨨","𥔚"}
	a[18586]={"鞪","𨍎"}
	a[18591]={"礉","𢾼"}
	a[18592]={"璬","礅","𥎟","𥕵","𥖃","𦍽"}
	a[18593]={"㻻","䃟"}
	a[18594]={"𤩀"}
	a[18595]={"𨡙"}
	a[18596]={"𣀆","𣍏"}
	a[18597]={"𤪕"}
	a[18600]={"䰝"}
	a[18602]={"䤌","𦗢"}
	a[18604]={"𨡴"}
	a[18614]={"𨣁"}
	a[18650]={"硲","𥎏"}
	a[18651]={"","𤥫"}
	a[18660]={"㢵","硆","𥓂","𧲅","𩠑"}
	a[18661]={"暓","珨","琀","𥓺"}
	a[18670]={"𥎄","𦐬","𦒗"}
	a[18671]={"瞀","𦕲"}
	a[18672]={"𤦜"}
	a[18673]={"㻥"}
	a[18680]={"磳","𢐞","𣩮","𩈣"}
	a[18681]={"瑲","璔","𤩓"}
	a[18682]={"䣻","𣩧","𦖘"}
	a[18683]={"𨡭"}
	a[18691]={"璯"}
	a[18692]={"磰","𤩕","𥕼"}
	a[18693]={"𦖣"}
	a[18701]={"𤪔"}
	a[18710]={"鬺"}
	a[18712]={"𨢩"}
	a[18740]={"砏","𥍠","𥐤"}
	a[18741]={"嵍","玢","𠝸"}
	a[18742]={"𧱜"}
	a[18750]={"殇","翂","𧱬"}
	a[18751]={"聁"}
	a[18753]={"𠢐"}
	a[18760]={"𢐢"}
	a[18761]={"骛","鹜","𥒋","𥖴","𦕎"}
	a[18762]={"珤","碖","酚","𪚐"}
	a[18763]={"𤦎"}
	a[18770]={"䃋","𩨈","𩨊"}
	a[18771]={"瑐","瑜","𦕞"}
	a[18772]={"𪘯"}
	a[18773]={"䎾","騖","𧟯"}
	a[18774]={"珻"}
	a[18780]={"䜽","彅","殤","𥕀"}
	a[18781]={"鶩","𦖭"}
	a[18782]={"𤦽"}
	a[18783]={"𥖁"}
	a[18791]={"聬","𡦇"}
	a[18792]={"䤅","𥗖"}
	a[18793]={"䩈"}
	a[18795]={"酶"}
	a[18800]={"䩎"}
	a[18802]={"醶"}
	a[18805]={"𨣆"}
	a[18820]={"豵","𧲓"}
	a[18831]={"𤋄"}
	a[18840]={"磫","𢐔"}
	a[18841]={"㻜","瑽","𦕦","𦖏"}
	a[18851]={"䂠","矤","𥒆","𦗜"}
	a[18861]={"琁","𨂣"}
	a[18862]={"聅","联"}
	a[18870]={"殮"}
	a[18873]={"𤧞"}
	a[18880]={"䃠","礆"}
	a[18881]={"䃚","璇","𥖄"}
	a[18891]={"𦗹"}
	a[18893]={"磸"}
	a[18920]={"𣧠"}
	a[18930]={"𢏏","𥑒"}
	a[18932]={"𣻊"}
	a[18941]={"㮗"}
	a[18942]={"楘","𥠪"}
	a[18950]={"𩒈"}
	a[18951]={"䋷","硢","","𦁘","𦕗"}
	a[18952]={"㻌","𣺶"}
	a[18953]={"𣀗","𥼅"}
	a[18973]={"酴"}
	a[19021]={"孙"}
	a[19102]={"𨢉"}
	a[19112]={"𥗿"}
	a[19163]={"𡦓"}
	a[19170]={"㱯"}
	a[19171]={"𤘑"}
	a[19172]={"㼆","𣩑"}
	a[19173]={"𨡅"}
	a[19180]={"磑"}
	a[19181]={"𤧸"}
	a[19182]={"磪","𤨠"}
	a[19183]={"璀"}
	a[19230]={"砂"}
	a[19231]={"𤤉"}
	a[19241]={"𦕈"}
	a[19250]={"㢷","硶"}
	a[19251]={"琌"}
	a[19302]={"𡆊"}
	a[19320]={"𣧖"}
	a[19331]={"𢙏"}
	a[19341]={"㷦"}
	a[19351]={"𢞚"}
	a[19361]={"褧"}
	a[19373]={"醚","𤫁"}
	a[19441]={"𥕚"}
	a[19450]={"硄"}
	a[19451]={"珖","𥑓","𦕤"}
	a[19463]={"𤦔"}
	a[19470]={"硙","𥓤","𩧱"}
	a[19471]={"𡦒"}
	a[19481]={"𤨾"}
	a[19482]={"𣰲"}
	a[19484]={"𡐜"}
	a[19492]={"䃬"}
	a[19493]={"𤩫"}
	a[19513]={"𦨆"}
	a[19531]={"𢌚"}
	a[19542]={"𤥎"}
	a[19543]={"珱"}
	a[19552]={"弢","𥑍"}
	a[19553]={"𧲂","𩨇"}
	a[19562]={"𢏫"}
	a[19563]={"𤪏"}
	a[19564]={"𤤓"}
	a[19571]={"硸"}
	a[19572]={"瑺","𥻴"}
	a[19573]={"弾","磷",""}
	a[19574]={"璘"}
	a[19582]={"𩕼"}
	a[19584]={"𦗲"}
	a[19592]={"𤫉","𤮪"}
	a[19593]={"䫰"}
	a[19602]={"𦗴"}
	a[19611]={"𡿤"}
	a[19614]={"𨤂"}
	a[19651]={"𤥮"}
	a[19680]={"𥗞"}
	a[19681]={"𤫎","𥉔"}
	a[19691]={"礑"}
	a[19692]={"璫"}
	a[19700]={"磞","𢐒","𥖱"}
	a[19711]={"䨭"}
	a[19713]={"㼇","瓗"}
	a[19714]={"𨣛"}
	a[19720]={"𣧈"}
	a[19731]={"𧰹"}
	a[19732]={"𡙼"}
	a[19740]={"㢫","䝎","𥐢"}
	a[19741]={"㢼","𣧪"}
	a[19743]={"𤛮"}
	a[19750]={"矟"}
	a[19751]={"础","磱","𦔺"}
	a[19752]={"𤩂"}
	a[19760]={"弰","硝","𡷆","𥓡","𥔗"}
	a[19761]={"珰","琑","瑞","𧰎"}
	a[19762]={"聉"}
	a[19765]={"𠭴"}
	a[19770]={"碋","𥕂"}
	a[19771]={"𤨈","𥎐"}
	a[19772]={"磮"}
	a[19773]={"𨣃"}
	a[19782]={"礃","𨡀"}
	a[19792]={"𧲑","𧲚"}
	a[19801]={"𤪸"}
	a[19810]={"𤆉"}
	a[19811]={"𦘆"}
	a[19820]={"𣧛","𣨬"}
	a[19831]={"琰","𤊇"}
	a[19841]={"琐","耿","𥔍","𦖠"}
	a[19842]={"𤧐"}
	a[19851]={"碳"}
	a[19852]={"䎿","醈"}
	a[19863]={"𨡲"}
	a[19870]={"𥔭"}
	a[19871]={"瑣"}
	a[19872]={"𥎜"}
	a[19873]={"𤑶","𨤁"}
	a[19881]={"𤫙"}
	a[19920]={"𥙏"}
	a[19931]={"𣧲"}
	a[19941]={"𥒄"}
	a[19942]={"𤥄"}
	a[19952]={"𤪤"}
	a[19960]={"礯"}
	a[19971]={"𤨲"}
	a[20000]={"丨","丿","𪘶"}
	a[20001]={"𨟝","𨟬"}
	a[20002]={"𨤅"}
	a[20010]={"䌪","繝","𦅘","𦇾","𪙨"}
	a[20011]={"酁","𩻘","𩻾"}
	a[20012]={"酇","𧃪","𧤽"}
	a[20014]={"𦧼"}
	a[20016]={"酆"}
	a[20021]={"䢴","䣋"}
	a[20030]={"𨙵","𨛅","𨛒"}
	a[20031]={"郛","𨙼","𨛐","𨛶","𨞃","𨞄"}
	a[20032]={"邾","𨚕","𨛲"}
	a[20040]={"邭","邰","𨝐"}
	a[20041]={"䢾","䣎","𨛀","𨟀"}
	a[20042]={"𨚥","𨛖"}
	a[20050]={"䣀","邹","郇","𦃛","𨚍","𨚔","𨚖","𨛉","𨝉","𨝋"}
	a[20051]={"郜","𨜫"}
	a[20052]={"鄒","鄱","𨛥","𨜕","𨜗","𨞣"}
	a[20053]={"鄅","鄛","𨛰"}
	a[20055]={"郵"}
	a[20060]={"𨛕","𨜓"}
	a[20061]={"𨞙"}
	a[20062]={"𦀨","𨜻","𨝘"}
	a[20063]={"綁"}
	a[20064]={"𨞷"}
	a[20070]={"郷","鄉","𨝁","𨝣","𨝤"}
	a[20071]={"鄊","𥡕","𨛵","𨝰"}
	a[20073]={"绑","𨞒","𨞹"}
	a[20074]={"𨞲"}
	a[20080]={"𨜬","𨝳","𨞆"}
	a[20082]={"酂","𨟜"}
	a[20091]={"䣜","䱶","𨞘","𨟌","𩻗"}
	a[20092]={"𨞭","𨟣","𩸾"}
	a[20102]={"𧤎"}
	a[20104]={"𩡤"}
	a[20105]={"𥤊"}
	a[20110]={"丄","𠃊","𠃋"}
	a[20111]={"𥃓","𧈚"}
	a[20114]={"䌯","𩐖"}
	a[20115]={"鱹"}
	a[20116]={"䚭","𤜍"}
	a[20120]={"","","","𠂛","𣥆"}
	a[20121]={"㸒","壬","","𡈼","𡍮","𡐼","𥝍"}
	a[20130]={"纟","𢀩"}
	a[20131]={"盉","𡋧","𣥚","𤔊","𥁢"}
	a[20140]={"𢒉","𣥋"}
	a[20141]={"䅝","𦧆"}
	a[20142]={"𤤋"}
	a[20143]={"䅒"}
	a[20145]={"垂"}
	a[20150]={"㸜","纻","𤗇","𦁈"}
	a[20152]={"𡏕"}
	a[20153]={"𢀠"}
	a[20162]={"埀","𥡫"}
	a[20163]={"𥠙"}
	a[20164]={"㙑","𡍴"}
	a[20165]={"重","𡍺"}
	a[20170]={"𦄙","𪘫"}
	a[20171]={"𤨐","𦄔","𧰌"}
	a[20172]={"𡔅"}
	a[20173]={"𩷶"}
	a[20174]={"𤚣"}
	a[20181]={"䀉"}
	a[20190]={"𪘲"}
	a[20191]={"𩇺","𩸨","𪙜"}
	a[20193]={"𣦴"}
	a[20194]={"貛"}
	a[20200]={"彡","",""}
	a[20203]={"𩼚"}
	a[20210]={""}
	a[20211]={"䲙","乔","𠂚"}
	a[20220]={"乡","𢆯"}
	a[20221]={"𥝘"}
	a[20253]={"𩸌"}
	a[20261]={"𥤇"}
	a[20263]={"𩺳"}
	a[20281]={"𥣮"}
	a[20291]={"𩼶"}
	a[20300]={"乑","","𡿨","𧰨"}
	a[20303]={"𩼑"}
	a[20306]={"㦌"}
	a[20310]={"么","乏","厶","饗","","𠂓"}
	a[20311]={"𢘳","𤇕","𤇠"}
	a[20317]={"𧔁"}
	a[20319]={"𤜒"}
	a[20320]={"幺","𧱌"}
	a[20321]={"忎","悉","𢗩"}
	a[20322]={"𢘗","𤆬"}
	a[20331]={"丢","稼"}
	a[20332]={"䖝","𥢯"}
	a[20333]={"𠂻","𨤜"}
	a[20340]={"𢚩","𢡺"}
	a[20341]={"𦫌"}
	a[20342]={"𧘰"}
	a[20343]={"𥡍","𧉷"}
	a[20351]={"綋","𩻢"}
	a[20352]={"蚃"}
	a[20353]={"𥣛","𧒁"}
	a[20354]={"熏","繱"}
	a[20355]={"𢛲"}
	a[20360]={"㥯"}
	a[20362]={"𦆟"}
	a[20365]={"𤋱"}
	a[20366]={"𧴟"}
	a[20370]={"𪘋"}
	a[20373]={"𦆥","𦇎"}
	a[20374]={"䌭","𤯻"}
	a[20385]={"𧕤"}
	a[20386]={"䌲","纄"}
	a[20400]={""}
	a[20403]={"鱵"}
	a[20406]={"𤜐"}
	a[20410]={"㐍","乚","乥","𠄌","𤕄"}
	a[20411]={"禿"}
	a[20414]={"𧈋","𪚼"}
	a[20415]={"𥤠"}
	a[20420]={"觅"}
	a[20421]={"乇","乯"}
	a[20430]={"𤔓"}
	a[20431]={"秃","𥞒"}
	a[20432]={"兎","毛","𤔆"}
	a[20440]={"紽","𡖟","𤓸"}
	a[20441]={"乖","𠾄"}
	a[20442]={"㸰","䅊","秺","𠨟","𢩥","𣬜","𤘺"}
	a[20443]={"𥠸"}
	a[20450]={"覓","𡖢"}
	a[20451]={"𤔞","𥟶"}
	a[20452]={"𡊥"}
	a[20453]={"𣮬","𥡃"}
	a[20455]={"𥟪","𥣫"}
	a[20457]={"𣩖"}
	a[20460]={"綄","綩","𤗍","𪗩"}
	a[20461]={"鮀","𨤖"}
	a[20462]={"𣮤","𦃑","𧣖"}
	a[20464]={"䌩"}
	a[20466]={"𣯣"}
	a[20470]={""}
	a[20471]={""}
	a[20472]={"𩶱"}
	a[20474]={"𡙶","𣯚","𣰥","𦇪"}
	a[20481]={"鯇","𩸩"}
	a[20482]={"𩽽"}
	a[20485]={"氁","鱴","𣯏","𩺆"}
	a[20486]={"𤛻"}
	a[20491]={"鲩"}
	a[20492]={"𦆼"}
	a[20493]={"𩽣"}
	a[20495]={"𩼘"}
	a[20496]={"毳"}
	a[20502]={"𩼵"}
	a[20506]={"鱯"}
	a[20511]={"千","币","","𠂟","𠄒","𠦬","𠧏 ","𠬪","𠭡"}
	a[20512]={"妥","𢍒"}
	a[20514]={"𩽕"}
	a[20516]={"鳠"}
	a[20521]={"受","𣁍"}
	a[20522]={"䄹","叐","秊","","𠂝","𤓾"}
	a[20523]={"委","𢍏"}
	a[20531]={"愛","𠭧","𤓴","𤓿"}
	a[20532]={"爰","爱","𠂷","𡴘","𤔠","𥝝","𨤑"}
	a[20533]={"䄵","𢎣","𥝯","𥞬"}
	a[20534]={"𢍃"}
	a[20535]={"𠂯"}
	a[20536]={"𤕇"}
	a[20541]={"𤔂","𤔐"}
	a[20542]={"舜","𡖨","𤙋"}
	a[20543]={"𤔤","𤚔"}
	a[20544]={"𠦚"}
	a[20552]={"䎹","𤔣","𦖗","𦥛","𩰣"}
	a[20553]={"𤔒"}
	a[20554]={"䅸"}
	a[20555]={"𠡦"}
	a[20557]={"𤛘"}
	a[20561]={"縡","𤔫"}
	a[20562]={"𩰥","𩹔"}
	a[20563]={"鮟"}
	a[20564]={"穁"}
	a[20565]={"𦧹"}
	a[20566]={"𨋟"}
	a[20568]={"䅿","𦂓"}
	a[20571]={"𠮗","𤔪","𤔭","𨤝"}
	a[20573]={"縙","𩽾"}
	a[20575]={"緙"}
	a[20576]={"穫"}
	a[20581]={"𡕽","𡖀"}
	a[20582]={"𡢛","𤔿","𤕀","𦄎"}
	a[20584]={"𩺵"}
	a[20585]={"𧤱","𨏜","𩹋"}
	a[20591]={"𠧎","𤕍"}
	a[20592]={"𡕼"}
	a[20593]={"𪉼"}
	a[20595]={"𧤣"}
	a[20598]={"𩻮"}
	a[20599]={"𧤻"}
	a[20600]={"𥖡"}
	a[20603]={"𪙏"}
	a[20604]={"𩡔"}
	a[20610]={"響"}
	a[20613]={"馫"}
	a[20614]={"𥤜"}
	a[20620]={"𠱦"}
	a[20630]={"㸓"}
	a[20631]={"㕿","呑","舌","𠮮","𠳅"}
	a[20640]={"𥄃"}
	a[20641]={"稥","香","𣅌","𪊁"}
	a[20642]={"番","𣬧","𤱜"}
	a[20643]={"貓"}
	a[20650]={"噕"}
	a[20651]={"㸔","𪏰"}
	a[20652]={"𩠼"}
	a[20654]={"䅦","𥟾"}
	a[20660]={"𧬑"}
	a[20661]={"𦄲"}
	a[20662]={"䌋","看","𦁖","𨤗","𩡠"}
	a[20663]={"緢","𦂍"}
	a[20665]={"𤚐"}
	a[20670]={"縮"}
	a[20671]={"鰫"}
	a[20672]={"𥄥","𦈘","𨤓"}
	a[20674]={"𤔱"}
	a[20680]={"缩"}
	a[20681]={"𤕈","𪘺"}
	a[20682]={"𨣩","𩡌","𩹃"}
	a[20683]={"縖","𩺗"}
	a[20684]={"鰙","𣦡","𦅷"}
	a[20685]={"犗"}
	a[20690]={"㗽"}
	a[20691]={"𠃇"}
	a[20692]={"𦇃"}
	a[20693]={"舙"}
	a[20694]={"𦧮"}
	a[20700]={"亅","嚮","豸"}
	a[20702]={"𪙰"}
	a[20703]={"𩼙"}
	a[20708]={"𩼬"}
	a[20710]={"屲","𠃀"}
	a[20711]={"䲘","乎","寽","鳤","𠂌","𠂿"}
	a[20715]={"𪚈"}
	a[20717]={"𪚂"}
	a[20718]={"𩽛"}
	a[20720]={"𠂜","𠂞","𠂠","𤔃"}
	a[20721]={"㟀","孚","岙","𠀭","𠂍","𤓳","𤔁","𥜻"}
	a[20722]={"手",""}
	a[20730]={"爲","𠌶","𤔄","𦙔"}
	a[20731]={"䍃","秀","𡥞","𡬳","𢆲","𤔡","𦉈"}
	a[20732]={"季","𡷩"}
	a[20733]={"爭","𠢏"}
	a[20734]={"爯"}
	a[20740]={"爳","紵","舀","𦟝"}
	a[20741]={"𡹁","𤔔","𥝙","𦙖"}
	a[20743]={"禹","𥞌"}
	a[20744]={"𤔇"}
	a[20745]={"𡸁"}
	a[20750]={"𤔌","𤔦"}
	a[20751]={"䌏","臿","𤔸","𤲑"}
	a[20752]={"𣅲"}
	a[20753]={"牸"}
	a[20755]={"𤙯"}
	a[20760]={"𤔘"}
	a[20761]={"喬","穒","𥟓","𥣗","𩶂","𩾭"}
	a[20762]={"𤔬","𪙖"}
	a[20766]={"掱"}
	a[20770]={"綰","馆","𤔰","𤔴","𪙼"}
	a[20771]={"爵","𦥫","𦥲"}
	a[20772]={"𦃜"}
	a[20773]={"𥢸"}
	a[20774]={"𤗩"}
	a[20775]={"𥤆"}
	a[20776]={"𤛟","𦈼"}
	a[20779]={"𨤚"}
	a[20780]={"绾"}
	a[20782]={"𦅶","𩰨"}
	a[20783]={"𠚟"}
	a[20784]={"𦇩"}
	a[20787]={"𤛶"}
	a[20790]={"䌣"}
	a[20793]={"𤯸"}
	a[20800]={"乊","𠂹"}
	a[20801]={"馪","𩼧"}
	a[20810]={"貁","辵","𤈚","𤏀"}
	a[20811]={"夭","秂","𡗮","𤇫"}
	a[20815]={"𩽜"}
	a[20821]={"𤓻","𧺆"}
	a[20822]={"𠂕","𢪐","𣬱","𥝚"}
	a[20830]={"䋉"}
	a[20831]={"奚","𡗞"}
	a[20833]={"𥟕"}
	a[20840]={"𧴭"}
	a[20841]={"𥟐","𨁢"}
	a[20842]={"𤕃","𦆬"}
	a[20845]={"𥠚"}
	a[20850]={"綻","𩠆"}
	a[20853]={"貘"}
	a[20860]={"绽","缤","𥦶","𧴺"}
	a[20864]={"𥡸"}
	a[20871]={"穦","𩸎"}
	a[20872]={"縯","𨅴"}
	a[20873]={"縸","馍"}
	a[20875]={"𩹅"}
	a[20880]={"繽"}
	a[20894]={"𧸬"}
	a[20900]={"爫","𤓯"}
	a[20907]={"㯔","𥼛"}
	a[20911]={"禾","釆","采","𥝩"}
	a[20916]={"䄟"}
	a[20920]={"糸","糹","系","𣲛","𤓹","𤔍","𤔹","𦃃"}
	a[20921]={"黍","𤓽","𥝸"}
	a[20922]={"𠂲","𥞫","𦓤"}
	a[20930]={"𦅽"}
	a[20931]={"𥞆"}
	a[20933]={"𣏮","𣗷"}
	a[20935]={"乗"}
	a[20940]={"𦃟"}
	a[20941]={"乘","𤔳"}
	a[20942]={"𢯣","𣒧"}
	a[20944]={"䅷","𡘸"}
	a[20945]={"秉"}
	a[20950]={"綜"}
	a[20951]={"𤔥"}
	a[20952]={"𥟅","𦃝"}
	a[20955]={"𨤘"}
	a[20956]={"𥢇"}
	a[20960]={"综"}
	a[20962]={"𣖄"}
	a[20971]={"鯮"}
	a[20972]={"䌨"}
	a[20996]={"𩻧"}
	a[21010]={"⺊"}
	a[21030]={"𤕬"}
	a[21100]={"䌔","𦃄"}
	a[21101]={"𥂷","𦄕","𩸋"}
	a[21102]={"𤛐","𧣰"}
	a[21103]={"鰋","𤛏","𥃍","𩻖","𪙛"}
	a[21104]={"䱳","𩺱"}
	a[21110]={"𦈗","𩐃"}
	a[21111]={"䶥","鰸","𤖥","𤖦"}
	a[21112]={"繮","纑","缰","鱷","𥤞","𦆠","𦇤","𩐏","𩽙","𪘽","𪙾","𪚍"}
	a[21113]={"䲔","鱸","𤜙","𤴅"}
	a[21114]={"㹔"}
	a[21115]={"𤜅"}
	a[21120]={"上","止","豾",""}
	a[21121]={"䝙"}
	a[21130]={""}
	a[21131]={"䄳","䅉","秠"}
	a[21140]={"䊼","䋔","紅","","𠧴","𣥌","𣥕","𣥖","𣥗","𦳌","𧖭","𧲽"}
	a[21141]={"𠧟","𡋬","𦤸"}
	a[21142]={"𤘹"}
	a[21150]={"䋊","絚","經","緪","红","貆","𣦄","𦈊"}
	a[21151]={"秬","虚","𠧱","𡌓","𦀇","𦀰","𧴆","𪉟"}
	a[21152]={"牼","秷","𡋪","𧴠","𪉖"}
	a[21153]={"𡎱","𥠍"}
	a[21160]={"䊺","䋌","䋗","歫","歮","饾","𠧠","𠧡","𦣽","𧳔","𧴎"}
	a[21161]={"絰","虗","魟","魾","𡖧","𪉙","𪏳"}
	a[21162]={"𡍏","𣥮","𤥹","𧢸","𨧔"}
	a[21163]={"𥤀"}
	a[21170]={"䇓","盨","絙","縆","𣦐"}
	a[21171]={"䱍","䱭","稏","绖","虛","𩷏","𪉣"}
	a[21172]={"虐","𤖢","𤘃","𤙆","𤪇","𦁩","𦇔","𨿳","𩵭"}
	a[21173]={"緸","𩷗"}
	a[21175]={"𤚕"}
	a[21176]={"䌳"}
	a[21180]={"䶙","貙","𠨅","𤖋","𦀞"}
	a[21181]={"䖒","䱌","䱏","虘","魱","鮔","𦅟","𧈀","𪗻"}
	a[21182]={"𥃈","𦃶","𦃷","𦄒","𧣒","𩶪"}
	a[21183]={"緾","雐","𦈑"}
	a[21184]={"𪐌"}
	a[21190]={"𣦕","𩠝","𩠡"}
	a[21191]={"䱎","䱴","𣦙","𥠶","𪙫"}
	a[21192]={"䚙","盧","鱋","𤖙","𤨗","𥡧","𨡰","𪘬","𪙽"}
	a[21193]={"𥃎","𦆑","𨨾","𩽏"}
	a[21194]={"𣯄","𥃏"}
	a[21201]={"馡","鯡","𧇁"}
	a[21202]={"𩇾"}
	a[21211]={"鲱","𧈂"}
	a[21212]={"𩽶"}
	a[21220]={"步","歩","歺","",""}
	a[21230]={"㱑","卢","𠧣","𠧳","𣥍","𤕫","𥾎"}
	a[21231]={"卐","𩰋"}
	a[21232]={"𠧜"}
	a[21240]={"𠧕","𠧻","𥾦","𦁗"}
	a[21242]={"𥹟"}
	a[21250]={"𣥩","𣥶"}
	a[21260]={"𤖄","𪗞"}
	a[21261]={"𩵧","𩷖"}
	a[21270]={"𣥿"}
	a[21271]={"𣦖","𥟍"}
	a[21280]={"緋","𤗋"}
	a[21281]={"鲈"}
	a[21290]={"绯","鼑"}
	a[21291]={"䱖","𪉷"}
	a[21302]={"𧔪"}
	a[21311]={"𢥨"}
	a[21320]={"卡","𢙡"}
	a[21330]={"忐","点","𠧗","𢙤","𢚎","𣥏"}
	a[21340]={"㤐","𢗓"}
	a[21341]={"䋬","秐","𥝮"}
	a[21342]={"𢝐","𤙐"}
	a[21350]={"紜","𢆹","𥾬"}
	a[21351]={"虑","豦","𤎴","𦁔","𧆝","𧴘"}
	a[21352]={"舔","虙","𤘳","𧉘","𧤲"}
	a[21353]={"𥡤"}
	a[21360]={"纭","𠨀","𢡬","𢤧","𦁄"}
	a[21361]={"鱁","𢛂","𧆸","𪐇"}
	a[21362]={"𥢚","𧤶"}
	a[21363]={"𥡱"}
	a[21371]={"繧","𥡷","𦄖","𧆹","𩵷"}
	a[21372]={"𤐸","𧣎"}
	a[21377]={"𦇼"}
	a[21380]={"𧶀","𪘝"}
	a[21381]={"𠫽","𩷩"}
	a[21382]={"慮","𤑰","𤓜","𥢴","𧣨"}
	a[21383]={"㦣"}
	a[21384]={"𦇟"}
	a[21391]={"䌢","𤖜"}
	a[21393]={"𦆄"}
	a[21400]={"𤭧","𤮘"}
	a[21401]={"𪘰"}
	a[21402]={"𧇢"}
	a[21403]={"𧇱","𧣾"}
	a[21404]={"𣰜","𧈊"}
	a[21410]={"䌬","甔","","","𪚖"}
	a[21411]={"䆍","甗","𤮙","𤮭","𪐖"}
	a[21412]={"纚","虤","𤜆","𤜎","𤮣","𤮧","𧈄","𩺺"}
	a[21413]={"穲","鱺","𤮝"}
	a[21414]={"𧥖"}
	a[21415]={"𣰼"}
	a[21416]={"𧥗"}
	a[21430]={"𠂧","𠑷","𠧒","𠧝","𠧽","𣲊","𧲦"}
	a[21431]={""}
	a[21440]={"𣥅","𣥓","𣥪","𥾕","𥾳"}
	a[21441]={"虍","𠒑","𠒣","𢆋"}
	a[21442]={"歲","歳","𥝪","𥝾","𧴖"}
	a[21450]={"𠧢"}
	a[21451]={"䖈"}
	a[21452]={"𣭏"}
	a[21453]={"穢"}
	a[21454]={"𣰹"}
	a[21460]={"𠨜","𤖊"}
	a[21461]={"䝞","虎","𤗑","𩶏"}
	a[21462]={"㼡","毡","甁","𣯪","𦂬","𦅵","𦆡"}
	a[21463]={"瓾"}
	a[21465]={"𣭿"}
	a[21470]={"瓵"}
	a[21471]={"魭","𤭇","𧆧","𩵡"}
	a[21472]={"虢","𣮗","𣮻","𣰃","𧣂","𩵪"}
	a[21473]={"𠓄","𣭞","𤯮","𥢈","𧢾"}
	a[21474]={"毢","𣰑"}
	a[21476]={"𣮚"}
	a[21480]={"頾","𤭘"}
	a[21481]={"𠿻","𤗕","𦁲"}
	a[21482]={"㽃","穊","鯱","𢇒","𧆬"}
	a[21483]={"䖗","鱥","𣯋"}
	a[21484]={"𣯗"}
	a[21485]={"甀","𤭮"}
	a[21490]={"𤮎","𦫤"}
	a[21491]={"𤮆"}
	a[21492]={"毴","鮿","𩾇"}
	a[21502]={"㪥","鰤","𣀝","𩐅","𩡘"}
	a[21503]={"𣀞"}
	a[21511]={"𠮘"}
	a[21512]={"𩽇","𩾎"}
	a[21513]={"㪭","㹛","䌰","顰","𣀶","𦇉","𦇸","𩖓"}
	a[21514]={"鱏","𢍷","𤛽","𧤧","𩡝","𩽪"}
	a[21515]={"𨏞"}
	a[21521]={"师","攴","豻","𧲺"}
	a[21522]={"𧲨"}
	a[21531]={"𠦀","𠦋","𠧔","𠧘","𢻭","𢻲","𣥈"}
	a[21532]={"媭","秆","秤"}
	a[21533]={"䄯","𠤡","𢼻"}
	a[21541]={"敊","𡴃","𢆌","𢻸","𢽥","𢽨","𣥰","𤖳","𥾍","𥾲"}
	a[21542]={"䖍","𠦮","𢌱","𣥎"}
	a[21543]={"㸩","𢼲","𤘴","𤘾","𥠛"}
	a[21544]={"𣥟"}
	a[21551]={"卓","敁","𠧫","𢂦","𢼌","𢼒","𢾃","𢿈","𧳝"}
	a[21552]={"虔","𠧾","𢼛","𢼤","𢽿","𢾽","𣀎","𦅙","𧆞"}
	a[21553]={"𢼾","𣥷"}
	a[21554]={"𢪙","𢿹","𧟰"}
	a[21555]={"稉"}
	a[21556]={"𢾦"}
	a[21561]={"䋙","饵","𢄼","𢼨","𤖁","𪗙","𪗡"}
	a[21562]={"㪓","䌄","嬃","魳","鮃","𢆒","𢿢","𣥭","𦁭","𦄱","𩶨","𪉞","𪗛"}
	a[21563]={"𠧺","𠮅","𢻛","𢿥","𧣀"}
	a[21564]={"䌁","綆","緶"}
	a[21565]={"拜"}
	a[21566]={"𤚘"}
	a[21571]={"䌺","綽","𢽣","𢿮"}
	a[21572]={"㪕","敮","處","鲆","𢆢","𦂇","𧯭"}
	a[21573]={"𢿑","𤙴","𤚨","𧆥","𧇆","𧇧"}
	a[21574]={"绠","缏","𤚳"}
	a[21581]={"绰","𢽭","𢾆","𥜂"}
	a[21582]={"敽","𡤫","𥣯","𪉫"}
	a[21583]={"颦","𤚷","𤚿","𩹐","𩺇"}
	a[21584]={"𥢏"}
	a[21585]={"鯁","鯾"}
	a[21591]={"㪫","纋","𢿡","𣀁","𦗁"}
	a[21592]={"𢆩","𩷹","𪉲"}
	a[21593]={"鰬","𢿊","𣦩","𤛾","𦈙","𧣺","𧤿"}
	a[21595]={"鲠","𢀋","𤛫"}
	a[21602]={"鰏"}
	a[21603]={"䅾"}
	a[21610]={"𧭹"}
	a[21612]={"䌮","䖜","鲾","𦇢","𧈔","𧭭"}
	a[21613]={"𩻛"}
	a[21630]={"占","𠧚","𠧪","𧳏"}
	a[21631]={"卤","鹵"}
	a[21632]={"卥"}
	a[21640]={"貊","𠮳","𣦗","𧮲"}
	a[21641]={"䄷","秥","𠧧","𠧸","𥞶"}
	a[21642]={"䄼"}
	a[21650]={"㔽","㫖","䜭","卣","𡖞","𣥜","𥿕"}
	a[21651]={"黏","𣑅","𣑾","𣥤","𧳎"}
	a[21653]={"䄽"}
	a[21660]={"絔","𣥧","𣦉","𥅵","𥇨","𥓇"}
	a[21661]={"𪉜"}
	a[21662]={"絤","𦧖"}
	a[21663]={"𥟁"}
	a[21664]={"牺"}
	a[21670]={"睿","緬","縉","𥈠","𪗦"}
	a[21671]={"鮎","鮖","𣥸","𤕻","𦀡","𧇖","𪘭"}
	a[21672]={"稫","綇","𤚛","𥕿","𦈋","𧆨","𧆱","𧇄","𧣔","𨟻"}
	a[21673]={"牾","𧆭"}
	a[21680]={"缅","缙"}
	a[21681]={"䋹","鲇","龉","𤗚","𩉃"}
	a[21682]={"䵗","𣊑","𩷵"}
	a[21690]={"𠨋","𢒷"}
	a[21691]={"䌿","齬","𦆇","𧈘","𩹠"}
	a[21692]={"鯃","𥢋"}
	a[21693]={"䲤","鯂","鱩"}
	a[21694]={"𧣮"}
	a[21700]={"𪙚"}
	a[21701]={"繻"}
	a[21702]={"膚","𦢖"}
	a[21703]={"㹘","𩤌"}
	a[21711]={"𦈡","𪙿"}
	a[21712]={"鱈","鱬","鳕","𥤃","𪇿"}
	a[21713]={"虧"}
	a[21714]={"䲐","𤜏","𦆷"}
	a[21715]={"𢖨","𩽔","𪙺"}
	a[21716]={"鱱","𧈉"}
	a[21717]={"𩽷"}
	a[21720]={"⺞","",""}
	a[21730]={"与","糽","饤","齿","𠨁","𡵩","𣥑","𣦵"}
	a[21731]={"𠬣","𥝑","𥞟","𥞧","𦙡"}
	a[21732]={"䄨","䄰","𤘖"}
	a[21736]={"穪"}
	a[21740]={"絎","齒","𠧷","𠨂","𥿶","𧴓"}
	a[21741]={"⻭","䋑","歯","紆","緉","𠄚","𠧤","𠧲","𠧼","𡥋","𥝜","𥞍","𦁥","𦂲"}
	a[21742]={"歬","𠧿","𥜽","𥾙","𩡨"}
	a[21745]={"䌤"}
	a[21750]={"㱒","䊸","䋍","牁","绗","肯","肻","𥾝","𧳲"}
	a[21751]={"䰳","纡","𠬙","𣦃","𤱹","𥢠"}
	a[21752]={"牱","禼","虏","虖","𢪓","𥜾","𧢴"}
	a[21753]={"𥡗"}
	a[21754]={"䖏"}
	a[21760]={"䋪","卨","𠧰","𣥴","𣦒","𦅏"}
	a[21761]={"鮞","齖","𠨄","𠨆","𡥣","𣥯","𧆪"}
	a[21762]={"䅶","䖉","𣦭","𤙀","𧢵","𩡽","𩶀","𩶁"}
	a[21763]={"駂","𧣐","𩦛","𩵯"}
	a[21764]={"𤚴","𩢻"}
	a[21766]={"𩣣"}
	a[21770]={"䶗","𣥫","𣥼","𣦋","𤗦","𦃔"}
	a[21771]={"縟","魺","鲕","𠨈"}
	a[21772]={"𤗭","𧆜","𧆣","𩆟","𩢠","𩱅"}
	a[21773]={"𤚾","𩣂"}
	a[21774]={"𩣎"}
	a[21780]={"𦈀","𪙹"}
	a[21781]={"缛","鲄","鲡","𩻞"}
	a[21782]={"𠚝","𢮠","𤔧","𦒕","𩢑","𩥓"}
	a[21783]={"虜","鰢","𧆿","𩺂"}
	a[21784]={"𩒹","𩓾"}
	a[21785]={"𧇏"}
	a[21786]={"𥣭"}
	a[21787]={"𩣷"}
	a[21791]={"鬳","𩹺"}
	a[21792]={"䲗","穤","𧤜","𪙥"}
	a[21795]={"𦆨"}
	a[21797]={"犡"}
	a[21800]={"䫜","顚","𩓟","𩔤"}
	a[21801]={"𤖤","𩔓","𩹸"}
	a[21810]={"龰","𩕢","𩕨"}
	a[21811]={"纈","𩖂","𩖌","𪚉"}
	a[21812]={"贙","顱"}
	a[21813]={"躗","𥣶","𩔺"}
	a[21814]={"𤓤"}
	a[21820]={"仧","贞","顺","须","𠧖","𣥐"}
	a[21830]={"歨","颎","𠧯","𢒩","𣦊","𤈭"}
	a[21831]={"𤍙"}
	a[21832]={"𡙾"}
	a[21840]={"顷","颍","频","颕","𠧛","𣦁","𨑛","𩖕"}
	a[21841]={"奌","颖","𠧵","𡙉","𤎵","𥎩"}
	a[21842]={"稬","𤌺","𪉗"}
	a[21843]={"𤘠"}
	a[21845]={"𡙏"}
	a[21850]={"䫉","縰","貞","順","須","颅","𤈱","𤈴","𤉭","𤖈","𦁡","𩑎","𩑑"}
	a[21851]={"緛","虡","颓","","𣦌","𤕺","𥎼","𧇀"}
	a[21852]={"𡚋"}
	a[21860]={"熲","","𩑮","𩓄"}
	a[21861]={"䅡","頱","頹","𧆩","𩒧"}
	a[21862]={"𡡓","𩓚"}
	a[21863]={"𤛦","𧆾"}
	a[21870]={"䋶","䫂","潁","緽","頃","頉","頻","𤌮","𦄼","𦅨","𨙁","𩑗","𩒛","𩓇","𩓣","𩓭"}
	a[21871]={"㯋","穎","𩑒","𩑦","𩓀","𩓖","𩓙","𩓬"}
	a[21872]={"䪻","頯","𤐧 ","𤓞","𥣇","𩑩","𩒶","𩹓"}
	a[21873]={"䫋"}
	a[21874]={"𩒰"}
	a[21880]={"䪷","䫠","䫩","頕","頴","顈","𣾢","𩒎","𩓯","𩔂","𩕞"}
	a[21881]={"䫣","纐","頟","頢","頺","頽","𩑴","𩒙","𩕓","𩕖"}
	a[21882]={"虞","鱖","𩔃"}
	a[21883]={"𧤼"}
	a[21884]={"䫇","𢀊","𩓿","𩔋"}
	a[21890]={"頠","頥","頿","𦅐","𦇖","𩑨","𩑽","𩒨","𩔪","𩔻","𩖁"}
	a[21891]={"䫝","缬","頶","𩒵"}
	a[21892]={"顪","鳜","𥣘","𩓅","𩕏"}
	a[21893]={"𩓞","𩔔","𩔹"}
	a[21894]={"𧇽"}
	a[21901]={"𣡼","𥾄"}
	a[21903]={"鳔"}
	a[21916]={"𠨌"}
	a[21920]={"尗"}
	a[21921]={"𥝣"}
	a[21930]={"紑","𠧶","𠧹","𤖯"}
	a[21931]={"𣏔","𥹄","𥹐","𨤐"}
	a[21932]={"𤘢","𤙦"}
	a[21940]={"䝠","𥘣"}
	a[21941]={"㮚","𥻆"}
	a[21950]={"𣦅"}
	a[21951]={"桌","𣓨","𥟃","𥟫","𩵣"}
	a[21952]={"𣗴"}
	a[21954]={"𥠲","𥢕"}
	a[21960]={"澃","縓","𦂥"}
	a[21961]={"䝣","䱈","鮛","𦅸"}
	a[21962]={"㹉","𣖴"}
	a[21963]={"䅺","䌚","𡤍","𦃊","𧇃"}
	a[21964]={"𠨇"}
	a[21970]={"𦅓"}
	a[21971]={"𦂘"}
	a[21972]={"縹","觨"}
	a[21980]={"𣻯"}
	a[21981]={"𦄽"}
	a[21982]={"缥"}
	a[21983]={"𧇥"}
	a[21993]={"鰾"}
	a[21994]={"𣟉"}
	a[22000]={"川","","","","","","","","","","𣥂"}
	a[22010]={"丩","","","𠂈","𨶼"}
	a[22011]={""}
	a[22020]={"爿","紃","絒","","","𠂁"}
	a[22022]={"㸪"}
	a[22030]={"糾",""}
	a[22032]={"㸨","𠂦","𤰃"}
	a[22040]={"纠"}
	a[22041]={"舏"}
	a[22042]={"𤰆"}
	a[22043]={"𠂵"}
	a[22050]={"紖","𣶒"}
	a[22052]={"觓"}
	a[22055]={"𢍖"}
	a[22060]={"纼"}
	a[22062]={"𧆮"}
	a[22071]={"𧆢"}
	a[22100]={"㡭"}
	a[22106]={"䱰"}
	a[22110]={"繼","𣦱"}
	a[22111]={"鑾","𤫜"}
	a[22113]={"𡐪"}
	a[22114]={"𡒽"}
	a[22116]={"豐","𧯽","𩾋"}
	a[22120]={"𧲰"}
	a[22130]={"","𡳿"}
	a[22131]={"𥂑"}
	a[22132]={"秹","𡉰","𥟰","𥢤","𥢰"}
	a[22141]={"紝","絍","饪","𡉸","𡍑"}
	a[22142]={"鋫","𤨽","𦤴"}
	a[22150]={"丝","些","𠥄","𢆸","𦇈"}
	a[22151]={"㘹","坒","纴","𤔕","𦁍","𨥣","𨨬"}
	a[22152]={"𨥢"}
	a[22156]={"䅜"}
	a[22161]={"鈭","𡋢","𥂽","𪊈"}
	a[22162]={"𧣜"}
	a[22164]={"𨧳"}
	a[22165]={"綞","𧳮"}
	a[22170]={"𣆟","𦁚","𪙸"}
	a[22171]={"𦀘"}
	a[22172]={"𦕢"}
	a[22173]={"𤙞","𧗓"}
	a[22175]={"缍"}
	a[22176]={"種"}
	a[22183]={"𨤦"}
	a[22185]={"歱","緟"}
	a[22186]={"𡦢","𩸫","𪐈"}
	a[22187]={"𤚏"}
	a[22192]={"𨩹"}
	a[22193]={"𧾭"}
	a[22200]={"𪔅"}
	a[22201]={"𢒸"}
	a[22206]={"䱿"}
	a[22210]={"斷","𠨫","𡿪","𣃔"}
	a[22211]={"彩","𥝞"}
	a[22220]={"丱","片","","𣧄"}
	a[22221]={"𢒒","𥝹"}
	a[22230]={"㣌","㣍","斨","紤","𡰮","𢒕","𢒚","𢒦","𢒪","𣂔","𣂠"}
	a[22231]={"断","𠂳","𥞄","𥟝","𥟞","𪏴"}
	a[22232]={"㸫","𣂛"}
	a[22240]={"㱔","㸞","斪","龂","𣂵","𤕰"}
	a[22241]={"㪾","𢒜"}
	a[22242]={"㣓","𢒱"}
	a[22250]={"齗","𢒟","𢒭"}
	a[22251]={"䰺","𢒛","𣂯"}
	a[22252]={"𧣊"}
	a[22253]={"虨"}
	a[22254]={"𢫶"}
	a[22255]={"𣂩"}
	a[22260]={"𢀅","𢇅","𢇇"}
	a[22261]={"魸","𣂣","𣂶"}
	a[22265]={"𧴃"}
	a[22270]={"齭","𣂢","𣂸"}
	a[22271]={"𦅈"}
	a[22273]={"䱑"}
	a[22280]={"㫁","鼎","𠤞","𣂾","𤖎"}
	a[22283]={"𧈇"}
	a[22292]={"𩻬"}
	a[22293]={"䲉"}
	a[22296]={"𧈎"}
	a[22300]={"䝖","巛","巜","戀","","","","","𡿦","𡿭","𧘇"}
	a[22301]={"𤬝"}
	a[22302]={"𤬛"}
	a[22304]={"𤬤"}
	a[22305]={"𢥩"}
	a[22310]={"纞","𤉩","𧟏","𧲲"}
	a[22311]={"𤉉","𥟦"}
	a[22312]={"蠻"}
	a[22314]={"䘅","蠿","𧖀"}
	a[22316]={"𧔯","𧔻"}
	a[22320]={"厸","煭","𡿽","𤉥"}
	a[22321]={"悡","私","𥝠"}
	a[22322]={"㼏","𡘿","𡿶"}
	a[22330]={"𡿧","𤖼","𤫻","𤬇","𥿯","𦄘"}
	a[22331]={"𤫪"}
	a[22332]={"𧏇","𧳻"}
	a[22340]={"𢆶","𢆾","𢇁","𣥬","𤫱","𤬌","𦁟","𧚲","𧛵","𩚓","𪗢"}
	a[22341]={"毖","𤬍","𦧔"}
	a[22343]={"䖽","𢛁"}
	a[22350]={"䘡","𢛋","𧙁"}
	a[22351]={"䱄","穏"}
	a[22352]={"䱘","觚","𤋤","𧤷"}
	a[22353]={"䵩","製"}
	a[22360]={"熊","紭","飺","𩝖"}
	a[22361]={"𦄭","𦆸","𩹒"}
	a[22362]={"䖪"}
	a[22363]={"𧌿"}
	a[22364]={"蠫"}
	a[22370]={"態"}
	a[22371]={"穩","鮆"}
	a[22373]={"𢢹"}
	a[22374]={"䱥","纁"}
	a[22376]={"𥢾"}
	a[22380]={"䌥"}
	a[22382]={"𩡢"}
	a[22390]={"𢇑","𦈠"}
	a[22391]={"𤬘"}
	a[22392]={"螚"}
	a[22396]={"𧔗"}
	a[22400]={"","","𠄑","𠙳"}
	a[22402]={"𩺛"}
	a[22403]={"䚦"}
	a[22404]={"𩴆","𩹣"}
	a[22405]={"𢇖","𩴪"}
	a[22410]={"㽋","儿","匕","𠃔","𠒕","𤕋","𦫲","𪓓"}
	a[22411]={"𥝏","𧳑"}
	a[22412]={"𠮖","𧥕"}
	a[22413]={"𣱂","𦇷"}
	a[22414]={"𣰔","𤜓"}
	a[22420]={"𠃏","𠄂","𠫖","𡖅","𤖨"}
	a[22421]={"兇","鬯","𠛦","𥝓","𧲢","𩟾"}
	a[22422]={"𣬟"}
	a[22430]={"乣","乿","此","比","糺","豼","𠃭","𠘩","𠘽","𠤐","𢀂","𣥃","𣦷","𥾖"}
	a[22431]={"㐠","䄻","乳","𠃶","𠃿","𧳌"}
	a[22432]={"㲑","毝","牝","秅","秖","秪","𡿳","𣬡","𥞝","𥠴"}
	a[22433]={"𣭫","𣮀","𣮂"}
	a[22440]={"㸠","乨","乩","絩","𤕷","𥾆"}
	a[22441]={"乱","巤","秕","紙","饦","𠃹","𠤗","𤖿","𤭤","𥞅","𥿄"}
	a[22442]={"𣰫","𤙔","𥾱"}
	a[22443]={"㲕","牴","秏","𢩷"}
	a[22444]={"𣮄","𥢲","𩙲"}
	a[22450]={"紕","紪","邕","齓","𦙌","𦚯"}
	a[22451]={"䂑","䰲","亂","纸","𠒒"}
	a[22452]={"㲏","䋃","䑛","舐","","𣥡","𤘥","𧢳"}
	a[22453]={"㲗","幾","毵","觗","𣭪","𣮁","𣮕","𥟯"}
	a[22454]={"牦"}
	a[22460]={"毙","纰","胤","能","龇","𢀀","𢆻","𣬅","𪘈"}
	a[22461]={"彪","鮡","𠃵","𦆻","𦉔","𩷋"}
	a[22462]={"㡬","㲒","毞","毿","魠","𢀺","𣭁","𣯺","𩶅","𩷙"}
	a[22463]={"犣","觝","魹","𣭡","𩹉","𪉚"}
	a[22464]={"㲎","穖","飜","𠙭","𣬺","𣭹"}
	a[22470]={"䌐","郺","齜","𤗅","𦃽"}
	a[22471]={"魮","","𢀇","𩶆","𩷁"}
	a[22472]={"𣭀","𥠱","𧗇","𧗒","𩸐"}
	a[22473]={"㲱","𣭤","𣮟","𣰮"}
	a[22475]={"𧳿"}
	a[22480]={"𪙷"}
	a[22481]={"𢀈","𤕆","𤗢","𦃇","𩷴"}
	a[22482]={"鱲","𢨂","𣯐","𣰆","𩙸","𩲨"}
	a[22483]={"畿","𣰀"}
	a[22484]={"𣰩","𧎶"}
	a[22485]={"𣰈"}
	a[22490]={"𠒴","𪕊"}
	a[22491]={"𢀐","𪘛"}
	a[22493]={"𣯹","𣰯","𧇯","𪙧"}
	a[22496]={"㘒","𠄉"}
	a[22501]={"㪻","卛","變","𠮓"}
	a[22502]={"孌","𡢮","𢍶"}
	a[22503]={"𦇱"}
	a[22505]={"𨍃"}
	a[22511]={"𣀵","𥜷"}
	a[22512]={"鱍","𥀺"}
	a[22513]={"䚨","𩏹","𪔥"}
	a[22515]={"䲒","𨏶"}
	a[22521]={"𠤏"}
	a[22522]={"㚇","䄭","𠦅","𡕰"}
	a[22523]={"䅑"}
	a[22531]={"䊹","版","饭","𡿹","𡿼","𤖴","𥾵","𥿊"}
	a[22532]={"綏","馁","𡖲","𥣁","𧳭"}
	a[22533]={"犁","稯"}
	a[22534]={"䅗"}
	a[22541]={"㠿","毕","綬","纤","𣥥","𣬆","𦆔","𦈈"}
	a[22542]={"姕","幷","緵","绥","𡛗","𣂭","𣬓","𥿈","𦆛"}
	a[22543]={"緌","𥟿"}
	a[22544]={"𤚠","𤛵","𥏶","𥟛"}
	a[22545]={"𡝧"}
	a[22551]={"㔬","绶","𠤚","𢆼","𣥨","𣬂"}
	a[22552]={"㿫","緩","魬","𢇂","𣬊","𤘤","𤿙","𦀦","𦂜","𦃉","𦇻","𦧦"}
	a[22553]={"䅍","鮾","𢆡","𥿙"}
	a[22554]={"𥠐"}
	a[22555]={"𤙲"}
	a[22561]={"綖",""}
	a[22562]={"綎","缓","鱫","𦂰","𦍧","𩸣"}
	a[22563]={"鯼","𦃱","𩼕"}
	a[22564]={"鯘","𤙾"}
	a[22567]={"𥣾","𥤈"}
	a[22568]={"𥡭"}
	a[22572]={"","𦇌","𦧝","𩡣"}
	a[22573]={"鰀","𤳊","𩡖"}
	a[22574]={"𢆟"}
	a[22581]={"𥤑"}
	a[22582]={"鯅","𥀍","𩸿"}
	a[22583]={"䱓","𧤔"}
	a[22585]={"𨋅"}
	a[22588]={"𡣢"}
	a[22591]={"𤗳","𧰍"}
	a[22592]={"𢍬"}
	a[22594]={"𧤋"}
	a[22600]={"𥉃"}
	a[22605]={"濌"}
	a[22610]={"㘘","曫","矕","𩠹"}
	a[22612]={"𣋧"}
	a[22613]={"辔"}
	a[22614]={"𣌇"}
	a[22615]={"轡"}
	a[22621]={"𧳦"}
	a[22630]={"𧲿"}
	a[22631]={"匘","甾","𡿵","𡿸"}
	a[22640]={"旨","𡿷"}
	a[22641]={"稲","𣇘"}
	a[22642]={"䅔","秳"}
	a[22650]={"⻡","㫮","呰","𤽤","𧥥","𩠐"}
	a[22651]={"絬","緇","𥟠"}
	a[22652]={"㸋","㸸","䅨","𥞸","𦧐"}
	a[22653]={"𡚘","𥢌"}
	a[22660]={"㸟","皆","砦","𣅜","𣥾","𧳧"}
	a[22661]={"缁","𣨯","𦧞","𦧬"}
	a[22662]={"繙","𥟴","𦧚"}
	a[22664]={"𩡊"}
	a[22670]={"啙","眥","𣌳","𪘇"}
	a[22671]={"䋸","稭","緍","鮜","𦅑","𦈏","𦧟","𧦙","𪗽"}
	a[22672]={"鯔","𥢺"}
	a[22680]={"訾","𦂄","𪗷"}
	a[22681]={"鮨","鲘","𩷽","𪘢"}
	a[22682]={"鲻","𩡐"}
	a[22683]={"鱕","𪊂"}
	a[22685]={"𨡐"}
	a[22690]={"䭬","𣉘","𩠜"}
	a[22692]={"𡅀","𤖣"}
	a[22693]={"𦧵"}
	a[22694]={"𣋤"}
	a[22700]={"刂","巒","","𠚩","𠚴","𠠪","𢇍","𢇕","𢑉","𦇵","𦑴"}
	a[22701]={"㡩","劖","臠","𠠤","𠠥 "}
	a[22702]={"劗","鱎","𪙬"}
	a[22703]={"䚩"}
	a[22710]={"凵","刎","彎","鸞","𠄍","𠚄","𠛏","𠛱","𠝄","𦇓","𦣏","𦦽","𧳀","𩪾"}
	a[22711]={"凶","刋","利","孿","𠚁","𠚍","𠛴","𠜖","𠜫","𠞙","𦇡","𨊟","𪚄","𪚅"}
	a[22712]={"㝈","攣"}
	a[22713]={"𢀏"}
	a[22715]={"𨪖"}
	a[22720]={"凼","絼","","𠁿","𠙵","𠙸","𠚅","𠚕","𠚭","𠚸","𠛁","𠛩","𠛫","𠜊","𠞎","𠞤","𡴳","𡴸","𡿩","𦃖"}
	a[22721]={"㓙","㓿","㜽","𠙷","𠙺","𠚀","𠚉","𠚊","𠚏","𠜎","𠜣","𠝯","𠞜","𥞉"}
	a[22722]={"𠙹","𠛃","𠛻","𠡩","𢩬","𤙪"}
	a[22730]={"㓠","㟗","刣","剝","剶","剼","豳","𠙼","𠚻","𠛎","𠛠","𠟮","𠯃","𡺳","𤮺","𦣹","𧴑"}
	a[22731]={"㓢","㓯","䅀","凷","刮","𠙽","𠚂","𠛯","𠝍","𠠍","𥟻"}
	a[22732]={"稃","𠚋","𠜐","𠤔","𡕜","𡥬","𡿲","𥞿","𥟳","𥠞","𪏹"}
	a[22733]={"㸹","制"}
	a[22735]={"剰"}
	a[22740]={"刨","𠜶","𠞔","𠞞","𠠗","𣬄","𤖺"}
	a[22741]={"剩","綒","胔","魝","𠜔","𠜪","𠝣","𠝲","𠟫","𠠌","𡦄","𤗠","𦅧","𦙄","𦣼"}
	a[22742]={"㓩","䅎","劌","𠝘","𠞃","𢃌","𢪇","𥝁","𥞲","𥾹","𧣭"}
	a[22743]={"剿","𠙾","𤙤"}
	a[22744]={"𠜕","𢪒","𢬛","𤘶","𦜾"}
	a[22745]={"稱","𠝶"}
	a[22750]={"䌃","幽","𠂱","𠚘","𠜸","𠜼","𠞚","𠠂","𠤛","𣬃","𣬇","𦅂","𦙍","𦥒","𩾣"}
	a[22751]={"䌊","劇","稻","綉","𠚌","𠝞","𠝪","𡥎","𡬸","𣂬","𥠉","𪘤"}
	a[22752]={"㓺","㧘","鯏","𠟾","𤙿","𤛨","𦁳","𩶈"}
	a[22753]={"𠟣","𤚭","𥜿"}
	a[22754]={"掰"}
	a[22755]={"掣"}
	a[22760]={"縚","𠜷","𠞿","𠟞","𠤟","𦙼","𪉈","𪗿","𪙂"}
	a[22761]={"䖌","䵚","绣","鲗","𡥝","𥠃","𦈬","𩶽","𪁐","𪙒"}
	a[22762]={"䅤","䱐","馟","𠞏","𠠞","𥝄"}
	a[22763]={"䱨","𤯪","𦜗"}
	a[22765]={"𠝤","𤛜"}
	a[22770]={"𠚒","𠟓","𠟧","𦂣","𦄮","𪗶"}
	a[22771]={"牐","𤕁","𦂉","𩡟"}
	a[22772]={"穚","觜","鰩","𧇛"}
	a[22773]={"鯚","龋","𪘥"}
	a[22774]={"搿","鯯","鯻"}
	a[22775]={"𧤊"}
	a[22776]={"𠁳"}
	a[22780]={"䋳","䶡","鴜","鸶","𠟭","𦐳","𪔂"}
	a[22781]={"繑","鰂","𢀉","𢑂","𣦜","𩹴","𩼿"}
	a[22782]={"穱","鳐","𪀻"}
	a[22783]={"歶","犞","齲"}
	a[22784]={"𢰿"}
	a[22790]={"鷥","𩨱"}
	a[22791]={"𩡎","𪘾"}
	a[22793]={"𠚛"}
	a[22794]={"劙"}
	a[22800]={"災","𦇥"}
	a[22801]={"奱","𧷠"}
	a[22811]={"𤉌","𧲶"}
	a[22812]={"𧹂"}
	a[22820]={"𠇿","𤋴","𤎸"}
	a[22821]={"𡗖","𡗬"}
	a[22822]={"秗"}
	a[22830]={"赀","𤇬"}
	a[22831]={"貕","饫","𠤕","𣧕"}
	a[22840]={"𢇃","𣢙","𤎁","𧴲"}
	a[22841]={"𡘌"}
	a[22842]={"𧴌"}
	a[22844]={"𧴇"}
	a[22850]={"𤎾","𧴦"}
	a[22851]={"縘","𢇈","𤴠"}
	a[22852]={"𨖪"}
	a[22853]={"穙","𥣜"}
	a[22856]={"𡚕"}
	a[22860]={"熋","眞","𧿿","𨖁"}
	a[22861]={"𠤤"}
	a[22862]={"纀","𤗵","𤳤","𦄾"}
	a[22864]={"㹒"}
	a[22870]={"貲"}
	a[22871]={"𡙊"}
	a[22872]={"𩹍"}
	a[22883]={"𧤫"}
	a[22890]={"𤓖"}
	a[22894]={"䆊"}
	a[22900]={"灓","",""}
	a[22901]={"欒","纅"}
	a[22904]={"𧈈"}
	a[22910]={"𣲂"}
	a[22911]={"𧳥"}
	a[22912]={"鱳","𦈄"}
	a[22913]={"觻"}
	a[22920]={"𥘈","𥾭"}
	a[22921]={"㴝","𥟜"}
	a[22922]={"梨","秝","𥟩"}
	a[22930]={"𤕯"}
	a[22931]={"綵","𣏁","𤕽","𤖱","𥟸","𥾜","𥿘","𦂏"}
	a[22933]={"𤚀"}
	a[22940]={"絲","𠬆","𤬖"}
	a[22941]={"䌽","枈","柴","粊","𥿴"}
	a[22942]={"𥡙","𪐐"}
	a[22943]={"巢"}
	a[22950]={"祡","紫"}
	a[22951]={"繇","𪗮"}
	a[22952]={"㭰","穌","𩡄"}
	a[22953]={"𤑗","𥢖","𥣈"}
	a[22955]={"𥠗"}
	a[22956]={"𥟱"}
	a[22960]={"𡮙","𦀣"}
	a[22961]={"鯀"}
	a[22962]={"㸣","䌜","稣","𣟾","𥣤","𩷌"}
	a[22963]={"繅","𩻌"}
	a[22965]={"𤖉"}
	a[22970]={"𦅹"}
	a[22971]={"鲧"}
	a[22972]={"𦅚"}
	a[22973]={"缫"}
	a[22980]={"䌛","𥡝","𧪬"}
	a[22981]={"樂","𣠋","𪘿"}
	a[22983]={"𩼋"}
	a[22984]={"䲃","𥣲"}
	a[22986]={"𢀌"}
	a[22990]={"䜌","","𦇹"}
	a[22995]={"𦆕"}
	a[23000]={"卜","","","",""}
	a[23010]={"外"}
	a[23011]={"𥝒"}
	a[23022]={"秘"}
	a[23030]={"𥾠"}
	a[23031]={"𠧨"}
	a[23032]={"𪏺"}
	a[23052]={"馝","鮅"}
	a[23062]={"𦁊"}
	a[23101]={"䆄"}
	a[23102]={"𩀊","𩀣"}
	a[23107]={"𨿿"}
	a[23110]={"繵","𪙵"}
	a[23111]={"鱣","鳣"}
	a[23112]={"𩁏"}
	a[23113]={"𡓱","𤫔","𥫂","𩽀"}
	a[23114]={"𩁨","𩻡"}
	a[23120]={"盀","𠫙"}
	a[23131]={"𥝕"}
	a[23142]={"牤","𡊄","𡊏","𡿾","𧳞","𨾇"}
	a[23143]={"𡊅","𥟚"}
	a[23150]={"亝","𥁐","𥁱"}
	a[23151]={"叁","垒","紸"}
	a[23153]={"䧷","䧽","稚","𥢱","𨾘","𨿐"}
	a[23160]={"䶘","叄","𠫰"}
	a[23161]={"䰶","𠴦","𦈍","𩶘"}
	a[23162]={"䧳","維","𠬁","𤯢"}
	a[23163]={"𠫶","𨾙","𨿁","𨿓","𨿚","𨿥","𩁄","𩁅"}
	a[23164]={"𤙵","𥂥","𨾤","𨾲"}
	a[23166]={"𨿍"}
	a[23171]={"䲞","𠬄","𠬅","𥂒"}
	a[23172]={"维","雊","𤙫","𧴗","𨾱","𨿅","𩀅","𩶃"}
	a[23173]={"雒","雞","𧣓","𨾰","𨾷","𨿖","𨿴","𩀘","𩁟"}
	a[23174]={"㹌"}
	a[23182]={"雌","雏","𠬋","𨾼","𪘮"}
	a[23183]={"䧼","䱦","𪉺"}
	a[23184]={"穜","雛","𧣽","𨿽","𩀷"}
	a[23185]={"𩀌"}
	a[23187]={"𨿠"}
	a[23192]={"雝","𡒥","𡗌","𢨑","𤒂","𪙞"}
	a[23193]={"𡒉","𣦟","𥽽","𦅅","𧇒","𨿧","𩁋"}
	a[23195]={"犝"}
	a[23210]={"𠬔","𠬘"}
	a[23221]={"参"}
	a[23230]={"參","𠫸"}
	a[23231]={"𠬊"}
	a[23232]={"䅟",""}
	a[23241]={"穇"}
	a[23250]={"縿","𠫼","𥚪"}
	a[23251]={"緕"}
	a[23252]={"犙"}
	a[23260]={"齴"}
	a[23261]={"穧"}
	a[23262]={"鯵","鲚"}
	a[23270]={"纃"}
	a[23271]={"鰺"}
	a[23272]={"鲹"}
	a[23280]={"𠬐"}
	a[23281]={"𪊆"}
	a[23290]={"䶩"}
	a[23291]={"鱭"}
	a[23303]={"鳡"}
	a[23305]={"穰"}
	a[23312]={"𩟷"}
	a[23313]={"𧖞","𩽱"}
	a[23314]={"纕","","𩼆"}
	a[23315]={"𤰂","𪊊"}
	a[23320]={"㕕"}
	a[23321]={"然","𠫵"}
	a[23322]={"𢢃"}
	a[23330]={"厽","叅","𠫛","𥿹","𦃳","𧴕"}
	a[23332]={"𥠩"}
	a[23340]={"怠","饻","𠫬"}
	a[23341]={"繎","𢛃"}
	a[23342]={"𧈧"}
	a[23350]={"絃","𦄣","𦅒"}
	a[23351]={"𤋣"}
	a[23352]={"𤛤"}
	a[23353]={"穛"}
	a[23356]={"䖸"}
	a[23360]={"緿","𢠀"}
	a[23361]={"𩷮"}
	a[23362]={"𦅃","𩹧"}
	a[23365]={"穣","𥣹"}
	a[23370]={"𣩻","𪗰"}
	a[23371]={"鮌","𠬀","𩻦"}
	a[23372]={"縗","𢣘","𤜄","𧣙"}
	a[23373]={"𥤂"}
	a[23374]={"𤛸","𧌦"}
	a[23380]={"繶"}
	a[23381]={"𪊉"}
	a[23382]={"缞"}
	a[23383]={"𣟼","𦆪","𪊄"}
	a[23384]={"𤜁"}
	a[23388]={"𧒎"}
	a[23392]={"繈","𧥉"}
	a[23393]={"鱤","𩸡"}
	a[23394]={"䗽"}
	a[23395]={"𩺼"}
	a[23400]={""}
	a[23402]={"纖","𧇭"}
	a[23403]={"𢨟"}
	a[23404]={"鱡"}
	a[23405]={"䶪","𧥄"}
	a[23410]={"䌱","𠂗","𠃕"}
	a[23412]={"䌴","氊","𤮲"}
	a[23413]={"纎"}
	a[23414]={"𣰷","𩽅","𩽠"}
	a[23420]={"允","𠘭","𠫝"}
	a[23421]={"𥝲"}
	a[23422]={"䄩"}
	a[23424]={"我"}
	a[23430]={"夞","𠫱","𧲪"}
	a[23431]={"𠫜","𢍿","𥾐"}
	a[23432]={"戕","","𢦤","𢧁","𥾮"}
	a[23433]={"𢧹","𣭍","𣭩","𤘚"}
	a[23434]={"㦵","䄾","牫"}
	a[23435]={"𥟥"}
	a[23440]={"𠒊","𠫞","𠫨"}
	a[23441]={"秔","紌"}
	a[23442]={"䋐","战","絾","𢦯","𣭉","𥡔"}
	a[23443]={"毶","絨","饯","𢧽","𣰂","𤘜"}
	a[23444]={"㲓","牋","牻","綫","饿","𣬽","𤖆"}
	a[23450]={"䋁","統","𠙃","𠫠","𥿼","𦀠","𦁙","𧴈"}
	a[23451]={"𢎕 ","𥿮","𦧊"}
	a[23452]={"牨","縬","鮘","𡕬","𢧍","𢧡","𢧼","𣮘","𩶄","𪗠","𪗥"}
	a[23453]={"䰹","毬","稢","繊","线","绒","𥠆","𦅞"}
	a[23454]={"縅","𢧗"}
	a[23455]={"毧","稶"}
	a[23456]={"𣮏","𤯫"}
	a[23460]={"綂","统","𠫮"}
	a[23461]={"䴚"}
	a[23462]={"㲙","緎","緘","魷","𢎓","𣭆","𣯶","𦈚"}
	a[23463]={"㦸","戯","鯎","𥢧"}
	a[23464]={"奙","毪","𢧛","𢧶","𢨓","𣮍","𪘐","𪘪"}
	a[23465]={"䱠","馢","𥣩"}
	a[23466]={"𣭾","𧣴"}
	a[23470]={"𪗜","𪗯"}
	a[23471]={"魧","鯍","𢎍","𢎎","𩶞"}
	a[23472]={"毰","織","缄","臧","鱿","𡰐","𢧝","𣯊","𤖔","𦄤"}
	a[23473]={"戱","鹹","𦃎","𦧩"}
	a[23474]={"㲝","𣯤","𦄩","𧣱"}
	a[23475]={"鰄","𣯍"}
	a[23481]={"𡁗","𧇠"}
	a[23482]={"䶢","𡰘","𢧠","𢨕","𣯖"}
	a[23483]={"䱛","鰔","𤖞","𤳀","𨿮"}
	a[23484]={"𧣼"}
	a[23485]={"虥","𢨘"}
	a[23487]={"𢨡"}
	a[23491]={"𠿕","𩺿"}
	a[23493]={"㹑","䆎","戲"}
	a[23494]={"𪙻"}
	a[23501]={"𦈞"}
	a[23502]={"鱆","𩺽"}
	a[23511]={"处",""}
	a[23512]={"𥤁","𩼎"}
	a[23513]={"𤜃"}
	a[23514]={"𤜀"}
	a[23516]={"𩽧"}
	a[23517]={"𨏾"}
	a[23521]={"䝜","夋","𠫘","𢁔","𧳚"}
	a[23522]={"发","弁","𣁝","𧲯"}
	a[23531]={"紋","絞","饺","𠫦","𨐍"}
	a[23532]={"牟","稄","稡","𠫚","𢌹","𥞑","𥞯","𧳛"}
	a[23533]={"秡","𡜀","𢀁","𢪖"}
	a[23541]={"㱖","斚","綷","纹","绞","馂","𠅱","𡖺","𦀷"}
	a[23542]={"紱","𤕳","𥞽","𥿋"}
	a[23543]={"𥟋","𥟣"}
	a[23544]={"㛷"}
	a[23551]={"締","齩","𦀓","𨐔"}
	a[23552]={"绂","辤","魰","鮫","𤗈","𥿵","𥿺","𦁉"}
	a[23553]={"𤙡","𤚢","𦀮","𧣦"}
	a[23561]={"缔","辝","𠨢","𤗪","𪘑","𪘧"}
	a[23562]={"䱣","辞","鮻","鲛","𠬂","𡞅","𥡢"}
	a[23563]={"䚝","馛","鮁","𠆕","𠫹","𥡒","𨐲"}
	a[23564]={"𤚅"}
	a[23565]={"𠫺","𠫿"}
	a[23571]={"繂","𦂊","𦈁"}
	a[23572]={"䱱","辭","𨐠","𩷔"}
	a[23573]={"觪","鯜","鲅","𠦷","𠦼","𥣣","𧤍","𩶢"}
	a[23574]={"𤛄"}
	a[23576]={"軬"}
	a[23583]={"縴","𤚮","𥢔","𥪵"}
	a[23584]={"𧣿"}
	a[23585]={"𨋿"}
	a[23586]={"𠬎"}
	a[23591]={"䌟","辪","𤖟","𤗺"}
	a[23592]={"𥀧","𪙘"}
	a[23593]={"𤛙"}
	a[23594]={"𩹹"}
	a[23602]={"𩹱"}
	a[23612]={"𤜊"}
	a[23630]={"台"}
	a[23631]={"咎"}
	a[23641]={"昝","秮"}
	a[23650]={"䀤","紿","饴","𡖤"}
	a[23651]={"稖","綹","𤱊","𥞞"}
	a[23652]={"畚","𤲙"}
	a[23653]={"𡘞"}
	a[23660]={"䋨","绐","𤗏"}
	a[23661]={"䅧","绺","𤲛"}
	a[23662]={"犃","𢮏","𤚵"}
	a[23663]={"𥢑"}
	a[23670]={"齝","𩐞"}
	a[23671]={"鮐"}
	a[23672]={"稸","稽","鯦","𥡳","𥡴"}
	a[23673]={"𨠒"}
	a[23674]={"𨠢"}
	a[23681]={"鲐","𩸬"}
	a[23682]={"諬"}
	a[23683]={"䆌","𤛅"}
	a[23690]={"𪘎"}
	a[23691]={"𩹎"}
	a[23701]={"鰝"}
	a[23703]={"𩫥","𩺫"}
	a[23704]={"𧤤","𧤪"}
	a[23705]={"𩺹"}
	a[23710]={"𠙴"}
	a[23712]={"齾","𦇽","𪚊"}
	a[23713]={"𦉥","𦉧"}
	a[23714]={"觹","𢹭","𧥏"}
	a[23716]={"𧥘"}
	a[23721]={"𠫣"}
	a[23731]={"䄱","𠫧"}
	a[23740]={"䏍","紡","𥾼"}
	a[23741]={"𦚅"}
	a[23742]={"嵆","嵇","牥","𥟆","𥠒","𧴁"}
	a[23744]={"𢒏"}
	a[23750]={"纺","𠫫"}
	a[23751]={"䅭"}
	a[23752]={"𠫻"}
	a[23753]={"䅻"}
	a[23755]={"秿","𧳵"}
	a[23760]={"牓","縍","𤗒","𦂶"}
	a[23761]={"魴","𥠣"}
	a[23762]={"稕","縭","𤗫","𤚰","𥡦"}
	a[23763]={"黐"}
	a[23764]={"䋠","𤗃"}
	a[23766]={"𤙭","𥠵"}
	a[23768]={"𣫽"}
	a[23770]={"䋭","𤗞","𦂃"}
	a[23771]={"稿","綧","鲂"}
	a[23772]={"缡","𦠬","𪐏"}
	a[23773]={"㹍","犉"}
	a[23774]={"鵞","𡦠"}
	a[23775]={"牔","縛","馎","𡦛","𥡨","𦂪"}
	a[23777]={"𤚽"}
	a[23780]={"縞"}
	a[23781]={"鰟",""}
	a[23782]={"犒","𧤞"}
	a[23785]={"缚","鯆"}
	a[23790]={"缟","鶭"}
	a[23791]={"鳑","𥢿","𦠋","𩹇"}
	a[23792]={"鯙","𦆈"}
	a[23795]={"𪙍"}
	a[23796]={"𩹲"}
	a[23802]={"獻"}
	a[23810]={"𤆃"}
	a[23811]={"𧳂"}
	a[23812]={"𧸾","𪚋"}
	a[23813]={"𦈆"}
	a[23820]={"贠"}
	a[23821]={"","𤉷","𤝀","𤟙"}
	a[23830]={"炱","𠫯"}
	a[23831]={"狀","矣","紎","絥","𥞨"}
	a[23833]={"𤘲"}
	a[23840]={"㚊","絯"}
	a[23841]={"𤊜","𥏑"}
	a[23842]={"𡘾"}
	a[23843]={"𠫪"}
	a[23850]={"貟","𧵏"}
	a[23851]={"𠤘","𤞣"}
	a[23852]={"鮲","𩵥"}
	a[23853]={"㸻"}
	a[23860]={"𧴵"}
	a[23861]={"貵","𤐮","𤒞"}
	a[23862]={"𤠪","𩡍"}
	a[23863]={"𩻿"}
	a[23866]={"𠔩"}
	a[23869]={"𠔰"}
	a[23870]={"𧵱"}
	a[23872]={"𤟜","𨐹"}
	a[23882]={"𦇰","𩹏"}
	a[23883]={"𤣏"}
	a[23884]={"𤢚"}
	a[23885]={"𦆌"}
	a[23910]={"厼"}
	a[23911]={"𧲷"}
	a[23918]={"𨤹"}
	a[23921]={"𠫭"}
	a[23922]={"秫","𥟇","𥡁"}
	a[23930]={"㕘"}
	a[23931]={"絉"}
	a[23932]={"𠫩"}
	a[23940]={"𡮟"}
	a[23941]={"㕖","枲","稤","絿","𤕾","𤗂"}
	a[23943]={"𤙠"}
	a[23950]={"絫","綡"}
	a[23951]={"䅫","𤗊","𦁛"}
	a[23952]={"㹁"}
	a[23953]={"𤚊"}
	a[23960]={"𦂠"}
	a[23961]={"𦂅"}
	a[23962]={"鯄","𤚒","𦧢"}
	a[23963]={"觩"}
	a[23964]={"穕"}
	a[23970]={"𦅍"}
	a[23971]={"鯨","𦈒"}
	a[23972]={"𣙼","𤛡","𧤀","𩾁"}
	a[23973]={"䌖","𧤇"}
	a[23981]={"鲸"}
	a[23982]={"𧤚"}
	a[23983]={"䢄","𦈜"}
	a[24101]={"鰚"}
	a[24102]={"鰉"}
	a[24103]={"䑟"}
	a[24104]={"纏","纒"}
	a[24112]={"鳇"}
	a[24115]={"𩼼"}
	a[24151]={"𤕸"}
	a[24161]={"𩶫"}
	a[24171]={"𦅺"}
	a[24172]={"䅣"}
	a[24180]={"縇"}
	a[24182]={"𤚗"}
	a[24183]={"𤚝"}
	a[24192]={"鰘"}
	a[24193]={"缠"}
	a[24211]={"𪖤","𪖵"}
	a[24212]={"𦇺","𪖸"}
	a[24240]={"纩"}
	a[24241]={"穆"}
	a[24250]={"𦆲"}
	a[24251]={"𥢣"}
	a[24252]={"𥠇","𥡆"}
	a[24261]={"魲","𦂢"}
	a[24303]={"𩽁"}
	a[24304]={"𧥍"}
	a[24307]={"𧕞"}
	a[24311]={"𩽲"}
	a[24314]={"𧖠"}
	a[24320]={"䝦"}
	a[24340]={"絋"}
	a[24350]={"㦝","𦀬"}
	a[24351]={"稂","𦃞"}
	a[24352]={"𥡥","𦄝"}
	a[24360]={"𤗀"}
	a[24361]={"牕","總","𢽂","𥡈","𦫑"}
	a[24362]={"𤓏","𥡊"}
	a[24363]={"𤳯"}
	a[24368]={"䆂"}
	a[24370]={"縋"}
	a[24371]={"𪙋"}
	a[24372]={"𥡋"}
	a[24373]={"穮"}
	a[24377]={"𦆆"}
	a[24380]={"缒"}
	a[24381]={"憩","𦧯","𩷕"}
	a[24384]={"犥","𤳼"}
	a[24390]={"𦇭"}
	a[24391]={"𥤍","𥤓","𩺬"}
	a[24398]={"𩼔"}
	a[24400]={"𦆘"}
	a[24403]={"𩴥","𩺮"}
	a[24410]={"𤾿"}
	a[24413]={"𩴛","𪚪"}
	a[24414]={"䶱","龝","𪛁"}
	a[24420]={""}
	a[24440]={"貌"}
	a[24441]={"𦧑"}
	a[24451]={"貔"}
	a[24452]={"𣯔","𩳏"}
	a[24453]={"𤚃","𥡂"}
	a[24460]={"𦀸","𪗴"}
	a[24462]={"鯳","𤗧"}
	a[24463]={"𣰤"}
	a[24470]={"𦫖"}
	a[24471]={"𦃋"}
	a[24472]={"䌆","𣯑"}
	a[24473]={"𤚪","𩱾"}
	a[24474]={"𤛂","𩲫"}
	a[24475]={"魏","𣮐"}
	a[24476]={"𣮣"}
	a[24482]={"䌒","𤒣"}
	a[24483]={"䴜"}
	a[24487]={"𦓌"}
	a[24491]={"𢁏","𧇚"}
	a[24492]={"𩹻"}
	a[24493]={"𩹷","𪋍"}
	a[24502]={"𧇤"}
	a[24533]={"𧳴"}
	a[24542]={"𥿽"}
	a[24543]={"貏"}
	a[24551]={"𤗙"}
	a[24552]={"繌"}
	a[24554]={"稗"}
	a[24556]={"𦅳"}
	a[24561]={"䝥","綿"}
	a[24562]={"𢅁"}
	a[24563]={"牌","綼","𥡅","𦂀","𦂖","𦃍"}
	a[24564]={"𪐄"}
	a[24565]={"𤚡"}
	a[24571]={"绵"}
	a[24572]={"𠤨","𥢐"}
	a[24573]={"𨤟"}
	a[24582]={"𩸊"}
	a[24584]={"䱝"}
	a[24585]={"䚜"}
	a[24597]={"犩"}
	a[24605]={"𩹶"}
	a[24613]={"𥗶"}
	a[24614]={"𤜋"}
	a[24616]={"䭳"}
	a[24621]={"𧳄"}
	a[24630]={"貃"}
	a[24641]={"䄸","穃","𥿳"}
	a[24650]={"絈","𦀙"}
	a[24651]={"𤗄"}
	a[24652]={"𥠑"}
	a[24660]={"𦁦"}
	a[24661]={"𦂦"}
	a[24663]={"𥣳"}
	a[24670]={"𦂨"}
	a[24671]={"鮊"}
	a[24675]={"䅯"}
	a[24680]={"𦃧"}
	a[24681]={"鲌"}
	a[24684]={"䌅"}
	a[24686]={"𤚫"}
	a[24700]={"鵮","鷆","𪂺","𪃓","𪃨","𪃰","𪄉"}
	a[24701]={"䖚","鵫","𪆛","𪆺"}
	a[24704]={"𪇑"}
	a[24709]={"𤛑"}
	a[24710]={"鶛","𪄢","𪆻","𪈮"}
	a[24711]={"鷮","𪆋","𪇱","𪈂"}
	a[24712]={"鸆","鸕","𪇤","𪇸","𪈿"}
	a[24713]={"𪃤","𪄾","𪇦"}
	a[24715]={"䳯"}
	a[24718]={"鱅","鳙","𪈜"}
	a[24722]={"貈"}
	a[24732]={"𤘻"}
	a[24740]={"䋆"}
	a[24741]={"𥿾"}
	a[24742]={"𡖫","𥿦"}
	a[24743]={"𧴏"}
	a[24750]={"饷","鳪","𤖽","𥿧","𩾑","𪁰"}
	a[24751]={"鸨","𥡇"}
	a[24752]={"𤚞"}
	a[24753]={"稨","𦩉"}
	a[24754]={"鹅"}
	a[24756]={"𡖭"}
	a[24760]={"鴔","鸬","鸲","𦆭","𩾮","𩾲","𩿌","𩿥","𪅈","𪅊","𪆍","𪈵"}
	a[24761]={"䳉","鴁","鸹","鹞","𥡼","𪃩","𪉍"}
	a[24762]={"牑","編","鵎","𢲒","𥣄","𩸅"}
	a[24763]={"𩶣"}
	a[24764]={"犏"}
	a[24770]={"𦄋","𦅜","𩾕","𩾰","𩿃","𩿄","𪀖","𪀩","𪂒","𪇹","𪉆"}
	a[24771]={"䳕","䳿","鴇","鵕","鵴","鹄","𥡐","𦆒","𪆈","𪆜"}
	a[24772]={"编","鴘","鴩","鴸","鶏","𦆉","𪃊","𪅌"}
	a[24773]={"𪉱"}
	a[24774]={"鵝","𤖑","𦇑"}
	a[24777]={"𧴄"}
	a[24780]={"鴝","鶨","鹐","𩾤","𪀈"}
	a[24781]={"䴂","鰞","鴢","鴰","鵅","鵚","鶅","鷂","鷄","𥣰","𪁮","𪇈"}
	a[24782]={"䲼","鯓","鴾","鶢","𩿂","𪅞"}
	a[24783]={"鯿","𣝜"}
	a[24784]={"牖"}
	a[24785]={"𡑈","𡼻","𡿁"}
	a[24788]={"𥡲"}
	a[24790]={"䳄","䳌","鴲","𩿿","𪀀","𪀗","𪀨","𪀽","𪃚","𪅎","𪆓"}
	a[24791]={"鵠","鵵","鷠","𪂬"}
	a[24792]={"䴄","鵤","鶵","鷭","𪆶"}
	a[24793]={"鳊"}
	a[24795]={"䳠"}
	a[24797]={"牅","牗","𦄢"}
	a[24801]={"𨞑"}
	a[24806]={"𧥌"}
	a[24810]={"𨙧"}
	a[24830]={"𧳖"}
	a[24851]={"綟"}
	a[24861]={"𤖏"}
	a[24864]={"𦁶"}
	a[24871]={"㱗"}
	a[24872]={"𩸭"}
	a[24873]={"𤚯","𩼈"}
	a[24874]={"㗮"}
	a[24875]={"穬","𨤡"}
	a[24882]={""}
	a[24884]={"纊"}
	a[24890]={"𦆯"}
	a[24892]={"𩡗"}
	a[24895]={"𦆍"}
	a[24896]={"𤳲"}
	a[24905]={"𩾌"}
	a[24940]={"𦃲"}
	a[24941]={"𣑞","𥟡"}
	a[24951]={"𥠘"}
	a[24952]={"䌕","𤙷"}
	a[24953]={"𪐎"}
	a[24960]={"線"}
	a[24961]={"𩶙","𩻴"}
	a[24964]={"𥣝"}
	a[24965]={"穅"}
	a[24970]={"缐"}
	a[24973]={"䲈"}
	a[24981]={"鰁"}
	a[24991]={"鳈","𦤞"}
	a[24993]={"𦇘"}
	a[24995]={"鱇"}
	a[25001]={"𠆥"}
	a[25011]={"","","𠄓"}
	a[25012]={"升","𦫵"}
	a[25021]={"㚈","斘"}
	a[25022]={"科","𣁷"}
	a[25031]={"紏","𣁭","𥾅"}
	a[25032]={"𥾷"}
	a[25033]={"㸯"}
	a[25042]={"䌀"}
	a[25043]={"𤯘","𦧌"}
	a[25044]={"犐"}
	a[25051]={"𪗕"}
	a[25052]={"𩵬"}
	a[25053]={"斛"}
	a[25063]={"𠦲"}
	a[25064]={"𥡿"}
	a[25071]={"𠦣"}
	a[25093]={"𧤰"}
	a[25111]={"𣦳"}
	a[25112]={"𤗿","𩻭"}
	a[25116]={"𪙟"}
	a[25117]={"豓","豔"}
	a[25121]={"","𠂒"}
	a[25131]={"𧲭"}
	a[25132]={"圱","生","𤯴","𥝟"}
	a[25133]={"𡉼"}
	a[25141]={"壯","𡉟","𣥲"}
	a[25142]={"夝","𤯖"}
	a[25143]={"牡"}
	a[25151]={"𡖠"}
	a[25152]={"𡖪","𤏝","𦀴"}
	a[25153]={"㘶","䅅","稑","紲"}
	a[25154]={"牲"}
	a[25161]={"𦀜","𪘠"}
	a[25162]={"絓","𦁪","𩵚"}
	a[25163]={"绁","𨧭"}
	a[25164]={"甡"}
	a[25171]={"馇","馌","𧴒","𪘡"}
	a[25172]={"稙","銺"}
	a[25173]={"鮏","齛","𥣸","𩶦"}
	a[25174]={"𤯷"}
	a[25181]={"𡖻"}
	a[25182]={"𪉶","𪗹"}
	a[25183]={"犆","鮭","鯥","𪉯"}
	a[25184]={"觟"}
	a[25187]={"𥡣"}
	a[25191]={"","𪙁"}
	a[25192]={"鰪","𣦲"}
	a[25193]={"鲑"}
	a[25196]={"㽓","䌍","馑"}
	a[25198]={"㹏"}
	a[25201]={"靠"}
	a[25251]={"䋾"}
	a[25252]={"䵙"}
	a[25273]={"𧤌"}
	a[25277]={"𦇋"}
	a[25306]={"鰱"}
	a[25307]={"𥣴"}
	a[25312]={"𩼂"}
	a[25313]={"𩽒"}
	a[25314]={"觾"}
	a[25316]={"𦇀"}
	a[25317]={"馕","𦈃"}
	a[25319]={"𤜗"}
	a[25332]={"怣","𤇓"}
	a[25341]={"紘","𦀗","𩠅"}
	a[25342]={"絊","𢘡","𢛭","𥞋","𥿭","𦅢","𧙍"}
	a[25344]={"𤙃"}
	a[25351]={"紶","綕","纮"}
	a[25352]={"𦁨"}
	a[25354]={"𤛚","𧎗"}
	a[25361]={"憄","裝","𤍹","𦁷"}
	a[25362]={"䌸","𩷧"}
	a[25363]={"䱁","𧚒"}
	a[25364]={"穂"}
	a[25365]={"𢤅"}
	a[25371]={"㷱","䏻"}
	a[25372]={"魼","𩷓"}
	a[25373]={"䱪","憇","𤳖","𦁆","𦈐"}
	a[25374]={"𦅋"}
	a[25375]={"穗"}
	a[25383]={"繨"}
	a[25384]={"䲇","繐"}
	a[25385]={"縺"}
	a[25386]={"𦇠","𧎬","𧑤","𪐍"}
	a[25391]={"𦅇"}
	a[25393]={"𩼰"}
	a[25394]={"鲢","𧑯"}
	a[25402]={"䖛"}
	a[25403]={"繞"}
	a[25404]={"𦇴"}
	a[25405]={"㹓","𢴽"}
	a[25406]={"𠒾","𣰾"}
	a[25411]={""}
	a[25412]={"鼄"}
	a[25413]={"䶧","𣰬","𧈙"}
	a[25414]={"鱙","𠓙","𣠎","𧇶"}
	a[25415]={"𡚥"}
	a[25423]={"𣭈"}
	a[25431]={"先"}
	a[25433]={"𣬯","𥞠"}
	a[25435]={"𥠏"}
	a[25441]={"龀"}
	a[25442]={"𥾑","𩵏"}
	a[25443]={"𤘱"}
	a[25444]={"𣬳","𣭐","𤘛","𤘫"}
	a[25451]={"続","齔","𡖬","𦀈"}
	a[25452]={"純","饨","饶","魤"}
	a[25453]={"𣭊","𣭎","𤙥","𧢶","𧢽"}
	a[25458]={"𣭌"}
	a[25462]={"兟","纯","绕","𩵐"}
	a[25463]={"㸿","毨","鮱","𣭟"}
	a[25464]={"𣰁"}
	a[25465]={"䅖","𣭴","𣯩","𤙸","𨤕"}
	a[25472]={"𤕿","𩶤"}
	a[25473]={"䚚","魨"}
	a[25474]={"𤗎","𦁏"}
	a[25475]={"𦁱"}
	a[25483]={"鲀"}
	a[25484]={"𣮛"}
	a[25485]={"𡢎"}
	a[25486]={"𤛪"}
	a[25492]={"𧆻"}
	a[25493]={"甝","𣮲"}
	a[25494]={"穘"}
	a[25495]={"馣","𩸆"}
	a[25502]={"𡤨"}
	a[25503]={"𢻨","𧇡"}
	a[25516]={"𥤙"}
	a[25522]={"䋂","牛","牜","𡚮","𡚷","𧲤"}
	a[25523]={"秭","𧳐"}
	a[25532]={"妝","舛","𡛝","𤖩"}
	a[25533]={"秓","𥝫","𥞎","𪏮"}
	a[25534]={"牬","稀","𤘙","𧳅","𧳡"}
	a[25535]={"𥝷"}
	a[25542]={"㩼","䋅","歧","𢺵","𢻃","𥾣","𥾧"}
	a[25543]={"䵓","稜","絺","𡞓","𥞢","𩵲"}
	a[25544]={"㸬","牪","𣥞","𤘧","𤙅","𤯕","𦄫"}
	a[25552]={"綾","𢻇","𣥻","𦁑"}
	a[25553]={"娤","弉","𢍎","𥾫","𦧉","𦧋"}
	a[25554]={"𤯙","𥟀"}
	a[25555]={"𦧏"}
	a[25562]={"㩺","㩻","緈","绫","𡞩"}
	a[25563]={"䰽","纬","𢻙","𦂡","𩵠","𩵼","𩶉"}
	a[25564]={"𧢿","𧣄","𧣈"}
	a[25565]={"𥢟","𧣩","𩰢"}
	a[25566]={"犇"}
	a[25567]={"㩾"}
	a[25573]={"鯪","𢻗","𥢍"}
	a[25574]={"䰷","𥅶","𩶮"}
	a[25575]={"𦕡"}
	a[25576]={"緀","𪐃"}
	a[25577]={"𦅠"}
	a[25583]={"鲮","𢻤","𥀡"}
	a[25585]={"缂"}
	a[25586]={"𪉪"}
	a[25588]={"𤛭"}
	a[25596]={"䭰","𨌄"}
	a[25597]={"𧤒"}
	a[25599]={"𤛕"}
	a[25602]={"𩼒"}
	a[25603]={"鰭","𦆶","𩼺"}
	a[25604]={"鰆","𧤮"}
	a[25605]={"𧤺"}
	a[25612]={"穯","鱚"}
	a[25613]={"䲛","鳍"}
	a[25614]={"䲠",""}
	a[25615]={"䲋"}
	a[25616]={"𤕌","𤴋","𪙡"}
	a[25617]={"鰽"}
	a[25618]={"𤴎"}
	a[25641]={"告"}
	a[25642]={"吿","秙","𠱒"}
	a[25651]={"𣧮","𤖲","𥿍"}
	a[25652]={"秸","𥞴","𧳯","𪏻"}
	a[25653]={"牯"}
	a[25661]={"夡","結"}
	a[25662]={"𥑦","𦧒"}
	a[25663]={"㸵","牿","稓"}
	a[25671]={"结"}
	a[25672]={"眚","穑","穡","緒","緖","鮕","𣗺","𣦈","𤯣","𤯬","𥣱","𦁎"}
	a[25673]={"䅲","𧣗"}
	a[25674]={"𤚻","𥓧","𥠔"}
	a[25681]={"䶜","牆","繬","𤖠","𤗼","𪗾"}
	a[25682]={"绪","鮚","鯌","𠼑","𥢗"}
	a[25683]={"䚛","𤛷","𦅁"}
	a[25684]={"𦆏"}
	a[25691]={"繥"}
	a[25692]={"㬱","鲒","齰","𤖧"}
	a[25693]={"䱜","鯺"}
	a[25694]={"觰","𦅦"}
	a[25696]={"𤗰","𦄧","𩠎"}
	a[25702]={"鰖","鳚","𩺙"}
	a[25703]={"鯖","鰣","𧤓","𧤦"}
	a[25706]={"鱄","𩹝"}
	a[25709]={"𧤳"}
	a[25711]={"豺"}
	a[25712]={"䌧","䲊","𤘀","𩱕","𩱩"}
	a[25713]={"䲖","鲭"}
	a[25714]={"㹗"}
	a[25716]={"䵻","𦄑"}
	a[25721]={"𡭫"}
	a[25722]={"𡬟","𥞂"}
	a[25731]={"䊷","紂","紨","𡬧"}
	a[25733]={"䝡",""}
	a[25741]={"䌶","䝝","纣"}
	a[25742]={"𥾒","𥾰"}
	a[25743]={"秲","𥞈","𥞘","𧴝"}
	a[25744]={"𤙂","𥡹"}
	a[25751]={"𡬲","𡷥"}
	a[25752]={"歭","紺","鮒","𤯞","𥟏","𦀃","𩠁"}
	a[25753]={"𥞳"}
	a[25754]={"特","𢫰","𤚟","𧣘"}
	a[25755]={"𤙢"}
	a[25761]={"絝","絠","綺","𡖮","𡬹"}
	a[25762]={"䋻","綍","绀","饽","鲋","𤯝","𦂂","𦂭","𩧶","𩷺","𪉋"}
	a[25763]={"犄","甜"}
	a[25764]={"㹀","鯑","𦀳"}
	a[25765]={"𤯟","𦄂"}
	a[25771]={"绔","绮"}
	a[25772]={"䌾","𧆯","𪗳","𪗺"}
	a[25773]={"䋽","魽","𤚑","𤛀","𤛌","𦅎","𩶬"}
	a[25774]={"㸢","𤖐","𧣑","𩡙","𩢫","𩣏","𩺴"}
	a[25776]={"犕","𥡵","𦼌"}
	a[25779]={"𥠾"}
	a[25781]={"齮","𦃣","𪘃"}
	a[25782]={"䭲","綪","鮪","鮬","𩸞","𪀾","𪘱"}
	a[25783]={"觭","馞","鮳","𢇎","𦆝","𩷚","𩹞"}
	a[25784]={"𥡟","𥣉"}
	a[25785]={"縳","𩷨"}
	a[25787]={"𣥽","𤚚"}
	a[25788]={"𦃪"}
	a[25792]={"䲁","鲔","鲥",""}
	a[25793]={"鲓","𤛩","𥤏","𦆐"}
	a[25794]={"甧","𩇛","𩡒"}
	a[25795]={"𩾂"}
	a[25801]={"牘","續","齻"}
	a[25802]={"缵","贊","𣞟","𩺘"}
	a[25803]={"犢","𦇅","𩼜"}
	a[25804]={"纉","馩","鱝"}
	a[25806]={"𦦘"}
	a[25810]={"𨤴"}
	a[25811]={"𤘄"}
	a[25812]={"䶦","纘","𧷤","𩽆","𪚇"}
	a[25813]={"穳","鰿"}
	a[25815]={"𧴅"}
	a[25822]={"失","𡚰","𥝛","𥞵"}
	a[25826]={"𥡠"}
	a[25831]={"㷇","綊","𨑡"}
	a[25833]={"䄮","秩","𥞗","𥞦"}
	a[25835]={"𦄍"}
	a[25836]={"𨗃"}
	a[25837]={"𥢡"}
	a[25841]={"焋"}
	a[25842]={"䊿","紩","𩠃"}
	a[25844]={"𤙈"}
	a[25851]={"䶝","𤒧"}
	a[25852]={"奘","牍","𤞛"}
	a[25853]={"䅩","稘","𤱽"}
	a[25854]={"犊","緓"}
	a[25855]={"䄺"}
	a[25861]={"𦆖"}
	a[25862]={"綨","续","𠝰","𡖾","𦦕","𪗫"}
	a[25863]={"䱃","䱋","奊","𣗻","𧴍","𩵩"}
	a[25864]={"绬"}
	a[25865]={"穔"}
	a[25871]={"𦄗","𦆋"}
	a[25872]={"稹","绩","赞","鯐"}
	a[25873]={"𥢼","𩽺"}
	a[25874]={"䌙","𤖖","𤗶","𥢊"}
	a[25875]={"緁"}
	a[25876]={"𤛥"}
	a[25877]={"𤙶"}
	a[25881]={"縝"}
	a[25882]={"䶞","齼"}
	a[25883]={"積","鯕","𤖘","𤗸"}
	a[25884]={"鲼"}
	a[25885]={"鮧","𥣢","𪉮"}
	a[25886]={"疀"}
	a[25891]={"缜"}
	a[25892]={"歵","績","𤖓","𤗮"}
	a[25893]={"鲯"}
	a[25894]={"𩻁"}
	a[25895]={"鱑","𥣪","𩹀"}
	a[25896]={"觵"}
	a[25905]={"𣝖"}
	a[25911]={"䝗","貅","𠁫","𧳟"}
	a[25915]={"𩡥","𩡦"}
	a[25922]={"䅘","朱","𥝰","𧳕"}
	a[25931]={"䊾","䋱","牀"}
	a[25932]={"𩠄"}
	a[25933]={"秣","秼","𤘬","𥞊","𥟂"}
	a[25941]={"䝤"}
	a[25942]={"㸡","絑","綝","𤕹","𥿉","𦧳"}
	a[25943]={"桀","𦠁","𪏿"}
	a[25944]={"𧳣"}
	a[25951]={"爒","𨝖","𪘆","𪘨"}
	a[25952]={"䅴","鮴","鯠","","𩠽","𩵦"}
	a[25953]={"䋘","䚞","綀","練","𡖯","𤖂","𤗛","𥢻","𦁜","𦧙"}
	a[25954]={"𤒗","𤗥","𤯡","𥠹"}
	a[25955]={"𤙨","𥠓"}
	a[25961]={"䌇","繚"}
	a[25962]={"䌝","𩺲"}
	a[25963]={"䱅","练","鮇","鮢","𦈌","𩠿"}
	a[25964]={"牃","牒","緤","縥","𣘳","𤗗","𦧤"}
	a[25965]={"䵔","𤐬"}
	a[25966]={"𤚩","𥣆"}
	a[25971]={"缭","𦄨"}
	a[25972]={"䱞","縤","𦈟","𩹟","𩺚"}
	a[25973]={"𤄳","𪘜"}
	a[25974]={"鰊","𩸏"}
	a[25975]={"䑜","觫","𤗣","𧤈"}
	a[25976]={"𤗽"}
	a[25982]={"齽"}
	a[25985]={"鯟","鰈","𧤠"}
	a[25986]={"䚢","𧤛"}
	a[25987]={"𪐓"}
	a[25988]={"𥤕"}
	a[25995]={"鲽"}
	a[26002]={"鲴"}
	a[26004]={"𧤯"}
	a[26016]={"𩼯"}
	a[26020]={""}
	a[26030]={"旧","𢒤","𧲥"}
	a[26031]={"和"}
	a[26040]={"𥿖"}
	a[26041]={"𠲆","𦂮"}
	a[26042]={"秵","稇","稛","𤘘","𥝿"}
	a[26043]={"秞","釉","𥞚"}
	a[26050]={"𦀄","𦀝"}
	a[26051]={"䵒","細","絪","綑","𤱸"}
	a[26052]={"牭","紬"}
	a[26053]={"㸶"}
	a[26054]={"牰"}
	a[26060]={"絗","𡖣"}
	a[26061]={"细","鮂",""}
	a[26062]={"䌷","稒","","𠷷","𦀶","𧣕"}
	a[26071]={"緗","齫","𪘩"}
	a[26072]={"𤳞","𧣛","𩶛","𩶾"}
	a[26073]={"鮋"}
	a[26081]={"缃","鮰","𩶖"}
	a[26082]={"𣦦","𦄰"}
	a[26083]={"鲉"}
	a[26084]={"鰰"}
	a[26092]={"鯝"}
	a[26101]={"鳁"}
	a[26102]={"纙"}
	a[26103]={"䭪","鯹"}
	a[26104]={"鲤"}
	a[26110]={"𧴢"}
	a[26111]={"𪙳"}
	a[26113]={"𦆊","𦈅","𩽩","𩽰"}
	a[26115]={"鱧","鳢","𥤐"}
	a[26142]={"𧈞"}
	a[26151]={"𥠺"}
	a[26153]={"貍"}
	a[26160]={"䋎","縕"}
	a[26162]={"程"}
	a[26170]={"䌉","緼"}
	a[26171]={"𦀚"}
	a[26172]={"𤛁"}
	a[26173]={"䋥","𤖃","𥠀"}
	a[26180]={"缊"}
	a[26181]={"䱇","鰮","𪉸"}
	a[26182]={"觛"}
	a[26183]={"纆"}
	a[26191]={"馧","鰛","𨰒"}
	a[26193]={""}
	a[26194]={"䌡","鯉"}
	a[26241]={"𧳠"}
	a[26253]={"𥟗"}
	a[26261]={"綥"}
	a[26263]={"𣇑"}
	a[26283]={"𧤃"}
	a[26291]={"𩹡"}
	a[26301]={"鱞"}
	a[26302]={"䚪","繦","繾","鳂","𤜑","𦇞"}
	a[26303]={"𪐔"}
	a[26312]={"缱"}
	a[26313]={"𩽎"}
	a[26315]={"𩼅"}
	a[26316]={"𩼞"}
	a[26332]={"𧳃"}
	a[26341]={"惒"}
	a[26342]={"𧴔"}
	a[26350]={"𥄉"}
	a[26352]={"䅰","蚀"}
	a[26353]={"䆀"}
	a[26354]={"𤙕","𧴊"}
	a[26361]={"緦"}
	a[26362]={"𦄿"}
	a[26363]={"㦟","𪒚"}
	a[26370]={"𢡕"}
	a[26371]={"䋿","缌"}
	a[26372]={"䶚"}
	a[26373]={"𩶥"}
	a[26374]={"触","𡣉","𧑪"}
	a[26380]={"繯"}
	a[26381]={"𦈓"}
	a[26382]={"鰓","𪉭"}
	a[26383]={"䚡","𩻤"}
	a[26385]={"穠"}
	a[26390]={"缳","𦆴"}
	a[26391]={"𦇏"}
	a[26392]={"鰃","鳃"}
	a[26393]={"𧤖"}
	a[26394]={"繷","𨑊"}
	a[26395]={"䵜"}
	a[26400]={"䚃"}
	a[26401]={"覷","鯤","𨞦"}
	a[26402]={"䚠","犤"}
	a[26403]={"𣰕","𧇙"}
	a[26405]={"𠓍"}
	a[26410]={"𧡑","𨝅"}
	a[26411]={"覤","覰","覻","鲲","𨛸","𨟩"}
	a[26412]={"𣱁","𧢏","𨝞"}
	a[26413]={"䲅"}
	a[26414]={"𣰽","𣱀"}
	a[26415]={"𣱃"}
	a[26440]={"児","𣅏"}
	a[26441]={"𥞏"}
	a[26442]={"𣭓","𥾴"}
	a[26445]={"䄿"}
	a[26452]={"𣬣","𣬰","𥞷"}
	a[26453]={"𣭋"}
	a[26454]={"絏","𣭦"}
	a[26460]={"縨","覙","𠬓","𧠪","𧠬","𧡠","𨛷"}
	a[26461]={"䅐"}
	a[26462]={"𣆨","𣭒","𤙧"}
	a[26463]={"𣭗","𣮃","𣯂","𥠎"}
	a[26470]={"絸","覑","𦀕","𦃻","𦠺","𧠛","𨜁"}
	a[26471]={"䅙","𣆶","𧠒","𧠾","𧡓"}
	a[26472]={"㲩","𣮷","𤙝"}
	a[26473]={"毸","覣"}
	a[26474]={"齥"}
	a[26480]={"緄","繉","覘","馄","𧠜","𪘄 "}
	a[26481]={"𥇅","𧠺","𧡾"}
	a[26482]={"覒","𧡩","𧣤"}
	a[26483]={"䋲","𦃰"}
	a[26484]={"𣮶"}
	a[26485]={"𣮨"}
	a[26490]={"绲","𣯫","𧡹","𧴞","𨝠","𪘟"}
	a[26491]={"䆉","䖑","䱒","覶","𧆽","𧠼","𩷪"}
	a[26492]={"𣮎","𣮑","𧇮"}
	a[26493]={"䖖","绳"}
	a[26495]={"縄"}
	a[26499]={"𣯴"}
	a[26502]={"繓","鰻","𠧄","𩻙"}
	a[26503]={"繟","𧤏","𩻋","𩼓","𩽞"}
	a[26505]={"𥣊"}
	a[26508]={"𩺷"}
	a[26509]={"䱾"}
	a[26512]={"䶫","纓","鳗","𦈛","𧴣"}
	a[26513]={"䴝","貜","𣠏","𩽢","𩽴","𪙣"}
	a[26514]={"鱓","𤜉","𥤘","𦧴"}
	a[26515]={"觶","𦅿"}
	a[26523]={"𧲬"}
	a[26533]={"种"}
	a[26544]={"𥞁"}
	a[26551]={"貋","𥄁"}
	a[26552]={"𧳼"}
	a[26553]={"稷","紳","𥟑"}
	a[26554]={"𤙇","𩰡"}
	a[26561]={"䝢"}
	a[26562]={"稈","𤑹","𦃩"}
	a[26563]={"绅","𥠰","𪗧"}
	a[26564]={"㹄","𦁰"}
	a[26568]={"貗"}
	a[26572]={"䅼","𥠋","𦆎"}
	a[26573]={"䆁","釋","魻"}
	a[26574]={"𩡃"}
	a[26575]={"𩶳"}
	a[26579]={"䅹"}
	a[26581]={"緝","縵","馒","𦂆"}
	a[26582]={"繹"}
	a[26583]={"貚","𤛔","𩷑"}
	a[26587]={"縪"}
	a[26588]={"縷","𤗬"}
	a[26591]={"缉","缦"}
	a[26593]={"穝","𩹽"}
	a[26594]={"𧤨"}
	a[26601]={"鯧"}
	a[26604]={"𥣬","𩺅"}
	a[26611]={"鲳"}
	a[26612]={"𩻂"}
	a[26613]={"鱪","鱰","𦇄","𩻨"}
	a[26614]={"𤜈"}
	a[26651]={"稆"}
	a[26660]={"絽"}
	a[26664]={"𦀵"}
	a[26671]={"䅛"}
	a[26680]={"𦝕"}
	a[26682]={"𥡏"}
	a[26683]={"𦃠"}
	a[26691]={"𡗈","𦄛","𪉨"}
	a[26700]={"𦈖"}
	a[26701]={"𦧭","𩸠"}
	a[26702]={"𧤉","𩹂"}
	a[26703]={"𩼟"}
	a[26704]={"觸"}
	a[26710]={"齶"}
	a[26711]={"鰐","鰨","鳄","鳎","𩻠"}
	a[26742]={"𥞡"}
	a[26750]={"𣆄","𦇧"}
	a[26751]={"𥟘"}
	a[26752]={"𡖦"}
	a[26753]={"𢬚"}
	a[26760]={"緆","𦙃"}
	a[26761]={"䅌","䅥","𥠜","𧳪"}
	a[26762]={"䅞","𥟄","𧴉"}
	a[26770]={"㡫","䋵","絹","","𢇋"}
	a[26771]={"䵘","舓","𥟮"}
	a[26772]={"㹇","稩","𠢎","𤚺","𦀔"}
	a[26773]={"䅢","𤙰","𥣋","𦂕"}
	a[26774]={"甥"}
	a[26780]={"绢","𦂝","𦄡"}
	a[26781]={"緭","鯣"}
	a[26782]={"𦂈","𦆂"}
	a[26784]={"𤛯","𩶍"}
	a[26790]={"䌈","𦆅","𪘹"}
	a[26791]={"馤","鰑","𡀻","𩷫","𩹄"}
	a[26793]={"䚟","齵"}
	a[26794]={"鰅","𤗱","𥐂"}
	a[26795]={"䚤"}
	a[26801]={"鳀"}
	a[26802]={"𧷪"}
	a[26803]={"穨","𥣧"}
	a[26820]={"𧲻"}
	a[26831]={"积","𧿗"}
	a[26840]={"呉","𥿗","𧳒"}
	a[26841]={"𥞺"}
	a[26850]={"织","𤗁"}
	a[26851]={"𣅔","𣅳"}
	a[26853]={"䅪"}
	a[26860]={"齞","龊","𧳷"}
	a[26861]={"䅠"}
	a[26862]={"㸽","馈","𥟔","𥠝"}
	a[26863]={"𤙬"}
	a[26864]={"穓"}
	a[26870]={"㔭","緹","齪","𤗘"}
	a[26872]={"缋","𧣫"}
	a[26873]={"犑"}
	a[26880]={"縜","缇"}
	a[26881]={"𦧧"}
	a[26882]={"𤛬","𩶭"}
	a[26883]={"𥢢"}
	a[26890]={"𧵯"}
	a[26891]={"鯷"}
	a[26892]={"㚍","䚣","繢","𤗴"}
	a[26901]={"缲","𩻱"}
	a[26912]={"鱢"}
	a[26913]={"纝"}
	a[26915]={"𤜖"}
	a[26942]={"𣕷"}
	a[26950]={"県"}
	a[26951]={"緥"}
	a[26954]={"稞"}
	a[26960]={"𢒬"}
	a[26961]={"鰥","𩹌"}
	a[26962]={"𥡜","𧤩"}
	a[26963]={"㚌","綶","馃","𤖇"}
	a[26965]={"䊬"}
	a[26970]={"𣎕"}
	a[26971]={"縲","鳏","𧴜"}
	a[26973]={"㹎"}
	a[26980]={"𦅡"}
	a[26981]={"缧"}
	a[26982]={"䆆","𦆿","𦧲"}
	a[26984]={"犦","𩸄"}
	a[26991]={"繰"}
	a[26995]={"𤜌"}
	a[27000]={"𠤂"}
	a[27001]={"䎗","𠢼","𠣿","𩸀"}
	a[27002]={"鰗","鲷"}
	a[27003]={"㔧"}
	a[27004]={"𠤍"}
	a[27005]={"𦑝"}
	a[27006]={"𠤋"}
	a[27007]={"鰳"}
	a[27010]={"勹","勺","勽","勿","匂","灳","豹","","","","𠚣","𠚬","𠤈","𠤉","𠧓","𠨐","𪙩"}
	a[27011]={"豽","𠠲","𧲡"}
	a[27012]={"匁","匆","𠣄","𧇟"}
	a[27017]={"鳓"}
	a[27020]={"勾","匀","匃","匇","𠚨","𠣐"}
	a[27021]={"䄪","匈","匊","𠚲","𠠳","𠡝","𠣌","𠣥","𥝢","𥝤","𧲳"}
	a[27022]={"㔓","䄲"}
	a[27030]={"㓜","勻","匄","句","幻","归","糿","約","紉","豿","𠣎","𠣏","𠣒","𠣓","𡖑","𢆵","𥾉","𥾸","𦆗","𧲩"}
	a[27031]={"䋄","䵑","勼","匉","幼","糼","納","𠡔","𠡢","𠣍","𠣔","𠣟","𡖎","𥾔","𦚛","𩟿","𪏯","𪏵"}
	a[27032]={"㔜","䋞","牣","物","𠣘","𠣦","𢪥","𤚂","𥡓"}
	a[27033]={"劧","劮","牞","𠡻","𥝳"}
	a[27034]={"𤘞"}
	a[27038]={"𧲾"}
	a[27040]={"匌","旬","约","纫","𠜰","𠣑","𠣖","𠨞","𡖒","𡖜","𣍢","𤖮","𥾞","𥾡","𦒩","𧳆"}
	a[27041]={"㔪","䄴","劬","匋","甸","纲","纳","𠡇","𠣕","𠣗","𦑂"}
	a[27042]={"㔚","勨","𠣜","𠣠","𥡚","𦂴","𦐝"}
	a[27043]={"劺"}
	a[27044]={"𤘪","𥿑"}
	a[27050]={"䀏","䌻","夠","絅","絇","綗","綱","𠜧","𠣡","𠣭","𡖖","𤖵","𥾶","𦃁"}
	a[27051]={"秱","魛","魡","魩","𠵞","𢻿","𥠈","𥾛","𥿌","𧳜","𩵕","𪗝"}
	a[27052]={"㔞","勂","匒","犅","魶","𠝵","𠡪","𤘽","𥢀","𦙚","𩵓","𩶩"}
	a[27053]={"勫","觔","𠞰","𠣮","𠣯","𠣲"}
	a[27054]={"勦","匍","𡖔","𡖝","𥾢","𥿛"}
	a[27055]={"牳"}
	a[27056]={"𤘟","𤘼"}
	a[27058]={"𤙉"}
	a[27060]={"䋚","䌹","絢","絧","網","翗","訇","饲","𠝅","𠣙","𠣚","𠣤","𠣪","𠣱","𤖾","𥿆"}
	a[27061]={"㔩","䑚","綯","鱽","𠢰","𠣳","𠣴","𠣾","𩵻"}
	a[27062]={"䱡","勮","稠","𠟿","𠣰","𤙓","𦀖","𦐨","𦑨","𧣏","𩸢","𪗤"}
	a[27063]={"𠢍","𠢶"}
	a[27064]={"匎"}
	a[27065]={"䑙","勳","舑","𠣞","𠣵"}
	a[27070]={"㔨","绚","齣","𠝎","𦐛","𦑙"}
	a[27071]={"㚋","䎊","勓","匐","稝","綢","绹","鮈","","𠢒","𠣸","𠤀","𠤇","𩵺"}
	a[27072]={"䱂","勪","𠣽","𠤄","𠬏","𩶵","𩹾"}
	a[27073]={"𠤅"}
	a[27074]={"𠢴","𧍀","𩶋"}
	a[27075]={"𠞕","𩶎"}
	a[27076]={"動"}
	a[27080]={"匑","綳","齨","𧥻","𪗪","𪘍"}
	a[27081]={"䎋","䱩","匓","绸","鮙","鮦","","𠣹","𤔲","𦑳","𩶧"}
	a[27082]={"翻","翽","𤕅","𪐉","𪘖"}
	a[27083]={"𤔺"}
	a[27090]={"匔","绷","𠤊"}
	a[27091]={"鲖","𦅤","𦑪","𧇂"}
	a[27092]={"鯛"}
	a[27093]={"勴","𡭒","𧣷","𩷻"}
	a[27101]={"韰","齷","𤩤"}
	a[27102]={"䌦","壡","𡓝","𧷎","𪘴"}
	a[27104]={"𤛹"}
	a[27111]={"䪥","𧇣"}
	a[27112]={"𤫀","𩽍"}
	a[27113]={"䴞","鰹"}
	a[27114]={"𧤵","𧥋"}
	a[27116]={"繣"}
	a[27117]={"𩻽"}
	a[27120]={"𠁢"}
	a[27130]={"彑","𢆴"}
	a[27131]={"竖","𡐩"}
	a[27132]={"坚","𧲵"}
	a[27140]={"𠜞","𧳺"}
	a[27141]={"玺","𡉲"}
	a[27142]={"𥝦"}
	a[27150]={"盌","盠","𢀟"}
	a[27151]={"租","紐","鱼","𥁒","𥁽","𥞓","𥞭","𨥒"}
	a[27152]={"経","錅","𡋹","𡌪","𤙊","𨾉","𨾞","𪏲"}
	a[27153]={"㚅","𥡑"}
	a[27160]={"組","经","豋","𢇀","𣨖","𤕲","𧴙"}
	a[27161]={"墾","纽","𡋜","𦁧"}
	a[27162]={"墏","錖","𡎙","𡑶"}
	a[27163]={"𨩂","𨿯"}
	a[27170]={"组","龃","𡲂","𦄪","𧯡"}
	a[27171]={"䋼","銞","𥡪","𥣎","𥿲"}
	a[27172]={"𤪰","𥟽","𨫥"}
	a[27173]={"𤖍","𥟷","𩶜"}
	a[27175]={"㹊"}
	a[27176]={"𧗃"}
	a[27180]={"齟","𡗃","𤖗"}
	a[27181]={"䌂","䱉","𤖛","𤪎"}
	a[27182]={"壑","鯭","𡐍"}
	a[27183]={"鲣"}
	a[27184]={"𤚄"}
	a[27191]={"龌","𧇿"}
	a[27192]={"䌑","𡑧","𧇇","𧣬"}
	a[27193]={"䵛","𤧧","𥣞"}
	a[27195]={"㙰"}
	a[27201]={"鲫"}
	a[27205]={"繡"}
	a[27210]={"夕","","","","","","","","𠁡","𠂊","𠃑"}
	a[27211]={"㣊","䵼","𡕓","𩻲"}
	a[27216]={"鱐"}
	a[27220]={"厃","夘","多","","","","","𠨍","𡖄","𡖇","𡖉","𧳁","𧳤"}
	a[27230]={"卶"}
	a[27231]={"移"}
	a[27232]={"𢒢"}
	a[27233]={"㹋"}
	a[27240]={"𡖰","𤖻","𥿫"}
	a[27241]={"𪐀"}
	a[27243]={"𥠨"}
	a[27250]={"够","𠨒"}
	a[27251]={"穋"}
	a[27260]={"繆"}
	a[27261]={"𩶰"}
	a[27262]={"𧣣"}
	a[27265]={"繍"}
	a[27270]={"缪"}
	a[27271]={"鮣","𩽿"}
	a[27281]={"䲟"}
	a[27282]={"䚧"}
	a[27291]={"鯽"}
	a[27301]={"𩼣"}
	a[27302]={"蠁","𪙢"}
	a[27306]={"蟹"}
	a[27308]={"𧒒"}
	a[27310]={"","","𠚤","𡖋","𢘞","𢝩","𤆐","𤆒","𤆫"}
	a[27311]={"冬","𢤰","𦇶","𧲴"}
	a[27312]={"𦇗","𩽐"}
	a[27313]={"鱻"}
	a[27314]={"䲜","虪","𥤚","𥤛","𧖢"}
	a[27315]={"𩼠","𩽵"}
	a[27316]={"𧖢"}
	a[27320]={"䝆","忽","𢚿","𤇐","𤇘","𤈕","𧰼"}
	a[27321]={"𥠖"}
	a[27322]={"怱"}
	a[27330]={"彖","綛","𢘵","𢛦","𤇗","𧳩"}
	a[27331]={"㥎","終","象",""}
	a[27332]={"秾","𤊝","𤙹"}
	a[27333]={"𥠡"}
	a[27334]={"𢜓"}
	a[27340]={"怨","炰","貇","𤈖","𦁕","𧰲","𧱈"}
	a[27341]={"㤩","惄","终","魚","𢤂","𤬂","𥿢","𧚩","𪐁"}
	a[27342]={"㸾","惣","牎","緫","𤌉","𤌝","𧉏"}
	a[27344]={"㶻","㹅","𢝰"}
	a[27350]={"急","懇","緣","𦃕","𦃵","𧰺","𩚏"}
	a[27351]={"䂕","裻","𥢩","𦂯","𩠇"}
	a[27352]={"惫","鮗"}
	a[27353]={"䖿","𥢦"}
	a[27354]={"𧴂"}
	a[27360]={"䋟","缘","𣥦"}
	a[27361]={"稳","馋","𣩕","𥢘","𦧫"}
	a[27362]={"䖤","䗍","鯬","𧌜"}
	a[27363]={"黧","𢢍","𤑩","𥣙","𦃐","𦄥"}
	a[27364]={"𤑊"}
	a[27370]={"熈","龈","𩚴"}
	a[27371]={"䱲","餐","𢣕"}
	a[27372]={"䱗","鱌","𥣦","𦄦","𦆜","𩷰","𩺈"}
	a[27373]={"䆈","螿","𤗓","𥣔","𩷃","𪒺"}
	a[27374]={"縫"}
	a[27375]={"螽","𧍸"}
	a[27376]={"勲","𧋴"}
	a[27380]={"齦"}
	a[27381]={"𦆣","𩚻","𩜨","𩝫","𩷱"}
	a[27382]={"䲆","𧣢","𧥂","𧹾","𩺰","𩾄"}
	a[27384]={"缝","鰠","𢢣"}
	a[27386]={"憅"}
	a[27390]={"𤑪"}
	a[27391]={"𢤕"}
	a[27392]={"𧈆","𪙕"}
	a[27393]={"䱼","𩼦"}
	a[27394]={"蠡","鳋","𧕼"}
	a[27395]={"𩻸"}
	a[27401]={"䖕","毚","鲵","𧇅","𧇌","𧇔"}
	a[27402]={"䖘","𣯀","𣯥","𧇹","𩘅"}
	a[27403]={"䬌","氇","氌"}
	a[27405]={"𧑴"}
	a[27409]={"毽"}
	a[27410]={"䵶","繩","饣","𥣨","𪓟"}
	a[27411]={"㸥","㽈","纔","鱦","𠣈","𪓷","𪓻","𪔁","𪚃"}
	a[27412]={"𣬚","𦧻","𩻼","𩼍","𩽝","𪚺"}
	a[27413]={"䆋","𠓗","𤜇","𦇿","𧥓","𩴷","𪚵","𪚾","𪛃"}
	a[27414]={"𣰞","𧥒"}
	a[27415]={"𡤳","𡤺","𪚧","𪚫"}
	a[27416]={"艷"}
	a[27418]={"𪚿"}
	a[27420]={"𠃉 ","𡗇"}
	a[27421]={"㐑"}
	a[27422]={"𥝴"}
	a[27423]={"秇"}
	a[27430]={"䝚","夗","𠙀","𠤓","𧲧"}
	a[27431]={"𠙝","𠠷","𥝗"}
	a[27432]={"紈","𣬝","𣬞","𣬤","𣬨","𤘕","𥝡"}
	a[27433]={"䄬","𣭬","𤘗"}
	a[27440]={"包","危","紦","色","饥","𠑾","𠚱","𡖕","𤖫","𥾊","𥿡"}
	a[27441]={"䄫","䊵","免","兔","秜","紞","𡖓","𣥇","𥝧"}
	a[27442]={"䊶","纨","飖","𠙎","𡖊","𡖐","𣬴","𣭥","𣭧","𤕮","𤖪","𥿞"}
	a[27443]={"𣬢","𣬥","𤘣"}
	a[27444]={"牠"}
	a[27450]={"紀","絕","觇","貎","𠘷","𠙑","𢀸","𢀽","𣥘","𥾚","𥿎","𦫓","𧠇","𧴀","𩠀"}
	a[27451]={"㓄","","𡖴","𣔗","𪏸"}
	a[27452]={"㲌","㸭","䅋","勉","龟","𣬠","𣭚","𣭨","𤙌","𤙙","𥞔","𧆟"}
	a[27453]={"毱","𣬬","𣮋","𣮓","𦧇","𩶴"}
	a[27454]={"𣬼","𩗔"}
	a[27460]={"㲋","絶","纪","饱","𣬋"}
	a[27461]={"䋋","絻","𡕚","𤭜","𥿒","𦃥","𦫝","𪉛","𪏶"}
	a[27462]={"㕙","䶔","魫","𠄇","𠬍","𣬶","𣭙","𤘷","𦂱","𩵍"}
	a[27463]={"䅏","𥠢","𥡾","𦃫","𧣁","𩵔"}
	a[27464]={"𥢓"}
	a[27465]={"𢭥","𣭇","𣯲","𥝀","𥡩","𩗯"}
	a[27470]={"㼝","䋩","䶕","绝","龅"}
	a[27471]={"䆇","䰾","虝","觑","馜","魢","𠙡","𠙪","𦫬","𨛫","𩵗","𩵨"}
	a[27472]={"毥","麁","𣦫","𣭜","𦂔","𦡖","𦫦","𧆼","𧣃","𧣍","𩖿"}
	a[27473]={"颻","𣯁","𥡄"}
	a[27474]={"𦄌"}
	a[27475]={"⻲","㲧","𥡌"}
	a[27480]={"齙","𦫭","𪗼"}
	a[27481]={"彘","鮑","鮠","鱾","鲃","𧇰","𩸦"}
	a[27482]={"觤","鮸","𣯒","𣰇","𦆵","𧆰","𩸃"}
	a[27483]={"鯴","𩹥"}
	a[27484]={"𣯜"}
	a[27485]={"亀"}
	a[27486]={"穐","𣯭"}
	a[27490]={"齯","𦄓","𦦃"}
	a[27491]={"鯢","鲍","","𥣅","𩾆","𪕘"}
	a[27492]={"觬","𣮴","𧇝","𧣶","𩘠","𩾃","𩾅","𪘣"}
	a[27493]={"鲺"}
	a[27494]={"𦅥","𦫯"}
	a[27502]={"𦇍"}
	a[27503]={"皻","鲰","𠧇","𥣡"}
	a[27505]={"齳"}
	a[27506]={"鯶"}
	a[27507]={"𤛰"}
	a[27511]={"夂","帅","",""}
	a[27512]={"鰕","𦇙","𪙦"}
	a[27513]={"觼","𧥎"}
	a[27514]={"𡕗","𥀵","𩏣"}
	a[27517]={"𧈑"}
	a[27518]={"鰎","𩻥"}
	a[27521]={"収","𠥾","𢁟"}
	a[27522]={"䝛","𠬞","𢁙","𢌳","𥝐"}
	a[27531]={"䝘","処","叔","紁","𢑓","𣦼","𤕭"}
	a[27532]={"𡖌","𡛹","𢍅","𤿈","𥝥"}
	a[27533]={"夅","秛","𡕖","𡕘"}
	a[27541]={"㠾","㣇","級","𠬳","𠭓","𠭣","𡕫","𢂭","𣦻","𣪄","𣪑"}
	a[27542]={"妴","紴","𠦨","𠭖","𢍝","𣥣","𣪖","𤖷","𤚶","𥝻","𥟧","𥾤","𥿸"}
	a[27543]={"㕟","㛑","䴻","犂","皴","𥀉","𥝼"}
	a[27544]={"夆","释","𤙎","𥞜","𪏼"}
	a[27547]={"䄶"}
	a[27551]={"级","𠭝","𠭟","𠭠","𢑞","𣥹","𣪈","𣪴","𤕱","𤖬","𤖰","𦔰"}
	a[27552]={"䅓","紣","𢻁","𢾨","𣪜","𤿘","𤿝","𥡖","𥾯","𧳶","𩵎"}
	a[27553]={"㢡","絳","𠢅","𠭉","𤚜","𤛿","𦀁","𦃏","𧢷","𧢹"}
	a[27554]={"𡖚","𡠍"}
	a[27555]={"𠭘","𠭢","𥟒","𧳳"}
	a[27556]={"紼","貄"}
	a[27561]={"㕡","𡕱","𣪶","𦁴","𧧞","𧮸"}
	a[27562]={"皱","稺","缨","魥","𡕴","𢍪","𣫋","𤿎","𤿟","𤿡","𥀰","𦀩","𦂤","𪉘"}
	a[27563]={"彜","穉","绎","绛","觙","鮍","𤿩","𤿯","𥀄","𥠧","𧆤","𪗵"}
	a[27564]={"皺","綘","綴","𤖀","𤿥","𧢻"}
	a[27565]={"𠭗","𠭮","𧳰"}
	a[27566]={"㸼","绋","𤿪"}
	a[27567]={"𥞰"}
	a[27571]={"㱕","夐","敻","綅","貑","𠭸","𢑼","𣨏","𦃘","𦕕","𧧙","𨓼"}
	a[27572]={"䱙","緅","馊","𠭹","𢑷","𤿷","𦃈","𩵤","𩷅","𩷍","𩽹"}
	a[27573]={"彝","鲏","𥀈","𦈉"}
	a[27574]={"稦","缀","解","𣬔","𧴛","𩷄"}
	a[27575]={"𨍂"}
	a[27576]={"䋖","𥏚","𦘖"}
	a[27577]={"鮄"}
	a[27581]={"㕢","叡","𠮉","𡕷","𢿌","𣊸","𣪰"}
	a[27582]={"㣈","緞","𠮏","𡟮","𣪙","𥡽","𦃌","𩾈"}
	a[27583]={"緯","𠮋","𡒒","𣪦","𣬐"}
	a[27584]={"𦖥"}
	a[27585]={"緷","𩷭","𩸉"}
	a[27586]={"𧣸"}
	a[27587]={"㹆","肄"}
	a[27591]={"㲃","㲊","縀","𡕳","𤗜"}
	a[27592]={"缎","鮼","鯞","齱","𠭯","𣪽","𧇈","𩸤"}
	a[27593]={"䱸","犌","鯫","𤳫","𩹨"}
	a[27594]={"繲","𠟳","𣬒","𩽼"}
	a[27595]={"𦇊"}
	a[27596]={"𤛳"}
	a[27597]={"𦂩"}
	a[27599]={"犍"}
	a[27601]={"缗","舚","𦧱"}
	a[27602]={"𩺜"}
	a[27604]={"鲪"}
	a[27610]={"𧬰"}
	a[27611]={"鰼","鳛","𣬕","𥌄","𧭐"}
	a[27612]={"𣡳","𩽈"}
	a[27613]={"𠤪"}
	a[27630]={"名","貂","","","𠮥","𠯳"}
	a[27631]={"各","貉"}
	a[27640]={"㫚","曶"}
	a[27641]={"","𣅈","𤰧","𧳽"}
	a[27642]={"䅂","备"}
	a[27650]={"㸛","䀜","牊","紹","𥿨"}
	a[27651]={"絡","饹","𦧕"}
	a[27652]={"嗠"}
	a[27653]={"𤙑"}
	a[27660]={"䚻","绍","龆","𣆌","𦀆","𧥧","𧥲","𧳬"}
	a[27661]={"㽜","睝","络","𣈉","𥓍"}
	a[27662]={"䅕","𤗌","𥠷"}
	a[27664]={"𤙳"}
	a[27670]={"眢","詧","詹","齠","𥖞","𦦌","𪗸"}
	a[27671]={"䋧","督","馏","魯","鮉","𦂑","𦃓","𪘊"}
	a[27672]={"䵕","鮥","𥟵","𩹕"}
	a[27673]={"觡","𣞴","𦀲","𩠨"}
	a[27680]={"𦥵","𧧁"}
	a[27681]={"鲁","𢑦","𩺠","𩻎"}
	a[27682]={"穭","𤖕","𤚤","𦃴","𨡓 "}
	a[27683]={"𧤝","𩹿"}
	a[27690]={"䌌","𠸿","𤖝","𤗨","𤗻","𦅼"}
	a[27691]={"緡","𥇠","𥉆"}
	a[27692]={"䱟","穞","鰡","𣦠","𤛊"}
	a[27693]={"醬","𧣻"}
	a[27694]={"鮶"}
	a[27700]={"䶤"}
	a[27701]={"䱻","鱜","𦅀","𩾊"}
	a[27703]={"觺","𤛧"}
	a[27704]={"𧤢","𧥁","𩹆"}
	a[27710]={"亇"}
	a[27711]={"鰯","𪚆"}
	a[27712]={"䌵","䚥","鱘","𤛒","𤛴","𪚌"}
	a[27714]={"𩻣"}
	a[27720]={"⻇","邜","𠣧","𡴲","𡵁","𡵶","𧢲"}
	a[27721]={"䄦","䏑"}
	a[27722]={"务"}
	a[27730]={"𠣢","𡵪","𢆳","𤊱","𥾇"}
	a[27731]={"䄧","剓","𦆢","𩁼"}
	a[27732]={"秄","𠡴","𡕕","𥝔","𥞇"}
	a[27733]={"𢩸"}
	a[27740]={"䋒","刍","紓","鄬","饧","𠜌","𠣨","𡖛","𤉢","𥾋","𥿷","𦁮","𦙑","𨚷"}
	a[27741]={"將","肾","𠕗","𡕙","𡖏","𢂺","𥞮","𥾌","𩧸"}
	a[27742]={"甮","芻","角","𠡡","𢂟","𢃝","𤛃","𦁯","𧳊","𧳹"}
	a[27743]={"争","𠡵","𢮃","𤰅","𨛘"}
	a[27744]={"䅄"}
	a[27750]={"纾","臽","𡖥","𢏃","𥾏","𦥜","𨛹"}
	a[27751]={"帰","胷","𡦁","𢏒","𥞐","𥟺","𨝹","𨤒","𩵌"}
	a[27752]={"孧","𠡹","𢪸","𥞼","𥠿"}
	a[27753]={"䅳"}
	a[27754]={"𤯜"}
	a[27755]={"㔟","𤙒"}
	a[27760]={"䋓","郻","鄕","鸳","𠣬","𢏽","𢔐","𢕊","𣤃","𥿓","𦂧","𦙵","𧳸"}
	a[27761]={"㝁","稰","魣","𠶰","𥠁","𥿱","𦁐","𦃬"}
	a[27762]={"䰵","縐","𦡼","𧢼","𧣉","𧣡"}
	a[27763]={"䋫","𤛛"}
	a[27764]={"犓","觕","𨜚"}
	a[27770]={"㔃","緺","縃","繘","绉","馅","𡖿","𢏔","𢏻","𣨷","𦀯","𦁵","𦥢","𩠋"}
	a[27771]={"㔢","鵹","𠠋","𥠳","𦂫","𦛫","𦛬","𩷂","𩷾"}
	a[27772]={"駌","𢑭","𢳉","𧢺","𩻟"}
	a[27773]={"𤕂"}
	a[27780]={"縎","馉","鴛"}
	a[27781]={"𢒫","𥣟","𦂷","𨟇","𪇺","𪉦","𪊀","𪘳","𪙝"}
	a[27782]={"䱆","鱂","鳉","齺","𢴭","𤙗","𤚱","𧣚","𪙗"}
	a[27783]={"鯒","𥠫","𦅉"}
	a[27784]={"䱢"}
	a[27785]={"𠢲"}
	a[27786]={"𡼉","𢑩"}
	a[27790]={"䶟","𦈔","𪙀","𪙃","𪙆","𪙑"}
	a[27791]={"䱤","䱬","鱊","𦅛","𦢇","𩷐","𩹢"}
	a[27792]={"鲟","𥢛","𧤐","𧤬","𧤾","𩡏"}
	a[27793]={"鲬"}
	a[27794]={"𥢨"}
	a[27796]={"𢵠"}
	a[27800]={"㱍","𦇐"}
	a[27801]={"𣤦","𦇣"}
	a[27802]={"繏","馔","𩼨"}
	a[27803]={"𣤴","𦇛"}
	a[27804]={"𥤌"}
	a[27810]={"久","欠","灸","炙"}
	a[27811]={"鱮","𣤱","𥤎","𧇻","𩼾","𩽬"}
	a[27812]={"𥤒","𦈝","𨙞","𩽯"}
	a[27813]={"𩻝"}
	a[27814]={"䲚","𦧺"}
	a[27820]={"烉","负","","𣢊","𣢐","𣣛","𤉯","𦠹"}
	a[27821]={"夨","贤","","𡗛","𣣅","𨖤"}
	a[27822]={"𧲱"}
	a[27830]={"㸝","䊻","饮","𣢃","𣢄","𣢰","𣢾","𣣓","𤋳"}
	a[27831]={"䅆","奂","奐","釈","𣣨"}
	a[27832]={"𡘅","𤊘","𤘯","𨗬"}
	a[27833]={"秧","𡕛","𥝭"}
	a[27840]={"㰧","䋇","欤","欨","絘","𣢤","𣢻","𣣧","𤕶","𥿇","𨑔"}
	a[27841]={"㰫","㰶","㰿","欵","欸","矦","𡙟","𣢜","𣢢","𣢷","𣢸","𣣜","𣣳","𣤓","𤍵","𤟌","𤟒"}
	a[27842]={"䊽","欳","紻","𡘓","𣢡","𣢳","𤌽","𤟏","𥠅"}
	a[27843]={"𡚆"}
	a[27850]={"㰣","㰬","負","𣢋","𣢪","𣣸","𨒼","𨓶"}
	a[27851]={"䝨","𣣕","𣣡","𩰠","𩵢"}
	a[27852]={"㱀","奬","獎","","𡖸","𣣇","𣣯","𣤠","𩵋"}
	a[27853]={"𤚙","𤱾"}
	a[27854]={"㰱","䝟"}
	a[27855]={"𣣮"}
	a[27860]={"㷗","㷩","欿","𣣊","𣤝","𨗝"}
	a[27861]={"歃","歔","疑","緱","𡗁","𡘬","𡙝","𢑣","𤐏","𤗝","𥟭","𦂐","𦃺"}
	a[27862]={"夤","歑","𡖷"}
	a[27863]={"䱀","𡙖"}
	a[27864]={"觖"}
	a[27865]={"稧"}
	a[27867]={"𡙇"}
	a[27870]={"𣤍","𣤣","𣤧","𤋅","𥛤","𦃼","𧵍"}
	a[27871]={"㚟","䆅","䝳","缑","𣣍","𣤙","𤟭","𨄚"}
	a[27872]={"犋","𥣖","𦆃","𧥊","𧷧","𧽩"}
	a[27881]={"𣤿","𦆦"}
	a[27882]={"鯸","𣬎","𩺟","𩺶"}
	a[27883]={"𧴡"}
	a[27891]={"㱆","穥","𣤰","𦇳"}
	a[27892]={"䲌"}
	a[27893]={"𩔒"}
	a[27895]={"䱮"}
	a[27900]={"𦣐"}
	a[27910]={"尔","𣱹"}
	a[27921]={"称","粂","𥟖"}
	a[27922]={"夈","条","𡕝"}
	a[27930]={"","𢑛","𧱤"}
	a[27931]={"紧","黎","𣐦","𧳨"}
	a[27932]={"䊍","棃","𥞛","𥣵"}
	a[27940]={"彔","祭","𢑡","𤖅"}
	a[27941]={"洜"}
	a[27942]={"粲","縧","𥠊","𥣥","𥺤","𪐅"}
	a[27943]={"𤛺"}
	a[27944]={"𦓫","𧳙"}
	a[27945]={"𥟤"}
	a[27950]={"綠","縁","𦂞"}
	a[27951]={"䋴","漿","穄","𢇐","𥞾","𥿰","𦀉","𦃡","𩶗"}
	a[27952]={"䊢","梷","槳","绦"}
	a[27953]={"𤛼","𥢽","𥻊"}
	a[27960]={"緑","縩"}
	a[27961]={"𣗸","𦂋","𪘉"}
	a[27962]={"𣝟","𥛬"}
	a[27963]={"鰷","𣓞"}
	a[27964]={"縔","𤖒"}
	a[27970]={"绿"}
	a[27971]={"𣔵","𦃨"}
	a[27972]={"鰇","𣝆","𩼽","𪙙"}
	a[27973]={"鲦","𢑥","𩻳"}
	a[27974]={"𨽻"}
	a[27975]={"𨽹"}
	a[27981]={"䱚","鰶","𩸹"}
	a[27982]={"觮","𧤆"}
	a[27983]={"彙","𦄜","𩼇"}
	a[27984]={"𨽾","𨾃"}
	a[27985]={"𨽽","𨽿","𩺞"}
	a[27991]={"𢇔"}
	a[28010]={"乆","以"}
	a[28020]={"𣦸","𥾺"}
	a[28030]={"纵"}
	a[28040]={"𪗔"}
	a[28041]={"魜","魞","𩵒"}
	a[28050]={"𠈽"}
	a[28061]={"䖋"}
	a[28101]={"𥃠","𪊇"}
	a[28104]={"鱃"}
	a[28110]={"亾","兦"}
	a[28111]={"𥃢","𦣸 "}
	a[28112]={"𥤟","𧥈"}
	a[28120]={"𠆦"}
	a[28130]={"监","貖","𡖗"}
	a[28141]={"䅬","鉴"}
	a[28143]={"𥟨"}
	a[28150]={"縊","𦆧"}
	a[28151]={"䋮","絟"}
	a[28153]={"牷"}
	a[28156]={"𦇲"}
	a[28160]={"䍀","缢","𡲡"}
	a[28161]={"𦥋","𩹁"}
	a[28170]={"齸"}
	a[28172]={"縒","𧣝"}
	a[28177]={"𥣺"}
	a[28180]={"𡖽"}
	a[28181]={"𡓼"}
	a[28183]={"馐","鹺","鹾","𥃊"}
	a[28184]={"𨪔"}
	a[28190]={"繿"}
	a[28192]={"𤖚","𩺻","𪙉"}
	a[28193]={"䱹","盭","𩡚"}
	a[28211]={"𥝵"}
	a[28220]={"紒","紾"}
	a[28222]={"𤘦","𤙁"}
	a[28230]={"紟","𧲮"}
	a[28232]={"𤘡"}
	a[28240]={"齘"}
	a[28241]={"秨","魪","鹶","𦧈"}
	a[28242]={"𧣋"}
	a[28250]={"䋏","䶖"}
	a[28251]={"䰼","","𩠻"}
	a[28252]={"㸲"}
	a[28270]={"齚"}
	a[28271]={"鮓"}
	a[28280]={"𠹨"}
	a[28281]={"鲊","𩸍"}
	a[28302]={"𡅖"}
	a[28310]={"㤀","","𡿬"}
	a[28311]={"𥝨"}
	a[28313]={"鱶"}
	a[28320]={"𥾪"}
	a[28321]={"秢","𥝶","𥠂"}
	a[28330]={"㱓","紷","𤕵","𦁤","𦂁","𦂵"}
	a[28331]={"稔","穟","𢜕","𤋈"}
	a[28332]={"㸳","𤚋"}
	a[28340]={"総","繸","龄","𤗉","𩠈"}
	a[28341]={"鹷","𤋥","𥢁"}
	a[28342]={"䅵","𧐱"}
	a[28343]={"𢛮"}
	a[28350]={"䍁","絵","縂","飧","齡","𦁇"}
	a[28351]={"䰸","煞","縌","魿","齢","𩠌"}
	a[28352]={"䚗","𧌢"}
	a[28354]={"䌗"}
	a[28357]={"𠔨","𤑃"}
	a[28358]={"稴"}
	a[28360]={"绘","飨","𦁌"}
	a[28361]={"稵","鯰","鯲","𥣏","𩸂"}
	a[28363]={"𧎃"}
	a[28367]={"縑"}
	a[28368]={"𪐋"}
	a[28371]={"繺","鲶","𥣓"}
	a[28372]={"懲","𩺝"}
	a[28373]={"𩸈"}
	a[28375]={"𩻚"}
	a[28377]={"缣"}
	a[28378]={"鹻"}
	a[28380]={"𠎜","𧫹"}
	a[28381]={"鲙"}
	a[28383]={"𩹑"}
	a[28387]={"𪙊"}
	a[28388]={"馦","鰜"}
	a[28391]={"鰦"}
	a[28398]={"鳒"}
	a[28402]={"𣯾","𣰦"}
	a[28403]={"𧇞"}
	a[28410]={"䌫","纜"}
	a[28411]={"𥤝"}
	a[28414]={"𩦻"}
	a[28420]={"㠩"}
	a[28422]={"𣭕"}
	a[28430]={"览"}
	a[28431]={"稅","𠈣","𥞙"}
	a[28432]={"㲐","𣬫","𣭔"}
	a[28433]={"𣬲"}
	a[28440]={"纶","𥿪"}
	a[28441]={"税","𥝖","𥝬"}
	a[28442]={"𣨦"}
	a[28443]={"𥞀","𥡉"}
	a[28450]={"䌼","紇","綐","饩"}
	a[28451]={"𢼁"}
	a[28452]={"絁","𤕴","𩠂"}
	a[28453]={"𣮙"}
	a[28454]={"㸱"}
	a[28460]={"纥","缆","龁","𥾨","𦆳"}
	a[28461]={"䲝","𩶡","𩸟"}
	a[28462]={"𣬿","𣭝","𧣥","𧤄"}
	a[28463]={"犔","𣯘","𣰒","𣰓","𥠥","𥣍","𦧓"}
	a[28464]={"𣮺","𤙚"}
	a[28470]={"齕","𣱡"}
	a[28471]={"䰴","鮵","𧆷","𩵸"}
	a[28472]={"㲮","毺","𣮹","𣯙","𣯿","𤖌","𦂛","𪉡"}
	a[28473]={"䰿"}
	a[28474]={"𧣟"}
	a[28477]={"犠"}
	a[28480]={"𪗟"}
	a[28482]={"氆","𨝟"}
	a[28483]={"㡮","𢇓","𣰎","𣰪","𧤟","𩷿","𩸑","𩹦"}
	a[28484]={"𣮩"}
	a[28486]={"犧"}
	a[28491]={"𧆫","𧇎","𧇓"}
	a[28492]={"𡢔"}
	a[28495]={"𪙴"}
	a[28496]={"䲑"}
	a[28502]={"鳆"}
	a[28503]={"䲎","䲣"}
	a[28504]={"𩼛"}
	a[28506]={"𢍸"}
	a[28507]={"𧈓"}
	a[28513]={"犪"}
	a[28518]={"豒"}
	a[28521]={"收"}
	a[28522]={"𡚶","𥝺","𧳉"}
	a[28531]={"𡖙","𢼃","𢼇"}
	a[28532]={"𧳋"}
	a[28533]={"牧","𥞩","𥢭"}
	a[28541]={"敂","饰","𢼉","𢽆","𥿬","𦖴"}
	a[28542]={"㪇","敋","敌","敹","絣","饼","𢽈","𢾢","𩵹","𪉢"}
	a[28543]={"稊","𢽋","𢽌","𢿔","𤙘","𤯛"}
	a[28551]={"𢻹","𢼮"}
	a[28552]={"䰻","䱔","牂","絴","綈","𢽍","𢿳","𦀅","𦍲","𦍹","𩽻","𪚏"}
	a[28554]={"䍧","𤚓"}
	a[28561]={"𢽶","𢿶","𦆓","𪙅"}
	a[28562]={"稪","绨","𩵱","𪘀"}
	a[28563]={"鮩","𥠽","𩡡"}
	a[28565]={"𤚖"}
	a[28567]={"𡐱"}
	a[28571]={"緮","𢿓","𣦇","𦆮"}
	a[28572]={"敿","緻","𥢹","𪐒"}
	a[28573]={"鮮","鮷","𢿐","𦈎"}
	a[28574]={"觧"}
	a[28581]={"繳","𦅄"}
	a[28582]={"𦅣"}
	a[28583]={"繖","馓","鲜","","𦇕"}
	a[28584]={"犜"}
	a[28585]={"觯"}
	a[28586]={"𦆞"}
	a[28591]={"缴"}
	a[28592]={"馥","鰒","𩼌","𩽚"}
	a[28593]={"䱷","","𣀹","𣀿","𤳺","𦇫","𦥐","𩹈","𪉿"}
	a[28594]={"𧤡","𩼃"}
	a[28595]={"䲄","觲","𦇁"}
	a[28600]={"𩠥"}
	a[28601]={"鱠"}
	a[28602]={"𥌟"}
	a[28603]={"䲡","鱔"}
	a[28613]={"鳝"}
	a[28630]={"临","𧳇"}
	a[28631]={"谸"}
	a[28640]={"綌"}
	a[28641]={"秴"}
	a[28650]={"給","绤","饸","𣨄","𦅊"}
	a[28651]={"谿","𦁃"}
	a[28652]={"𧳫"}
	a[28660]={"㬟","䛓","给","𧴚"}
	a[28661]={"䅮","𥢥","𦧛"}
	a[28662]={"𤚥"}
	a[28663]={"𣈊","𤙱"}
	a[28670]={"牄","繒","𣍐","𦃹","𪘁","𪘒","𪙮"}
	a[28671]={"馠","鮯","𥢶","𩻶"}
	a[28672]={"緧","𤚬","𤛢"}
	a[28680]={"繪","缯"}
	a[28681]={"𥋪"}
	a[28682]={"繕"}
	a[28690]={"䭫","𪙎","𪙭"}
	a[28691]={"䱽","䲕","鱛","𦅩"}
	a[28692]={"缮","𦅝"}
	a[28693]={"鰌",""}
	a[28694]={"𧤕"}
	a[28702]={"觴"}
	a[28703]={"𥤉","𧇾"}
	a[28704]={"鱒"}
	a[28711]={"𩻵"}
	a[28712]={"𦇬"}
	a[28714]={"鳟"}
	a[28716]={"𩽡"}
	a[28721]={"秎"}
	a[28730]={"紛","𤖭"}
	a[28732]={"㧛","㸮"}
	a[28735]={"𦆤"}
	a[28740]={"纷","貐"}
	a[28741]={"饬","𪏱"}
	a[28742]={"𠃰","𧴐"}
	a[28743]={"稐"}
	a[28750]={"𪗣"}
	a[28751]={"馚","魵","𥠕","𥿐"}
	a[28752]={"綸"}
	a[28760]={"牏","緰","𦂒","𦂚"}
	a[28761]={"𡺧","𥡺"}
	a[28762]={"𤚎"}
	a[28763]={"䋦","𥢜","𦧣"}
	a[28765]={"𤙩"}
	a[28770]={"𦅖","𦈕"}
	a[28771]={"𦡒","𪉰"}
	a[28772]={"㠞","觞"}
	a[28773]={"鯩"}
	a[28774]={"𥢎","𧣵"}
	a[28781]={"𩷸"}
	a[28783]={"繜","𣦝"}
	a[28784]={"䱕"}
	a[28791]={"䱵","𩡓"}
	a[28792]={"𤛣","𩹊"}
	a[28810]={"𨑢"}
	a[28821]={"𥡬"}
	a[28830]={"緃","縱","𦄚"}
	a[28832]={"㷏"}
	a[28840]={"縦"}
	a[28841]={"𠤑"}
	a[28850]={"𦀢"}
	a[28851]={"𤕼"}
	a[28853]={"𥠦"}
	a[28860]={"𩠍"}
	a[28861]={"㷺","𦆀"}
	a[28862]={"𩶇"}
	a[28863]={"鹸"}
	a[28864]={"𥣕"}
	a[28865]={"𨕽"}
	a[28870]={"䌞","縼"}
	a[28871]={"𦅗"}
	a[28881]={"鹼"}
	a[28883]={"𦅆"}
	a[28890]={"䶨"}
	a[28891]={"䲂","䲓"}
	a[28892]={"𩻀"}
	a[28930]={"𥿜"}
	a[28932]={"稌"}
	a[28941]={"䋡","馀"}
	a[28943]={"𤙛"}
	a[28960]={"𥛓"}
	a[28962]={"鮽"}
	a[28981]={"𥜄"}
	a[29020]={"𥾓"}
	a[29041]={"𩵖"}
	a[29111]={"𥽠"}
	a[29121]={""}
	a[29141]={"継"}
	a[29142]={"鍫"}
	a[29151]={"继"}
	a[29153]={"䨂"}
	a[29161]={"䅱"}
	a[29163]={"𦂙"}
	a[29172]={"繀","𤗯"}
	a[29173]={"𤛋"}
	a[29174]={"𤛍"}
	a[29183]={"𦨁"}
	a[29190]={"䶣"}
	a[29191]={"䱺"}
	a[29201]={"𡮿"}
	a[29210]={"𡭥"}
	a[29211]={"秒"}
	a[29220]={"紗","𢆷","𢆽"}
	a[29230]={"纱","𢇄","𦀛"}
	a[29231]={"秽"}
	a[29241]={"魦","𥣀"}
	a[29242]={"觘"}
	a[29251]={"鯋"}
	a[29260]={"緲"}
	a[29261]={"𩷒"}
	a[29270]={"缈"}
	a[29311]={"𤋦"}
	a[29313]={"𩽳"}
	a[29321]={"愁"}
	a[29343]={"蝵"}
	a[29352]={"𩹤"}
	a[29354]={"㹖"}
	a[29374]={"𤚍"}
	a[29383]={"𥤗"}
	a[29391]={"鲿"}
	a[29394]={"𩺉"}
	a[29411]={"䵸"}
	a[29422]={"毜"}
	a[29432]={"毯","𥞕"}
	a[29440]={"絖"}
	a[29442]={"𣮅"}
	a[29443]={"毩","𣭑"}
	a[29451]={"甃"}
	a[29452]={"𣮜","𣮼","𣮽"}
	a[29453]={"䅚"}
	a[29454]={"𣯢","𤙍"}
	a[29461]={"𧡣"}
	a[29462]={"綣","觥","𣭱","𩠉"}
	a[29463]={"𣮞","𪐂"}
	a[29464]={"犈"}
	a[29470]={"𦄬"}
	a[29472]={"绻","𧇸"}
	a[29473]={"𣦬"}
	a[29483]={"䱧","𣜨"}
	a[29484]={"𣯧","𤛲","𥣼"}
	a[29493]={"𧈒","𪊃"}
	a[29502]={"𣬘"}
	a[29522]={"㡑"}
	a[29523]={"媝"}
	a[29532]={"䋝"}
	a[29533]={"秚"}
	a[29542]={"牉","絆"}
	a[29544]={"𤘸","𤚈"}
	a[29552]={"绊"}
	a[29553]={"缕","𡡏"}
	a[29563]={"繗","𤗷","𩶐"}
	a[29572]={"𩷘"}
	a[29573]={"𣬗","𩼩"}
	a[29576]={"𥣿"}
	a[29577]={"𥤅"}
	a[29584]={"鱗"}
	a[29585]={"䚬"}
	a[29594]={"鳞"}
	a[29602]={"𩼉"}
	a[29611]={"鱨"}
	a[29640]={"𦀭"}
	a[29663]={"醔"}
	a[29672]={"㹙","㹚","𥢷"}
	a[29681]={"𤗾"}
	a[29684]={"𤳿"}
	a[29702]={"纗"}
	a[29703]={"𩼝"}
	a[29704]={"𦇜"}
	a[29713]={"𩽌","𩽨"}
	a[29714]={"觽","觿","𧥅"}
	a[29715]={"𧈜","𩦶"}
	a[29716]={"𧖍"}
	a[29721]={"秈","貀"}
	a[29722]={"𥞻"}
	a[29730]={"貒","𧳍"}
	a[29732]={"𡥻","𡵣","𥞃","𥡎","𥢒","𪐆"}
	a[29733]={"揫"}
	a[29740]={"𦓟","𩠊"}
	a[29741]={"稍","絀","饳","鹙","𥠄"}
	a[29742]={"𡚂"}
	a[29743]={"𥟬"}
	a[29744]={"𥟎"}
	a[29750]={"綃","緔","𪗘"}
	a[29751]={"绌"}
	a[29752]={"䭱","𤙜","𤙽","𩸁"}
	a[29753]={"𧤙"}
	a[29760]={"绡","绱","𦓛"}
	a[29761]={"䴛","鶖","𦄏","𪗨"}
	a[29762]={"䭯","䲏","𣟽","𩶌"}
	a[29763]={"𢵥","𣦧"}
	a[29770]={"𪘞"}
	a[29771]={"鮹","𩡈"}
	a[29772]={"𧣪","𧤗","𩠏"}
	a[29773]={"𪐑"}
	a[29774]={"𠢺","𩷼"}
	a[29781]={"𩺀"}
	a[29785]={"𥣌"}
	a[29790]={"繃"}
	a[29793]={"𩻰"}
	a[29810]={"𤎢","𨕪"}
	a[29811]={"秋","𥟢"}
	a[29820]={"緂","𤔵"}
	a[29822]={"𤘭"}
	a[29830]={"𢀆","𤏕","𤏜"}
	a[29831]={"䋺","舕","𨕼","𪉧"}
	a[29832]={"𡙀","𤑀","𥸸"}
	a[29840]={"𦦨"}
	a[29841]={"𩵰","𩸥"}
	a[29842]={"𧣹","𩷎"}
	a[29850]={"燄"}
	a[29852]={"鰍"}
	a[29861]={"𦃸"}
	a[29862]={"鳅"}
	a[29875]={"䆏"}
	a[29881]={"𩹳"}
	a[29889]={"𥤄"}
	a[29921]={"湬"}
	a[29922]={"𥞪"}
	a[29931]={"䋛","𦂎","𨒠"}
	a[29941]={"𦆱"}
	a[29950]={"𦇝"}
	a[29951]={"𥡶"}
	a[29952]={"䱊","𩡀","𩡅","𩶚"}
	a[29961]={"𦃒"}
	a[29962]={"𦅌"}
	a[29973]={"𩺭"}
	a[29981]={"𩻃"}
	a[30000]={"㵎","丶","澗","𣾬"}
	a[30001]={"潤","濶","灍","𤁐"}
	a[30003]={"瀾"}
	a[30004]={"斕","𨟚"}
	a[30010]={"㶄","㶕","灁","譋","讇","𤁵","𤃷","𤄒","𤅝","𧬱","𧮑"}
	a[30011]={"𤀳","𨟍"}
	a[30012]={"㶒","𤂶","𤄎"}
	a[30013]={"灛","讕","𨟞"}
	a[30015]={"灡"}
	a[30020]={"邺"}
	a[30021]={"邲","郊"}
	a[30030]={"邙","邡","郂","𣃶","𨚳","𨛧"}
	a[30040]={"邟"}
	a[30041]={"𨛌","𨜎"}
	a[30050]={"涧","部","𨜷","𨝗"}
	a[30051]={"润"}
	a[30052]={"鄴","𣵷","𨝏","𨞊"}
	a[30053]={"澜"}
	a[30054]={"斓"}
	a[30060]={"𠘁"}
	a[30061]={"郭","𣻩"}
	a[30062]={"𨝭"}
	a[30070]={"㴸","鄗"}
	a[30071]={"漷","鄐","鄣"}
	a[30072]={"𤀝"}
	a[30073]={"㴫"}
	a[30080]={"㵍"}
	a[30081]={"潣","澖"}
	a[30083]={"𨝯"}
	a[30090]={"𤀵","𤂷"}
	a[30091]={"𤁹","𨞥","𨟐"}
	a[30100]={"氵","誼","韲","𠆊"}
	a[30101]={"䥆"}
	a[30102]={"𤁮"}
	a[30103]={"㻾"}
	a[30104]={"灌"}
	a[30105]={"𥪽","𥫍"}
	a[30110]={"亠","亹","冫","諠","𩐐"}
	a[30111]={"斖","𣁪","𧫡"}
	a[30114]={"讙","𩁧"}
	a[30116]={"𨮲"}
	a[30120]={"亡","立",""}
	a[30130]={"𠅉","𤣥"}
	a[30131]={"主"}
	a[30132]={"𣴭"}
	a[30140]={"涳","衁","𥁃","𥩟"}
	a[30141]={"銮","𣁇"}
	a[30142]={"淽","","𣁑"}
	a[30150]={"亱","澨"}
	a[30151]={"㴏","㵥","𡔞","𤣴"}
	a[30152]={"産"}
	a[30153]={"產"}
	a[30162]={"漥"}
	a[30163]={"𣼥","𨤫"}
	a[30170]={"渲","竩","齍"}
	a[30171]={"𠅴","𥂶"}
	a[30172]={"雍","𥃀"}
	a[30173]={"濭","童"}
	a[30180]={"𥂡","𥂬","𥃂","𧧼"}
	a[30181]={"㙜","㙶","𡎲","𡑔","𥂣","𥃐","𩫊"}
	a[30187]={"𣿅"}
	a[30190]={"亶","𤃾"}
	a[30191]={"𡓩"}
	a[30192]={"灆","𩐺","𩫍"}
	a[30193]={"壅","𣁫"}
	a[30195]={"𨬇"}
	a[30197]={"𥪿"}
	a[30200]={"𩫖"}
	a[30206]={"𪗍"}
	a[30210]={"亣","齏","𪔉"}
	a[30211]={"齐"}
	a[30215]={"𤄙"}
	a[30220]={"䇂","产","彦","","𡿫"}
	a[30221]={"彥",""}
	a[30231]={"⻫","斉","斎"}
	a[30240]={"",""}
	a[30241]={"𠅛"}
	a[30250]={"齊","齋","齌","𡱀","𣹧","𦠃"}
	a[30252]={"𥪫"}
	a[30256]={"潇"}
	a[30260]={"㵳","夣"}
	a[30261]={"𪗅","𪗉","𪗌"}
	a[30262]={"䶒","𤁸"}
	a[30267]={"𤂣"}
	a[30270]={"𠅡","𪗈","𪗋"}
	a[30271]={"𤀥","𩹵"}
	a[30280]={"瀄","𪗇"}
	a[30281]={"齑"}
	a[30282]={"𧓉"}
	a[30290]={"齎"}
	a[30291]={"𪗏"}
	a[30292]={"𧩳"}
	a[30300]={"⺀","𠁼","𧝑","𧞂"}
	a[30302]={"𠆟"}
	a[30303]={"𧝕"}
	a[30304]={"䗸","𧓂","𧓚"}
	a[30307]={"䘇"}
	a[30310]={"⻍","亦","卞","","","𠆠","𢗻","𢣫","𧞗","𧮗"}
	a[30311]={"𠅕"}
	a[30312]={"饔","𠆡","𣁆","𤓥","𧞻"}
	a[30313]={"䜢"}
	a[30314]={"𧕔","𧖊"}
	a[30315]={"𧮇"}
	a[30316]={"讛","𧕕","𧕢","𧖁","𩫲"}
	a[30317]={"𧮚"}
	a[30320]={"亪","恋","衣","豙","","","𠅄","𡿮","𤇯","𤫹","𧘭"}
	a[30321]={"忞"}
	a[30330]={"忘","玄","衮","𧘠"}
	a[30331]={"淧","𧘮"}
	a[30332]={"㴀","𧘙"}
	a[30340]={"䘱","哀","烹","袞","袤","袲","𢚟","𣸘","𤉿","𧘩","𧙩","𧙰","𧚤","𧛨"}
	a[30341]={"浤","衷","衺","𠅤","𢝃","𧘘","𧘫","𧙉","𧙦","𧙵","𧚍","𧛙","𧱏"}
	a[30342]={"蛮","袠","𣽫","𧛿"}
	a[30343]={"蚉"}
	a[30344]={"濍"}
	a[30350]={"恴","袬","褱","豪","𧘎","𧙃","𧙎","𧙬","𧚞","𧚱","𧛁"}
	a[30351]={"竤","褎","褒","𧘦"}
	a[30352]={"䖟","濛","衰","𢛫","𧊯","𧘝","𧘨","𧙏","𧜯"}
	a[30353]={"𧝻","𪐰"}
	a[30354]={"㐮","亵","懑","𣽬","𤍍","𤎉"}
	a[30357]={"亷"}
	a[30360]={"悥","意","袌","裒","裦","𠆘","𢜖","𧙪","𧙴","𧜟","𩛚"}
	a[30361]={"𠆁","𧚌","𧝾"}
	a[30362]={"褭","𣻡","𧝥","𧝺"}
	a[30363]={"裹","裏","𤁬","𧉶"}
	a[30364]={"𧚰"}
	a[30367]={"𠔳"}
	a[30370]={"裛","𧚹","𧩰","𩝦","𩫕"}
	a[30371]={"襃"}
	a[30372]={"褏","褢","𢡃","𧋲","𧜈"}
	a[30373]={"裏","𧜍"}
	a[30374]={"䙝","褻","𧞚"}
	a[30375]={"螡"}
	a[30380]={"裵","𧜉","𧜏"}
	a[30381]={"𧛫","𧜪"}
	a[30382]={"𧜫"}
	a[30383]={"瀗"}
	a[30384]={"蝱"}
	a[30390]={"𠆐","𩫞"}
	a[30391]={"𢢦","𤂳"}
	a[30392]={"𧭊"}
	a[30393]={"𤂡"}
	a[30394]={"襄"}
	a[30395]={"𧏼"}
	a[30400]={"赢"}
	a[30401]={"䊨","𣜄","𥢵"}
	a[30402]={"嬴"}
	a[30410]={"䇔","贏","鸁","𠆚","𦆁","𦣖","𧝹","𪓖"}
	a[30411]={"𡑤","𨭞","𩼊"}
	a[30412]={"甕","羸","蠃","驘","𡳴","𦢼","𦣉"}
	a[30413]={"臝","𦣔"}
	a[30414]={"𡣍","𤰑","𦏞","𧬯"}
	a[30415]={"𦣄","𨏩"}
	a[30421]={"㐎","𠅂"}
	a[30430]={"㐬","亢","充","兖","巟","沱","𣲽","𥩕"}
	a[30431]={"𠒋"}
	a[30433]={"㳸"}
	a[30434]={"𠅫"}
	a[30440]={"㐔","兗","𠅙","𠑽","𠘺","𣵻","𥩗","𥪐","𧘊"}
	a[30441]={"𣲼"}
	a[30450]={"㖜","浣","涴","竞","𣵸"}
	a[30451]={"𠅢"}
	a[30452]={"⻯","㵁","𠅨","𣸆","𣺬"}
	a[30454]={"瀎"}
	a[30460]={"亮","竟","𠅔","𠅭","𠆃","𧙌"}
	a[30461]={"亳","斍","𣱅"}
	a[30462]={"㵃","滗","竜","𠅞","𠅦","𠅬","𠅰","𥪑"}
	a[30464]={"𣿎","𤃴"}
	a[30470]={"詑","𣨻","𣽆"}
	a[30471]={"滱","𥪖"}
	a[30472]={"毫","𠅸","𠅾","𣄓","𩱿"}
	a[30474]={"𠅟"}
	a[30480]={"䯩","","𣎆","𦝠"}
	a[30481]={"詫"}
	a[30482]={"亴","𠆝","𠙰","𤃫","𦟀","𩙷"}
	a[30484]={"𠂅"}
	a[30490]={"䛷","𩫓"}
	a[30491]={"𩫂"}
	a[30492]={"謊","𠅪"}
	a[30494]={"㶓"}
	a[30501]={"𦎧","𩫏"}
	a[30503]={"㶘"}
	a[30504]={"𠆎","𩏉"}
	a[30507]={"譁"}
	a[30511]={"交","文","𤄘","𩫚"}
	a[30513]={"𠆛"}
	a[30514]={"𦏝"}
	a[30515]={"護","頀"}
	a[30521]={"卒","变","変","夜","市","帟"}
	a[30522]={"娈","弈","𢌮","𢌸"}
	a[30531]={"㠵","䘚","帝","辛","","𢂪","𣸈","𨐋"}
	a[30532]={"妄","妾","弃","洝","竎"}
	a[30533]={"㪯","𣁄","𣁕"}
	a[30541]={"𠅋","𢂋","𢂙","𣿈"}
	a[30542]={"浶","𤙺","𨐌"}
	a[30543]={"㛳","㵏","𠅊"}
	a[30544]={"𠅚","𡟖"}
	a[30545]={"漭"}
	a[30551]={"㚆","滓","漃","率","𢂚"}
	a[30552]={"斊","𣁌"}
	a[30553]={"𤕚"}
	a[30561]={"章","𠅖","𣿟"}
	a[30562]={"𡕨","𡣹","𢍓"}
	a[30563]={"牽","𢅈","𣺱"}
	a[30564]={"𤁊","𧩃"}
	a[30567]={"澕"}
	a[30571]={"𠦸","𣹦","𣼡","𣽧","𧨠"}
	a[30573]={"㵺"}
	a[30574]={"濗","𣽇","𩎮"}
	a[30575]={"濩"}
	a[30581]={"𠅷","𠆀","𦕺","𧫒","𧬵","𩫒"}
	a[30582]={"濅","𤀤","𤚸"}
	a[30583]={"𧬖","𧬝"}
	a[30585]={"𥪠","𧬏"}
	a[30586]={"潷","𠆜"}
	a[30589]={"𠆉"}
	a[30591]={"𠆆","𧪹","𧫑","𩫎"}
	a[30592]={"𦎫","𧫸"}
	a[30595]={"𤂹"}
	a[30597]={"𨌤"}
	a[30600]={"譗","𠅿","𦤘","𧨟","𩐼","𪗐"}
	a[30602]={"讅","𣋿"}
	a[30603]={"㽫"}
	a[30610]={"譶","𥗧"}
	a[30612]={"𧭽"}
	a[30613]={"𨑂"}
	a[30614]={"𧮎"}
	a[30615]={"𨏯"}
	a[30630]={"㕻","","𠅓"}
	a[30631]={"吝"}
	a[30640]={"吂","咅","溶","𠱫","𣅀"}
	a[30641]={"㖱","亩","𠲩","𠷗"}
	a[30650]={"㐭","言","訁","音","","𠆋","𥃰","𥄈"}
	a[30651]={"㖖","啻","𤰡","𤰸"}
	a[30652]={"溚","𥩫"}
	a[30653]={"渃","渵"}
	a[30660]={"㴭","㴼","亯","盲","","𠆗","𣽛","𥩶"}
	a[30661]={"畗","畜","𣁎"}
	a[30662]={"瀋","𠶷"}
	a[30663]={"𠲯"}
	a[30670]={"","𧧑"}
	a[30672]={"濸"}
	a[30674]={"𨐡"}
	a[30680]={"𥆕"}
	a[30681]={"𠆖"}
	a[30682]={"𨢞"}
	a[30690]={"𠆌","𠆒"}
	a[30691]={"㐯"}
	a[30693]={"諾"}
	a[30700]={"𧭈"}
	a[30701]={"𧭀"}
	a[30702]={"𡃬","𦡚","𩥊"}
	a[30703]={"罋","𤃂","𧪮","𪙯"}
	a[30710]={"𡄚","𡅟","𧭠","𪚎"}
	a[30711]={"𢑸","𥫐"}
	a[30712]={"譪","𤅰"}
	a[30713]={"𤅲"}
	a[30714]={"𤅢"}
	a[30715]={"䜕","𤅠"}
	a[30720]={"峦","方","","𠅁"}
	a[30721]={"㐫","脔","𡵡"}
	a[30730]={"泞","𡵍","𧘉"}
	a[30731]={"孪","斋","𠅈","𠜡","𢂠","𦘻"}
	a[30732]={"挛","斈","𦛄"}
	a[30740]={"亨","商","弯","旁","竒","竚","鸾","𥩧","𦚍","𧥛","𧥜"}
	a[30741]={"䐡","滵","𣻜","𥩽","𦙟"}
	a[30742]={"离","𥩝"}
	a[30743]={"涝","𣫭"}
	a[30744]={"满"}
	a[30750]={"亭","肓","育","裔","𠅏","𠅘","𣴩","𣶆","𥩬","𥩮","𦚏","𧘯"}
	a[30751]={"享","啇","𠅵","𦚾","𧮼"}
	a[30752]={"渮","𠆈","𥩸"}
	a[30760]={"涫","濘","高","髙","鵉","𠅠","𤀨"}
	a[30761]={"㵠","鴍","𠅝","𥩭","𦠕"}
	a[30762]={"𠹧"}
	a[30764]={"𠱗"}
	a[30770]={"䯧","瀉","詝","𦦏","𪙔"}
	a[30771]={"𠅥"}
	a[30772]={"㵧","𠾃"}
	a[30774]={"瀳"}
	a[30775]={"澫","𣿝"}
	a[30780]={"朚"}
	a[30781]={"𧧕","𩫃"}
	a[30783]={"𦡈"}
	a[30790]={"䛪","膏","𪁚"}
	a[30792]={"𧪆","𧮉"}
	a[30793]={"𧨄"}
	a[30794]={"𢶜"}
	a[30801]={"𤅋"}
	a[30803]={"謨","𩐻"}
	a[30810]={"六","","𠅃"}
	a[30811]={"𧮡"}
	a[30812]={"𥫈"}
	a[30814]={"𧮈"}
	a[30820]={"亥","泬","𠅆","𡖍","𤆴"}
	a[30821]={"奕","𡙩"}
	a[30831]={"㴱","涋","湥","𠅑"}
	a[30832]={"𣸨"}
	a[30833]={"𣵽"}
	a[30840]={"淀","滨","𢒲","𨀶"}
	a[30841]={"𠅌"}
	a[30842]={"𠆇","𠔚"}
	a[30844]={"渶"}
	a[30860]={"䛎","賌","𤌾","𧶜"}
	a[30861]={"𠅧","𥏉"}
	a[30862]={"演"}
	a[30863]={"漠","𥫆"}
	a[30870]={"㵓","濱","𠆄","𧷔","𩇰"}
	a[30871]={"䯨","𠅲","𧦂","𧸈"}
	a[30873]={"㵹","𥪢","𧨶"}
	a[30880]={"濵","諚","𤀋","𧷞"}
	a[30881]={"𩫀"}
	a[30884]={"瀽","韺"}
	a[30892]={"𠆑"}
	a[30893]={"𧬧"}
	a[30900]={"𧭂"}
	a[30901]={"𣚏"}
	a[30902]={"𧭝"}
	a[30903]={"𤄶"}
	a[30906]={"䜓"}
	a[30910]={"𥜘"}
	a[30912]={"𣡥"}
	a[30913]={"𦇨"}
	a[30920]={"𣱵","𣷖"}
	a[30921]={"栾","𠅅","𣁃"}
	a[30922]={"㪰"}
	a[30930]={"京","𠆂","𥾻"}
	a[30931]={"亲","杗","浨","紊","","𣏋"}
	a[30933]={"㴕","𣸃"}
	a[30940]={"亰","淙","𠆏","𥿿"}
	a[30942]={"𣐽","𣓀"}
	a[30945]={"𥠤"}
	a[30950]={"𥪗"}
	a[30951]={"稁","𣖇"}
	a[30952]={"潆","𠆅","𣽤"}
	a[30953]={"椉"}
	a[30955]={"棄"}
	a[30961]={"稟","𠅺","𣖈"}
	a[30962]={"𤁱"}
	a[30963]={"𣕏"}
	a[30964]={"𣓪"}
	a[30966]={"㵩"}
	a[30970]={"禀"}
	a[30971]={"槀","稾"}
	a[30980]={"誴"}
	a[31101]={"誆","譃"}
	a[31102]={"瀘","讈","𠘌","𤀌","𪓐"}
	a[31103]={"諲"}
	a[31110]={"䛩","謳","𧬃","𪚠"}
	a[31111]={"壟","謯","讍","𡔆","𤅷","𧩆","𧫔","𧬩","𩑊","𩫧"}
	a[31112]={"謔","𡔕"}
	a[31113]={"瀖","𨰯"}
	a[31120]={"𣲚","𣳎"}
	a[31130]={"冮","汇","江","沚","𣲅","𣳋"}
	a[31131]={"沤"}
	a[31132]={"𣳐"}
	a[31140]={"泟","涇","𠗊","𣥊","𣥢"}
	a[31141]={"汪","𣶖"}
	a[31142]={"㳹","𣴥"}
	a[31150]={"冱","沍","洍","洰","浢","𣲳","𣵨"}
	a[31151]={"洷","𥩨"}
	a[31152]={"𡊺"}
	a[31153]={"𣵱"}
	a[31155]={"盓"}
	a[31160]={"洹"}
	a[31161]={"洭","𣶪","𣻶","𥁡"}
	a[31162]={"涯","渱","瀝","𠘟","𣾀","𣿬","𤁋"}
	a[31163]={"凐","湮"}
	a[31166]={"𤄽"}
	a[31170]={"䪦","澁","訌","訨","誣","𣵾","𣷻"}
	a[31171]={"𢄫","𣵹","𦣭"}
	a[31172]={"滙","𡒖","𣹐","𥂳"}
	a[31173]={"湹","𣶕"}
	a[31180]={"䪫","証","誙","𧩄"}
	a[31181]={"溼","𤃁","𤃍","𧥶"}
	a[31182]={"誑"}
	a[31183]={"竰","𤄊"}
	a[31184]={"𤁄"}
	a[31190]={"䛠","漚","詎","𧥮","𧧰","𧯹"}
	a[31191]={"誈","𣻐"}
	a[31192]={"𧦩"}
	a[31193]={"𤀶"}
	a[31201]={"𤅦"}
	a[31210]={"誹"}
	a[31230]={"涉","渉","𣲠"}
	a[31240]={"泸"}
	a[31242]={"𠘔"}
	a[31270]={"渄"}
	a[31271]={"𤀍"}
	a[31272]={"𣾔"}
	a[31281]={"𣂇"}
	a[31290]={"𧨊"}
	a[31300]={"䛫"}
	a[31301]={"澐","𤅒"}
	a[31310]={"䜑","襲","𢤲","𢥮","𧟟"}
	a[31311]={"戅","𢥹","𤅫","𥫒","𧬞"}
	a[31312]={"蠪","𤄦","𧭜"}
	a[31315]={"𧕎"}
	a[31320]={"𠖺","𣳓","𣵠"}
	a[31321]={"涿"}
	a[31330]={"𣸾","𤊁"}
	a[31331]={"添"}
	a[31332]={"𤃉"}
	a[31340]={"沄","𢢵","𣲑"}
	a[31341]={"𥪌"}
	a[31350]={"惉","浱"}
	a[31351]={"𢙁"}
	a[31352]={"𣻴","𣽗"}
	a[31360]={"涱"}
	a[31361]={"滤","澽","諑"}
	a[31362]={"憑"}
	a[31371]={"𧨩"}
	a[31372]={"𣾤"}
	a[31374]={"慿"}
	a[31380]={"𠅹","𣽏","𧥼","𧦚","𧧎"}
	a[31381]={"澪","𧞮"}
	a[31382]={"𣾱"}
	a[31383]={"濏"}
	a[31390]={"漲","誫"}
	a[31392]={"濾","𣾲"}
	a[31401]={"㡣","𧩗"}
	a[31402]={"潖","𧇦"}
	a[31410]={"瀧","龍","龖","龘","𤮜","𤮨","𪚥"}
	a[31411]={"㵡","諕","𤮩","𥫏","𧭌"}
	a[31412]={"灑","𡦨","𧭣","𪚢"}
	a[31413]={"㼿"}
	a[31421]={"𣲪"}
	a[31431]={"𣁯"}
	a[31440]={"沅","𣲁","𣴑"}
	a[31441]={"","𣁿","𣲘"}
	a[31450]={"𠅮"}
	a[31451]={"漑"}
	a[31452]={"濊","𣸰"}
	a[31453]={"𣻝"}
	a[31460]={"瓬","𤭈","𤭉"}
	a[31461]={"㳧","𣄵","𤭢"}
	a[31470]={"㼚","𤭊","𤭕"}
	a[31471]={"淲","𣄶"}
	a[31472]={"凴","虠","𠙖"}
	a[31480]={"䛃","瓿","𧦠"}
	a[31481]={"溉","𧥭"}
	a[31482]={"㶁","𣾳","𤂢"}
	a[31484]={"𠙥"}
	a[31485]={"𥪺"}
	a[31490]={"𩐛"}
	a[31491]={"甋","𤭞"}
	a[31492]={"𤂆","𧬨"}
	a[31497]={"𤁦"}
	a[31501]={"𧨳"}
	a[31502]={"𧪤","𩐮"}
	a[31503]={"𤄑"}
	a[31505]={"𤁡"}
	a[31511]={"䜡","聾","𢥭","𪚑"}
	a[31512]={"龏","𣀦","𪎁","𪚜"}
	a[31513]={"灄","譚","讘"}
	a[31515]={"𣀮"}
	a[31516]={"𤃸"}
	a[31531]={"汗","沞","泙","浉","𣲏","𣳶"}
	a[31532]={"汧","𠖱"}
	a[31541]={"𢾬","𣳙","𣴯","𣶿"}
	a[31542]={"潊"}
	a[31543]={"𡜡"}
	a[31551]={"洱","𣸒"}
	a[31552]={"𡜂","𡝫","𢽫","𣴱"}
	a[31553]={"㳥","𡝝","𣷑"}
	a[31554]={"㴗","浭","𣸇"}
	a[31555]={"㴁"}
	a[31561]={"㪗","涆","淖"}
	a[31571]={"溮","竨","訐","評","韴","𢾊","𢾑","𣀤","𣵼","𧥪"}
	a[31572]={"訮","𢿪","𣽠","𧥯"}
	a[31573]={"滠","𤁁"}
	a[31574]={"𣿺"}
	a[31575]={"湃"}
	a[31576]={"𣺕"}
	a[31581]={"敲","渳","瀀","𧦡"}
	a[31583]={"潭","𤁎"}
	a[31591]={"誀","𧨢"}
	a[31592]={"詽"}
	a[31600]={"𧨿","𧩤","𧪽"}
	a[31601]={"語","𤀃"}
	a[31602]={"㵢","潛"}
	a[31610]={"䜜","礱","讋","𡃡","𧮝","𧮩"}
	a[31611]={"諨","𤁳","𤃩"}
	a[31612]={"灀","譖","𤄐"}
	a[31640]={"㓈","㳪","沰","沾"}
	a[31641]={"滷"}
	a[31642]={"𣵔"}
	a[31650]={"䇉","洦","站","𣃷"}
	a[31651]={"𠗐","𣵞","𣶓"}
	a[31652]={"洒"}
	a[31660]={"湎","溍","竡","𠗍","𣴨","𣶊","𣷶","𣽊","𣿰","𣿼"}
	a[31661]={"浯","𧱳"}
	a[31662]={"酒"}
	a[31663]={"𣁹"}
	a[31670]={"滣","𤀹"}
	a[31671]={"湢"}
	a[31672]={"𤃹"}
	a[31680]={"濬","詀"}
	a[31681]={"𤃒","𧫓"}
	a[31690]={"𣾝"}
	a[31691]={"澑","𧨼"}
	a[31692]={"𤃔","𤅟","𧧍"}
	a[31700]={"䛿","𧨷","𧩂","𧫌"}
	a[31701]={"䇕","𤁰","𧨪"}
	a[31702]={"謼"}
	a[31710]={"謌","鸗","𡾩","𣽄"}
	a[31711]={"謣","譳","𤂥","𪚞"}
	a[31712]={"灊","驡","𢸭","𦪿"}
	a[31713]={"𧬭"}
	a[31715]={"𧭡","𩦍"}
	a[31716]={"灞","𤆀"}
	a[31717]={"㶚"}
	a[31720]={"㓅","汀","𣲇","𣶹"}
	a[31721]={"冴","𢗈","𣲨","𣷌"}
	a[31730]={"汅","洏","洐",""}
	a[31731]={"汙","沥","𣶮"}
	a[31732]={"𣲐"}
	a[31735]={"濔"}
	a[31740]={"污","沔","河","𢘟","𣵣","𣶰"}
	a[31741]={"汚","𣻚"}
	a[31742]={"𣶭","𣾅"}
	a[31750]={"𣶢","𣽈","𤁧","𥩤"}
	a[31752]={"溤","馮","𣵋","𣽣","𩣠"}
	a[31753]={"𩢌"}
	a[31754]={"洅"}
	a[31760]={"滆","漹","訂"}
	a[31761]={"㴟","溽","𣵍","𣶩","𣾥"}
	a[31762]={"滹"}
	a[31764]={"𠗦"}
	a[31765]={"瀰"}
	a[31770]={"䛔","滒","𣶇","𣸝","𧦯"}
	a[31771]={"訏","訝","𣽐"}
	a[31772]={"𩣐"}
	a[31775]={"𧭉"}
	a[31780]={"㴐","漘","訶","𥫇","𧨂"}
	a[31781]={"𧥦","𧧝"}
	a[31782]={"𣿋"}
	a[31785]={"濿","𤅤"}
	a[31790]={"𥫀","𧬐","𪘙"}
	a[31791]={"濡","𧨵","𪁘"}
	a[31792]={"竵","𣼻","𧪨"}
	a[31800]={"㶊","𩐳","𩕴"}
	a[31801]={"𤁪","𤃑"}
	a[31802]={"𩔣","𩕇"}
	a[31810]={"䯪","灝","灦","顫","颤","𠗇","𣄩","𣄫","𧩬","𨇘","𩐵","𩔽"}
	a[31811]={"䫯","贑","龑","𤅡","𧫪","𩕆","𩕲","𪚔"}
	a[31812]={"䜖","龔","𤅆"}
	a[31813]={"𩕉"}
	a[31820]={"㳁","渋","𣲓"}
	a[31821]={"𣴇"}
	a[31830]={"浈"}
	a[31831]={"𣵕"}
	a[31832]={"𣺗"}
	a[31840]={"漇","颏","颜","𣴸","𣶵"}
	a[31841]={"渜"}
	a[31850]={"滪","濒","颃"}
	a[31851]={"㵐"}
	a[31852]={"𣻔"}
	a[31860]={"湏","湞","𣻳","𤂓"}
	a[31861]={"頝","𤃡","𩑯"}
	a[31870]={"㴿","頦","頫","顔","顡","𣹟","𤂔","𤃣","𥪙"}
	a[31871]={"䚶","顇","顏","𤁾","𧨗"}
	a[31880]={"澒","澦","瀕","頏","𣿤","𤁫","𩑹","𩒘"}
	a[31881]={"䫕","𣽥","𩒊"}
	a[31882]={"𣿦","𤀪","𤂯","𤄹","𩓗"}
	a[31890]={"䫓","灏","𤃌","𤅓"}
	a[31891]={"瀩","𤂌","𧩐","𩕺"}
	a[31892]={"澞","𩕟"}
	a[31893]={"瀬","𤅎"}
	a[31902]={"謤"}
	a[31910]={"龒"}
	a[31911]={"㰍"}
	a[31920]={"㳅"}
	a[31921]={"𣸸"}
	a[31930]={"沶"}
	a[31935]={"𤂝"}
	a[31940]={"𣸼"}
	a[31941]={"𣸺"}
	a[31942]={"𣼝","𤂈"}
	a[31943]={"瀮"}
	a[31950]={"源"}
	a[31951]={"𠘍","𣿚"}
	a[31953]={"凓","溧","潥"}
	a[31961]={"渠"}
	a[31962]={"㵗","漂"}
	a[31963]={"𣁡"}
	a[31970]={"𧧌","𩐡"}
	a[31972]={"𣄔"}
	a[31982]={"𧬎","𨐣"}
	a[31990]={"謜"}
	a[31991]={"𧬷"}
	a[32000]={"丬","州","","",""}
	a[32010]={"汌","洲"}
	a[32021]={"渊"}
	a[32050]={"訓","詶","𧥞"}
	a[32060]={"淵","訆"}
	a[32080]={"訠"}
	a[32100]={"證"}
	a[32101]={"𧧺"}
	a[32110]={"䜝","业"}
	a[32115]={"諥"}
	a[32116]={"灃","𠘦"}
	a[32121]={"𣳊"}
	a[32130]={"㳋"}
	a[32131]={"㳝","淫","𠗝","𡋈"}
	a[32140]={"𣹉","𤁺","𥁷"}
	a[32141]={"垽","𣳴"}
	a[32151]={"𥁩","𥁼"}
	a[32152]={"鋈","𣺡"}
	a[32155]={"涶"}
	a[32160]={"澄"}
	a[32162]={"𡎒"}
	a[32170]={"竳","𧦺"}
	a[32171]={"䚾","䛘","𧬡"}
	a[32175]={"湩"}
	a[32190]={"𤃶"}
	a[32191]={"𩫔"}
	a[32195]={"諈"}
	a[32196]={"壍","𨮜"}
	a[32202]={"𧬜"}
	a[32210]={"𣲀","𤂊"}
	a[32211]={"㳢","㶌"}
	a[32220]={"沂","𣴖"}
	a[32221]={"涁","𢒌","𣁰"}
	a[32230]={"㳨","沜"}
	a[32231]={"淅"}
	a[32232]={"浵","𣹊"}
	a[32240]={"𥩜"}
	a[32241]={"新","𣶁"}
	a[32242]={"浙"}
	a[32250]={"䚲"}
	a[32251]={"澵","𤗟","𨐏"}
	a[32252]={"𣂺"}
	a[32253]={"渐"}
	a[32260]={"訢","𣂳","𤂖","𩐙"}
	a[32261]={"彰","澎","𤁀"}
	a[32262]={"凘","澌","𤗔"}
	a[32270]={"𧦓"}
	a[32272]={"𧨘"}
	a[32275]={"漸"}
	a[32280]={"𤃮"}
	a[32290]={"濎","𠘋"}
	a[32291]={"𣃎"}
	a[32300]={"𣶾","𤂜"}
	a[32304]={"瓤"}
	a[32310]={"讔","𤬥"}
	a[32315]={"𩟗"}
	a[32320]={"泒","泛","派","𣲖","𩇨"}
	a[32331]={"㴽","𣿜","𣿿"}
	a[32333]={"𤔟"}
	a[32350]={"泓","𣳯","𤬃","𧦐"}
	a[32351]={"畆","𣸢","𤱔"}
	a[32360]={"𧦟","𧦼"}
	a[32361]={"涨","𢣪"}
	a[32362]={"𩷯"}
	a[32370]={"濦"}
	a[32380]={"㶏"}
	a[32403]={"譏"}
	a[32405]={"氃"}
	a[32410]={"𣲣"}
	a[32411]={"謕","𣳸"}
	a[32412]={"氈","𩙼"}
	a[32416]={"𣰶"}
	a[32417]={"魙"}
	a[32420]={"兆","𠖬"}
	a[32422]={"𣲭"}
	a[32430]={"洮","𣴋"}
	a[32431]={"㐢","㳐","汑","汦","泜","𣁶"}
	a[32432]={"溌"}
	a[32440]={"沘","泚","𥩼"}
	a[32441]={"㳶","乵"}
	a[32442]={"𣲞"}
	a[32450]={"𠃴","𣺣","𤁯"}
	a[32451]={"𨐐"}
	a[32452]={"竓","𠄅","𢅛","𣬵"}
	a[32453]={"㲞"}
	a[32454]={"𣯌"}
	a[32460]={"㴩","䚰","漞"}
	a[32461]={"𧦄"}
	a[32463]={"㲔","𣮭"}
	a[32470]={"㴰","湚","誂"}
	a[32471]={"㴲","滮","託","詆","𧧗"}
	a[32472]={"𣯃","𣯓","𣯞","𣯟"}
	a[32474]={"㲫"}
	a[32480]={"䚹","訿"}
	a[32481]={"䛢","𧧲"}
	a[32482]={"䚽"}
	a[32483]={"𣮢","𣯵"}
	a[32484]={"㲤"}
	a[32490]={"𧧊","𧭞"}
	a[32492]={"𩫁"}
	a[32493]={"𣯸"}
	a[32511]={"彣","𧬋","𪗑","𪗒 "}
	a[32513]={"鼝","𧬟"}
	a[32516]={"聻"}
	a[32521]={"汘","汳","泝","𣳭"}
	a[32522]={"浽","𣶧"}
	a[32531]={"丵","涭","竏"}
	a[32533]={"涹"}
	a[32541]={"𣄁"}
	a[32542]={"湲","𣸖"}
	a[32543]={"𥪍"}
	a[32551]={"涎","𣸍"}
	a[32552]={"涏"}
	a[32553]={"㜪","𡞠","𤀾"}
	a[32554]={"𤃙"}
	a[32561]={"䛀","訴"}
	a[32564]={"𡣎","𤃊"}
	a[32571]={"䛵"}
	a[32572]={"𤅥"}
	a[32573]={"諉"}
	a[32581]={"潑"}
	a[32582]={"諼","𤀣"}
	a[32583]={"叢"}
	a[32587]={"嬱"}
	a[32589]={"𤄪"}
	a[32591]={"誕"}
	a[32592]={"誔"}
	a[32593]={"灇","鼗"}
	a[32600]={"𣿉","𧩢"}
	a[32601]={"䛻","諙"}
	a[32610]={"諧"}
	a[32615]={"𩉍"}
	a[32617]={"䤔"}
	a[32640]={"㴞","洉","𠯺","𠲻"}
	a[32641]={"㓉","㴡","活","淄","湉"}
	a[32650]={"涾","𣾂"}
	a[32651]={"湽","𣴠","𣸩"}
	a[32652]={"潘"}
	a[32653]={"醤"}
	a[32660]={"𣾨"}
	a[32661]={"㵌","涽"}
	a[32662]={"旙","𣽰"}
	a[32663]={"𣸅","𤄜"}
	a[32670]={"湝","𣶫","𣽪","𧦎","𩠪"}
	a[32671]={"𧩣"}
	a[32672]={"𤃃"}
	a[32673]={"𤀦","𥖍"}
	a[32680]={"㴯","詬"}
	a[32681]={"話","𦧨","𩡕"}
	a[32682]={"𣽅"}
	a[32690]={"詣","誻","𧨥"}
	a[32691]={"䛡","𩡑"}
	a[32692]={"譒","𣿛"}
	a[32695]={"𣋫"}
	a[32701]={"䛽","𧪥"}
	a[32710]={"灣","𣳺"}
	a[32711]={"刘","剂","譑","𠛡","𠜅","𣴈"}
	a[32720]={"刻","测","𠛍","𠛪","𠜆"}
	a[32721]={"汹","泘","浏","浖","浰","渕","黹","𠜇","𢗮","𣵃","𣵜"}
	a[32722]={"渆","𠡖","𣲬"}
	a[32730]={"冽","剠","峾","洌","𠗗","𠗢","𠛑","𠝒","𣶄","𣸟","𣺧"}
	a[32731]={"㴊","剤","浮","𣵛","𣷬","𣺤","𣾙"}
	a[32732]={"𣹄"}
	a[32733]={"凈","淨","溂"}
	a[32740]={"㴈","剖","潙","𠞬","𣸛","𣺳"}
	a[32741]={"凿","涮","滛"}
	a[32742]={"㳵","𠞑","𠟪","𢄁","𣷨"}
	a[32743]={"淛"}
	a[32745]={"𤂒"}
	a[32750]={"䚯","劑","測","滔","𠗧 ","𠞌","𣸠"}
	a[32751]={"𠗜","𠞩","𠞶","𣼔"}
	a[32752]={"剷","𣹨"}
	a[32753]={"渪","𠟇","𣽮"}
	a[32761]={"㴙","瀏","訩","誗","𣼉","𣾷","𤁴","𧦝"}
	a[32762]={"𣿖"}
	a[32763]={"竬"}
	a[32767]={"𠠟"}
	a[32770]={"𠟼","𧦻","𧧋"}
	a[32771]={"𧪗","𧬿","𪁕"}
	a[32772]={"𤅪"}
	a[32773]={"𠟍"}
	a[32780]={"譌","𩑁"}
	a[32781]={"灂","誘","謡","𠘣","𣾧","𧧸"}
	a[32783]={"𤂅","𤂗","𧨰","𧩒","𧩲"}
	a[32790]={"㔊","謟","𤂄","𤄅"}
	a[32791]={"𤄉"}
	a[32794]={"㶜"}
	a[32810]={"䜠"}
	a[32811]={"㓇"}
	a[32821]={"沃"}
	a[32822]={"渓"}
	a[32830]={"浜"}
	a[32831]={"𣴌","𣺍"}
	a[32832]={"奨"}
	a[32841]={"湀","溪","𤎀"}
	a[32842]={"菐","𣾴","𤂛"}
	a[32851]={"𥪦"}
	a[32852]={"濮"}
	a[32860]={"𣄌"}
	a[32861]={"彂","訞","𧨞"}
	a[32864]={"𤄤"}
	a[32870]={"𠘖","𤁩","𩕝"}
	a[32881]={"謑"}
	a[32892]={"𧭎","𩑀"}
	a[32900]={"沠"}
	a[32901]={"𧭄"}
	a[32910]={"𣲙"}
	a[32911]={"灤","𠗡","𣵚","𣶶","𧭥"}
	a[32912]={"𩑄"}
	a[32920]={"䝉","冰","𣳛","𣴍"}
	a[32921]={"泺","𣲲","𣹌"}
	a[32922]={"𣓮","𣼖"}
	a[32930]={"渁","𣾜"}
	a[32931]={"潻","𣻬"}
	a[32940]={"𣹭"}
	a[32942]={"業"}
	a[32945]={"𣶸"}
	a[32951]={"楽","溗"}
	a[32952]={"澲"}
	a[32953]={"漅","𪎤"}
	a[32961]={"訸"}
	a[32965]={"𥪕"}
	a[32970]={"𧧈"}
	a[32971]={"𤄏","𧬠"}
	a[32973]={"𤀇"}
	a[32981]={"𠘙"}
	a[32990]={"𤅇"}
	a[32991]={"濼","𧪝","𧪾"}
	a[32992]={"𤄿","𧬬","𩑃"}
	a[32993]={"䜈"}
	a[32995]={"𥜙"}
	a[33000]={"灬",""}
	a[33010]={"心","","𢖩","𣱶"}
	a[33011]={"必"}
	a[33020]={"沁","𠖶","𠧞","𢗰","𥩖"}
	a[33021]={"泌"}
	a[33022]={"𣵝"}
	a[33041]={"𤱈"}
	a[33050]={"訃"}
	a[33060]={"𧦨"}
	a[33061]={"䛑"}
	a[33100]={"澶","𠘐"}
	a[33102]={"灉","𩁈"}
	a[33110]={"譠","𤅈","𤅣"}
	a[33111]={"𠆞"}
	a[33112]={"灗","𩁉"}
	a[33113]={"䜃","𧬤"}
	a[33114]={"𧮛","𩁛"}
	a[33116]={"𪏜"}
	a[33118]={"灘"}
	a[33130]={"汒","泣","涖"}
	a[33131]={"𢗺","𥁑"}
	a[33132]={"𡊭"}
	a[33140]={"竝","𣺄"}
	a[33141]={"㴵","注","𡏬","𣶂"}
	a[33142]={"㳴","㴤","𢜐"}
	a[33150]={"𣸓","𥩚"}
	a[33151]={"𥩣"}
	a[33152]={"准","淮","𣻰"}
	a[33153]={"㙙","𣿷"}
	a[33154]={"𥂆"}
	a[33160]={"㴉"}
	a[33161]={"堃","𣸫"}
	a[33162]={"滻","𣾯","𨾔","𨾾"}
	a[33163]={"滩","雜","𨿤","𨿼"}
	a[33164]={"𨤩"}
	a[33165]={"𡏋"}
	a[33171]={"瑬","鎏"}
	a[33172]={"濰","𨾒"}
	a[33173]={"𤄖","𨾨"}
	a[33174]={"𥂈","𧗉"}
	a[33181]={"註","謐"}
	a[33182]={"潍","澭","𨿦","𩀖"}
	a[33183]={"潼","𡑠","𣁦","𤄬","𨭉"}
	a[33184]={"離"}
	a[33190]={"𧪻"}
	a[33191]={"𧨉"}
	a[33192]={"濉","誰","𤃎"}
	a[33193]={"𣄛","𨿡","𩀻"}
	a[33194]={"灕"}
	a[33200]={"䜞"}
	a[33220]={"𣸥"}
	a[33221]={"济"}
	a[33230]={"浐"}
	a[33231]={"渗"}
	a[33240]={"滲","𠗿"}
	a[33241]={"済"}
	a[33260]={"濟","𣺴"}
	a[33270]={"諺"}
	a[33280]={"謲"}
	a[33290]={"𩫦"}
	a[33300]={"譹",""}
	a[33302]={"䜗"}
	a[33304]={"瀼"}
	a[33310]={"䪰","誸","譩"}
	a[33311]={"讁","𢥺"}
	a[33312]={"𧟛","𧮨"}
	a[33314]={"讓"}
	a[33315]={"𤅑"}
	a[33320]={"汴","洂","𠅯","𣵅"}
	a[33321]={"𣺒"}
	a[33330]={"㳖","惢","滾","𠗪","𠘠","𣺓"}
	a[33340]={"㵕","泫","滚","𣳵","𣾫"}
	a[33341]={"𤏅"}
	a[33342]={"𢠔","𤌞"}
	a[33350]={"𣃡"}
	a[33352]={"潐"}
	a[33357]={"濓"}
	a[33360]={"濠","瀤","玆","訫","𧧩"}
	a[33362]={"滖","澸"}
	a[33370]={"䜇","澺","滋","𧧮"}
	a[33371]={"𤁷"}
	a[33372]={"𢣑"}
	a[33380]={"詃"}
	a[33383]={"𣿞"}
	a[33392]={"譙","𤅭"}
	a[33394]={"譲","𢥗"}
	a[33400]={"競"}
	a[33401]={"𧫾"}
	a[33402]={"識","𧬣"}
	a[33403]={"𤃪"}
	a[33404]={"𤄛"}
	a[33410]={"灜","竸","𣬙","𤅗","𧫘","𧫙"}
	a[33412]={"浌","瀛","讖","𤅀","𧭶","𧮊"}
	a[33413]={"䜟","𩫨"}
	a[33414]={"𧮓"}
	a[33420]={"㓍"}
	a[33421]={"𣳌"}
	a[33422]={"㓕","㳀","㳚",""}
	a[33430]={"沇"}
	a[33431]={"沋","𥩦"}
	a[33432]={"䇅","泧","泷","浝","滅","𥩱"}
	a[33433]={"浅","𢦬","𣶔"}
	a[33434]={"㳦","涐","淺","𣸵"}
	a[33440]={"㳘","沆","流"}
	a[33441]={"乼","𠅣","𣶑"}
	a[33442]={"𠗼","𢣳","𢧂","𣴤","𣸂","𥩡","𦁋"}
	a[33443]={"溅","𣸶","𣺭","𥏛"}
	a[33444]={"溨","𢧞","𣴮"}
	a[33450]={"旈","渷","𣃚","𣴹"}
	a[33451]={"㗟","就","𨐑"}
	a[33452]={"减","戠","斌","淢","減","𠗱"}
	a[33453]={"㴳","渽","𣾒"}
	a[33454]={"𣽖"}
	a[33462]={"䛋","𡯶","𣺁","𣻟","𣻼","𣽚","𤎷","𧥾"}
	a[33463]={"㵄"}
	a[33464]={"𤁢"}
	a[33465]={"𤄣"}
	a[33470]={"湸","滰","𣼠","𧧢"}
	a[33471]={"訧","𡰔","𡰜"}
	a[33472]={"旘","滝","誠","𧧐","𧨺"}
	a[33473]={"濈","𢨀","𢨅","𣿐","𤂴","𧧟"}
	a[33474]={"濺","誐","誡","諓","𣿽","𤄔"}
	a[33475]={"㵶","𢨞"}
	a[33480]={"𥪰","𧦑","𧨆"}
	a[33481]={"試"}
	a[33482]={"㵴","𧪖","𧫳"}
	a[33485]={"𢨒"}
	a[33486]={"瀻"}
	a[33490]={"髚"}
	a[33492]={"瀸","諴","𤄞"}
	a[33493]={"瀐","𢨊"}
	a[33502]={"𥌊"}
	a[33503]={"謢"}
	a[33511]={"𤂸","𥫉","𧫱","𧭫","𧭺"}
	a[33512]={"辯"}
	a[33521]={"汶","洨","𠗕","𢖻"}
	a[33522]={"𣁉"}
	a[33531]={"浚","液","淬","𠗚","𥩛"}
	a[33532]={"㳎","㴒","冹","沷","泼"}
	a[33541]={"㳯","渧","竣"}
	a[33542]={"㳰","洠","淁","𤁜","𪓌"}
	a[33543]={"黻"}
	a[33551]={"𡕧"}
	a[33553]={"𣺦"}
	a[33561]={"詨","𣼧","𩐟"}
	a[33562]={"辡","辨"}
	a[33563]={"㕠","凖","準"}
	a[33564]={"﨎","𣽦"}
	a[33565]={"𣹷"}
	a[33566]={"㜑"}
	a[33571]={"漳","誜","誶","𠆙","𣹾"}
	a[33572]={"㦚","㵷","瓣","詙","辧","𠆓","𤀫","𤀲","𧦣","𨐰"}
	a[33573]={"辦","辬","𣽲","𥪣","𨐵"}
	a[33581]={"䛨","澼","諦","𥪮","𧩇"}
	a[33582]={"㸤","辩","辮","𧧄","𧩕"}
	a[33584]={"𢤴"}
	a[33592]={"辫","𨐱"}
	a[33600]={"䪭","誩","諳","𧩵","𧪄","𩐴"}
	a[33601]={"𧬍"}
	a[33602]={"𨐼"}
	a[33610]={"𧭛","𧮦"}
	a[33611]={"讟","𣞇"}
	a[33612]={"𧭻"}
	a[33630]={"吢"}
	a[33640]={"冶","治","𣷧"}
	a[33641]={"𤽣"}
	a[33650]={"涪","𢙈"}
	a[33651]={"𣸄"}
	a[33660]={"湆","𠗥","𣵧"}
	a[33661]={"𣾪"}
	a[33670]={"暜","湻","𤾕","𧜊"}
	a[33671]={"滀"}
	a[33672]={"𣄏","𣽢"}
	a[33680]={"詒"}
	a[33681]={"䛮"}
	a[33693]={"𥗱"}
	a[33700]={"諪"}
	a[33701]={"諄","謫","鷲","𧩽"}
	a[33702]={"㝇"}
	a[33710]={"謞","𧫐"}
	a[33712]={"𤅘"}
	a[33716]={"𤅳","𩫯"}
	a[33720]={"𣳍"}
	a[33721]={"𡶇"}
	a[33730]={"汸"}
	a[33740]={"涥"}
	a[33744]={"𠗒"}
	a[33750]={"㳙","湾","滂","滳","𠗵","𣹿","𣿱"}
	a[33751]={"浳","𥪟"}
	a[33752]={"漓","𣾌"}
	a[33754]={"浦"}
	a[33760]={"㵝","淯","渟","湇","𣺃"}
	a[33761]={"淳","滴"}
	a[33764]={"𥪀"}
	a[33765]={"溥","黼"}
	a[33769]={"𤰐"}
	a[33770]={"滈","訪","𥪜"}
	a[33771]={"䇏","𧧣","𧨨"}
	a[33773]={"𤃼"}
	a[33775]={"𣄎"}
	a[33776]={"𣽡"}
	a[33780]={"𣽱","𥪼"}
	a[33781]={"鹫"}
	a[33790]={"謗","謪","𧨜","𪃂"}
	a[33792]={"謧"}
	a[33793]={"𣫺"}
	a[33794]={"誧","𤁭"}
	a[33811]={"𠘘"}
	a[33812]={"讞","𤅊"}
	a[33813]={"𥫎","𧫟"}
	a[33820]={"𣴃"}
	a[33821]={"汱","洑","状","𣵉"}
	a[33831]={"湙"}
	a[33833]={"𣽼"}
	a[33840]={"𥩲"}
	a[33841]={"涘","𣶍"}
	a[33842]={"𤟞"}
	a[33851]={"竢","𤱶"}
	a[33852]={"𣸋"}
	a[33861]={"𤡎"}
	a[33862]={"䝺","赟"}
	a[33870]={"該","𨃱"}
	a[33871]={"𩫈"}
	a[33881]={"誒","蹵"}
	a[33892]={"贇"}
	a[33900]={"𧬀"}
	a[33921]={"沭","𣒕"}
	a[33930]={"旀","凉"}
	a[33931]={"梁","浗","滦","粱","𠗈","𥞹","𥪆"}
	a[33940]={"凉","涼","𦁞"}
	a[33941]={"㳿","橤","𠗛","𣼆"}
	a[33942]={"𣼅"}
	a[33944]={"𣿀"}
	a[33950]={"繠"}
	a[33960]={"𡮎"}
	a[33961]={"訹"}
	a[33962]={"𤀮"}
	a[33963]={"潗","𣙤","𣚘","𣽘"}
	a[33970]={"𠅽"}
	a[33971]={"凜","澟","𧧷"}
	a[33974]={"𣠛"}
	a[33980]={"凛","諒"}
	a[33981]={"𧨯"}
	a[34010]={"㿕","癇","癎"}
	a[34040]={"𤷸"}
	a[34041]={"痫"}
	a[34070]={"㾿"}
	a[34091]={"𤺖","𤺛"}
	a[34100]={"𤹪"}
	a[34101]={"𤹡"}
	a[34102]={"㿑","㿚","𤻡"}
	a[34110]={"𤺺"}
	a[34111]={"諻","韹","𧫍"}
	a[34112]={"㿖","癯","癰"}
	a[34113]={"癨"}
	a[34114]={"𤼐"}
	a[34118]={"癱"}
	a[34130]={"洫","痖","𠗅","𣾈"}
	a[34131]={"𣷆"}
	a[34140]={"疘","𤵁","𤵛","𤵢","𥩹"}
	a[34141]={"㽵","痤","𣷂","𤵞","𤶄","𤷏"}
	a[34150]={"㾤","症","痉","痙","𣶺","𤶰","𤸸","𤻸"}
	a[34151]={"㾣","潌","疟","疰","痊","𤵿","𤷁","𤷪","𤷾","𤸙","𤺞"}
	a[34152]={"㾠","瘞","𤵙"}
	a[34153]={"疶"}
	a[34160]={"疸","疽","痘","𤹻"}
	a[34161]={"痓","𤶜","𤶶"}
	a[34162]={"㾏","痽","𤷟","𤸰","𤻤"}
	a[34163]={"瘗"}
	a[34165]={"𤷣"}
	a[34170]={"㾚","瘟","𤶢","𤸳","𤺌","𧧓"}
	a[34171]={"㾴","湟","𤶚","𤶲","𤷉","𤷷","𤸱","𤹺"}
	a[34172]={"瘎","瘥","癧","𤼎"}
	a[34173]={"㾖","瘫","癦","𤸇","𤹩"}
	a[34180]={"瘂","𤶍","𤺙"}
	a[34181]={"㾮"}
	a[34182]={"㿀","㿈","𤷨","𤺷","𤻕"}
	a[34183]={"癃","𤻜"}
	a[34185]={"瘇"}
	a[34192]={"瘧","癕","𤻷"}
	a[34193]={"癍","𤺄"}
	a[34194]={"瀍"}
	a[34196]={"瘽"}
	a[34201]={"𤻖"}
	a[34202]={"灖"}
	a[34220]={"㲿","疒","疥","疹","𤴫","𤵌"}
	a[34230]={"㽱","沪","疖","痧","𤴽","𤴾"}
	a[34240]={"㽼","㾟","痑","𤵠"}
	a[34241]={"瘆"}
	a[34242]={"𤸜"}
	a[34250]={"痄","瘮","𤶙","𤷽"}
	a[34251]={"𤸋"}
	a[34260]={"瘳"}
	a[34261]={"㾡","痹"}
	a[34262]={"𤻟"}
	a[34270]={"癠"}
	a[34271]={"𤺬"}
	a[34272]={"𤺊"}
	a[34275]={"𤺋"}
	a[34280]={"痱"}
	a[34290]={"癤"}
	a[34291]={"濞"}
	a[34296]={"𧫲"}
	a[34300]={"瘬","𧪩","𧪲"}
	a[34301]={"𢥔"}
	a[34302]={"𤻱"}
	a[34306]={"𤼖"}
	a[34307]={"譧"}
	a[34310]={"𣷁","𤼛","𤼣"}
	a[34311]={"𤼝"}
	a[34314]={"𤼠"}
	a[34317]={"𤼚","𤼜"}
	a[34320]={"𤴩"}
	a[34330]={"㽿","㾉","溛","潨","疜","疺","𤵂","𤵑","𤸉","𤹐","𤺟"}
	a[34331]={"疼","瘃","𤵄","𤵉","𤵘"}
	a[34340]={"䇊","瘀","𣾋","𤶊","𤶝","𤻄","𧙜"}
	a[34341]={"斏","瘱","𤷞","𤸛","𤸽","𤹂"}
	a[34342]={"㵂","𣿵","𤐅","𤺣"}
	a[34350]={"浪","痃","𣽍","𤵋","𤸁","𤸲","𤺑","𤺫"}
	a[34351]={"㾀","㿆","漗","痣","𢞱"}
	a[34352]={"㶐","㶝","痋","𣿶","𤹊","𤹯"}
	a[34353]={"𣼄","𤶉"}
	a[34360]={"㴧","㾗","痕","瘜","𤃆","𤷜","𤸊","𤸐","𤸖","𤸤","𤹎","𤺀"}
	a[34361]={"𤸕"}
	a[34362]={"癄"}
	a[34363]={"瘙"}
	a[34364]={"𤻠"}
	a[34367]={"㾾","濂"}
	a[34370]={"㾼","㾽","痮","癊","癒","𤀴","𤸌","𤹏"}
	a[34371]={"㾯","𤹸"}
	a[34372]={"瀌","𤸬","𤹛","𤺸","𤻮"}
	a[34373]={"瘛","𧎿"}
	a[34380]={"瘾","癏","癔","𤻌","𤻘","𤻩"}
	a[34381]={"𧪳"}
	a[34382]={"謶"}
	a[34383]={"𥫑"}
	a[34385]={"𤹨","𤻹"}
	a[34390]={"癋","癮","誏","𤄺","𤻗"}
	a[34391]={"謥"}
	a[34392]={"癢","𤼉","𧭧"}
	a[34393]={"灋","𤻰","𤼂"}
	a[34394]={"癑"}
	a[34401]={"𤺝","𧪫"}
	a[34402]={"謉","𤼋"}
	a[34410]={"𤶃","𤼃"}
	a[34412]={"㿛","𤼘"}
	a[34414]={"𧫥","𪚹"}
	a[34420]={"𣵆"}
	a[34421]={"𣵇"}
	a[34422]={"𤵩"}
	a[34430]={"㽶","疕"}
	a[34431]={"疯"}
	a[34432]={"𣸴"}
	a[34440]={"㾃","疮","𤴥","𤴪","𤴰","𤴴","��","𤵯"}
	a[34441]={"㽸","疣","疧","疷","","𣳥","𣻎","𤴦","𤴱","𤵦","𤵻"}
	a[34442]={"㾱","痝"}
	a[34443]={"𤴯"}
	a[34444]={"𤷃"}
	a[34450]={"疙","疤","疪","疵","痆","痥","𣴟","𣴡","𣾊","𤴸","𤴺","𤵎","𤶨"}
	a[34451]={"㾌","痜","𤵀","𤵾"}
	a[34452]={"痲","𤵊","𤵚","𤶁","𤶮"}
	a[34454]={"𤵺","𤹃"}
	a[34460]={"疱","𤶋","𤷧"}
	a[34461]={"𣹮","𤵤"}
	a[34462]={"溾","瘋","𤷄","𤷇","𤹈","𤻀"}
	a[34470]={"瘪","𤶛","𤷅","𧥬"}
	a[34471]={"㾩","𤷊"}
	a[34472]={"漉","瘣","𤷀","𤷋","𤸩","𤹋","𤺁","𩲉","𩲌"}
	a[34474]={"痷","𤻵"}
	a[34480]={"滬","癙","𣹋","𣿆","𤷂","𤹍","𧨎"}
	a[34481]={"㾷","𤷡","𧧉","𧨱"}
	a[34482]={"𤻦","𩲋"}
	a[34485]={"𤻛"}
	a[34492]={"𤻯"}
	a[34501]={"𤹱","𧨮"}
	a[34502]={"䜂","𤼄"}
	a[34503]={"癉","癣"}
	a[34505]={"㿏","𤺽"}
	a[34511]={"𧬁"}
	a[34512]={"癭","𤻢"}
	a[34513]={"𩫫"}
	a[34521]={"𤴧"}
	a[34531]={"㽹","𣳝","𤴨","𤵒","𤶀","𤶌"}
	a[34532]={"㽴","㾅","㾳","𣼀"}
	a[34533]={"𤵽"}
	a[34541]={"㴑","㽺","痠","瘁","𣴔","𣶉","𤴲","𤵍","𤵓","𤵣","𤵧","𤶤","𤸃"}
	a[34542]={"㽻","疲","𣴁","𣴿","𣹚","𤴹","𤵃","𤵗","𤵟","𤵬","𤶟","𤷠","𤺓"}
	a[34543]={"㾙","渒","痿","瘘","𤁌"}
	a[34551]={"㾕","㾥","淿","疫","","𠦥","𠦭","𣴢","𤵷","𤶣","𤷹","𤻅"}
	a[34552]={"疩","痒","瘿","𤵭","𤶪","𤶯","𤷖"}
	a[34553]={"渡","痺","𤵸","𤶦"}
	a[34554]={"痩","𤹴"}
	a[34555]={"𤵵"}
	a[34556]={"疿"}
	a[34562]={"㿁","滜","𤷒"}
	a[34563]={"㾲","䇑","瘅","𤹆"}
	a[34564]={"㾘","瘷","𤶞","𤶱"}
	a[34571]={"㾛","癁","癓","𣽎","𤷌","𤷎","𤷘","𤸑","𧩮"}
	a[34572]={"㿂","瘢","瘦","𤷺","𤸓","𤸿","𤹹","𤺅"}
	a[34574]={"𨐜"}
	a[34575]={"㾝","㿃","𣹫","𤸞"}
	a[34581]={"㾵","瘴","𣿒","𤹉","𤹌","𤹫","𤺃","𧩔","𧩯"}
	a[34582]={"癥","𤺍","𤻂","𧫝"}
	a[34583]={"𤸆"}
	a[34584]={"𤸷"}
	a[34585]={"瘒","𤻙"}
	a[34587]={"𤹝"}
	a[34588]={"瘻"}
	a[34591]={"䛲","瘕","癈","癖","𤻁"}
	a[34592]={"㿄","𤹥","𧩅"}
	a[34593]={"癜","癬","諀","𧩧"}
	a[34594]={"㿍","𡦟"}
	a[34599]={"𤻺"}
	a[34600]={"㵿","𤺒"}
	a[34601]={"癅"}
	a[34602]={"𤻃","𤼁"}
	a[34610]={"𤻳"}
	a[34611]={"𤼅","𧫨"}
	a[34612]={"㿊","癗"}
	a[34613]={"㿔","𧮠"}
	a[34630]={"𣵁"}
	a[34631]={"𣳦"}
	a[34640]={"泊","𣷀","𤵪","𤹁"}
	a[34641]={"𣷅","𤷻"}
	a[34643]={"渖"}
	a[34650]={"㴦","㾂","㾑","洎","痁","痞","𣶎"}
	a[34651]={"㽽","湐","痂","𣽸","𤶂","𤷑"}
	a[34652]={"㾄","㾒"}
	a[34653]={"𣾆"}
	a[34660]={"㾇","㾔","㾦","㾪","痐","𣼂","𤶓","𤷩","𤻣"}
	a[34661]={"痴","𤵹","𤶕","𤶳","𤹇","𤽞","𩠾"}
	a[34662]={"瘩","𤄟","𤶈","𤺏"}
	a[34663]={"瘔","𤸠"}
	a[34670]={"㿘","瘖","瘡","𣾉","𤶘","𤹜","𤺥","𤺧"}
	a[34671]={"䛜","痦","痻","痼","瘤","𤷼"}
	a[34672]={"㾞","瘄","瘏","𤸈"}
	a[34673]={"𤶷","𤹲"}
	a[34674]={"溏","𠗶"}
	a[34680]={"㾬","癐","𤷐","𤸔","𤹦"}
	a[34682]={"𤺪"}
	a[34683]={"𤺦","𤼍"}
	a[34690]={"㿇","䛸","癚","詯"}
	a[34691]={"𤸅"}
	a[34692]={"𤺈"}
	a[34700]={"鶕","𤻈","𪂔"}
	a[34701]={"鶉","𪄱","𪅄","𪆡","𪆩"}
	a[34702]={"𤼑","𤼒","𪅯","𪇶"}
	a[34703]={"𤺿"}
	a[34704]={"𪆟"}
	a[34710]={"謆","鶮","鷾","鸇","鹯","𤺜","𧭇","𪆸","𪆿","𪈗"}
	a[34711]={"癵","𪄄","𪅂","𪆂","𪆾","𪈃"}
	a[34712]={"㿒","㿜","癴","𤼡","𪆝","𪇉","𪈷","𪛎"}
	a[34713]={"䴀","𪈯"}
	a[34714]={"𪈸"}
	a[34715]={"𤅼"}
	a[34716]={"𤅩"}
	a[34717]={"𤅽"}
	a[34718]={"𤰎","𩫱"}
	a[34720]={"𤴮","𤵇","𤸹"}
	a[34721]={"𣺑","𤵅"}
	a[34730]={"疔","疗","疝","𤵆","𤵈","𤵏","𤵐","𤶆","𤺗"}
	a[34731]={"㾈","疛","痢","𣲿","𣳿","𤵡","𤷗"}
	a[34732]={"洀","𤷫"}
	a[34740]={"㽲","㾍","㾐","疓","疠","疡","𣵈","𣷔","𣹁","𤶵","𤷝"}
	a[34741]={"㽳","㽾","䴔","澚","疨","疬","病","癆","","𠗏","𣾡","𤴳","𤶖","𪉃"}
	a[34742]={"澝"}
	a[34744]={"𠘚","𣽹"}
	a[34745]={"𤀑","𤻞"}
	a[34750]={"溩","疞","疴","痀","痟","𣳨","𤵼","𤶇","𤷛","𤸢","𤺠"}
	a[34751]={"𣿾","𤀀","𤵱","𤹰","𤺉"}
	a[34752]={"㴜","疳","痈","痔","痵","𠗬","𤴿","𤶸","𤷔","𤹳"}
	a[34753]={"斒","痨","痸","瘌","𤵝","𤻚"}
	a[34754]={"㾆"}
	a[34760]={"㾎","痌","痬","痾","瘉","瘠","鸿","𤵰","𤷥","𤸼","𤹀","𤹟","𤹧","𩾯"}
	a[34761]={"㾨","痏","瘹","瘺","竧","鳼","鴓","鵁","𤁗","𤶡","𤶴"}
	a[34762]={"㾫","㾺","痛","瘸","𣿕","𤷤","𤺇"}
	a[34763]={"痗","𠘢","𤃯","𤸝","𪓎"}
	a[34764]={"痚","痡"}
	a[34765]={"𤸣","𤸻"}
	a[34770]={"㾓","痯","瘍","瘑","鴋","鴗","鴵","𤸀","𤸎","𤸥","𤸮","𤹢","𤹷","𤺎","𤺨","𤻉","𤻝","𤻨","𪃛"}
	a[34771]={"㶉","鵺","𤷙","𤹞","𤹬","𤺐","𤺼","𪁽","𪂨","𪅍"}
	a[34772]={"𠘇","𤂃","𤄄","𤹣","𧧔","𪃡"}
	a[34773]={"𤸒"}
	a[34774]={"𤸟","𤸶"}
	a[34775]={"𤸚","𤸵"}
	a[34780]={"㾶","㾸","䲳","䲻","痭","鴻","鶁","𤁻","𤸾","𤺹","𪀞"}
	a[34781]={"㾰","鶙","鹑","𩿢","𪃽"}
	a[34782]={"𤻶","𦤢","𪁠","𪆵"}
	a[34783]={"𤸦","𤺩"}
	a[34785]={"癘","𤸪","𤹵"}
	a[34787]={"滽"}
	a[34788]={"𣁠"}
	a[34790]={"䳝","癌","𤻥","𧧆","𧪛","𪄲"}
	a[34791]={"鸂","𪃕","𪄣"}
	a[34792]={"䴆","癟","諞","鸈","𤺻","𤻋","𪅆"}
	a[34793]={"𪄠","𪄰"}
	a[34794]={"𠘒"}
	a[34800]={"𤻆"}
	a[34801]={"㿗","癫","𤼊"}
	a[34803]={"癩"}
	a[34810]={"𤼈","𤼟"}
	a[34811]={"癲"}
	a[34812]={"𤼗"}
	a[34813]={"𤼌","𤼤"}
	a[34814]={"𤼢","𩑈"}
	a[34815]={"𧫰"}
	a[34820]={"疢","疭","痰","𤵮"}
	a[34825]={"𤀿"}
	a[34830]={"疚","瘲","𠗞","𤴼"}
	a[34831]={"㾜","㾭","涙","𤴻"}
	a[34840]={"疻","痎","𣴼","𣾄","𤷓"}
	a[34841]={"淚","疾","瘓","𤶅","𤷿"}
	a[34842]={"澳","疦","𤀈","𤸗"}
	a[34844]={"𣷄","𤵨"}
	a[34850]={"㿅","𤶧","𤸺"}
	a[34851]={"痪","瘚","𤶗","𤶥","𤸂","𤸭","𤺂","𤻊"}
	a[34852]={"𤹶","𤺾"}
	a[34854]={"痶","𤸡"}
	a[34861]={"㿐","㿓","溴","瘊","瘐","𤺤"}
	a[34862]={"𤷍","𤻇"}
	a[34863]={"瘶"}
	a[34864]={"痍","𠘛"}
	a[34870]={"㿌","𤷢","𤸘","𤻍"}
	a[34871]={"瘯"}
	a[34873]={"瘼","癞","𤺆"}
	a[34874]={"瀇","瘈","癀"}
	a[34875]={"𤼇"}
	a[34880]={"𤸫","𤼏"}
	a[34881]={"瘨","癡","𧩈"}
	a[34882]={"䜒","𧫽"}
	a[34883]={"㿎","𤁂"}
	a[34890]={"𤺘"}
	a[34891]={"㿙","𧪠"}
	a[34892]={"㿉","𤹠"}
	a[34893]={"癪","𤺔"}
	a[34896]={"𤺕"}
	a[34901]={"𤻲"}
	a[34902]={"𤻿"}
	a[34910]={"𤼙"}
	a[34913]={"癳"}
	a[34920]={"𣺊","𤵲"}
	a[34921]={"𣵄","𤶩"}
	a[34930]={"㽷","泳","𤵜","𤹭"}
	a[34931]={"㾁","㾋","㾢","𤴷","𤵥","𤶔","𤷕"}
	a[34932]={"𤶫"}
	a[34940]={"㴃","瘝","𠗯","𤵫","𤹮"}
	a[34941]={"淭","𣓬","𤶠","𤶭"}
	a[34942]={"㾊","痳","𣻕"}
	a[34943]={"𤶬"}
	a[34950]={"湶","𣸔","𤷦","𤸄"}
	a[34951]={"㾻","𤷈","𤸍","𤸏"}
	a[34952]={"𣼟","𤹤"}
	a[34953]={"𤺢"}
	a[34960]={"瘵","𤷚"}
	a[34961]={"㴪","㾹","療","𣝨","𤸴","𤹄","𤹅"}
	a[34962]={"𤃰"}
	a[34963]={"㾧"}
	a[34964]={"漮","𣾩","𤷆","𤸯"}
	a[34970]={"詠"}
	a[34971]={"瘰","𠘡","𣻏"}
	a[34972]={"瘭","𤼀"}
	a[34980]={"癝","𤺡"}
	a[34981]={"癛"}
	a[34982]={"𤻴"}
	a[34983]={"𤃱","𤺚","𤻧"}
	a[34991]={"㿋"}
	a[34992]={"𤼆"}
	a[35011]={"㲼","斗"}
	a[35021]={"㳆","汁","𣷊"}
	a[35031]={"䇆","竍"}
	a[35032]={"竔"}
	a[35042]={"𣻠"}
	a[35051]={"𣁼","𣂆"}
	a[35054]={"𣂂"}
	a[35061]={"䚵","計","𣂅"}
	a[35062]={"䛂","𣂉"}
	a[35101]={"𧪞"}
	a[35102]={"諶"}
	a[35111]={"𧬇"}
	a[35112]={"𧭏"}
	a[35113]={"𣄟","𧫠"}
	a[35114]={"𤅏"}
	a[35115]={"灎","𧫴","𧭩"}
	a[35116]={"謹"}
	a[35117]={"灩","𤅿"}
	a[35121]={"汢"}
	a[35131]={"壮","𣳇","𥁇"}
	a[35141]={"𣹆"}
	a[35142]={"泩","𣺜"}
	a[35143]={"泄"}
	a[35151]={"𣴣","𣺔"}
	a[35152]={"㓐","洼","淕","𠗮","𣳃"}
	a[35153]={"滢","漜"}
	a[35154]={"𡒗"}
	a[35161]={"渣","溘"}
	a[35162]={"湛","𥃌"}
	a[35163]={"溎","鍙","𣻺","𣾛"}
	a[35171]={"淔","𤀢"}
	a[35172]={"鍌","𤃓","𥪘","𧥨"}
	a[35175]={"𤁉"}
	a[35181]={"潱"}
	a[35182]={"𧨌"}
	a[35183]={"詍","𨮝"}
	a[35186]={"漌","𣾑"}
	a[35192]={"詿","𤁅"}
	a[35204]={"灪"}
	a[35207]={"瀟"}
	a[35221]={"㪲"}
	a[35222]={"𣷏"}
	a[35231]={"𣵒"}
	a[35241]={"𣶐"}
	a[35242]={"𣄄"}
	a[35243]={"𣾖"}
	a[35261]={"𣽂"}
	a[35281]={"𧩫"}
	a[35302]={"𧫉"}
	a[35311]={"㓒","㳲","䜔","𤅵","𤈀"}
	a[35312]={"讌","𠦑"}
	a[35314]={"譓"}
	a[35315]={"謰","𤄝"}
	a[35316]={"譿"}
	a[35317]={"灢"}
	a[35321]={"汰","","𣸳"}
	a[35322]={"㳤","𣷸","𣺖"}
	a[35331]={"㳒","㳠","㳡","汯","浾","𢜃","𣲔","𣶠"}
	a[35332]={"泍","𧚛"}
	a[35341]={"法","竑","𣺚"}
	a[35342]={"","𢝳","𣶽"}
	a[35343]={"𣶨"}
	a[35344]={"𧍦"}
	a[35351]={"装","𤣦"}
	a[35352]={"𣾣","𤀸","𤂑"}
	a[35353]={"懣","涟"}
	a[35354]={"𣽑"}
	a[35361]={"溒","𣾓"}
	a[35362]={"㵭","懟","𤃇","𤃖"}
	a[35363]={"𣶣","𣽕","𣿔"}
	a[35365]={"𢣣"}
	a[35371]={"𣺮","𧨃"}
	a[35372]={"𤀱","𧦹"}
	a[35373]={"澾"}
	a[35374]={"潓","𣷼"}
	a[35375]={"懘","漣"}
	a[35377]={"𤂍","𤃈"}
	a[35381]={"㵦","詓","誌"}
	a[35391]={"瀡"}
	a[35392]={"諘","𤂠","𤒵"}
	a[35393]={"𧫻"}
	a[35402]={"𧨙"}
	a[35403]={"𥪯"}
	a[35404]={"䛳"}
	a[35407]={"𧭖"}
	a[35413]={"譊"}
	a[35414]={"𧭵"}
	a[35421]={"乧","沎"}
	a[35422]={"㳣"}
	a[35424]={"𣸻"}
	a[35431]={"㖍","㲺","㳈","㳳","涜"}
	a[35432]={"㖳","𣲃","𣸱","𣸿"}
	a[35441]={"冼","洗"}
	a[35442]={"沌","浇","𣻻"}
	a[35451]={"𠗌"}
	a[35452]={"滼"}
	a[35453]={"𣷝"}
	a[35454]={"𤃿"}
	a[35461]={"訛"}
	a[35462]={"港","𣴧"}
	a[35463]={"誮","𤂾"}
	a[35464]={"淹","𤂘"}
	a[35471]={"𧥩"}
	a[35472]={"𠒮","𣼜","𧥫","𧦏"}
	a[35474]={"𣃾"}
	a[35481]={"詵","読","𡰗"}
	a[35482]={"訰","𣿑"}
	a[35483]={"㝄"}
	a[35492]={"𦓄"}
	a[35493]={"澆"}
	a[35502]={"𧪇"}
	a[35505]={"諽","𤅞","𧫚"}
	a[35509]={"𤁥"}
	a[35512]={"𤃕","𧬕","𪗓"}
	a[35522]={"妆","汝","泲","𣼊"}
	a[35532]={"㳍","汥","汼","沛","𣳰","𣴓"}
	a[35533]={"泋","浠","𣁾","𣳏"}
	a[35534]={"汫","𣸽"}
	a[35542]={"凌","攱","淩","𢻉","𣴰","𣷟"}
	a[35543]={"沣","𣲗","𣻿","𨐎"}
	a[35544]={"渀","滞","漤","𣂎","𣳪"}
	a[35545]={"𣺛"}
	a[35546]={"𣾘"}
	a[35552]={"㓑","涬","訤"}
	a[35553]={"𣺞"}
	a[35555]={"𡣩","𣵐"}
	a[35562]={"𣶃"}
	a[35563]={"𣸉","𤅨"}
	a[35565]={"㴖","淎","滯"}
	a[35566]={"㵮","凄","淒","𤄀"}
	a[35572]={"䚳","𢻕","𧥸","𧦞"}
	a[35573]={"䛥","𢻓"}
	a[35574]={"𣿯"}
	a[35582]={"𧨫"}
	a[35583]={"𤂁","𧥹","𧧳"}
	a[35584]={"𧧅"}
	a[35586]={"𨐥"}
	a[35587]={"𣿢","𤂤"}
	a[35592]={"䛭"}
	a[35595]={"𤅯"}
	a[35602]={"濳","諎","諸"}
	a[35603]={"𡦡"}
	a[35611]={"㪳","䜐","譆"}
	a[35612]={"㶆","𧪡","𧫭"}
	a[35613]={"譇","𩫭"}
	a[35614]={"譛"}
	a[35616]={"䜊"}
	a[35618]={"𤅍"}
	a[35621]={"𠰣"}
	a[35631]={"㳓"}
	a[35641]={"沽"}
	a[35642]={"𤁇"}
	a[35643]={"㴌","㵈"}
	a[35644]={"𣺋"}
	a[35651]={"洁","浩","𥩪"}
	a[35652]={"𣈌","𥆳"}
	a[35661]={"𣶥"}
	a[35662]={"㳻","渚","澘","𥆴"}
	a[35663]={"潴","𣾟"}
	a[35664]={"𤃐"}
	a[35671]={"濇","瀒"}
	a[35672]={"䇎","瀦","𡁨","𣹡","𥪤"}
	a[35673]={"㵔","湱","湷","𣿏"}
	a[35674]={"𨐟"}
	a[35681]={"㵆","㵙","澔","詁"}
	a[35682]={"𣹴","𣼤","𤀺"}
	a[35684]={"潜"}
	a[35686]={"漕"}
	a[35691]={"詰","誥","𣽋"}
	a[35693]={"𤃺"}
	a[35695]={"𤁏"}
	a[35701]={"謝"}
	a[35702]={"濤","譵","𤃦"}
	a[35704]={"𤄵"}
	a[35711]={"䜏","𤁟","𧩭"}
	a[35712]={"請","譸","𦒭"}
	a[35715]={"𧮧","𩐸"}
	a[35717]={"𧨴"}
	a[35718]={"講","𧪸"}
	a[35721]={"泭"}
	a[35722]={"対","𣶼"}
	a[35723]={"𣼵"}
	a[35731]={"𣃜"}
	a[35732]={"㳔","𣲟","𣳹","𣵎","𣽽"}
	a[35733]={"𣳘","𣼛"}
	a[35734]={"𣺏"}
	a[35741]={"渏","𡬱","𣺈"}
	a[35742]={"㵜","泔","洊","洔","淓","𣷎","𣹀","𣼏"}
	a[35743]={"満","滿","𤁃"}
	a[35744]={"𤂉"}
	a[35745]={"𣺙","𤂙"}
	a[35751]={"㴻","洧","洿","𣺠","𣻷"}
	a[35752]={"㓓","對","洘","浡","淆","淸","湳","漪","𣾐","𥩩","𥩳"}
	a[35754]={"涍","涛","𣺇"}
	a[35761]={"㓔","㴬","旑","討","詂","𤀽"}
	a[35762]={"潸","濧","𡭊","𣿴","𥩾"}
	a[35763]={"㵇","湗"}
	a[35764]={"𣽉"}
	a[35771]={"𣷿","𧨽"}
	a[35772]={"凊","清","溡","澍","𣹥","𣾏"}
	a[35773]={"㵱","𣻞"}
	a[35775]={"漙"}
	a[35778]={"溝"}
	a[35781]={"𣿂"}
	a[35782]={"詌","詩","靖","𣼌"}
	a[35783]={"𣻛","𧫩"}
	a[35785]={"竱"}
	a[35791]={"䛴","詴","誇","𥪹"}
	a[35792]={"䪬","誖","誵","諵","𤃽","𧪶"}
	a[35793]={"𧬺"}
	a[35794]={"誟","𤂇","𤅬"}
	a[35803]={"𤃋"}
	a[35804]={"𧩻"}
	a[35805]={"誱","𪏆"}
	a[35811]={"㴺","头","謓","讀"}
	a[35812]={"灒","謮","讚","𧮃"}
	a[35813]={"䜁"}
	a[35814]={"讃"}
	a[35821]={"汏","洃","浹","𠗉","𣵩"}
	a[35825]={"漺","𠗾"}
	a[35831]={"𥪂"}
	a[35832]={"㓋","泆","洪","浃"}
	a[35841]={"𣿳"}
	a[35842]={"渎","𥩺"}
	a[35843]={"𣸣","𣿮"}
	a[35844]={"㴣"}
	a[35852]={"淇","渍","濋"}
	a[35854]={"㶂","洟","𣾁"}
	a[35861]={"䛟","詼","𧧵"}
	a[35862]={"𣄃","𣺐","𤒷","𥪓"}
	a[35864]={"凑","湊","潢","𤂀","𤄓"}
	a[35865]={"𣶏","𤂲","𧫗"}
	a[35871]={"滇"}
	a[35872]={"詄","鿁","𣿙","𤄠","𧥱","𩐠"}
	a[35873]={"濆"}
	a[35875]={"㶇","𣄂"}
	a[35876]={"漢"}
	a[35881]={"𥪧"}
	a[35882]={"漬","𤅖"}
	a[35883]={"𣽒"}
	a[35891]={"凟","瀆"}
	a[35892]={"諆","𤄴"}
	a[35894]={"濽"}
	a[35902]={"䛾"}
	a[35904]={"𧬔"}
	a[35921]={"㳜","沐","淶","𣸷"}
	a[35922]={"㵉","𠗑","𣿻"}
	a[35931]={"漆","𣵟","𣾰"}
	a[35932]={"冻","沫","沬","洓","洙","涞","淋","𣸑","𣼒","𣾕"}
	a[35933]={"溁"}
	a[35941]={"㴎","渿"}
	a[35942]={"㭍","㶋","㶙","㽔","柒","𣕟","𣸡"}
	a[35943]={"凁","洡","涑","湅","潹","𠘆","𣷞","𣼑","𤁞"}
	a[35951]={"溹","潦"}
	a[35952]={"凚","澿"}
	a[35953]={"湈","溙","滐","竦"}
	a[35954]={"凍","涷","渫","溱","𠗨","𣷵"}
	a[35955]={"𤂋"}
	a[35961]={"䛙","誺"}
	a[35962]={"溸","𤯼"}
	a[35964]={"辣"}
	a[35971]={"䜉","𧩚"}
	a[35972]={"濝","誅","諃","𧧒","𧭪"}
	a[35983]={"誄","誎","諫","𧩜","𩐫"}
	a[35984]={"𡦚","𩐷"}
	a[35987]={"𤅅"}
	a[35991]={"䜍"}
	a[35993]={"謀","謋"}
	a[35994]={"䛶","諌","諜","𩐱"}
	a[36022]={"㴢"}
	a[36030]={"㴄","泅"}
	a[36031]={"𣷓"}
	a[36033]={"𣳑"}
	a[36040]={"㳱","汨","汩","泗","溷","𠖻","𣴺"}
	a[36041]={"沺","泇","洇","涃","𠗃","𣲷","𣶱"}
	a[36042]={"油","洳"}
	a[36044]={"浀"}
	a[36050]={"泪","洄","𣶡"}
	a[36051]={"𣲶","𣳲"}
	a[36052]={"𣶴"}
	a[36060]={"𣶦","𣺀"}
	a[36061]={"凅","涸","湘",""}
	a[36063]={"涠"}
	a[36070]={"𣴵","𧥣"}
	a[36072]={"漍"}
	a[36080]={"訵","𣿹","𧥵"}
	a[36081]={"𧦤"}
	a[36082]={"䛆"}
	a[36090]={"䛛"}
	a[36093]={"潿"}
	a[36100]={"𥫅","𧨤"}
	a[36101]={"𧨚"}
	a[36111]={"𥫊"}
	a[36112]={"灈","謃"}
	a[36114]={"灅","𧬹"}
	a[36116]={"𤅱"}
	a[36140]={"泹","溫","𣳄"}
	a[36150]={"湿","𣵤","𣸭"}
	a[36151]={"𣳤"}
	a[36152]={"𥁵"}
	a[36153]={"𠗔"}
	a[36160]={"温","𣵀","𣺯","𣽭"}
	a[36161]={"浧","涅","𡐀"}
	a[36162]={"𣽿"}
	a[36163]={"浬"}
	a[36172]={"湦"}
	a[36174]={"濹"}
	a[36180]={"盪"}
	a[36181]={"𡑑"}
	a[36182]={"塣","𣹽"}
	a[36184]={"澧"}
	a[36190]={"詚"}
	a[36191]={"璗"}
	a[36192]={"𤄷"}
	a[36211]={"𧭬"}
	a[36251]={"淠"}
	a[36281]={"䛺"}
	a[36290]={"𣿓"}
	a[36291]={"𧨬"}
	a[36310]={"䜙","譞","𢥫","𧭑","𧮅"}
	a[36311]={"𢥿","𧭴"}
	a[36312]={"譴","讉"}
	a[36314]={"㶞","譨"}
	a[36330]={"𣳧","𣶜"}
	a[36342]={"浊","𣷡"}
	a[36350]={"𤁆"}
	a[36351]={"㴓","𣽻"}
	a[36352]={"潶"}
	a[36361]={"渨"}
	a[36362]={"𣹑"}
	a[36364]={"漶"}
	a[36370]={"澴","𢡂","𣺝","𣽙","𣿌"}
	a[36372]={"𤃭"}
	a[36380]={"㶎","䜚","濕"}
	a[36381]={"𤃅","𤒕"}
	a[36382]={"䛱","漒"}
	a[36383]={"𤄢"}
	a[36384]={"濃","𠘊"}
	a[36391]={"諰"}
	a[36392]={"瀜","瀢","𧑘"}
	a[36400]={"誢","𧨛"}
	a[36410]={"䛰","𤅻"}
	a[36411]={"𧭼","𩫩"}
	a[36412]={"㵾","𩇟"}
	a[36413]={"䚒"}
	a[36440]={"况","況","𣵿"}
	a[36444]={"洩"}
	a[36451]={"𣁐"}
	a[36460]={"浥","涀","滉"}
	a[36461]={"覕","𧠷"}
	a[36462]={"𣸀"}
	a[36470]={"混","覜"}
	a[36473]={"渑"}
	a[36480]={"詋"}
	a[36481]={"親"}
	a[36484]={"䛖"}
	a[36490]={"覫","郶","𤁣"}
	a[36491]={"瀙"}
	a[36492]={"𧡿"}
	a[36501]={"䛞"}
	a[36502]={"瀴","髜","𧬳"}
	a[36505]={"𥫖"}
	a[36511]={"諿","謾","𧩙"}
	a[36512]={"譯","讝","𠘥","𤅙","𧮆","𧮜"}
	a[36513]={"譂","𡅄","𧮞"}
	a[36514]={"㶠","䯬","嚲","𩑇"}
	a[36515]={"𥫕"}
	a[36517]={"𧫤"}
	a[36518]={"謱"}
	a[36519]={"𩫰"}
	a[36532]={"㳞","冲","沖","浺"}
	a[36533]={"㳏"}
	a[36541]={"𣳀","𣳚","𣴉"}
	a[36542]={"㳌","𠖹"}
	a[36543]={"𠗩","𣴪"}
	a[36551]={"渂"}
	a[36552]={"溭","𣺂"}
	a[36553]={"𣶻"}
	a[36561]={"𣵡"}
	a[36562]={"𤀎","𥪎"}
	a[36571]={"湒","漫"}
	a[36572]={"凙","澤","訲","𡢈"}
	a[36577]={"㓖","滭"}
	a[36578]={"漊"}
	a[36582]={"䛅","𣼦"}
	a[36583]={"訷"}
	a[36584]={"䛕"}
	a[36592]={"㵊","謖"}
	a[36593]={"潬"}
	a[36603]={"㵽"}
	a[36610]={"誯"}
	a[36612]={"𤃵"}
	a[36613]={"讄"}
	a[36650]={"𣳮"}
	a[36670]={"淐","𣹈","𣼞"}
	a[36671]={"𣽞"}
	a[36681]={"潪"}
	a[36682]={"濖","𣻲"}
	a[36690]={"𣎘"}
	a[36691]={"𤀅"}
	a[36692]={"濐"}
	a[36700]={"諹","謁","𤀰"}
	a[36701]={"𧬴"}
	a[36702]={"䛣"}
	a[36703]={"𧪓"}
	a[36710]={"諤","𧩑","𧬌","𧬒"}
	a[36711]={"謂"}
	a[36712]={"𧪯","𩑂"}
	a[36740]={"瀱","𣸤"}
	a[36741]={"涡"}
	a[36750]={"𠗓"}
	a[36751]={"𣃫"}
	a[36760]={"涓","渇","渴","湯","𣽷","𥪔"}
	a[36761]={"淂"}
	a[36762]={"涄"}
	a[36763]={"湡"}
	a[36764]={"𣹤"}
	a[36770]={"竭","𣶀","𣷢"}
	a[36771]={"渭","𣿘"}
	a[36772]={"濁","𥪁"}
	a[36773]={"𣂌"}
	a[36780]={"湂","溻","澏","澷","𣻵","𤣨"}
	a[36782]={"𢴳"}
	a[36790]={"瀃","𣽺","𧦢"}
	a[36791]={"𣽴"}
	a[36800]={"諟","𤀭","𥪾"}
	a[36803]={"𤅹"}
	a[36810]={"韻","𧪼"}
	a[36811]={"𧬂","𧬮"}
	a[36812]={"䜋"}
	a[36813]={"謴"}
	a[36830]={"潀","𣲵"}
	a[36831]={"𣵗"}
	a[36840]={"浞","涢","𣷐"}
	a[36841]={"𣵖"}
	a[36850]={"䇍","浿"}
	a[36851]={"洖"}
	a[36852]={"溃"}
	a[36860]={"湜","燙"}
	a[36861]={"淏","湨"}
	a[36863]={"潩"}
	a[36870]={"㵋","䛊","溳","𣄍"}
	a[36873]={"𣄗"}
	a[36876]={"螤"}
	a[36880]={"䛤","𥪩"}
	a[36881]={"㵑","㶔"}
	a[36882]={"潰"}
	a[36890]={"𧧾"}
	a[36891]={"誤"}
	a[36892]={"濻","𣄜"}
	a[36901]={"𧫖"}
	a[36910]={"𩐿"}
	a[36911]={"譟","髞"}
	a[36912]={"𧭤"}
	a[36913]={"㶟","𧮔","𧮢"}
	a[36920]={"潈"}
	a[36930]={"𣽁","𣾞"}
	a[36940]={"𣹺"}
	a[36941]={"㳭","湺"}
	a[36952]={"𠘏"}
	a[36953]={"淉"}
	a[36960]={"𠘉"}
	a[36961]={"漯"}
	a[36962]={"㵖"}
	a[36970]={"澋","𧪟"}
	a[36972]={"瀑"}
	a[36980]={"𤂽"}
	a[36981]={"澡"}
	a[36983]={"𤄗"}
	a[36993]={"課"}
	a[37001]={"勯","調","𧪜"}
	a[37002]={"𧩝"}
	a[37004]={"𧧛"}
	a[37005]={"勷"}
	a[37010]={"","𠖳","𦒜","𧬘","𧮍"}
	a[37011]={"为","𠢻","𤂂"}
	a[37012]={"謿","𤅾"}
	a[37013]={"𦒍"}
	a[37014]={"𤄡"}
	a[37020]={"㲽","汋","沕","𣱼","𣴆"}
	a[37021]={"氻","汭","沩","𣲒","𣲢"}
	a[37022]={"効","𠠼"}
	a[37030]={"㳉","汈","汮","沟","𠛳","𠨑","𣃗","𣵓","𣷣","𥩘","𥪈"}
	a[37031]={"劾","泐","洶","淗","𠜨","𦐑"}
	a[37032]={"𣲥","𣳔","𣷃"}
	a[37033]={"𣲫"}
	a[37040]={"㓏","泂","泃","浻","𠖷","𥩞"}
	a[37041]={"劥","勍","沏","泑","𠡆"}
	a[37042]={"𣷋"}
	a[37043]={"𣳠"}
	a[37044]={"𣲕","𣲹"}
	a[37048]={"𣳷"}
	a[37050]={"㓊","泀","洞","洵","竘","𣶈","𥪇","𦚎"}
	a[37051]={"勏","淘","𠡽","𣁚","𣵦","𥪃"}
	a[37052]={"㳩"}
	a[37053]={"𣳱"}
	a[37060]={"䪨","翊","訋","訒","𣶯","𦐤","𧥟"}
	a[37061]={"凋","淍","溯","訥","𠞻","𣵪","𦑋"}
	a[37062]={"𠢗","𣷥","𧧜"}
	a[37063]={"渤","𣾗"}
	a[37064]={"㴂","𣵢","𣶞"}
	a[37068]={"𣸙"}
	a[37070]={"淜","渹","韵","𠹪","𣷠","𦐄","𧥺","𧩘"}
	a[37071]={"湖","詾","諊","𧦘","𧦛"}
	a[37074]={"𧧚"}
	a[37080]={"䚴","訽","詗","𤂕","𦟁","𧨝","𩐝"}
	a[37081]={"詏","𣿸"}
	a[37084]={"䛁","勭","𣽯","𧦦"}
	a[37085]={"𣹼","𣼚"}
	a[37086]={"𤄆"}
	a[37090]={"詞","詡","詢","詷","誷","𣻫","𣼐","𧧖","𧨋","𩐤"}
	a[37091]={"䛬","𤄇"}
	a[37092]={"潮","𤁝"}
	a[37101]={"𧩦"}
	a[37103]={"𨯳"}
	a[37105]={"𣻱"}
	a[37106]={"澅"}
	a[37110]={"䛼","譅","𤅚","𧪀","𧪧"}
	a[37111]={"瀣","𧫢","𧭅","𧭸"}
	a[37112]={"䀍","𧗜","𧩖"}
	a[37113]={"鑿"}
	a[37114]={"𡔊","𧗛"}
	a[37117]={"𨐶"}
	a[37130]={"㳑","𣹃","𥁤"}
	a[37131]={"𡋆","𡋋"}
	a[37132]={"㳗","𡉢"}
	a[37140]={"泾","洆","涩","盗","盜"}
	a[37141]={"垐","沑","𠗠"}
	a[37142]={"𣲾","𣶳"}
	a[37150]={"䀀","沮","盕","𣴻","𣶅","𥩿"}
	a[37151]={"𣶬","𣷉","𥁭","𧖶","𨦠"}
	a[37152]={"䇈"}
	a[37160]={"𣹣","𣻭","𥩢"}
	a[37161]={"埿","渔","溋",""}
	a[37162]={"𠘓","𨦮"}
	a[37163]={"㴶","湰","錃"}
	a[37170]={"䀊","湼","澀","𣿍","𥂖"}
	a[37171]={"渥","𡎿","𣶝"}
	a[37172]={"𣻹"}
	a[37173]={"漋"}
	a[37174]={"濜"}
	a[37180]={"𣵬"}
	a[37181]={"䚼","望"}
	a[37182]={"瀊","𠗻","𣿣"}
	a[37183]={"𣿫"}
	a[37184]={"塾"}
	a[37186]={"𥂵"}
	a[37187]={"堻"}
	a[37190]={"䜀","詛","𤀄","𤁍","𤃗","𧦒","𧧫","𧫺"}
	a[37191]={"㵬"}
	a[37192]={"濯","𧪪"}
	a[37210]={"汐",""}
	a[37211]={"𣺫"}
	a[37221]={"𠨘"}
	a[37230]={"泖","𠗄"}
	a[37240]={"䇋","𠨛"}
	a[37241]={"𠗺","𣻗"}
	a[37244]={"㴋"}
	a[37250]={"漻","𠗽"}
	a[37260]={"𣹜"}
	a[37270]={"誃","𧥤","𧥴","𧩀","𧬶"}
	a[37280]={"㶀"}
	a[37281]={"謻"}
	a[37290]={"謬"}
	a[37295]={"潚"}
	a[37300]={"𥫄"}
	a[37302]={"𤂿","𧭍","𩐹"}
	a[37304]={"韼"}
	a[37310]={"𤅁"}
	a[37311]={"𤅛","𧭋"}
	a[37312]={"戆","戇","𧭟"}
	a[37315]={"𧬪"}
	a[37321]={"泈"}
	a[37330]={"恣","浕","涊","淴","𠗋","𣼢"}
	a[37331]={"浓","𣹞"}
	a[37340]={"湪","溕"}
	a[37341]={"潒","𣺵"}
	a[37350]={"泿","𢚑","𢛜","𣽓","𤀊"}
	a[37351]={"漁","𢛣","𣾎","𩶲"}
	a[37352]={"𣼈","𤂏","𧊒"}
	a[37353]={"㴍","溞","螀"}
	a[37360]={"㴔","餈","𠘑","𢞉","𣴦","𤀠","𤎹","𤏁","𦫋"}
	a[37361]={"𤂻"}
	a[37362]={"㵵","慂","𣺹","𣻢"}
	a[37363]={"㶖","熟","𩸓"}
	a[37364]={"漨","𤄩"}
	a[37370]={"濄","認","𧩓"}
	a[37372]={"𧩪","𩜥"}
	a[37380]={"䛹","凞","𠘕","𧪣"}
	a[37381]={"𤅮","𩸧"}
	a[37383]={"滟","𧪅"}
	a[37386]={"𤄁"}
	a[37390]={"詪","誋","𧩷","𧩺"}
	a[37392]={"𩼪"}
	a[37400]={"誽","𧩠"}
	a[37401]={"髛","𠆔"}
	a[37410]={"澠","譝","𦒮","𪓼"}
	a[37411]={"氿","沨","瀺","讒","𣳜","𤅌"}
	a[37412]={"䜛","濪","灚","𤄻","𩇝"}
	a[37413]={"𪛀"}
	a[37414]={"灔","𦏧"}
	a[37416]={"灧"}
	a[37420]={"乲","𣲆","𣲩"}
	a[37422]={"汍"}
	a[37430]={"㲸","㲹","氾","汎","𣴊"}
	a[37431]={"汛","沈","飒","𠗟","𠙇","𣳽"}
	a[37432]={"池","𠖵"}
	a[37440]={"汜","沉","泥","洬","竌","𣶘","𤂚"}
	a[37441]={"𠡌","𠡜","𠡤","𣁈"}
	a[37442]={"𣸦"}
	a[37450]={"㫉","䇃","泡","洈","𠃻","𣲻","𥩙","𥩥"}
	a[37451]={"冺","凂","泦","泯","浼","𢁆","𦫨"}
	a[37452]={"渢","𣳞"}
	a[37453]={"𩖣"}
	a[37460]={"淣","瓷","𣣰","𣾚"}
	a[37461]={"䇇","氓","𣹠"}
	a[37462]={"浘","訙","颯","𠅶","𠢖"}
	a[37463]={"孰"}
	a[37464]={"𣸚"}
	a[37470]={"淝","訉"}
	a[37471]={"訅","訊","訦"}
	a[37472]={"㴷","䪧","訑","𠅩","𣽝","𧦭","𩘁","𩪿"}
	a[37473]={"𨐦"}
	a[37477]={"𣽳"}
	a[37480]={"㵯","䒍","䛄","䛏","記"}
	a[37482]={"𠣺","𩘍"}
	a[37486]={"𣷾"}
	a[37490]={"䛌","詭","𧧘","𩐜"}
	a[37491]={"䛉"}
	a[37492]={"諷","𤀧"}
	a[37494]={"𤅜"}
	a[37501]={"誛","謘","𣾮"}
	a[37502]={"䜄","瀫","諏","謏","𣫞","𤁨","𥪳"}
	a[37504]={"𥪴"}
	a[37505]={"竷","𠮒"}
	a[37506]={"𧧪"}
	a[37510]={"𧮘"}
	a[37511]={"譭","讂","𦗤","𧪕","𧫫","𧭦"}
	a[37512]={"皽","𧫮"}
	a[37513]={"諱"}
	a[37514]={"𣫩","𪎇"}
	a[37515]={"瀈","諢","𣫡"}
	a[37516]={"𥀶"}
	a[37517]={"𥫓"}
	a[37518]={"𩍷"}
	a[37521]={"汉","汊","汷","𠬧","𣴂"}
	a[37522]={"𣲋"}
	a[37531]={"汲","沒","𣲌","𣴄","𣷕"}
	a[37532]={"姿","波","𣴗"}
	a[37533]={"㿰","𣻑"}
	a[37541]={"没","浫","淑"}
	a[37542]={"㳃","溆","𣴅","𣸹"}
	a[37543]={"泽","洚","洢","𣲺","𥀆"}
	a[37544]={"婆"}
	a[37546]={"沸"}
	a[37551]={"㱾","毅","竐"}
	a[37552]={"𠭇","𣹂","𣺲"}
	a[37553]={"浑","𣸎","𣺆","𣻋","𥀏"}
	a[37554]={"浲","涰"}
	a[37561]={"㓎","㴆","䘲","浸","訍","𣴫","𣴬","𣷽","𣹲"}
	a[37562]={"㿶","殶","溲","漽","竮","𣪲","𣿡"}
	a[37563]={"𣼨"}
	a[37564]={"𡣼"}
	a[37565]={"𡣂"}
	a[37566]={"冿","津","𣸁"}
	a[37571]={"溊","濢","訯","𣪟","𣫛"}
	a[37572]={"嬜","詖","𣫖","𣹰","𣺎","𥪏","𧦀"}
	a[37573]={"湋","詉","𣪻"}
	a[37575]={"渾"}
	a[37581]={"溵","設","諔","𣪢","𣪪","𧦮"}
	a[37583]={"澱","濲","𣫚","𧦾","𧧭","𩐨"}
	a[37584]={"澥"}
	a[37585]={"𣄈"}
	a[37586]={"䛍","𩐚"}
	a[37587]={"湕"}
	a[37591]={"毃"}
	a[37592]={"㵻","𧩱","𩐦"}
	a[37593]={"瀔"}
	a[37594]={"諁","韸","𧧽","𩐾"}
	a[37597]={"旔"}
	a[37601]={"䛯","𧪭"}
	a[37603]={"㵫","𧨡","𩐩"}
	a[37610]={"謵","譫","𤄧","𩐶"}
	a[37611]={"𧭷"}
	a[37612]={"𧬅","𧮙"}
	a[37614]={"𧮒"}
	a[37616]={"䤗"}
	a[37640]={"咨","沼","洺"}
	a[37641]={"洛","𠗂"}
	a[37650]={"㳷","沿","𣵥"}
	a[37651]={"𣹒"}
	a[37652]={"𠴸","𣶤"}
	a[37660]={"滘","𣷍","𣸬"}
	a[37661]={"涺","溜","𠸆","𣇹","𣹢"}
	a[37662]={"碆"}
	a[37663]={"涒"}
	a[37670]={"湄","𣷤","𣽃","𥒟"}
	a[37671]={"𣿧"}
	a[37672]={"酱","𥇲"}
	a[37680]={"㴘","䛇","漝","澹","詔","詺","韶","𣿠"}
	a[37681]={"湣","潞","澛","瀂","詻"}
	a[37682]={"潳"}
	a[37690]={"諮","𣻥"}
	a[37691]={"𣄤"}
	a[37693]={"䃞"}
	a[37700]={"諂","諝","諣","譎","𣾭"}
	a[37701]={"𧬲"}
	a[37702]={"灟"}
	a[37710]={"瀥","𧧠","𧩛","𧪦","𧪱","𩐯"}
	a[37711]={"㐧","𧪂","𧫿"}
	a[37712]={"𦦹","𧮏","𩐽","𪈋"}
	a[37715]={"瀞","𤁿"}
	a[37716]={"𤀷","𧬦"}
	a[37730]={"汤","汿","𣱴","𣱽","𨚪"}
	a[37731]={"将","汓","溈","為","𠡑"}
	a[37732]={"𣁻","𤄨"}
	a[37740]={"冯","涵","𠗙","𠗷","𣼇"}
	a[37741]={"𣿲"}
	a[37742]={"𢫴","𣺥","𤂎"}
	a[37743]={"𦛇"}
	a[37744]={"𣣀","𦈳"}
	a[37750]={"泻","𣺅"}
	a[37751]={"㴠","浔","淈","滫","漏","潃","𣼣","𦈱"}
	a[37752]={"涌"}
	a[37753]={"净","浄","𣵊"}
	a[37754]={"㨇"}
	a[37755]={"𣸏"}
	a[37760]={"㴮","㵼","淊","渦","湑","潏","潟","澙","𣻍"}
	a[37761]={"𠗴","𣁘","𣺷","𥪊"}
	a[37762]={"𤀯","𥪒","𥪥"}
	a[37763]={"湧","竫"}
	a[37764]={"𣺘"}
	a[37767]={"𣷈"}
	a[37770]={"䚮","滑","𣹯","𧥰","𧦃"}
	a[37771]={"𣹍"}
	a[37772]={"𡦔"}
	a[37773]={"𣹏","𣹩","𣽔"}
	a[37777]={"䳐"}
	a[37783]={"𠘈","𣽶"}
	a[37790]={"溺","𧦫","𧧱"}
	a[37791]={"䛝","潯","誳","謠","𧫞"}
	a[37792]={"䪮","誦","謅"}
	a[37793]={"㶅","潺","諍"}
	a[37796]={"𩰾"}
	a[37800]={"𣄣","𤄕"}
	a[37802]={"赣"}
	a[37803]={"瀷"}
	a[37804]={"𧩶"}
	a[37810]={"","𠖮","𣤽","𤈾","𧩿","𧭾"}
	a[37811]={"譺","𩑅"}
	a[37812]={"灨","譔","贛"}
	a[37813]={"𩫠"}
	a[37814]={"𥫔"}
	a[37817]={"𩍯"}
	a[37820]={"㳄","次","汣","沢","𣶋"}
	a[37821]={"𣢠","𣸧","𣼋","𣿁"}
	a[37830]={"欬","烫","资","𣢅","𣢦","𣳟","𣳩","𣶛"}
	a[37831]={"㰵","奖","渙","𠗫","𣵫"}
	a[37832]={"决","決","泱"}
	a[37840]={"㰠"}
	a[37841]={"涣","𣾠"}
	a[37842]={"㪱","𣃝","𣣑"}
	a[37844]={"淟","𠗘"}
	a[37850]={"㰴","𣣱","𣹱"}
	a[37851]={"㳛","畝","𣢿"}
	a[37852]={"㱉"}
	a[37853]={"漱","𠘂"}
	a[37854]={"𣸲"}
	a[37860]={"䚿","凕","歆","溟","資","𣣎","𣼗"}
	a[37861]={"㵤","凝","歒","𣽟","𩐬"}
	a[37863]={"濑","𡦦","𤍨"}
	a[37864]={"𤄸"}
	a[37870]={"㵣","㶑","歊","澬","訳","𣽌"}
	a[37872]={"濥","訣","詇"}
	a[37873]={"𡥹"}
	a[37874]={"𡙰"}
	a[37876]={"㵒"}
	a[37880]={"𣹎"}
	a[37883]={"𤒆"}
	a[37884]={"斔","𤅂","𧨸"}
	a[37885]={"𤄼"}
	a[37886]={"𤁤"}
	a[37890]={"㵰","𤃚"}
	a[37891]={"諛","𤂐","𤃘","𤄚","𧩨","𧩩"}
	a[37892]={"潠"}
	a[37893]={"瀨","𠘝"}
	a[37894]={"𣤸"}
	a[37903]={"糳"}
	a[37913]={"𥽿"}
	a[37914]={"𪎲"}
	a[37920]={"沵"}
	a[37921]={"𣒿","𣳼","𤂱","𥹦"}
	a[37922]={"鿄","𣺢"}
	a[37930]={"浆","淥"}
	a[37931]={"栥","桨","深","秶","粢","𣓥","𥹭"}
	a[37932]={"涤","滌","𣺉"}
	a[37933]={"𣑱"}
	a[37940]={"㳮","𣵌","𥿩"}
	a[37941]={"渘","𣑃"}
	a[37942]={"染"}
	a[37945]={"𣵏","𤂰"}
	a[37950]={"渌","漈","𣳆","𤀼"}
	a[37951]={"楶","𥺜"}
	a[37952]={"澯","𢒶"}
	a[37960]={"𥪋","𥪬","𧦽"}
	a[37963]={"𤁼"}
	a[37964]={"䇐","𨽷"}
	a[37971]={"𧨾"}
	a[37972]={"𣻨"}
	a[37973]={"㓗","潔"}
	a[37981]={"𠘤","𧧇","𧨇"}
	a[37983]={"𥪲","𥽦"}
	a[37984]={"𤃲"}
	a[37990]={"𧨹","𧫕"}
	a[37991]={"𧩴"}
	a[37995]={"𠘞","𤃀"}
	a[38000]={"𠔂"}
	a[38010]={"汃","汄"}
	a[38020]={"㫃","泤","𣲄"}
	a[38041]={"畒"}
	a[38102]={"𧪘"}
	a[38103]={"𣄢"}
	a[38110]={"旜","𧭗"}
	a[38111]={"𤅸"}
	a[38113]={"𨰩"}
	a[38130]={"㳕","湴","𠖽","𣳁","𥁣","𥁳"}
	a[38131]={"𡋇","𡌂","𣴶"}
	a[38132]={"㵚"}
	a[38140]={"湓","溢","滥","𠖸","𣃢"}
	a[38141]={"㓌","凎","洤","淦","𠗎","𣴞"}
	a[38142]={"滏","𡍼","𣺨"}
	a[38150]={"𥁿"}
	a[38151]={"𣷒","𤁈","𥂋"}
	a[38152]={"塗","𡌼"}
	a[38160]={"㫌"}
	a[38161]={"𣄀"}
	a[38162]={"旌","溠","𥂚"}
	a[38164]={"塰"}
	a[38170]={"諩","𥪱"}
	a[38171]={"𤀟","𧨀"}
	a[38172]={"𣻓","𨨼"}
	a[38173]={"潅"}
	a[38180]={"濫","謚","𧨦"}
	a[38181]={"詮","𣁥"}
	a[38182]={"𤂦","𥂦"}
	a[38183]={"墪","𡒱"}
	a[38190]={"諡"}
	a[38192]={"𡒋","𣦤"}
	a[38193]={"鐜","𤅺","𩀥"}
	a[38210]={"沴","𣲤"}
	a[38213]={"𣄨"}
	a[38220]={"斺","汵","𧱘"}
	a[38230]={"㫇","𣃭"}
	a[38240]={"㫅","旂","泎"}
	a[38250]={"䚸","診","𣃽"}
	a[38260]={"䪩","訡"}
	a[38280]={"詐","𧧻"}
	a[38286]={"𧪺"}
	a[38301]={"𩞤"}
	a[38310]={"𢜅"}
	a[38312]={"𢥲","𣄧","𩑉"}
	a[38313]={"𢥦"}
	a[38320]={"㳂","冷","於","泠"}
	a[38321]={"𢞾"}
	a[38330]={"淤","淰","澻","竛","𣃠","𥩷"}
	a[38331]={"凇","淞","滺"}
	a[38334]={"㶃"}
	a[38340]={"旅","旍","浍","𣄚","𣸮","𤏄"}
	a[38341]={"溔","𣿇"}
	a[38344]={"潕"}
	a[38350]={"旞","湌","玈","飡","𣄆","𣸊","𣻒"}
	a[38352]={"𣻧"}
	a[38353]={"𧏅"}
	a[38357]={"溓","𠗳"}
	a[38360]={"滋","訟","詅","𣿪","𧧡","𩚷"}
	a[38363]={"𧌱"}
	a[38370]={"濨","諗","譢","𧧴","𧩟","𩐭"}
	a[38371]={"𩜢"}
	a[38372]={"憝"}
	a[38377]={"𤅃","𤅄"}
	a[38378]={"𨐩"}
	a[38382]={"䗠","瀁","𧝗"}
	a[38383]={"𤃬","𧐈"}
	a[38384]={"䗐","譕"}
	a[38390]={"𧬫"}
	a[38392]={"𣄦","𧪁","𩺯"}
	a[38397]={"謙"}
	a[38400]={"㓆"}
	a[38402]={"𧩹"}
	a[38405]={"議"}
	a[38410]={"灠","𤂺","𧭚","𧮤"}
	a[38413]={"𤅴"}
	a[38420]={"沦","涗"}
	a[38430]={"乻","沧"}
	a[38440]={"䇄","旕","汔","汽","涚"}
	a[38441]={"𣃮"}
	a[38442]={"沲","𠙟","𣴾"}
	a[38450]={"斻","旐"}
	a[38451]={"滊"}
	a[38452]={"㳾","施","𣃯","𣵺","𩙴"}
	a[38455]={"𣿭"}
	a[38460]={"旎","旒"}
	a[38461]={"𣃹"}
	a[38462]={"旄","湤","溬"}
	a[38470]={"旊","詤","說","𣃿","𣽩"}
	a[38472]={"𣹪"}
	a[38475]={"𥫃"}
	a[38480]={"訖","説","𣄙"}
	a[38482]={"𣄞","𧦧"}
	a[38484]={"𣄑"}
	a[38490]={"𧥷"}
	a[38491]={"𧪢"}
	a[38492]={"漧"}
	a[38502]={"𧩼","𧭕"}
	a[38503]={"䜘","謸"}
	a[38511]={"㳇","譤"}
	a[38512]={"譀","譈"}
	a[38521]={"㳊","浟","𠖴","𢼜"}
	a[38522]={"效","滧"}
	a[38531]={"放","汻","𢻬","𢼵","𢽯","𣵑"}
	a[38532]={"洴","潎","𢽮","𣀅"}
	a[38541]={"㫍","斾","潋","𢽺","𣷫","𤁚"}
	a[38542]={"洋","涕","漵","𢾉","𢾣","𣃩","𣃬","𣶌","𣹶","𣻪","𥩵"}
	a[38543]={"𡝶","𦍢"}
	a[38551]={"敨","浒","𣸪"}
	a[38552]={"旆","旇","渰","𢍡"}
	a[38553]={"𢽒"}
	a[38554]={"潄","𣿊"}
	a[38561]={"㵟","䚺","溦","澓","","𠘄","𠘜","𢄲","𢾚","𢾛","𣀩","𣄐"}
	a[38562]={"㴛","敦","敵","𢄧","𣃻","𣿗"}
	a[38563]={"㴾","滶","𣃵","𤀂"}
	a[38564]={"𡟕"}
	a[38565]={"漖"}
	a[38571]={"㪟","㪣","澈","激","瀲","許","𤁲","𥪚"}
	a[38572]={"潡","澂","澉","瀓","誁","𪍧"}
	a[38573]={"潵","濣","𤀡"}
	a[38574]={"㫏","𣿨"}
	a[38576]={"㵲"}
	a[38581]={"滸"}
	a[38582]={"詳"}
	a[38583]={"㶍","澣"}
	a[38592]={"𧩸"}
	a[38594]={"亸"}
	a[38595]={"㫎"}
	a[38600]={"謒","譄","譜","𧪃"}
	a[38605]={"𤅔"}
	a[38610]={"瀶","譮"}
	a[38612]={"𧫧","𧬆"}
	a[38620]={"㫈"}
	a[38630]={"浴"}
	a[38631]={"𠳛"}
	a[38640]={"冾","洽","浛","𥪉"}
	a[38650]={"𣃴","𥩻","𥪶"}
	a[38651]={"涻","𢂷"}
	a[38660]={"凔","渞","滄","潧","潽","𠘎","𣃧","𣄅"}
	a[38661]={"𣃳","𣉯"}
	a[38662]={"㵛","湁","湭"}
	a[38670]={"䛦","澮","竲"}
	a[38671]={"𣿥"}
	a[38672]={"旛","𣻦"}
	a[38674]={"𤃏"}
	a[38680]={"詥","誝","𣄕","𣻙","𥫁","𧬢","𩐥","𩐧"}
	a[38682]={"𣄉","𤃳","𤄫","𦏎","𨢯"}
	a[38690]={"旝"}
	a[38692]={"䃦"}
	a[38700]={"謭"}
	a[38701]={"鷟","𪆎"}
	a[38702]={"瀚","瀹"}
	a[38710]={"譾","𠖲","𧬈"}
	a[38712]={"讑","𤅕","𧭆","𪆃"}
	a[38713]={"譐"}
	a[38715]={"𤁶"}
	a[38720]={"汾"}
	a[38730]={"竕",""}
	a[38731]={"黺"}
	a[38740]={"洕","𣃦"}
	a[38741]={"𣃰","𣳬"}
	a[38742]={"淪","溣","𠗭","𣸯"}
	a[38750]={"渝","湔","𣄊"}
	a[38751]={"斿","膐"}
	a[38752]={"旃","𠘅","𡥮","𣃼","𣼕"}
	a[38753]={"海"}
	a[38760]={"㫊","旓","滃","訜","𣸜"}
	a[38761]={"游"}
	a[38763]={"㳺"}
	a[38764]={"㫋"}
	a[38770]={"䚷","漡","膂"}
	a[38771]={"旖","𤀉"}
	a[38772]={"㽏","𡭅","𡼖"}
	a[38773]={"澊","𢳈","𣼿"}
	a[38780]={"潝","𩩘"}
	a[38781]={"𪄫"}
	a[38782]={"㵸","論"}
	a[38783]={"竴"}
	a[38784]={"撉"}
	a[38790]={"諭","𣄘","𧪈"}
	a[38793]={"誨"}
	a[38795]={"瀭"}
	a[38800]={"譣"}
	a[38810]={"㶛","旟"}
	a[38811]={"𣄪","𧬄","𧹄"}
	a[38820]={"漎"}
	a[38830]={"𣃨","𣄡"}
	a[38831]={"浂"}
	a[38840]={"㳬"}
	a[38841]={"㵪"}
	a[38850]={"旋","𧦁"}
	a[38851]={"族","湵"}
	a[38852]={"渼"}
	a[38853]={"𣾇"}
	a[38860]={"㵅","漩","澰"}
	a[38861]={"㴨","㵀"}
	a[38862]={"𣾍"}
	a[38863]={"𣄠","𤄂"}
	a[38870]={"𣄝","𩐰"}
	a[38871]={"䛈","𣽜"}
	a[38872]={"旗"}
	a[38873]={"𤄾"}
	a[38892]={"䞄"}
	a[38901]={"𧫛"}
	a[38910]={"𣳅"}
	a[38920]={"㫆","㴚","𣵂"}
	a[38921]={"𣷦"}
	a[38930]={"𣶗"}
	a[38931]={"凃","涂"}
	a[38933]={"𣓰"}
	a[38941]={"滁","𣓫"}
	a[38942]={"𣻌"}
	a[38950]={"㳽","𧦜"}
	a[38952]={"𣼁"}
	a[38960]={"𧧂"}
	a[38961]={"漾"}
	a[38971]={"𧧶"}
	a[38982]={"旚"}
	a[38983]={"瀿"}
	a[39020]={"𣃘"}
	a[39050]={"䚱"}
	a[39100]={"𧪚"}
	a[39101]={"𧰄"}
	a[39102]={"䜅"}
	a[39110]={"𤅐"}
	a[39120]={"㴴"}
	a[39130]={"𥁲"}
	a[39131]={"𡋷","𣿩"}
	a[39140]={"潂","𣶟"}
	a[39141]={"灐"}
	a[39142]={"𣼎"}
	a[39151]={"瀅","𣷪"}
	a[39152]={"𣳫","𣵭"}
	a[39160]={"凒","溰","𤀆"}
	a[39161]={"漟","鲨","𧯺"}
	a[39162]={"凗","漼"}
	a[39170]={"𥪪"}
	a[39171]={"䛧","𧥳"}
	a[39172]={"漄"}
	a[39193]={"𧪴"}
	a[39210]={"沙"}
	a[39211]={"𣶲"}
	a[39220]={"竗","𡭹"}
	a[39230]={"涔","玅","𣵙"}
	a[39232]={"𣴷"}
	a[39250]={"渺","訬"}
	a[39251]={"𣺌"}
	a[39260]={"𤣧"}
	a[39300]={"𣷇"}
	a[39310]={"𣲡"}
	a[39312]={"讜"}
	a[39321]={"㴹"}
	a[39330]={"裟"}
	a[39331]={"㵞"}
	a[39342]={"𧋊"}
	a[39351]={"鯊"}
	a[39352]={"㶈"}
	a[39362]={"𣽵"}
	a[39363]={"滍"}
	a[39370]={"𨗞"}
	a[39371]={"謎"}
	a[39382]={"灙"}
	a[39410]={"乷"}
	a[39420]={"𣴕"}
	a[39430]={"洸","𣵘","𣺼"}
	a[39432]={"𣿄"}
	a[39440]={"䣉"}
	a[39442]={"㲚"}
	a[39451]={"𣻖"}
	a[39452]={"淃"}
	a[39470]={"𩐣"}
	a[39471]={"𣹵"}
	a[39480]={"潉"}
	a[39521]={"𣳒"}
	a[39522]={"娑"}
	a[39532]={"㸺","冸","泮"}
	a[39533]={"溇"}
	a[39542]={"𥪄"}
	a[39543]={"溄"}
	a[39553]={"潾"}
	a[39554]={"𣺿"}
	a[39563]={"溿"}
	a[39572]={"詊","詜"}
	a[39611]={"譡"}
	a[39612]={"𧬸"}
	a[39640]={"硰"}
	a[39650]={"渻","𥆝"}
	a[39660]={"瀯","𤁽","𤃨","𩉀"}
	a[39671]={"澢"}
	a[39710]={"𣳈"}
	a[39712]={"讗","𧮄"}
	a[39720]={"汕","𣺟"}
	a[39731]={"泏","澇"}
	a[39732]={"挲"}
	a[39740]={"消","淌","湍","𣲸","𣷩","𣸌","𣹇"}
	a[39741]={"𣻸"}
	a[39742]={"𣼍"}
	a[39750]={"㴥","䇌","端","𣹝"}
	a[39751]={"潲","𣻘"}
	a[39752]={"𩣟"}
	a[39760]={"訕","𣺰"}
	a[39762]={"𣾦"}
	a[39771]={"䜎","詘","韷","𧪙"}
	a[39780]={"漰","誚","諯","𧩡"}
	a[39781]={"髝"}
	a[39800]={"𣲧"}
	a[39810]={"淡","𧭢"}
	a[39820]={"濙","𣃛","𣴽"}
	a[39821]={"湫","𣴒"}
	a[39831]={"湠"}
	a[39842]={"𣺸"}
	a[39850]={"溑","談"}
	a[39851]={"𡙑"}
	a[39860]={"𧭓"}
	a[39862]={"𣹸"}
	a[39866]={"𤀬"}
	a[39874]={"瀵"}
	a[39921]={"桬","洣"}
	a[39930]={"濴","𣼓","𦀟"}
	a[39931]={"濚"}
	a[39932]={"𪓋"}
	a[39936]={"𥽲"}
	a[39940]={"瀠"}
	a[39942]={"漛"}
	a[39943]={"𣼃","𤀻"}
	a[39950]={"漴"}
	a[39952]={"潫"}
	a[39961]={"詸"}
	a[39982]={"𤂵"}
	a[40000]={"䠾","襇","襉"}
	a[40002]={"𢋽"}
	a[40003]={"襴"}
	a[40010]={"𧟉"}
	a[40015]={"襽"}
	a[40020]={"祁","邝"}
	a[40030]={"䘏"}
	a[40031]={"郍"}
	a[40040]={"邬","𨚮"}
	a[40041]={"䣌"}
	a[40050]={"裥","郋","郎","鄔","𨈕","𨜩","𨜽"}
	a[40051]={"𦨰"}
	a[40053]={"襕","郫"}
	a[40060]={"廊","鄎","鄥"}
	a[40061]={"鄓"}
	a[40062]={"𨝀","𨝧"}
	a[40063]={"谰"}
	a[40064]={"𨝎"}
	a[40071]={"廓","鄡","𨜔","𨝲"}
	a[40072]={"𨞻","𨟖"}
	a[40074]={"鄌","鄺"}
	a[40082]={"鄜"}
	a[40083]={"𢌅"}
	a[40087]={"鄘"}
	a[40090]={"𨉰"}
	a[40091]={"𨞳"}
	a[40093]={"𨞶"}
	a[40094]={"鄽"}
	a[40100]={"𢋃","𪃗"}
	a[40101]={"𢋔"}
	a[40102]={"廬","廱","麆","𢌁","𢌏","𪊤"}
	a[40104]={"䙮","𪊧","𪋇"}
	a[40105]={"𪋂"}
	a[40111]={"皨","𢌔"}
	a[40112]={"𢌄","𪊥"}
	a[40113]={"𡔏","𩐕","𪋳"}
	a[40114]={"麠","𢌐","𩵇","𪈩"}
	a[40115]={"𪋠","𪋥"}
	a[40117]={"𪋻"}
	a[40120]={"应","血","𢈀"}
	a[40130]={"㡴","𢇜","𢇹","𢨼"}
	a[40131]={"庄","庒","座","𢇦"}
	a[40140]={"","𢈵","𢨧","𢨶","𣌣","𤼿","𤽋","𤽔","𧚬"}
	a[40141]={"𢉅","𢨫"}
	a[40142]={"盘","𢉉","𢊃"}
	a[40143]={"𢇸"}
	a[40150]={"㡹","㡺","㢄"}
	a[40151]={"庢","𢈜","𢨸"}
	a[40152]={"㢈","䧹","𥂓"}
	a[40153]={"塺","𡒃"}
	a[40154]={"𤽧"}
	a[40160]={"𢨷","𤽓","𤽢","𥁬"}
	a[40161]={"廅","皇","𢉗","𢩈","𢩏"}
	a[40162]={"雇","𢉮","𢊛"}
	a[40163]={"㢆","𡏙","𢉬"}
	a[40170]={"谊"}
	a[40171]={"𢉰","𢩘","𤽫","𦤃","𦤐"}
	a[40172]={"㢕","𢉺","𢋘"}
	a[40173]={"𢋨","𧍽","𧞔"}
	a[40175]={"𢋓"}
	a[40180]={"𢩔"}
	a[40181]={"𨉗"}
	a[40182]={"𢋊"}
	a[40183]={"塵"}
	a[40184]={"廛","𩀪"}
	a[40186]={"廑"}
	a[40191]={"㢒","𪆮"}
	a[40192]={"𧟋","𪊵"}
	a[40193]={"鏖","麈"}
	a[40194]={"䴤","𢌈"}
	a[40195]={"𧑢"}
	a[40210]={"广","庎","","𢌕"}
	a[40212]={"麡"}
	a[40220]={"㡻","庈","庍","户"}
	a[40221]={""}
	a[40230]={"㢁","㢋","㣎","庐","𢈨","𢊈","𤼽","𤽃","𧖪"}
	a[40240]={"㡸","扅","𠵓","𢨳","𢨺","𦣺"}
	a[40241]={"𢇆","𤽖","𤽟"}
	a[40250]={"廖"}
	a[40251]={"𢈷","𦤒"}
	a[40252]={"𪎠"}
	a[40260]={"皍","𢋿","𢩕","𪗆"}
	a[40262]={"䙦","廝"}
	a[40270]={"䨾","𦤝"}
	a[40280]={"廫","扉"}
	a[40281]={"鼻"}
	a[40291]={"𢋛"}
	a[40292]={"靡"}
	a[40302]={"麎","𩞇"}
	a[40304]={"𧑉","𧒂","𨙕"}
	a[40305]={"𪋝"}
	a[40306]={"襼","𧒟","𨙗"}
	a[40307]={"𧅣","𧓎","𨙚"}
	a[40310]={"之","応","辶","","𢇭","𨙢"}
	a[40312]={"𪋱"}
	a[40313]={"𪋪","𪚰"}
	a[40314]={"𧒙","𧖇","𨙟"}
	a[40315]={"䘀"}
	a[40317]={"蠯","𢌆"}
	a[40320]={"⻎","㡵","広","庅","衆","𡿻","𢇗","𢇫","𢈅","𢈕","𢉭"}
	a[40321]={"庝","𢊒","𢜆"}
	a[40330]={"庡","迱","邃","","𢇝","𢈳","𢈸","𢉍","𢊔","𢙥","𢝏","𢨱","𤽡"}
	a[40331]={"㥷","恖","𤰲","𤱮"}
	a[40332]={"㡷","庶","𢉐","𢉛"}
	a[40333]={"𦳯"}
	a[40340]={"㿝","扆","良","袅","𢇨","𢘣","𣌡","𤉽","𨖃"}
	a[40341]={"䢓","悤","𠃁","𢆿","𧱋"}
	a[40342]={"㦄","麽","𢊕","𤔨","𧉌"}
	a[40343]={"遳"}
	a[40344]={"廡","𢠓","𨕷"}
	a[40350]={"㡾","㢃","息","遾","𢈫","𢉟","𦤌","𨕠","𨖺"}
	a[40351]={"㧁","𠂽","𢊧"}
	a[40352]={"䙩","麼","𢉖","𢊇","𢊭","𦳖"}
	a[40353]={"逽","𢞢"}
	a[40354]={"𪎝"}
	a[40355]={"㢘"}
	a[40357]={"廉"}
	a[40360]={"廕","逭","𢊅","𢩆","𤽎","𨖎"}
	a[40361]={"𢉝","𧚡","𨖄"}
	a[40362]={"應","麃","𦤎","𨖬"}
	a[40363]={"艨","𨕡"}
	a[40364]={"䗪","𢋙","𧑬"}
	a[40367]={"𨕤","𨘄"}
	a[40370]={"䙚","裊","𦤆"}
	a[40371]={"𨗡"}
	a[40372]={"蛗","𤾬","𧛲","𨗪","𪊘","𪊳","𪋁"}
	a[40373]={"㢜"}
	a[40374]={"懬","𢌀","𧐠","𧞼","𨘟"}
	a[40375]={"邁","𧌠","𨖋"}
	a[40377]={"𨘬"}
	a[40380]={"𢩠"}
	a[40381]={"𨘲"}
	a[40382]={"𧞯","𩞁","𪊬"}
	a[40383]={"𧌛","𨘚","𪋗"}
	a[40384]={"𧕠","𪊜","𪊱"}
	a[40385]={"螷","𢋜","𢋭","𨗨","𨘉"}
	a[40386]={"𨖷"}
	a[40390]={"𢀎","𢊜","𤿄"}
	a[40391]={"𢌍","𢣽"}
	a[40392]={"䴌","廰","爢","𪋚"}
	a[40393]={"𢌇"}
	a[40400]={"𪁨"}
	a[40402]={"麅","𩴳","𪋃","𪋅"}
	a[40403]={"𢋼"}
	a[40404]={"麙","𣯝","𪇅"}
	a[40410]={"凣","讠","龐","","𪓨"}
	a[40411]={"𢌓","𢩢","𪓝"}
	a[40412]={"廲","麑","𡦹","𢌖","𩴸","𪊕","𪋆","𪓹"}
	a[40413]={"廳","龜"}
	a[40414]={"𢌒"}
	a[40415]={"𩵉","𪋺"}
	a[40416]={"麤","𣰗","𩵄"}
	a[40420]={"凢","庀","𠒇","𢨤"}
	a[40421]={"𢇙","𥸫"}
	a[40422]={"㡲"}
	a[40430]={"庣","袉","𢇟","𢇰","𢈃","𢨩","𢩂","𥙇","𧙇"}
	a[40431]={"㡯","㡳","底","","𠒆","𢇧","𢈑"}
	a[40432]={"庞","庬","𢇚","𢇠","𢈄"}
	a[40434]={"𢈽"}
	a[40440]={"凫","庇","庛","戹","皀","皃","𠘹","𤼾","𤽇","𤽏"}
	a[40441]={"庑","舵","𢇼","𢈇","𢉚","𣄯"}
	a[40442]={"㢉","㦾","庉","廃","𡴓","𢈐","𪎒"}
	a[40443]={"𠂸","𢈗"}
	a[40444]={"㡼"}
	a[40445]={"𧜆"}
	a[40450]={"㿡","䘼","庖","鸵","𢈌","𢨪","𢨴","𤽅","𤽕","𤽨","𧚁","𧠆"}
	a[40451]={"皂","诧","𠤣","𢉕","𣩇","𣬉","𣬌"}
	a[40452]={"䴟","鬼","","𢈿","𢨹","𪎑"}
	a[40453]={"𠃼"}
	a[40454]={"襪","𢊊"}
	a[40460]={"𠒎","𢈥","𢊡","𦣾","𨈷"}
	a[40461]={"䑱","艞","𢉓","𤱖"}
	a[40462]={"廆","谎","鹿","𪎛","𪎣"}
	a[40464]={"庵","衊","麾"}
	a[40470]={"扈","皖","臰","鳧","鳬","鴕","𢊩"}
	a[40471]={"𢈶","𢊀"}
	a[40472]={"廘","麀"}
	a[40474]={"䳗"}
	a[40475]={"㐣","𩴊","𪎜"}
	a[40480]={"䳃","𢩒","𤾇","𨉝","𪂊"}
	a[40481]={"廐"}
	a[40482]={"麂","𩲸"}
	a[40484]={"魔","𧝱"}
	a[40485]={"廤"}
	a[40490]={"𪂧","𪂭","𪓑"}
	a[40491]={"𤾒"}
	a[40492]={"麍","𢋩","𩳈","𪉕","𪊍","𪊚"}
	a[40494]={"𤾐","𪊯"}
	a[40495]={"𩳸"}
	a[40501]={"𢋁","𢌂","𢌉"}
	a[40502]={"廮"}
	a[40504]={"𪋙"}
	a[40505]={"𦤛"}
	a[40513]={"麚","麛","麞","𪈙"}
	a[40514]={"𪋄","𪋹"}
	a[40515]={"鸌"}
	a[40517]={"𪋀"}
	a[40519]={"𪋜"}
	a[40521]={"𢇪","𢇯","𢨰"}
	a[40522]={"𢇘"}
	a[40523]={"𢈒"}
	a[40531]={"㡿","帍","廀","戽","𢇛","𢇮","𢈡","𢈼","𢨦","𢨮"}
	a[40532]={"庋","废","庰","","𡕩","𢇩","𢇳","𢇴","𢇷","𢈧","𢉏","𢨬","𢨭"}
	a[40533]={"𢃁","𢍄","𢍢"}
	a[40534]={"𢍍","𢍙"}
	a[40541]={"㧀","帛","皁","𢉌","𢊿","𢩄"}
	a[40542]={"䑹","庘","庠","庱","𠂂","𡢜","𢇥","𢇽","𦪁"}
	a[40543]={"卑","席","库","度","𠭛","𢋉","𢋤","𢍉","𤽒"}
	a[40544]={"𡡉","𢈔"}
	a[40551]={"廠","皐","阜","𢉊","𤽝"}
	a[40552]={"庭","皋","𢉎","𢍂","𢩑"}
	a[40553]={"㢅","庳"}
	a[40554]={"庪","犘","𢈢","𢈦","𪎙"}
	a[40555]={"𢈰","𢊋"}
	a[40556]={"𢍘"}
	a[40561]={"廄","臯","𢈹","𢋌","𢩇","𣁓","𤽮","𦤁","𦤖"}
	a[40562]={"廋","睾","𢈾","𢊤","𢩓"}
	a[40563]={"㢑","廒","慶","谉","𢈤","𢊄"}
	a[40564]={"𡢦","𤾴"}
	a[40565]={"庫","廗"}
	a[40566]={"㡽"}
	a[40571]={"㢓","廈","辠","𢋣","𢋻","𦤂"}
	a[40572]={"𢋇","𧜮"}
	a[40573]={"𢊰","𢋮","𤾁","𦗕","𦤑","𪊓"}
	a[40574]={"𢋺"}
	a[40575]={"𢉦","𢋒","𧞤"}
	a[40576]={"肁","𢋑"}
	a[40578]={"廔","𦪠"}
	a[40581]={"廏","廢","廦","𦥺"}
	a[40582]={"𢊘","𩿼","𪀋"}
	a[40583]={"廯","𢊵","𢋪","𦤓","𪊴"}
	a[40584]={"廨","黀","𪊑"}
	a[40585]={"𦪪","𨋧","𨌱"}
	a[40586]={"艧"}
	a[40587]={"皣","𢉆"}
	a[40593]={"𨉴","𩲽"}
	a[40594]={"𢋖"}
	a[40597]={"𪊩"}
	a[40600]={"𢋧","𨉾"}
	a[40602]={"譍","𧫏","𪊣","𪊨","𪊰"}
	a[40603]={"麘","𨊊"}
	a[40612]={"䴦","𪋓","𪋢","𪋦"}
	a[40613]={"麢"}
	a[40614]={"𦤬","𪋏","𪋰"}
	a[40615]={"麏"}
	a[40620]={"","",""}
	a[40621]={"囟"}
	a[40622]={"囪"}
	a[40630]={"白","𢇞","𢈁"}
	a[40631]={"囱","甶",""}
	a[40632]={""}
	a[40640]={"启","店","自","褣","𢈆","𢈈","𢊓"}
	a[40641]={"𢇵","𢇶","𢈛","𢈣"}
	a[40642]={"庙"}
	a[40650]={"扂","𢈋","𢈚","𢩅","𢩎","𧖮"}
	a[40651]={"㧂","𢉃","𢋦"}
	a[40652]={"㢖","褡","𢊠","𤽚"}
	a[40653]={"庿","𢉳"}
	a[40660]={"㢇","𢈞","𢈺","𢉩","𢉲","𤽳","𧛪","𧝡"}
	a[40661]={"䘔","廂","廇","畠","𢈪","𢈬","𢩋","𣉭","𤽙","𦪥","𨈖"}
	a[40662]={"庮","庴","磨","𢉜","𢉧","𢉷","𪎗"}
	a[40663]={"诺","𢉱","𢉻"}
	a[40664]={"唐"}
	a[40670]={"廥","𥅉","𥅕","𨉷"}
	a[40671]={"䑿","廧","𢊉","𢋢","𢋾","𦤏"}
	a[40672]={"噟","麿"}
	a[40673]={"黁","𤽻","𧜅","𪊲","𪊽"}
	a[40675]={"𢋵"}
	a[40680]={"𢊴","𩐢"}
	a[40681]={"𢋡"}
	a[40682]={"䜆","廜","𢊂","𥉵","𥛼"}
	a[40690]={"皛","𢋀"}
	a[40691]={"𢊺"}
	a[40692]={"䒇","𢋂","𣋴","𥊹","𪊪"}
	a[40693]={"䴥","麐","麔","麕","𪊦"}
	a[40700]={"𨊎"}
	a[40702]={"鷹","𢋶","𪋣"}
	a[40710]={"","","𠕉","𥤢","𦓐","𪈼"}
	a[40712]={"𢐭","𩪠","𪋎"}
	a[40713]={"麝","𦉨","𪊹","𪋕","𪋯"}
	a[40714]={"𪎮"}
	a[40720]={"庁","","𠕜","𨈏"}
	a[40721]={"府","𠬦","𡗠","𨈐"}
	a[40722]={"舟","𠂥","𠔾","𥤬"}
	a[40724]={"𠂨"}
	a[40730]={"䘢","乌","向","岛","序","鸟","","𣍝","𧖧"}
	a[40731]={"㡰","庌","𢇿","𢉀","𢨽","𢩌"}
	a[40732]={"甪","腐","","","𠕍"}
	a[40740]={"房","烏","","𠂤","𠕫","𡷊","𢇺","𢈭","𢉒","𢉵","𢊌","𢊞","𢩐","𤉱","𧖨","𨈑"}
	a[40741]={"身","𠡈","𢈊","𢊯","𢨿"}
	a[40742]={"嶴","庤","扁","𠞧","𡻤","𢇾","𢊁","𢩀","𪎕"}
	a[40743]={"𠂺","𢉨"}
	a[40750]={"㢂","㢌","㢏","峊","廁","扃","扄","肩","鳥","","𠂶","𢈂","𢈉","𢩁"}
	a[40751]={"㢊","粤","粵","𢈓","𢈯","𢊥","𢩃","𣅞"}
	a[40752]={"㡍","䒀","廌","𢉞","𢉿","𤽘","𧛩"}
	a[40753]={"𢉠","𢊢","𩃽"}
	a[40754]={"庨","庯","摩"}
	a[40760]={"⻕","㠀","㢐","䘾","島","廍","扇","𠝷","𢉂","𢉥","𦙪","𦚑","𨸏","𩾦","𩿉"}
	a[40761]={"㢎","𢈲","𢉈","𢊍","𢋥","𦠂","𩾜"}
	a[40762]={"𢊶","𩲈","𪊮","𪎔"}
	a[40763]={"庽"}
	a[40764]={"𤯎"}
	a[40765]={"𢳅"}
	a[40770]={"臱","鳸","𢉁","𦤔","𩾖"}
	a[40771]={"㢗","𢉢","𢩖","𦤍"}
	a[40772]={"䵉","廚","𢉑","𢉼","𢋚","𤾸","𤾼","𧝶","𧞶","𪎧","𪙱"}
	a[40773]={"𢉋"}
	a[40774]={"𤯌","𪎪"}
	a[40775]={"𢊏","𥜍"}
	a[40777]={"庸"}
	a[40778]={"𤽛"}
	a[40780]={"䠻"}
	a[40782]={"䳸","膺","鹰","𢋄","𪊫","𪎩"}
	a[40783]={"𪋉"}
	a[40784]={"襺","𥜲","𪊗"}
	a[40790]={"𨊓"}
	a[40792]={"䯢","廟","𢳁","𦤥","𪊒"}
	a[40793]={"㢚","𪊛"}
	a[40794]={"𩦵"}
	a[40796]={"𥜴","𧟑"}
	a[40797]={"㢙"}
	a[40800]={"𨊕"}
	a[40801]={"𤾪"}
	a[40802]={"𪎬"}
	a[40803]={"㢞","麌"}
	a[40810]={"庂","𢉘","𢊽"}
	a[40812]={"軉","𨇭","𪋮"}
	a[40813]={"𪋧"}
	a[40814]={"𪋬","𪎯"}
	a[40820]={"㡱","㢔","扊","袕","𢇣","𢨨"}
	a[40821]={"庆","焤","𢈙","𢉸","𢊝"}
	a[40830]={"㒵","㡶","𢉄","𤽈"}
	a[40831]={"戻","戾","𢇻","𢉇","𢨾","𧛗"}
	a[40832]={"奥","奧","庻","𢈎","𢉙","𪎖"}
	a[40833]={"䄏","𡘻"}
	a[40840]={"䘺","臮","𢊚","𢊦","𦤈","𧜬"}
	a[40841]={"㚖","𢈟","𢈩","𢉡","𢨻","𤽬","𧛒","𧜕"}
	a[40842]={"𢈮","𢉶","𦩤"}
	a[40843]={"𡘠","𢈏"}
	a[40844]={"㢍","庚"}
	a[40850]={"庼","𠔙","𢋐"}
	a[40851]={"庾","廞","臭","𢊐","𦤀","𦩘"}
	a[40852]={"庹","𢋗"}
	a[40853]={"𤒐"}
	a[40854]={"赓","𪎞"}
	a[40860]={"㢛","鴥","𢉴","𢊼","𢋅","𤒝"}
	a[40861]={"","𢉯","𢊾"}
	a[40862]={"𢋲","𨄬"}
	a[40863]={"廙","𢊗"}
	a[40864]={"廣"}
	a[40865]={"𢈻"}
	a[40870]={"𢊎","𢊟","𢋆","𢋞"}
	a[40871]={"𢊹"}
	a[40872]={"𢋍"}
	a[40873]={"䴠","谟","𢊱","𪊏"}
	a[40880]={"廎"}
	a[40882]={"𢊮","𪊻"}
	a[40883]={"𢊷","𪊢"}
	a[40884]={"䙭","賡","𪊐"}
	a[40890]={"𢋫"}
	a[40892]={"㸏","𧸛","𪎫"}
	a[40893]={"廭","𢋷","𢋸","𪋐"}
	a[40895]={"黂"}
	a[40902]={"𪋈","𪋔"}
	a[40903]={"𢌑"}
	a[40905]={"麜","𪋊"}
	a[40910]={"灥","礻","衤"}
	a[40912]={"䴪","𪋵"}
	a[40914]={"䴩"}
	a[40920]={"永","𢇤"}
	a[40921]={"床","庥","庲","𢇲","𢈍"}
	a[40930]={"𢉔","𤽄"}
	a[40931]={"㦿","庩","庺","枭","𢈝","𤲄"}
	a[40932]={"㢀","麻","𡮰","𢊆"}
	a[40933]={"㭧"}
	a[40940]={"䋀","泉","𢈴","𦣿"}
	a[40941]={"𢉣","𢉹","𢊖","𣐩","𣒷"}
	a[40943]={"穈","糜","𢈠","𢊲"}
	a[40950]={"𣳻"}
	a[40951]={"䑸","臬","𢉪","𣓯"}
	a[40952]={"縻","𢉤","𢋎"}
	a[40953]={"𢊨","𪎭"}
	a[40954]={"康","𪎦"}
	a[40955]={"𢊪","𥹺"}
	a[40960]={"𢊻","𤀁","𧞍"}
	a[40961]={"䲷","梟","𢊸"}
	a[40962]={"㢝","𢊣"}
	a[40965]={"𢉫"}
	a[40966]={"𢋰","𧝵"}
	a[40970]={"𢊬","𣹻","𤂼"}
	a[40971]={"廩","𢋏","𦤗"}
	a[40972]={"𢋈","𢋹"}
	a[40973]={"䴢","緳","麇","麋","𢊳","𢋝"}
	a[40980]={"廪","𢋕"}
	a[40982]={"𦄐"}
	a[40983]={"𢋟","𪋩"}
	a[40987]={"𢌋"}
	a[40990]={"𤿁"}
	a[40992]={"麖"}
	a[40994]={"𪂝"}
	a[40998]={"𢋯"}
	a[41101]={"曁","𧞁"}
	a[41102]={"躽","𥜠","𦫄","𧝿"}
	a[41110]={"䳼","軀"}
	a[41111]={"䄥","𤿅","𧟙","𪖩"}
	a[41112]={"齇","𦫊","𧟂","𨊑","𪈒","𪖣"}
	a[41113]={"皬","艫","𪗁"}
	a[41130]={"𥘻","𧘲"}
	a[41140]={"祉","讧","让","诬","𥘺","𥙠","𧘍","𧘛","𧘿","𧙸"}
	a[41141]={"舡","讴","𥘛","𥙛"}
	a[41150]={"䄈","裋","证","𥘡","𥘹","𧘢","𧙅"}
	a[41151]={"䑭","䘭","祬"}
	a[41152]={"诳"}
	a[41156]={"𥜦"}
	a[41160]={"讵","𠃂","𣦑"}
	a[41161]={"躯","𥛳","𦨝","𧝔"}
	a[41162]={"褗"}
	a[41163]={"禋","𧛑"}
	a[41170]={"𣦘","𩾬","𪀇"}
	a[41171]={"诓","��"}
	a[41172]={"𥛡","𦪡"}
	a[41173]={"","𦪾"}
	a[41180]={"𨸿","𪀤"}
	a[41181]={"𦩒","𦪍"}
	a[41182]={"㿨","墍"}
	a[41186]={"𤿂"}
	a[41190]={"䙔","𪀏"}
	a[41191]={"𡒴","𡒿","𥛜","𪀒"}
	a[41192]={"谑","軅","𨊛"}
	a[41201]={"𥜸"}
	a[41210]={"𪁹"}
	a[41230]={"𥘕","𥙺"}
	a[41241]={"䑰","𦨘"}
	a[41251]={"舻"}
	a[41270]={"裶"}
	a[41280]={"诽"}
	a[41281]={"𦩋"}
	a[41290]={"𤾅"}
	a[41291]={"䙣"}
	a[41292]={"𪊔"}
	a[41301]={"𤾨","𨖜","𨗠"}
	a[41302]={"䢮","𨙤"}
	a[41310]={"𨊘"}
	a[41312]={"邐"}
	a[41313]={"䴫","𨘾","𨙓"}
	a[41320]={"䢋","辷","还","逐","𥙮","𨑜"}
	a[41330]={"迈","𧖹","𨑭","𨒩","𨓃"}
	a[41331]={"诼","迀","迂","迊","迓","迗"}
	a[41332]={"䢎"}
	a[41335]={"邇"}
	a[41340]={"裃","迃","运","远","迠","逕","逦","𥘟","𥘢","𧘾","𨑼","𨒌","𨒙","𨔀","𨔟"}
	a[41341]={"迋"}
	a[41342]={"逛","𨒿","𨓘"}
	a[41350]={"祳","裖","逗","遯","𨑵","𨒎","𨒑"}
	a[41351]={"𦨠","𨒬","𨓷","𨔁"}
	a[41352]={"迺","遤"}
	a[41354]={"䢚","𨔰","𨕞"}
	a[41360]={"逌","遉","𨓗","𨔖","𨔞","𨖸","𨘷"}
	a[41361]={"逜","逴","遽","𥜅","𧝲","𨓊"}
	a[41362]={"逎","𨕑","𨗢","𨘸"}
	a[41363]={"𨗆","𨗇"}
	a[41367]={"𧟐"}
	a[41370]={"䢝","𨓿","𨕐"}
	a[41371]={"逼","𤑏","𨔛","𨕸","𨕹","𨖝"}
	a[41372]={"𥜜","𨘹"}
	a[41373]={"𨖢","𨙦"}
	a[41380]={"䢥","躼"}
	a[41381]={"䙥","𨗺"}
	a[41383]={"遷"}
	a[41384]={"𨉼"}
	a[41387]={"𧟚"}
	a[41391]={"𨖆","𨖻","𨘀","𨼽","𩞚"}
	a[41392]={"𦪩","𨕿","𨖛","𨖹"}
	a[41393]={"𧏍","𨘈","𨙆"}
	a[41395]={"𦫆"}
	a[41397]={"𨙔"}
	a[41401]={"䳖","鼿"}
	a[41402]={"䫥","𩳤"}
	a[41403]={"魖","𩳌"}
	a[41404]={"㼺","魒"}
	a[41410]={"䡁","襱"}
	a[41411]={"齀","𦪽"}
	a[41412]={"㼾","襹","𥜰","𪈳"}
	a[41413]={"䰧","𩴶","𩵁"}
	a[41414]={"𩴘"}
	a[41415]={"𩳯"}
	a[41417]={"𤮇"}
	a[41430]={"𡨍","𥘳"}
	a[41441]={"䑢","𦨞"}
	a[41451]={"𥙤"}
	a[41452]={"𡪮"}
	a[41461]={"𤭂"}
	a[41462]={"𩳟"}
	a[41470]={"㼟"}
	a[41471]={"旣","裭","𡰈","𥚚"}
	a[41472]={"䰢","𩲑","𩲬","𩲹"}
	a[41473]={"魎"}
	a[41474]={"魉"}
	a[41480]={"𤭒"}
	a[41481]={"𧜳"}
	a[41482]={"甂","𦩕","𩲦","𩳍"}
	a[41483]={"㼰","褼","𣯦","𩳨"}
	a[41484]={"𤮢","𩳭"}
	a[41491]={"甈","𤭟","𤽾"}
	a[41493]={"𩲼","𩳀","𩳰"}
	a[41494]={"𤮊","𩥢"}
	a[41495]={"𩳹"}
	a[41502]={"鼾","𢿎"}
	a[41504]={"𣀯"}
	a[41511]={"鶳"}
	a[41513]={"襵","𨊈","𨊞"}
	a[41531]={"衦","𢄘","𥘏","𥘴"}
	a[41541]={"讦","评","𢻻"}
	a[41542]={"𦨗","𦨫","𧙒"}
	a[41551]={"𢾓","𢿉","𤽂","𤽐","𥙟","𧙫"}
	a[41552]={"㪐","𧙧"}
	a[41553]={"𧚂","𪎘"}
	a[41554]={"䙅","𥙴"}
	a[41561]={"師","衈","𨈙"}
	a[41562]={"𦫍","𧛓"}
	a[41564]={"㪏","𢾖"}
	a[41571]={"𧜂","𩾝","𩿐"}
	a[41572]={"䑲"}
	a[41573]={"𡠋"}
	a[41575]={"𧞝"}
	a[41578]={"𣀃"}
	a[41581]={"𢾥","𥜚"}
	a[41582]={"𢾱","𪀺"}
	a[41583]={"禫","𧝓"}
	a[41585]={"𣀫"}
	a[41591]={"𨉔"}
	a[41593]={"谭","𢿇"}
	a[41597]={"𦘟"}
	a[41602]={"𧝆"}
	a[41610]={"𨊚"}
	a[41611]={"𤾻","𥜧","𪖚"}
	a[41612]={"谮","𦫃"}
	a[41613]={"𪋶","𪖼"}
	a[41640]={"祏","袥","袩"}
	a[41642]={"𥙘"}
	a[41650]={"袹","𧮪"}
	a[41662]={"𥙫"}
	a[41663]={"舾"}
	a[41671]={"福","褔","语"}
	a[41682]={"𦩡"}
	a[41690]={"𨉥"}
	a[41691]={"𥛽"}
	a[41704]={"艣"}
	a[41713]={"𪎱"}
	a[41730]={"袻","裄","订"}
	a[41731]={"衧","裲","𦨍","𧘪"}
	a[41735]={"禰","襧"}
	a[41740]={"袔","𥘫","𧘚"}
	a[41741]={"讶","","𦨵"}
	a[41750]={"诃"}
	a[41751]={"舸","鿅"}
	a[41752]={"禡"}
	a[41754]={"𥚳"}
	a[41760]={"䙐","褃"}
	a[41761]={"褥","𥛑"}
	a[41762]={"𩢉"}
	a[41771]={"𤾖","𦜹","𧗈"}
	a[41772]={"艝","𦟡","𧗌"}
	a[41780]={"鴚","𨉿","𩾳"}
	a[41782]={"𨉸"}
	a[41784]={"騗"}
	a[41785]={"禲"}
	a[41791]={"襦","𥜗"}
	a[41792]={"鷌","𥜯"}
	a[41793]={"𢵿"}
	a[41800]={"顅","𩔦","𩔨"}
	a[41801]={"襭","顊","𥜝","𨇐","𩕍"}
	a[41802]={"䫧","𩕜"}
	a[41810]={"䫵","禵","","𩕰","𩖆"}
	a[41811]={"𩔇","𩔙","𩕎","𩕬"}
	a[41812]={"顧","𤾶","𩔴"}
	a[41830]={"祯"}
	a[41831]={"祆"}
	a[41840]={"褷","𥛨","𧚺"}
	a[41841]={"䙇"}
	a[41851]={"䙠"}
	a[41860]={"禎","𥚴"}
	a[41862]={"𦪘"}
	a[41870]={"𥛌","𩒯"}
	a[41871]={"䪿","𤑐","𩒩","𩔢"}
	a[41880]={"","𩑻"}
	a[41881]={"顖","𦩼","𩔅"}
	a[41882]={"禷","𩔶","𩔼"}
	a[41890]={"䫁","頧"}
	a[41891]={"𥜒","𧞣","𩕄","𩕅"}
	a[41893]={"䫌"}
	a[41911]={"𪆫"}
	a[41930]={"衃"}
	a[41950]={"𠂾"}
	a[41962]={"褾","𥛦"}
	a[41971]={"𥼒"}
	a[41982]={"𤾛"}
	a[41992]={"䴨"}
	a[42020]={"训","𥘊"}
	a[42050]={"𩾧"}
	a[42060]={"䄗","裫"}
	a[42070]={"𨈧"}
	a[42091]={"鼼"}
	a[42101]={"𪖛"}
	a[42105]={"𨉢"}
	a[42116]={"𥜨","𥜪"}
	a[42130]={"𥙂"}
	a[42131]={"祍","衽","袵"}
	a[42141]={"𥙲"}
	a[42160]={"䙞","𨈬"}
	a[42171]={"艠"}
	a[42175]={"褈"}
	a[42180]={"𤾢"}
	a[42185]={"𨉡"}
	a[42191]={"𨉉"}
	a[42210]={"衫","𥘎"}
	a[42220]={"祈","","𢒋"}
	a[42221]={"䑣"}
	a[42230]={"䜣"}
	a[42240]={"㣐","𤽆"}
	a[42242]={"㫂"}
	a[42250]={"𣂞"}
	a[42254]={"𢒹"}
	a[42261]={"𥛻"}
	a[42262]={"𧝤"}
	a[42272]={"𦪟"}
	a[42277]={"㣑"}
	a[42301]={"𨙑"}
	a[42310]={"巡","𨑝","𨑠","𨓌"}
	a[42317]={"𧖕"}
	a[42320]={"近","𥙎","𧙆","𨑎","𨑾","𨒢","𨖡"}
	a[42321]={"迁","返"}
	a[42330]={"衇","迾","逃","𤔚","𨒂","𨔜","𨔭"}
	a[42331]={"䢑","𨑳","𨒰","𨓮"}
	a[42332]={"𨔩","𨕗"}
	a[42333]={"逶"}
	a[42340]={"逅","𨒤","𨖿"}
	a[42341]={"适","透","遥","𨒥","𨓎"}
	a[42342]={"逝","𨑺","𨔄","𨔅"}
	a[42343]={"逓"}
	a[42350]={"𨓁","𨓬","𨖾"}
	a[42351]={"遜","邋","𨓈"}
	a[42352]={"㼐","䢬","逬","𤋞","𧊢","𨓛","𨖐","𨖠","𨖣","𨖦","𨗩"}
	a[42353]={"𨕘"}
	a[42355]={"𨔠"}
	a[42360]={"邆","𨓖","𨓯","𨕥","𪀐"}
	a[42361]={"遁","𨔨","𨙂","𩜸"}
	a[42362]={"𨓱"}
	a[42363]={"𨗂"}
	a[42364]={"䙧"}
	a[42370]={"𧞎","𧞞","𨖳","𨘁","𨘓","𪁯"}
	a[42371]={"䢪","遞","𨘺"}
	a[42372]={"𨕧","𨗙"}
	a[42375]={"𨔝"}
	a[42380]={"𨗰","𨙣"}
	a[42381]={"𢠾"}
	a[42390]={"邎"}
	a[42391]={"𨙃"}
	a[42400]={"𨸷"}
	a[42401]={"𪖑"}
	a[42402]={"𩴝"}
	a[42403]={"𪅹"}
	a[42405]={"魕"}
	a[42410]={"𥘍"}
	a[42411]={"鷈","齆"}
	a[42412]={"𣬖","𩴋"}
	a[42415]={"䶰"}
	a[42416]={"𨊉"}
	a[42417]={"𩴂"}
	a[42420]={"礼","𥘇"}
	a[42421]={"讬"}
	a[42430]={"祧"}
	a[42431]={"祇","祗","衹","袛","𦨊","𦪴","𧘐"}
	a[42432]={"䙍"}
	a[42440]={"䃾","䘣","癿"}
	a[42441]={"䑬","诋"}
	a[42442]={"𣮯","𦨎","𦨢"}
	a[42450]={"臫","𩾐"}
	a[42451]={"舭","𣬈","𤽪","𧞪"}
	a[42452]={"鬽"}
	a[42460]={"䠷","皉","𤽊","𥛟","𧜇","𩾙"}
	a[42461]={"𧚊"}
	a[42462]={"㿞","鬿","𣭺"}
	a[42463]={"禨","𧝞","𩲓","𩲔","𩲷","𩳡"}
	a[42464]={"𩳕"}
	a[42468]={"𣭣"}
	a[42470]={"褦","𨈚"}
	a[42471]={"䲬","禠","褫","𪀍"}
	a[42472]={"𨈥"}
	a[42473]={"𩲒","𩳎"}
	a[42474]={"㲢"}
	a[42476]={"𣮒"}
	a[42483]={"𩳂"}
	a[42484]={"𩲊"}
	a[42491]={"𪖐"}
	a[42496]={"㲥"}
	a[42511]={"𧟗"}
	a[42514]={"𪊶"}
	a[42521]={"𧘜","𧙝"}
	a[42531]={"诉","𧚯"}
	a[42532]={"舨","𥚾","𧛝"}
	a[42541]={"皈"}
	a[42542]={"禐","褑","𧜋"}
	a[42543]={"艐","诿","𧚜"}
	a[42551]={"䘰","𠭔","𦤇"}
	a[42552]={"谖"}
	a[42553]={"𦩮"}
	a[42561]={"皧","诞"}
	a[42563]={"艇","躷"}
	a[42581]={"襏"}
	a[42582]={"𨉈"}
	a[42583]={"𪁦"}
	a[42592]={"𦪑"}
	a[42595]={"䴧"}
	a[42640]={"𥙐","𧙺"}
	a[42641]={"䄆","𥚉"}
	a[42650]={"诟"}
	a[42651]={"䄕","话","𥙱"}
	a[42652]={"襎","𥛮","𦨯"}
	a[42653]={"𧚎"}
	a[42660]={"诣"}
	a[42661]={"䄑","䙉"}
	a[42663]={"𦪖"}
	a[42670]={"𠻡","𥚺","𧚻"}
	a[42671]={"𦧗","𦩽","𨈸"}
	a[42672]={"皤","𦧠"}
	a[42680]={"谐","𣊆"}
	a[42681]={"𦧰"}
	a[42690]={"𣊅"}
	a[42701]={"皭"}
	a[42710]={"𠚳"}
	a[42720]={"𠜄"}
	a[42721]={"𠜢","𠝠","𦨉"}
	a[42730]={"𠛆","𠝡","𧙷"}
	a[42731]={"讻","𠜺","𥚀","𧝉"}
	a[42732]={"𠞥"}
	a[42740]={"剆","𠞆","𧙮"}
	a[42741]={"𥙾"}
	a[42742]={"㓲","艀","𧘧"}
	a[42743]={"剫","𠜱","𥚲","𧚳"}
	a[42751]={"㓷","诱","谣"}
	a[42752]={"𠠣","𦩾"}
	a[42753]={"䄔"}
	a[42754]={"𠠒","𪎚"}
	a[42757]={"劆"}
	a[42760]={"禙","𠞛","𤾡"}
	a[42761]={"䙄","𠞇","𦩹","𨺀"}
	a[42762]={"𧝼"}
	a[42763]={"割"}
	a[42764]={"𠠎"}
	a[42770]={"褙","𪘷"}
	a[42771]={"𡭎"}
	a[42773]={"𦩿"}
	a[42780]={"𥛃"}
	a[42781]={"劓"}
	a[42782]={"𤿃","𦪞"}
	a[42783]={"䴣"}
	a[42790]={"𤾽"}
	a[42792]={"劘"}
	a[42814]={"𪋡 "}
	a[42815]={"𨊝"}
	a[42821]={"祅","袄"}
	a[42840]={"𨉒"}
	a[42841]={"䙆","䙎","𥛎"}
	a[42851]={"𥛕"}
	a[42852]={"襆","襥","𦩶"}
	a[42871]={"𥛺"}
	a[42872]={"𤾣"}
	a[42881]={"䳶","𨉊"}
	a[42883]={"䙫"}
	a[42893]={"𥜥"}
	a[42910]={"氷","𧘷"}
	a[42911]={"皪"}
	a[42912]={"𤾾"}
	a[42914]={"𪋫"}
	a[42920]={"𣲈"}
	a[42921]={"𥚖"}
	a[42930]={"𧚃"}
	a[42931]={""}
	a[42940]={"𧞑"}
	a[42941]={"𥡻"}
	a[42951]={"𠃆"}
	a[42961]={"緜"}
	a[42972]={"𤾧","𥠟"}
	a[43010]={"䃼","补","𥘚"}
	a[43020]={"讣"}
	a[43021]={"祕","袐"}
	a[43030]={"䘐"}
	a[43052]={"褂"}
	a[43100]={"䄠","襢"}
	a[43106]={"𩀛"}
	a[43110]={"䡀"}
	a[43111]={"𡬗"}
	a[43113]={"𪆏","𪖿"}
	a[43130]={"𥘸","𧙀"}
	a[43141]={"𥘭"}
	a[43151]={"谧"}
	a[43152]={"𥂏","𥂐","𧚮"}
	a[43160]={"䠴"}
	a[43162]={"谁"}
	a[43163]={"𦩏"}
	a[43171]={"𨈫"}
	a[43172]={"𤽼","𦩓"}
	a[43173]={"𦪉"}
	a[43182]={"𧝸"}
	a[43183]={"𧝎"}
	a[43185]={"𨿵"}
	a[43186]={"𨿶"}
	a[43192]={"鵻","𨿱"}
	a[43193]={"𤪉","𩀹"}
	a[43194]={"䙰","艟"}
	a[43210]={"𥜭"}
	a[43240]={"襂","谚"}
	a[43250]={"𧗋"}
	a[43260]={"䄢","𧞓"}
	a[43271]={"艩"}
	a[43300]={"邅"}
	a[43302]={"𨘿"}
	a[43304]={"禳","𧟄"}
	a[43305]={"𨘙"}
	a[43310]={"𨘔"}
	a[43312]={"𧟞"}
	a[43320]={"迯","迹","𧙡"}
	a[43321]={"䢒","迖","这","述","𨒜"}
	a[43330]={"䢍","遃","𨑑","𨒨"}
	a[43331]={"逑","逡","𨑫","𨒳"}
	a[43332]={"䢕","䢤","𨒋"}
	a[43340]={"袨","迒","迨","遪","𢞤","𥙆","𧛅","𨒴","𨓞","𨗘"}
	a[43341]={"迬","逘","遆","𨓫","𨕍"}
	a[43342]={"𨓋"}
	a[43350]={"䙛","𨘆"}
	a[43351]={"舷","𢩞","𦪜"}
	a[43352]={"進","𥛲","𧚴","𧝈","𧞰","𨖵"}
	a[43354]={"逋"}
	a[43360]={"這","逳","𥜇","𧞷","𩾽"}
	a[43361]={"䢦","適","𨗁"}
	a[43362]={"䙑","谯"}
	a[43364]={"𨗗"}
	a[43370]={"𧝘","𨕕","𨘰"}
	a[43371]={"遧","𢤊","𤾤","𦪳","𧝯","𨕢"}
	a[43373]={"𨖱","𨗑"}
	a[43375]={"𨘛"}
	a[43376]={"𨕝"}
	a[43381]={"避"}
	a[43392]={"𪆄"}
	a[43402]={"谶","𧪵"}
	a[43403]={"𧞬","𩴐"}
	a[43413]={"𪗃"}
	a[43421]={"䘝","𥘒","𥙜"}
	a[43422]={"䄀","𧘵","𧙠"}
	a[43432]={"𦨒","𦨮"}
	a[43433]={"䘬","𦨜","𦨷"}
	a[43434]={"䄉","䙁","祴","裓","","𧚄"}
	a[43440]={"䘪","裗"}
	a[43441]={"𧙢"}
	a[43442]={"䙘","诚","𧚑","𧛠"}
	a[43443]={"","𢧊","𦨩","𧚶"}
	a[43444]={"诫"}
	a[43445]={"𦩆"}
	a[43451]={"航","艈","试","𨈣"}
	a[43452]={"𠶶","𤽷","𦩐","𧛡","𨈟","𩱻","𪉇"}
	a[43453]={"𦪊"}
	a[43454]={"皒"}
	a[43455]={"𦩬"}
	a[43460]={"䦾"}
	a[43461]={"鴏"}
	a[43462]={"𧖻","𧝊"}
	a[43463]={"𦩢","𩲻"}
	a[43464]={"𧞩","𩲭"}
	a[43470]={"𨈢"}
	a[43472]={"𨹇","𩲠","𩿠","𪁒"}
	a[43473]={"𩳞","𪀚"}
	a[43474]={"䳘","魃","魆"}
	a[43475]={"𧞛"}
	a[43476]={"𢧪"}
	a[43481]={"𪀸"}
	a[43482]={"𩲥","𩴑"}
	a[43484]={"艥"}
	a[43486]={"襶"}
	a[43489]={"𢧳"}
	a[43492]={"襳","軄"}
	a[43494]={"魊","魋","魑","𩴁","𩴧"}
	a[43496]={"𩳐"}
	a[43503]={"𪄩"}
	a[43508]={"𦘥"}
	a[43511]={"𪇊","𪇷"}
	a[43512]={"𪖰","𪖶"}
	a[43513]={"𪋟"}
	a[43516]={"艭"}
	a[43521]={"䘨"}
	a[43531]={"䘸","䘹","祽","𥙅","𥚂","𧚉"}
	a[43532]={"祓","袚","袯"}
	a[43541]={"䘒","皎","禘","褅","谇"}
	a[43542]={"𦩇","𧚪"}
	a[43551]={"谛","𤽭"}
	a[43561]={"𧜠","𪁉"}
	a[43562]={"𧞠","𨈩"}
	a[43571]={"鵔","𧜰"}
	a[43572]={"䳁"}
	a[43573]={"𦤚"}
	a[43574]={"䑾","𪊝"}
	a[43581]={"𧞃","𨐳"}
	a[43583]={"𪊙"}
	a[43588]={"肈"}
	a[43593]={"𪋌"}
	a[43603]={"𪊺"}
	a[43640]={"𥙉"}
	a[43650]={"诒"}
	a[43651]={"𧖼"}
	a[43652]={"啔"}
	a[43660]={"𥚱"}
	a[43661]={"𦩜","𧝐"}
	a[43670]={"谙"}
	a[43671]={"䙒"}
	a[43672]={"䁉"}
	a[43680]={"𩿡"}
	a[43701]={"𪂎"}
	a[43712]={"𪆳"}
	a[43730]={"祊"}
	a[43740]={"访","𢨲"}
	a[43741]={"舫"}
	a[43750]={"䄘"}
	a[43752]={"䄜","褵"}
	a[43754]={"補","𥙷"}
	a[43760]={"䘻","谤"}
	a[43761]={"䙗","艕","𥚠","𥛚","𦨾"}
	a[43764]={"𧛥"}
	a[43765]={"䙏","禣"}
	a[43770]={"䲱","禞"}
	a[43771]={"谆","谪","𪁷"}
	a[43790]={"皜","𨉬"}
	a[43792]={"𧗔"}
	a[43794]={"𪁭"}
	a[43821]={"袱"}
	a[43832]={"𦨚"}
	a[43840]={"该"}
	a[43841]={"𤝡"}
	a[43851]={"诶"}
	a[43852]={"𦩈"}
	a[43860]={"䠹"}
	a[43861]={"𤟀","𩿁"}
	a[43871]={"𤟵","𤠊","𤠩"}
	a[43872]={"䙯"}
	a[43873]={"谳","𤡵"}
	a[43890]={"𢩡"}
	a[43921]={"䘤","𥙹"}
	a[43931]={"𥛫"}
	a[43941]={"𧚦"}
	a[43943]={"𣗆"}
	a[43950]={"谅"}
	a[43952]={"䋯"}
	a[43963]={"襍","𣙅"}
	a[44101]={"𨉤"}
	a[44130]={"裇"}
	a[44152]={"𦨺"}
	a[44170]={"䙋","躻"}
	a[44171]={"䄓"}
	a[44182]={"艎"}
	a[44191]={"𦪯"}
	a[44192]={"𦤤","𦪄"}
	a[44201]={"𧗗"}
	a[44211]={"𦤫"}
	a[44240]={"𢨯"}
	a[44280]={"𢩝"}
	a[44291]={"襣"}
	a[44300]={"𪄛"}
	a[44305]={"𨙡"}
	a[44320]={"𨓩"}
	a[44330]={"𨒆","𨕦","𨖼"}
	a[44331]={"䢘","𨓀"}
	a[44340]={"迫","逈"}
	a[44342]={"遮","𧜥","𨓍"}
	a[44350]={"追","邈","𧚅","𨓅"}
	a[44351]={"𧜢","𨓉","𨕾"}
	a[44352]={"遍","𢡔"}
	a[44361]={"艆"}
	a[44362]={"𥛪","𨖥"}
	a[44371]={"遑","𨕙"}
	a[44372]={"𧞧"}
	a[44380]={"躴","邉","邊","𨖂","𨘃","𨘢"}
	a[44382]={"𧞱"}
	a[44392]={"皫","軈"}
	a[44397]={"𦤩"}
	a[44401]={"䳹"}
	a[44411]={"𪕿","𪖻"}
	a[44412]={"𩙾"}
	a[44414]={"𩴡"}
	a[44419]={"𩴔"}
	a[44430]={"𥘆"}
	a[44441]={"舧"}
	a[44450]={"𧚷"}
	a[44460]={"𤾂"}
	a[44472]={"𤾝","𥛞"}
	a[44474]={"𩳉"}
	a[44481]={"𢅉"}
	a[44482]={"魄"}
	a[44483]={"𦪇"}
	a[44491]={"𨉮","𪄺"}
	a[44492]={"𨉵"}
	a[44494]={"𩴄"}
	a[44495]={"䰦"}
	a[44512]={"𨽪"}
	a[44513]={"𤾲"}
	a[44532]={"𥙔"}
	a[44551]={"𢂨"}
	a[44553]={"禆","裤","裨","褯"}
	a[44562]={"艊"}
	a[44564]={"艔","𦩖"}
	a[44571]={"𤾍"}
	a[44573]={"𤽹","𦪅"}
	a[44575]={"褲"}
	a[44581]={"皡"}
	a[44582]={"皞","𤾎"}
	a[44591]={"皥"}
	a[44593]={"𪂃"}
	a[44604]={"𡫲"}
	a[44613]={"𥜢"}
	a[44615]={"𥜮"}
	a[44640]={"袙","𥙃"}
	a[44651]={"舶","𥚰"}
	a[44660]={"㿟"}
	a[44661]={"𥚽"}
	a[44674]={"禟"}
	a[44680]={"𢩙","𨈻"}
	a[44685]={"𦪀"}
	a[44700]={"鵳","𪃼","𪅝"}
	a[44701]={"鷍"}
	a[44702]={"鷎","𪈠"}
	a[44710]={"","𪆹","𪇣","𪈄","𪈨","𪈬"}
	a[44711]={"䳨","鷱","𪄆","𪄜","𪈪"}
	a[44712]={"𨼱","𨽴","𪇛"}
	a[44713]={"𪖯"}
	a[44714]={"鶶","𨽄","𪇮","𪇵"}
	a[44716]={"𨽝"}
	a[44717]={"鷛","𪅟"}
	a[44718]={"𨽩"}
	a[44740]={"𧙹"}
	a[44741]={"舮"}
	a[44742]={"𦨤"}
	a[44750]={"𥙢","𥛊"}
	a[44751]={"裑","鸼","𥚟"}
	a[44752]={"褊","𥚹"}
	a[44757]={"𦨸"}
	a[44760]={"𧜣"}
	a[44761]={"𥜊","𧞄","𪉉"}
	a[44762]={"谝","鹧"}
	a[44763]={"艑"}
	a[44770]={"鴧","𩿇"}
	a[44771]={"䑷","鵃","鶐","𪁱","𪂸"}
	a[44773]={"鹎"}
	a[44774]={"鹒","𦪤"}
	a[44780]={"䳆","鶎","𪄑"}
	a[44781]={"𪁈","𪂑"}
	a[44782]={"䴈","鷓"}
	a[44790]={"鴭","鵢","𤾜","𪁜","𪁤","𪄝","𪉓"}
	a[44791]={"𨻑","𪁼","𪉔"}
	a[44792]={"鶣"}
	a[44793]={"鵯","𪃒"}
	a[44794]={"鶊"}
	a[44812]={"齅"}
	a[44842]={"襖","𥜌"}
	a[44854]={"𥚏"}
	a[44861]={"𥛩"}
	a[44870]={"𨉍"}
	a[44871]={"𨉕"}
	a[44872]={"𦤟"}
	a[44874]={"𥜟"}
	a[44910]={"𤆁"}
	a[44940]={"䘑","𣴏","𥚎"}
	a[44941]={"𦨬"}
	a[44971]={"𤾏"}
	a[44981]={"𤾚"}
	a[44994]={"躿"}
	a[45021]={"议","𧘞"}
	a[45022]={"舣","𥘥"}
	a[45031]={"计"}
	a[45032]={"𧘬"}
	a[45041]={"𣂁","𤽁"}
	a[45092]={"𪖘"}
	a[45111]={"𪆖"}
	a[45112]={"齄"}
	a[45113]={"𨊆","𪖢"}
	a[45117]={"𩴴"}
	a[45131]={"社"}
	a[45132]={"𥘠","𥚐"}
	a[45141]={"袏","𥙀"}
	a[45142]={"𥙭"}
	a[45143]={"䄁","袣"}
	a[45151]={"䀅"}
	a[45152]={"袿","𥙞","𥚊"}
	a[45161]={"𥚧","𥛐","𧛾"}
	a[45162]={"诖","𥚮"}
	a[45171]={"禃"}
	a[45172]={"谌","𧗀"}
	a[45173]={"禥"}
	a[45184]={"𦪆","𪊟"}
	a[45192]={"𨻏","𪂚"}
	a[45196]={"谨"}
	a[45266]={"𧜩"}
	a[45271]={"𥛄"}
	a[45301]={"𨙜"}
	a[45309]={"𨘪"}
	a[45311]={"𨘴"}
	a[45314]={"𨘫"}
	a[45317]={"𧟘"}
	a[45318]={"齉","𨙠"}
	a[45321]={"䢏","辻","达","过","迏","逨","𧘹","𨒏","𨒭"}
	a[45322]={"𨑞","𨒉"}
	a[45331]={"䄊","","𥙼","𨑒","𨑿"}
	a[45332]={"䢌","䢞","舦","迭","𧙄","𨑤","𨑬","𨒘","𨒪","𨒱","𨒲","𨓣"}
	a[45333]={"𨒍","𨓇"}
	a[45334]={"进"}
	a[45341]={"祛","袪","迲","选","逺","𨒐"}
	a[45342]={"迍"}
	a[45343]={"违","连","迣","速","𨓄","𨔘","𨔱"}
	a[45344]={"逩"}
	a[45351]={"迶","迼","造","遠","遼","𨓳","𨓾","𨔙","𨖚"}
	a[45352]={"裱","逵","逹","遖","𨔴","𨖑"}
	a[45353]={"裢","𧜦","𨓸","𨔬","𨔶","𨔽"}
	a[45354]={"䢡"}
	a[45361]={"褤","𨔦","𨔳","𨖒"}
	a[45362]={"躰","逪","𨕎"}
	a[45363]={"達","","𨕏"}
	a[45364]={"𥛸"}
	a[45365]={"連","遰","𨓰","𨔷"}
	a[45371]={"遀","𨕺","𨗟"}
	a[45372]={"䒃","","𨓽","𨗲","𨘞"}
	a[45373]={"𧞅","𨕌","𨖫"}
	a[45375]={"㦁","褳","𠁎","𨖇"}
	a[45378]={"遘","𨔸"}
	a[45381]={"䢫","𤾮"}
	a[45382]={"𨖊"}
	a[45383]={"𧎭","𨘜"}
	a[45384]={"","𦪭","𨗐","𨘝"}
	a[45386]={"遭"}
	a[45391]={"䢱","𨗣","𨙋"}
	a[45392]={"䜩"}
	a[45393]={"遶"}
	a[45394]={"𪊭"}
	a[45404]={"𦪛","𨊁","𩴀"}
	a[45406]={"𩳢"}
	a[45413]={"皢","𨊅"}
	a[45414]={"𩵆"}
	a[45415]={"䰫"}
	a[45416]={"𨊜"}
	a[45418]={"𩴓","𩴗"}
	a[45431]={"讹","𥙝"}
	a[45432]={"𥙕"}
	a[45443]={"𣁽"}
	a[45451]={"诜"}
	a[45463]={"魁","𩲅","𩲙"}
	a[45464]={"䄋","裺","𩲺"}
	a[45472]={"𨈺"}
	a[45473]={"𦩄"}
	a[45474]={"䰡","鬾","魅","𩲍","𩳅"}
	a[45483]={"𩲱"}
	a[45484]={"𩲵"}
	a[45485]={"𩳆","𩳒"}
	a[45486]={"𩴾"}
	a[45493]={"襓","𩳣","𩴤"}
	a[45494]={"魌","𨉚"}
	a[45504]={"𪖥"}
	a[45506]={"𤜘"}
	a[45522]={"䘠","𧘓"}
	a[45532]={"䃽","衼","鿆","𥙽","𧘟","𧙛"}
	a[45542]={"祾","裬","𨈠"}
	a[45543]={"祎","袆","𥙶","𦨟"}
	a[45544]={"讲","𥚙"}
	a[45552]={"𢻄","𤽌","𤽑"}
	a[45553]={"讳"}
	a[45561]={"𨈛"}
	a[45565]={"𧜵"}
	a[45566]={"褄"}
	a[45567]={"𥛵"}
	a[45572]={"𩿓"}
	a[45573]={"𨉀"}
	a[45574]={"𢻘"}
	a[45576]={"艜"}
	a[45583]={"𢻞"}
	a[45584]={"𢻠","𨸥"}
	a[45595]={"鹱"}
	a[45597]={"𢻩"}
	a[45603]={"𨉩"}
	a[45614]={"𪋑"}
	a[45615]={"𪖽"}
	a[45618]={"𧟔"}
	a[45641]={"祐","祜","𥙗","𧙖","𧙗"}
	a[45651]={"祮","祰","袺","诂"}
	a[45652]={"䑩"}
	a[45653]={"𧛭"}
	a[45661]={"诘","诰","𢩍"}
	a[45662]={"䄍","禇","艁","褚"}
	a[45671]={"皓","𥜎"}
	a[45672]={"诸"}
	a[45681]={"禧","鿋"}
	a[45682]={"艢"}
	a[45686]={"䄚","褿"}
	a[45693]={"㿤","𥜑","𪃞"}
	a[45697]={"艚"}
	a[45702]={"禱"}
	a[45711]={"𨼕"}
	a[45712]={"㿧","軇","𥜣","𪂴"}
	a[45713]={"𪄻","𪖟"}
	a[45715]={"𪅘"}
	a[45716]={"𪊷"}
	a[45721]={"祔","衬","袝","𥘑","𥘔"}
	a[45722]={"𥙌"}
	a[45731]={"讨","𡬪"}
	a[45732]={"䑧","𡬫"}
	a[45742]={"袸"}
	a[45743]={"襔"}
	a[45744]={"䙊"}
	a[45751]={"䄎","䠵","射","袴","裿","𥚓"}
	a[45752]={"诗","𧚆"}
	a[45754]={"祷"}
	a[45755]={"𥛣"}
	a[45761]={"𧛼"}
	a[45762]={"䜦","舿","襨"}
	a[45764]={"诪","𧝄"}
	a[45765]={"𧝫"}
	a[45766]={"𥜳"}
	a[45767]={"襻"}
	a[45771]={"䙃","䲧","谢","𥚨","𥛂","𥛒"}
	a[45772]={"𧚫"}
	a[45774]={"𤽯","𧝪","𧟆"}
	a[45775]={"𥛥"}
	a[45777]={"𧛔"}
	a[45778]={"褠"}
	a[45781]={"䠸","躸","𧝍"}
	a[45782]={"请","𤾑","𪀔"}
	a[45783]={"䄝","䑶","𧜧"}
	a[45786]={"𡦱"}
	a[45789]={"𦩷"}
	a[45791]={"𤾘"}
	a[45792]={"皘"}
	a[45796]={"𡦵"}
	a[45801]={"襫","𧟅","𧟎 "}
	a[45802]={"皟"}
	a[45804]={"𪃆"}
	a[45805]={"𦪸"}
	a[45812]={"禶","襸","𤿀","𧞲"}
	a[45813]={"䶑","𦫅"}
	a[45814]={"麒"}
	a[45815]={"𪏓"}
	a[45816]={"𪖮"}
	a[45821]={"裌"}
	a[45822]={"𧘒"}
	a[45831]={"诙"}
	a[45832]={"䃿","䜤","祑","衭","袟","𥙖","𦨐","𦩀"}
	a[45843]={"舼"}
	a[45852]={"祺","褀","读"}
	a[45854]={"𧙣"}
	a[45861]={"䲦","𧝭","𨖰"}
	a[45863]={"䑴"}
	a[45865]={"𧚨"}
	a[45871]={"禛"}
	a[45872]={"䳀","𤾀"}
	a[45873]={"𧝒"}
	a[45875]={"𦪗"}
	a[45876]={"𦩌"}
	a[45882]={"襀"}
	a[45884]={"䒈"}
	a[45891]={"䄣","襩"}
	a[45892]={"鶀","𪖨"}
	a[45894]={"𨊇"}
	a[45895]={"𪎰","𪏑"}
	a[45897]={"𪏒"}
	a[45913]={"𢆇"}
	a[45921]={"𥚒"}
	a[45931]={"𧜝"}
	a[45932]={"祙","祩","袜","袾","𣒐","𥘯","𦩑","𧙕","𧙞"}
	a[45941]={"𧛮"}
	a[45942]={"诛"}
	a[45943]={"𧚏"}
	a[45951]={"𥛰","𧛻","𧝜"}
	a[45952]={"皌","襟","𤽜","𨈼"}
	a[45953]={"禖","诔","谏"}
	a[45954]={"褋","襋","𪎡"}
	a[45962]={"𦪕"}
	a[45963]={"谋"}
	a[45964]={"谍"}
	a[45965]={"艓"}
	a[45966]={"𥜈"}
	a[45971]={"𣦨"}
	a[45976]={"𥜕"}
	a[45982]={"𣚩","𦤧"}
	a[45994]={"𪄈"}
	a[45998]={"𧟜"}
	a[46002]={"𨉹"}
	a[46040]={"衵","𠰦","𥘗"}
	a[46041]={"䄄","祵","裀","裍","𧛃"}
	a[46042]={"䄂","袖","袽"}
	a[46050]={"𧙊"}
	a[46051]={"𦨙"}
	a[46053]={"舳"}
	a[46061]={"祻","𦨧","𧛂"}
	a[46081]={"𪀁"}
	a[46090]={"𣉣"}
	a[46093]={"䙟"}
	a[46101]={"𦤨"}
	a[46111]={"𥜩"}
	a[46112]={"𨉽"}
	a[46113]={"𧟕"}
	a[46114]={"軆"}
	a[46150]={"袒","𥘵"}
	a[46160]={"褞"}
	a[46161]={"䄇","裎","𡎺","𦨪"}
	a[46163]={"裡","𥚃"}
	a[46172]={"𧛟"}
	a[46174]={"艃"}
	a[46183]={"𦩠"}
	a[46184]={"禮","𦪷"}
	a[46191]={"𨉑"}
	a[46192]={"𧟌"}
	a[46251]={"𥚈"}
	a[46302]={"谴"}
	a[46310]={"䴋","𨘵"}
	a[46311]={"𨙘"}
	a[46312]={"𨘊"}
	a[46313]={"䢲"}
	a[46315]={"齈"}
	a[46330]={"遝","𨑕","𨒅","𨒊","𨔃"}
	a[46332]={"迚"}
	a[46340]={"逻","","𨑨","𨓲"}
	a[46341]={"迦"}
	a[46342]={"迪","𨒇"}
	a[46343]={"迧"}
	a[46344]={"䢗","𨒧"}
	a[46350]={"䢙","迴","逥","逷","𨒚","𨓆","𨔯"}
	a[46351]={"禗","𥚸","𨔫"}
	a[46352]={"遗","𨓙","𨔣"}
	a[46353]={"𨕟"}
	a[46354]={"䜨"}
	a[46358]={"𨔂"}
	a[46360]={"逿","遈","遏","𥜏","𨓺","𨕔","𨕚"}
	a[46361]={"䙓","逞","𧗂","𧛚","𨔗"}
	a[46362]={"𦩭","𨗫"}
	a[46363]={"遇","𨓦"}
	a[46370]={"還","𨔹","𨕒","𨘖"}
	a[46371]={"遻","𨔺","𨕓","𨕣","𨕬","𨘣"}
	a[46372]={"𨗴"}
	a[46373]={"䙨"}
	a[46375]={"䗝"}
	a[46378]={"遱"}
	a[46380]={"遌","遢","𨕻","𨖞","𨗓","𨘒","𨙎"}
	a[46382]={"暹","遣","遺"}
	a[46383]={"遦"}
	a[46384]={"禯","襛"}
	a[46390]={"𧟍","𨗻"}
	a[46392]={"襁","邏","𧞸"}
	a[46400]={"𧡌","𪁗"}
	a[46401]={"𦤡"}
	a[46402]={"𧡦"}
	a[46403]={"𩳵"}
	a[46405]={"𩳓","𩴜"}
	a[46410]={"𧢘","𧢞"}
	a[46411]={"皩","𧢌","𧢫"}
	a[46412]={"𩴉"}
	a[46414]={"𩴮","𩵅"}
	a[46415]={"𩴼","𩵈"}
	a[46419]={"魓"}
	a[46440]={"祝"}
	a[46444]={"𧙟"}
	a[46460]={"視"}
	a[46470]={"裩","𣇙","𥚛","𧠧"}
	a[46471]={"䚀","𧠽","𧡬"}
	a[46472]={"𧜴"}
	a[46480]={"䚁","𤑎"}
	a[46483]={"𩳻"}
	a[46484]={"𩲳"}
	a[46485]={"䰠"}
	a[46490]={"襬","郒","𧠞"}
	a[46491]={"襯"}
	a[46492]={"䚌","𧡤"}
	a[46493]={"𩳦"}
	a[46494]={"𩳪"}
	a[46504]={"𦪢"}
	a[46512]={"𪈤"}
	a[46513]={"軃","𤾠","𥜵"}
	a[46514]={"麣","𤾺","𦫇"}
	a[46518]={"軁","𪅛"}
	a[46519]={"𪖹"}
	a[46532]={"祌","衶"}
	a[46542]={"䘥"}
	a[46543]={"神","舯"}
	a[46552]={"禝"}
	a[46553]={"舺"}
	a[46562]={"谡","𧖿"}
	a[46571]={"䜥","𥚶","𧜞"}
	a[46572]={"襗","𥜃","𦩅"}
	a[46573]={"𨈮"}
	a[46577]={"襅","𥛘"}
	a[46578]={"䄛","褸"}
	a[46581]={"皔","谩"}
	a[46582]={"𪀌"}
	a[46589]={"艛"}
	a[46592]={"襊","鵿"}
	a[46593]={"禪","襌"}
	a[46603]={"𧞭"}
	a[46614]={"𡄌"}
	a[46670]={"裮","𥚕"}
	a[46673]={"𥔻"}
	a[46680]={"躳"}
	a[46701]={"𠧊","𦤦"}
	a[46702]={"𨊒"}
	a[46710]={"𨊀"}
	a[46711]={"齃"}
	a[46712]={"𪇆"}
	a[46714]={"𡃯"}
	a[46741]={"祸","𥙙"}
	a[46750]={"裼","𧝁"}
	a[46760]={"禓","裐","褐"}
	a[46763]={"禑"}
	a[46770]={"禤","谒","𥚝"}
	a[46771]={"𥚷","𦩥"}
	a[46772]={"襡","𤽲","𪎥"}
	a[46780]={"㿣","禢","褟","𤾉","𥚜"}
	a[46781]={"谓"}
	a[46782]={"𦩝"}
	a[46783]={"𨉂"}
	a[46790]={"谔","𨉪"}
	a[46791]={"䑽"}
	a[46800]={"𪂿"}
	a[46802]={"䙬"}
	a[46812]={"䠿"}
	a[46830]={"𧙋"}
	a[46840]={"识"}
	a[46851]={"祦"}
	a[46852]={"䙌",""}
	a[46860]={"禔","褆","𤽱","𨈪"}
	a[46861]={"误"}
	a[46862]={"𦨳","𦨼"}
	a[46863]={"禩"}
	a[46870]={"䳅","","𥛍","𨉌"}
	a[46881]={"𧝂","𨉛"}
	a[46882]={"䙡",""}
	a[46892]={"𧗏"}
	a[46893]={"𦪒"}
	a[46912]={"鸔"}
	a[46913]={"𪈫"}
	a[46941]={"褓"}
	a[46950]={"昶"}
	a[46953]={"祼","裸"}
	a[46961]={"𥛧"}
	a[46962]={"𦩪"}
	a[46963]={"课"}
	a[46972]={"襮"}
	a[46981]={"襙"}
	a[46983]={"躶","𧟊"}
	a[47001]={"𪖙"}
	a[47002]={"𦒢"}
	a[47010]={"𨺅","𨽡","𨽵"}
	a[47011]={"齁"}
	a[47013]={"𪚭"}
	a[47020]={"初","礿","讱","𥘉","𥘨","𧘑"}
	a[47021]={"衲","𥘋","𥘝"}
	a[47030]={"衂","袀","𥘩","𧘤"}
	a[47031]={"舠","讷","𦨓","𦨔","𧖩"}
	a[47032]={"袇","𥘘"}
	a[47040]={"的","袧","𡩰","𥘮"}
	a[47041]={"劰","袎","𦨛"}
	a[47044]={"衻","袡"}
	a[47050]={"㓪","䘩","祠","祤","诇","𥙣","𧙈","𧙥"}
	a[47051]={"䑦","勆","祹","裪","𠡒"}
	a[47060]={"词","询","诩","𢊙","𩾡"}
	a[47061]={"䎇","禂","翶","裯","躹","鳨","𢄇","𥚬","𦨴","𧛞"}
	a[47062]={"𨈝"}
	a[47063]={"𦠫"}
	a[47070]={"䎅","䙀","䠺","朗","𨈳","𩿖"}
	a[47071]={"翝","翺","调","𢄗","𣎋"}
	a[47072]={"㔡","𦩍"}
	a[47073]={"𨈶"}
	a[47074]={"𨈜","𨈭"}
	a[47075]={"𠢹"}
	a[47076]={"𨉄"}
	a[47080]={"𨈹","𪀊"}
	a[47081]={"皗","𪀂"}
	a[47082]={"翩","𢩚","𦒌","𪊖"}
	a[47090]={"𨉫","𪀠"}
	a[47091]={"𨉜"}
	a[47092]={"翱","𪖔"}
	a[47101]={"𧞫"}
	a[47111]={"𡓬","𧰥"}
	a[47112]={"䶊","𤾫"}
	a[47141]={"𧘥"}
	a[47142]={"𧙔"}
	a[47150]={"䜧","祖","袓"}
	a[47151]={"衄","𥚼"}
	a[47152]={"𤯦"}
	a[47160]={"诅","𥙥"}
	a[47161]={"𡏅","𧛘"}
	a[47162]={"艋"}
	a[47171]={"𥂟","𦤊","𧛐"}
	a[47172]={"盤"}
	a[47180]={"𥙸","𥛈"}
	a[47181]={"𧞀","𨧒"}
	a[47182]={"𧜶"}
	a[47183]={"㿥","鎜","𦩙","𦪹"}
	a[47191]={"塱","𡒰"}
	a[47192]={"𥛿","𥜔"}
	a[47206]={"𦪓","𦪲","𦪺"}
	a[47211]={"𪖷"}
	a[47215]={"𪆭"}
	a[47230]={"卹","袳"}
	a[47250]={"卽"}
	a[47251]={"𠨙","𦤜"}
	a[47260]={"谬","𩾓"}
	a[47270]={"𩾱","𪀓"}
	a[47280]={"𪀃"}
	a[47290]={"𪅡"}
	a[47302]={"𧞘","𨘭"}
	a[47303]={"𨙒"}
	a[47307]={"𧔧"}
	a[47311]={"𧟒","𨙐"}
	a[47312]={"𨙙"}
	a[47315]={"𦫈"}
	a[47317]={"𨙀"}
	a[47318]={"蠭"}
	a[47320]={"辺","辽","迩","𨑏","𨑥"}
	a[47321]={"边","𨑧","𨒟"}
	a[47322]={"迆"}
	a[47330]={"辸","迉","迎","迟","迻","𨑐","𨑓","𨑦","𨒀","𨒮"}
	a[47331]={"䢊","迅","﨤","𨑍"}
	a[47332]={"𧛤","𨑣"}
	a[47340]={"䢛","禒","褖","迌","迡","迢","迥","迳","𧖷","𨑖","𨒡","𨒦","𨒵","𨔡","𨔵"}
	a[47341]={"襐","邌","𢜄","𢜷","𧝮","𨒝","𨓝","𨓧","𨓻","𨖶","𨘯"}
	a[47342]={"𢟁","𨑩","𨑽","𨓟","𨔇"}
	a[47343]={"逄","𨔤"}
	a[47350]={"䢐","䢧","裉","躵","迵","迿","退","逯","𣤎","𧚈","𨒁","𨒈","𨒶","𨗿"}
	a[47351]={"逸","遙","𨓜","𨓥"}
	a[47352]={"通","𨓠","𨓨","𨔧"}
	a[47353]={"逇","遬","𧜨"}
	a[47354]={"逢","逫","逮"}
	a[47360]={"褪","過","遹",""}
	a[47361]={"䢜","谗","週","遛","遟","遡","鴤","𨓴"}
	a[47362]={"遅","遚","遲","𨓭","𨔻"}
	a[47363]={"𨗮"}
	a[47364]={"䙜","𥛝"}
	a[47366]={"䢖","𨔥"}
	a[47370]={"䙤","䢣","𨖈","𨖯","𨗔","𨘌"}
	a[47371]={"𨗽"}
	a[47372]={"褩","𧞽","𨔚","𨖽"}
	a[47373]={"違","𨘇"}
	a[47375]={"運","𦪎","𨔪","𨕨"}
	a[47380]={"","𨕖","𨗧"}
	a[47381]={"慇","遐","𨗭"}
	a[47382]={"𨘮","𨙅"}
	a[47383]={"𦪶","𧍓","𨘂"}
	a[47384]={"螌","邂"}
	a[47386]={"䗬"}
	a[47390]={"𨘕"}
	a[47391]={"𨖏","𨘤"}
	a[47392]={"䢰","選","邍"}
	a[47394]={"𪒀"}
	a[47395]={"𨘡"}
	a[47400]={"鶃"}
	a[47402]={"䰬","鼽","𩳱","𩴃"}
	a[47404]={"𩴍"}
	a[47410]={"𥜐"}
	a[47411]={"䶌","𦫱","𧢦","𪖡","𪖱"}
	a[47412]={"䰨","艬","𪗂"}
	a[47413]={"䰯","𪚶"}
	a[47414]={"𦫉","𩙒","𩴹","𪋖 ","𪚽"}
	a[47415]={"𩳷"}
	a[47420]={"䘛"}
	a[47422]={"祂"}
	a[47430]={"视","𥘌"}
	a[47431]={"舤","衴","讽"}
	a[47432]={"衪"}
	a[47440]={"䘦","祀","讥"}
	a[47441]={"舰","讯","𥙵","𦨇","𦨌","𧙱"}
	a[47450]={"戺","祪","袍","记"}
	a[47451]={"舥","𠡞","𦨨","𦨲","𧚇"}
	a[47452]={"𤽰"}
	a[47460]={"䘽","皅","诡","𠙋","𨈔"}
	a[47461]={"躭","𦨹","𧖵"}
	a[47462]={"𩲁","𩲂","𩲃","𩲐","𩲟","𩲪"}
	a[47463]={"䑺","𩱹"}
	a[47464]={"䰣","褹","𩳫"}
	a[47470]={"鳦","𢀹","𦫙"}
	a[47471]={"𦩊"}
	a[47472]={"𩳲"}
	a[47473]={"艉","𠖡","𩳩"}
	a[47474]={"𩲢","𩲴"}
	a[47475]={"𩳗"}
	a[47480]={"𤾆","𨉆"}
	a[47482]={"𩲞","𩲤"}
	a[47483]={"𩳇","𩴙","𩴞"}
	a[47490]={"䳈"}
	a[47491]={"臲"}
	a[47492]={"魍","𩲲","𩳖","𪊋"}
	a[47495]={"𩴇"}
	a[47501]={"𪂋"}
	a[47502]={"䶋","𡚖","𨺔"}
	a[47503]={"𪖞"}
	a[47507]={"鞶"}
	a[47511]={"歸","𨉣"}
	a[47512]={"𪖧","𪖲"}
	a[47518]={"𨊖"}
	a[47521]={"䘜","衩","𥘓"}
	a[47531]={"衱","𥘜"}
	a[47532]={"䑡","被"}
	a[47541]={"祋","𥚔","𧘣"}
	a[47542]={"䑥","䘟","诐","𤙟","𥘧","𦨕"}
	a[47543]={"袶","𦨭","𧜁"}
	a[47546]={"𥘬","𧙂"}
	a[47551]={"帥","设","𥙈","𥚞"}
	a[47552]={"般","𥛹"}
	a[47553]={"裈","译"}
	a[47554]={"䄌","舽","裰","𧚋"}
	a[47557]={"𦨡"}
	a[47561]={"祲","𥛀","𧛺","𨈞"}
	a[47562]={"䙙","𢃺","𧚥","𨈵"}
	a[47563]={"幋","诨"}
	a[47564]={"媻"}
	a[47565]={"艂","𤿾"}
	a[47571]={"𣪔","𣪕","𣪧","𩾶"}
	a[47572]={"诹","𠮈","𥛆"}
	a[47573]={"禕","艘","褘","𣪞","𦨿"}
	a[47574]={"𧜱"}
	a[47575]={"禈","褌"}
	a[47577]={"𦨱","𦩦"}
	a[47581]={"𣪘"}
	a[47586]={"𥀱"}
	a[47587]={"𦩨"}
	a[47594]={"𥀔"}
	a[47595]={"𤾈","𥜉"}
	a[47600]={"𨉭"}
	a[47601]={"𧞟"}
	a[47610]={"𨊍","𨊗","𨻿"}
	a[47611]={"𥍁","𦒣","𧭔"}
	a[47616]={"𤾭"}
	a[47640]={"祒","袑","𥚭"}
	a[47641]={"袼","𥙻"}
	a[47650]={"诏"}
	a[47651]={"衉","𦨣"}
	a[47660]={"谘"}
	a[47661]={"船","裾","𤽥","𥚁","𥚑","𥛅","𧜄"}
	a[47663]={"裙"}
	a[47670]={"𤾌","𥚵"}
	a[47671]={"𠶳","𥚣"}
	a[47672]={"艍"}
	a[47675]={"𦩯"}
	a[47680]={"䄡","褶","襜","𧛕"}
	a[47681]={"鴼","𣈪","𧝴"}
	a[47682]={"磐"}
	a[47690]={"谵"}
	a[47691]={"䒁","艒","𥋩"}
	a[47692]={"䒄","艪","𥈼"}
	a[47700]={"𨉦","𪃀"}
	a[47701]={"𦩸","𨉯"}
	a[47702]={"䙱","𪄀"}
	a[47710]={"𤾦","𨉱"}
	a[47712]={"襷"}
	a[47715]={"𨟨"}
	a[47720]={"𧘈"}
	a[47730]={"礽","𧘌"}
	a[47731]={"䑠"}
	a[47740]={"䘞","䘶","祃","郞","郎","𧘏"}
	a[47741]={"𦨋"}
	a[47742]={"𨞓"}
	a[47750]={"𥘰","𧖾","𧜛","𧝌"}
	a[47751]={"䘿"}
	a[47752]={"𧚔","𧛸"}
	a[47760]={"禍","诌","𥚍","𥚩","𥛯","𧚧","𧜔","𧝃","𧞦","𨝺","𩾒"}
	a[47761]={"𥙯"}
	a[47762]={"䒂","䣗","诵","𩧷"}
	a[47763]={"䑼","诤"}
	a[47770]={"䘓","谄","谞","谲","躬","𥛔","𧜓","𩿋","𪁲"}
	a[47772]={"𦠷"}
	a[47773]={"𧜭"}
	a[47774]={"搫"}
	a[47780]={"𥛇"}
	a[47781]={"䑵","𦝭"}
	a[47784]={"𡦆"}
	a[47791]={"襑"}
	a[47792]={"𪄞"}
	a[47800]={"𧞨"}
	a[47810]={"𤓫"}
	a[47830]={"欰","𣢖"}
	a[47832]={"䄃","䘧","袂"}
	a[47840]={"𣢵","𣤄","𪉁"}
	a[47842]={"诀","𣤡","𧖫"}
	a[47850]={"欴","歍","焈","𣢛","𣢼"}
	a[47851]={"䙈","𤴙","𥚦"}
	a[47854]={"㷭"}
	a[47860]={"㰾","䄙","𣣝","𧜀"}
	a[47861]={"谀"}
	a[47863]={"𧝝"}
	a[47864]={"㱂","禊","褉"}
	a[47867]={"𣤤"}
	a[47870]={"𢌃","𧝽"}
	a[47872]={"鴃"}
	a[47873]={"𦤕"}
	a[47875]={"𦩣"}
	a[47880]={"𧛴"}
	a[47881]={"𦪬"}
	a[47882]={"𨃞"}
	a[47886]={"𧝇"}
	a[47890]={"𧞏"}
	a[47891]={"䳧","𧟈","𪂷","𪖓","𪖗"}
	a[47892]={"襈"}
	a[47893]={"䄤","襰"}
	a[47915]={"齂"}
	a[47920]={"祢"}
	a[47931]={"𥙨","𧙤"}
	a[47940]={"祿"}
	a[47943]={"𦩁"}
	a[47950]={"䄞","䘵","禄"}
	a[47951]={"䋜","𦂟"}
	a[47952]={"䑮"}
	a[47954]={"褬","𥛋"}
	a[47963]={"槃","𦪫"}
	a[47970]={"𤽺"}
	a[47971]={"躱","躲","𣕼"}
	a[47972]={"縏"}
	a[47973]={"𦩺"}
	a[47980]={"𣼙"}
	a[47981]={"㮾","𢅞"}
	a[47990]={"鵦"}
	a[48010]={"𧘋"}
	a[48020]={"认"}
	a[48021]={"𦨈"}
	a[48102]={"𪖜"}
	a[48110]={"𨊔"}
	a[48130]={"裣"}
	a[48140]={"褴","𧙓"}
	a[48141]={"䘳"}
	a[48150]={"谥"}
	a[48151]={"艗","诠"}
	a[48152]={"𦪮"}
	a[48161]={"𡏩","𧜡"}
	a[48162]={"褨"}
	a[48173]={"艖"}
	a[48180]={"襤","𥜓"}
	a[48184]={"𦪋"}
	a[48191]={"艦"}
	a[48192]={"𨉶"}
	a[48210]={"祄","衸","袗","𥘼"}
	a[48213]={"𪚬"}
	a[48220]={"衿","诊","𥘞"}
	a[48230]={"𥙚"}
	a[48231]={"䑤"}
	a[48240]={"祚"}
	a[48242]={"𦩔"}
	a[48250]={"诈","𩾴"}
	a[48251]={"舴"}
	a[48260]={"𨉅"}
	a[48261]={"𪂀"}
	a[48302]={"𨙄"}
	a[48310]={"込","𨑸","𨑹","𨒛"}
	a[48318]={"𪖳"}
	a[48320]={"䢨","衳","袊","遂","𨑟","𨑪"}
	a[48321]={"𨑷"}
	a[48330]={"䄒","䙂","祣","禭","襚","讼","逧","𧛄","𨑶","𨒄","𨔆"}
	a[48331]={"䘴","舩","舲","迕","送","逆","途","𨒾","𨓵"}
	a[48332]={"迸"}
	a[48340]={"䢔","皊","谂","迄","迮","𨓚","𨗀"}
	a[48341]={"䢟","禚","艌","𨒣"}
	a[48342]={"迤","递","𨒫","𨗅"}
	a[48344]={"𨖴"}
	a[48350]={"䠲","逾","𤽿","𦤉"}
	a[48351]={"䢭"}
	a[48352]={"𨔼"}
	a[48354]={"遫"}
	a[48360]={"䢢","禌","道","𧛏","𧛛","𨗦","𨗳"}
	a[48361]={"遊","𨖌","𨖟"}
	a[48362]={"遒","𨗯"}
	a[48363]={"逰","遨","𨗤"}
	a[48364]={"𨗾"}
	a[48367]={"谦"}
	a[48368]={"𦩵"}
	a[48370]={"𨗥","𨺵"}
	a[48371]={"㦘","邀","𨘻"}
	a[48372]={"䢩"}
	a[48373]={"遵","𨗖"}
	a[48374]={"𨗕"}
	a[48375]={"𨗼"}
	a[48382]={"𨖍"}
	a[48391]={"𨘋","𨘥"}
	a[48405]={"鸃"}
	a[48412]={"𩴵","𪇳","𪖴"}
	a[48413]={"𧟖"}
	a[48430]={"论"}
	a[48440]={"祱","裞"}
	a[48441]={"舱","𦩃"}
	a[48442]={"袘","𥙁"}
	a[48450]={"讫","说"}
	a[48451]={"𦨏","𧜃"}
	a[48452]={"魀","𧛖","𩲝","𩲩"}
	a[48453]={"䑨"}
	a[48460]={"𤽍","𨉋"}
	a[48461]={"𥙰"}
	a[48470]={"𨈨"}
	a[48476]={"艤"}
	a[48480]={"㘏"}
	a[48482]={"𩳋","𩴌"}
	a[48492]={"𪁸"}
	a[48497]={"䰮"}
	a[48499]={"魐"}
	a[48511]={"𥜶"}
	a[48512]={"鷻","𪈶"}
	a[48517]={"𦘦"}
	a[48521]={"𥘦","𧘶"}
	a[48531]={"𢼄"}
	a[48532]={"襒","𧚭"}
	a[48541]={"敀","许"}
	a[48542]={"祥","祶","𢃘","𢽲"}
	a[48543]={"䑫","䵇"}
	a[48551]={"啟","𢼚","𢿬","𨈡"}
	a[48552]={"皏","详","𢾟","𥚫","𦫏"}
	a[48553]={"䑯","禅"}
	a[48554]={"𢾅"}
	a[48561]={"敫","複"}
	a[48562]={"𧛢"}
	a[48564]={"𤾵"}
	a[48568]={"𣀊"}
	a[48571]={"𧝳"}
	a[48572]={"𦎒","𦩟","𧝋"}
	a[48573]={"𧝠"}
	a[48582]={"䒆","𢿭","𧗐","𪁩"}
	a[48583]={"𦪔","𦪧"}
	a[48587]={"䒉","肇","𢾹"}
	a[48591]={"皦"}
	a[48592]={"𪖖"}
	a[48593]={"𣀐"}
	a[48594]={"𪋋"}
	a[48601]={"𪖝"}
	a[48611]={"䶎","䶐","譥"}
	a[48612]={"𥜫"}
	a[48630]={"裕","𥙿"}
	a[48640]={"祫","袷","𥛾","𧚼"}
	a[48651]={"䑪","啓"}
	a[48660]={"䙢","𨈴"}
	a[48661]={"晵"}
	a[48662]={"禉"}
	a[48670]={"禬","襘","谱"}
	a[48671]={"䁈","艏","艙","𥛶"}
	a[48673]={"𦩲"}
	a[48680]={"噵","𤾙"}
	a[48682]={"𧝙"}
	a[48690]={"𤾥"}
	a[48702]={"禴","𪄟"}
	a[48703]={"䚫","𩦨"}
	a[48711]={"鸄"}
	a[48713]={"𪖦"}
	a[48720]={"衯"}
	a[48740]={"𤽉","𧛳"}
	a[48741]={"𡹘"}
	a[48742]={"𥙡","𥚗","𦜑"}
	a[48750]={"䄖","褕","躮"}
	a[48753]={"䑳","𢯄","𧚀"}
	a[48760]={"谕","𧛹","𧜲"}
	a[48761]={"䏿","𤽦","𦩞"}
	a[48763]={"诲"}
	a[48770]={"谫","𥛙"}
	a[48771]={"導"}
	a[48772]={"䑻"}
	a[48780]={"䠼","𧝅"}
	a[48783]={"𢶡"}
	a[48784]={"𦪚"}
	a[48791]={"𦪙"}
	a[48812]={"𪇥"}
	a[48820]={"㸂","䙕"}
	a[48831]={"𤉰"}
	a[48840]={"𨈦"}
	a[48842]={"𥎻","𦨶"}
	a[48851]={"𦩂"}
	a[48860]={"襝","𥜋","𧜽","𪅜"}
	a[48861]={"䠶"}
	a[48862]={"𥛏"}
	a[48870]={"𤒮"}
	a[48872]={"𥜁"}
	a[48882]={"躾"}
	a[48890]={"𨉺"}
	a[48910]={"𥙄"}
	a[48920]={"袮"}
	a[48941]={"𣷙"}
	a[48942]={"棨","艅"}
	a[48951]={"綮"}
	a[48962]={"𣘼"}
	a[48971]={"䆃","鵌","𣜦","𦄊"}
	a[48972]={"𣜥"}
	a[48981]={"𦅾"}
	a[48993]={"𪊸"}
	a[49040]={"𨈓"}
	a[49164]={"𦩱"}
	a[49171]={"𦩴"}
	a[49180]={"皚"}
	a[49182]={"皠"}
	a[49190]={"䠽"}
	a[49210]={"𥘤","𧘡"}
	a[49221]={"𦨖"}
	a[49240]={"𨈘"}
	a[49241]={"𦨽"}
	a[49290]={"𪃐"}
	a[49302]={"㿩"}
	a[49310]={"𨗄"}
	a[49311]={"逖"}
	a[49320]={"辿","逤"}
	a[49321]={"迷","𨕩"}
	a[49322]={"䢠","𨔮","𨖉"}
	a[49331]={"逊","𨒞"}
	a[49332]={"𨒃","𨒽 "}
	a[49340]={"逍","遄"}
	a[49341]={"谜"}
	a[49342]={"䢯","𨒯"}
	a[49350]={"𨓂"}
	a[49351]={"𨓏","𨓹","𨖮"}
	a[49353]={"遴","𧔶","𨔢"}
	a[49362]={"𧜜"}
	a[49363]={"𨖀"}
	a[49364]={"𨔲"}
	a[49372]={"𨖭","𨘳"}
	a[49375]={"𧑥"}
	a[49384]={"䲍"}
	a[49393]={"𨙏"}
	a[49395]={"𨘼"}
	a[49413]={"𪖾"}
	a[49420]={"𥙑"}
	a[49450]={"㿠"}
	a[49452]={"裷","𩲎","𩴩"}
	a[49460]={"谠","𨉁"}
	a[49462]={"𩲀","𩲿","𩳑"}
	a[49470]={"皑","𠒸"}
	a[49481]={"皝"}
	a[49482]={"魈"}
	a[49492]={"𩴎"}
	a[49495]={"𩴠","𩴭"}
	a[49504]={"𪋲"}
	a[49515]={"麟","𪋷"}
	a[49532]={"袢","𥘽"}
	a[49533]={"褛","𦩎"}
	a[49542]={"衅"}
	a[49544]={"𥚿"}
	a[49553]={"褝","𥛷"}
	a[49554]={"𦩫"}
	a[49555]={"𦩩"}
	a[49592]={"𨻪"}
	a[49671]={"襠"}
	a[49673]={"𤳮"}
	a[49674]={"𤳔"}
	a[49682]={"艡"}
	a[49683]={"䒅"}
	a[49691]={"𦫁"}
	a[49714]={"𪋸"}
	a[49721]={"䘷"}
	a[49730]={"讪"}
	a[49731]={"舢","袦","𥙋"}
	a[49740]={"䘯","裆","褍","𥙬","𥚻"}
	a[49741]={"诎"}
	a[49742]={"𦨥"}
	a[49750]={"诮"}
	a[49751]={"艄"}
	a[49752]={"𧚸"}
	a[49754]={"𠢧"}
	a[49760]={"𣻮","𧞖"}
	a[49761]={"䠳","軂"}
	a[49770]={"躺"}
	a[49772]={"𦤙"}
	a[49780]={"䙖"}
	a[49785]={"𦫀"}
	a[49792]={"𧟃"}
	a[49793]={"𪅻"}
	a[49810]={"裧","𤇷","𥘙"}
	a[49814]={"𨽫"}
	a[49820]={"谈"}
	a[49821]={"𦩗"}
	a[49830]={"𤾃"}
	a[49831]={"𨕜"}
	a[49840]={"𨉇"}
	a[49841]={"𤎥"}
	a[49864]={"𤒼"}
	a[49881]={"𦫂"}
	a[49883]={"𧷽"}
	a[49950]={"𥛢"}
	a[49951]={"𣜅"}
	a[49953]={"𣽨"}
	a[49954]={"𣚗"}
	a[49963]={"𦪝"}
	a[50001]={"㐅","乂","义","橌","橺","","","𠂭","𨞜","𨟉"}
	a[50002]={"嫺","橍","櫊","𡢃","𨞪"}
	a[50004]={"欄","𨟤"}
	a[50005]={"孄"}
	a[50009]={"鄻"}
	a[50010]={"韊"}
	a[50011]={"十","壛","櫚","櫩","","𠂇","𡓲","𣠸","𣠼","𣡞","𤜡","𨟛"}
	a[50012]={"𡣽","𡤡","𤯐"}
	a[50015]={"𨎫"}
	a[50016]={"欗","鞹"}
	a[50017]={"孏","𨏦"}
	a[50018]={"䪍"}
	a[50019]={"轥"}
	a[50021]={"䢶","郟","郲","𨙩","𨙯","𨙴"}
	a[50022]={"邚","𨛊"}
	a[50031]={"䣇","䣛","郝","𨙭","𨞢"}
	a[50032]={"䢼","邞","郄","郏","郴","𤞡","𨙲","𨙶","𨙸","𨚘"}
	a[50033]={"娴","郗"}
	a[50034]={"𨙷","𨚢"}
	a[50041]={"桏","𨚧","𨛢","𨜨"}
	a[50042]={"㭨","邨","邯","邿","𨚲","𨚴"}
	a[50043]={"䣂","邦","𡟦"}
	a[50045]={"𨟅"}
	a[50046]={"𨚓"}
	a[50051]={"郀","郁","郆","𨜅","𨝷"}
	a[50052]={"邽","郣","郩","𨜆"}
	a[50053]={"梛"}
	a[50054]={"娜","梆","郙"}
	a[50061]={"榔","𣘙","𨚤","𨜤","𨜴"}
	a[50062]={"㮋","嫏","椰","都","𨛳","𨝵"}
	a[50064]={"䣍","垹","𨜒","𨝴"}
	a[50066]={"郪"}
	a[50071]={"𨝊"}
	a[50072]={"槨","郬","閷","𣗐","𤡦"}
	a[50073]={"郼"}
	a[50074]={"𣚋"}
	a[50075]={"鄟"}
	a[50082]={"㯗","墎","酀","𣘥"}
	a[50083]={"嫻","𤡲","𨶓"}
	a[50084]={"䣠"}
	a[50086]={"鄞","鄪"}
	a[50091]={"𤡥"}
	a[50092]={"𨝌"}
	a[50094]={"鄼","𡢸"}
	a[50095]={"䣢"}
	a[50102]={"𡕄","𤨻"}
	a[50103]={"櫙","𠁕"}
	a[50104]={"䥅","𦦜","𨫹"}
	a[50105]={"權","𡚜","𨌵"}
	a[50106]={"孉","𡕂","𩋡"}
	a[50111]={"𡔾","𤜚","𨰵"}
	a[50113]={"矗","𤫍","𤫒","𩏆"}
	a[50114]={"𡕈","𡕍"}
	a[50115]={"壦","𩋢"}
	a[50116]={"𡚛"}
	a[50117]={"𨎽"}
	a[50118]={"䡷","𧄓","𩍰"}
	a[50119]={"𡚟"}
	a[50121]={"土","圡","士","","","","","𣎶"}
	a[50131]={"㭗","夳","左","杢","盇","盔","𡘃","𡘄","𤟄"}
	a[50132]={"在","圶","奁","桽","","𠀏","𡉄","𡉣","𡘫","𥁅"}
	a[50141]={"壶","椌","𡘵","𥁋"}
	a[50142]={"圭","坴","","𠄬","𡘇","𡙯","𡚏","𤦃","𥁈"}
	a[50143]={"𡉈","𤯗"}
	a[50151]={"㚗","埪","壴","壸","奆","查","査","盍","𡗨","𡘰","𥁓"}
	a[50152]={"㚃","𠄤","𥩴","𪍂"}
	a[50153]={"㚝","㮅","奎","奞","𡉫","𡙃","𨾮"}
	a[50154]={"𥁫"}
	a[50161]={"䀁","椬","直","𠷔","𡘍","𣝃","𤟿","𥄂"}
	a[50162]={"樦","𡔫","𢀡"}
	a[50163]={"垚","壵","𡔦","𣌽","𣕈","𣙜"}
	a[50164]={"𡍊","𡑷","𡙔","𨤭"}
	a[50165]={"壷","𡏑"}
	a[50171]={"壹","楦","𡘟","𣔉","𣩉"}
	a[50172]={"媗","𡌬","𡔪","𡕃","𡙙","𡢒","𦤼"}
	a[50173]={"𥂙","𦥆","𨾭"}
	a[50181]={"塇","壺","𡔭"}
	a[50182]={"𡌴","𡔸","𡔹"}
	a[50183]={"𡐎","𡔼"}
	a[50184]={"㙓","壒","𦤿"}
	a[50185]={"鞚","𨌊"}
	a[50189]={"嬞"}
	a[50191]={"壼","奩","𡙞","𡚍"}
	a[50192]={"孂","臺"}
	a[50193]={"𡔳","𡚊","𦥂"}
	a[50195]={"獾","𡔲"}
	a[50196]={"𪎅"}
	a[50201]={"𪔄"}
	a[50208]={"櫹"}
	a[50209]={"𡣾"}
	a[50211]={"夰","夼","","𡗦"}
	a[50221]={"","𡗲","𢒊"}
	a[50222]={""}
	a[50231]={"奅","奓","","𡉅","𡘧","𡙓"}
	a[50232]={"𡥇"}
	a[50233]={"栉","𡖘","𣘡"}
	a[50234]={"𪍋"}
	a[50241]={"声","𡔜","𡗵","𡗸","𣜤"}
	a[50243]={""}
	a[50244]={"𪍬"}
	a[50251]={"榨","𡔝"}
	a[50253]={"𡏗"}
	a[50261]={"𡙆","𡱠","𣟹"}
	a[50262]={"𤱿"}
	a[50271]={"奫","𩇩"}
	a[50273]={"㙹"}
	a[50281]={"櫛","𣙒"}
	a[50282]={"𩇶"}
	a[50291]={"鼒","𪔇"}
	a[50302]={"㦞"}
	a[50305]={"𡄜"}
	a[50306]={"𧔵"}
	a[50307]={"𣡊"}
	a[50308]={"𧓕"}
	a[50310]={"𧖚"}
	a[50311]={"㝳","㣻","冭","太","杰","𢗦","𣑰","𧔄","𨏕"}
	a[50315]={"䪀","蠧"}
	a[50317]={"囊","蠢","蠹","𧰣"}
	a[50318]={"𧕰","𨏥","𩍹"}
	a[50319]={"𩎀"}
	a[50321]={"㤲","厷","厺","态","枩","赤","赱","𠫓","𡗓","𡗪","𡗷","𡘎","𢖽"}
	a[50322]={"㣽","本","枣","𠥽","𠫤","𡗭","𢗤","𤆖"}
	a[50331]={"㺠","䘮","丧","去","志","榢","𡘚"}
	a[50332]={"专","嫁","栆","𢗣"}
	a[50333]={"㤗","𡗫","𡙒"}
	a[50341]={"㥁","夽","怘","𡊮","𡋡","𡗰","𡘳","𤋯","𤣛"}
	a[50342]={"㚠","表","𠫢","𢙮","𧙐"}
	a[50343]={"恵","獴","𡘕","𣚜","𤈂","𧈠","𧈹","𧉓"}
	a[50344]={"焘"}
	a[50345]={"檧"}
	a[50351]={"㤫","袁","𠷫","𡙤"}
	a[50352]={"恚","𢚦"}
	a[50353]={"叀","檬","𪐡"}
	a[50354]={""}
	a[50360]={"𣝈"}
	a[50361]={"套","悫","悳","𡘷","𢝫"}
	a[50363]={"㥣","𡒯","𧚐","𪒁"}
	a[50364]={"䵆","惠","櫁","𢞨","𣞷","𧉉"}
	a[50365]={"櫵","𠁱","𢞯","𨊢"}
	a[50366]={"𣝘"}
	a[50371]={"㥲","喪","惪","熹"}
	a[50373]={"惷","𧍾","𧞢"}
	a[50374]={"䖯","𢡘"}
	a[50375]={"螙","𣟋","𦓷","𧋌","𧎆"}
	a[50377]={"嚢","𣟀"}
	a[50381]={"憙"}
	a[50382]={"𤎿"}
	a[50383]={"憃","𡙿"}
	a[50384]={"櫶","𡚉"}
	a[50386]={"𡕀","𢀃","𧑖","𨌆"}
	a[50391]={"𡃟","𡕅","𡚔","𤑌"}
	a[50392]={"燾","𡤁"}
	a[50393]={"𪑵"}
	a[50395]={"𧏋"}
	a[50396]={"蟗"}
	a[50397]={"𩍬"}
	a[50399]={"𩍎"}
	a[50401]={"",""}
	a[50403]={"𡕁","𩎺"}
	a[50407]={"韤"}
	a[50411]={"㔫","鼀","鼁","","𠘮","𠤎","𡕋","𪓡"}
	a[50412]={"鼃","","","𡯃","𪓤"}
	a[50413]={"𧢆"}
	a[50415]={"𡰝"}
	a[50417]={"𧹺"}
	a[50421]={"七","尢","朰","𡘁","𣎳","𤝛"}
	a[50422]={"","𠑸"}
	a[50431]={"㐊","㐋","圥","壱","売","柁","𠒀","𡯁","𡯜","𣑯"}
	a[50432]={"兂","奃","尧","屯","𡙚","𤝨","𤞌"}
	a[50433]={"㐂","𣬛"}
	a[50441]={"克","坨","夿","𠒈","𡊪","𡗼","𣔛","𤞵","𤟊"}
	a[50442]={"㖝","䴱","唜","𡡃"}
	a[50443]={"㔺","姹","尭","𡗥","𤠤"}
	a[50444]={"𡘤"}
	a[50445]={"𢎯"}
	a[50451]={"㖛","唟","壳","梡","椀","𠦐","𡋞"}
	a[50452]={"㙀","垞","婉","𠘸","𪌡"}
	a[50453]={"㚜","奯","𠒖","𡩆","𣓋","𣔶","𣖨","𩖘"}
	a[50454]={"㮱","奄","𣘷"}
	a[50455]={"櫗","𣝕"}
	a[50461]={"䙽","垸","埦","𡔧","𣖰","𣨑","𧡛"}
	a[50462]={"䴷","𡔵"}
	a[50463]={"塃","𠒏","𡚓"}
	a[50464]={"𡡄"}
	a[50471]={"𡘹","𥄽"}
	a[50474]={"𡔩","𡙮"}
	a[50475]={"䡐","𠧋","𩉺"}
	a[50477]={"𣚖","𣞕"}
	a[50478]={"𩋖"}
	a[50481]={"嗭","𡔻"}
	a[50483]={"䪑","堯"}
	a[50484]={"𡔬"}
	a[50485]={"𣞓"}
	a[50493]={"𠒶","𣞑","𩎼"}
	a[50495]={"䡝","輐","𨋐"}
	a[50497]={"𩋪"}
	a[50499]={"韈"}
	a[50501]={"鞾"}
	a[50502]={"爻"}
	a[50503]={"丯"}
	a[50508]={"䩸","𨍷"}
	a[50509]={"𦨅"}
	a[50510]={"韄","韡"}
	a[50511]={"轟"}
	a[50512]={"丈","女","𤕜"}
	a[50513]={"𢁫"}
	a[50514]={"𠂖","𠧈","𠧉","𡚠"}
	a[50516]={"𣡀"}
	a[50517]={"䨼"}
	a[50518]={"䪝","𨏣","𩇥"}
	a[50519]={"𢆅","𨎮","𨎳"}
	a[50522]={"㐄","友","夲","巿","布","支","麥","","","","𠬲","𡗡","𡗴","𢁛","𢂯","𢾶","𤕐","𤟫"}
	a[50523]={"㚏","卉","希","","","𠂙","𢌶","𢌾"}
	a[50524]={"㚣"}
	a[50532]={"㚔","夌","𡗧","𢆎","𣔱"}
	a[50533]={"㛮","丰","桉","车","韦","","","𠦃","𠦄","𡉓","𡕟","𡕲","𡗢","𡗹","𢺶","𣏪"}
	a[50534]={"㘷","吏","奔","姲"}
	a[50535]={"𡘛"}
	a[50536]={"姦"}
	a[50542]={"㕝","幸"}
	a[50543]={"垵","弆","牵","羍","麦","𡞛","𢌻"}
	a[50544]={"㯜","叓","","𠦡","𠬻","𠬼","𠭄","𡕤","𡙹"}
	a[50545]={"𡜦","𡝁"}
	a[50546]={"𡝉","𣙷"}
	a[50547]={"㚕"}
	a[50550]={"𤢁"}
	a[50552]={"耷","","𠦝","𡘨","𣔼","𦕂"}
	a[50553]={"𡜌","𢜤","𤙏","𦍒"}
	a[50554]={"帮","𣓒","𣘘"}
	a[50555]={"奉","婶","車","轰","𠦪"}
	a[50556]={"妻"}
	a[50562]={"辜","𠦵","𡙋","𡙐"}
	a[50563]={"𡙘","𦍬"}
	a[50564]={"榵","𡙜","𢍚","𢍣"}
	a[50565]={"媶"}
	a[50566]={"獲","𡢷","𣝸","𨊦"}
	a[50567]={"樥","𡝽"}
	a[50568]={"樺"}
	a[50569]={"嬅"}
	a[50572]={"𠭩","𡑉","𣘕","𥆗"}
	a[50573]={"𡙣","𨝜"}
	a[50574]={"𣝁"}
	a[50575]={"𣙻"}
	a[50576]={"䩳","檴"}
	a[50577]={"嬳","鞍","𨋌"}
	a[50578]={"墷"}
	a[50582]={"𠁰"}
	a[50583]={"𢅍"}
	a[50584]={"幚","𢄿"}
	a[50585]={"𣁤"}
	a[50586]={"𡍦","𦔋"}
	a[50587]={"𡢯"}
	a[50588]={"𠦴","𦔠"}
	a[50594]={"𡒡","𩎲","𪔌"}
	a[50595]={"𡤏"}
	a[50596]={"鼖"}
	a[50597]={"𨐉"}
	a[50598]={"耯","𨍔","𩋐"}
	a[50601]={"𡔶"}
	a[50604]={"𡚗"}
	a[50605]={"𨍤","𩏒"}
	a[50611]={"𡕎"}
	a[50613]={"嚞","𥗤"}
	a[50616]={"𩍏"}
	a[50618]={"轄","𨎜"}
	a[50621]={"𠮣"}
	a[50631]={"古","右","夻","杏"}
	a[50632]={"𠯌"}
	a[50633]={""}
	a[50641]={"㚚","吉","昚","杳","榕","𠮷","𣅎"}
	a[50642]={"奋","嫆","𠯛","𡘒","𡙂","𣐭","𣓩","𤲝","𤲷"}
	a[50643]={"𡘊","𤠟","𤰔"}
	a[50644]={"猫"}
	a[50651]={"㚛","塎","眘","𠻮","𡍐","𡍬","𡘐","𥃭"}
	a[50652]={"楁","𤱒"}
	a[50653]={"㫩","榙","𠰫","𠾤"}
	a[50654]={"㜓","楉","楛","𠲀"}
	a[50655]={"婼","媌","𡞯"}
	a[50661]={"㯚","啬","嗇","奤","樎","𠹫","𠾂","𣘜","𥑟","𧥢"}
	a[50662]={"㜚","旾","𣛗"}
	a[50663]={"㫪","㰂","塔","奢","春","砉","𣇸"}
	a[50664]={"嬸"}
	a[50671]={"㙮","喜","楍","𡐑","𡙗","𣖎"}
	a[50672]={"𠶮","𡑛","𥒐"}
	a[50673]={"曺","𠵤","𡙍","𡙬","𣌼","𤳛"}
	a[50674]={"㮫"}
	a[50675]={"軎","𡟲","𣛰"}
	a[50681]={"𡙄"}
	a[50682]={"㮺","嘉","𡔯","𡙲"}
	a[50683]={"櫡","𠺇"}
	a[50684]={"奮"}
	a[50685]={"䡥","墸"}
	a[50692]={"夁"}
	a[50693]={"𡈋"}
	a[50694]={"㜴"}
	a[50696]={"辖","𨍇","𨎣","𩋽"}
	a[50697]={"鞳"}
	a[50701]={"乄","犭",""}
	a[50705]={"䩪","輨"}
	a[50709]={"𩍁"}
	a[50710]={"𩏯","𩏵"}
	a[50711]={"䪇","寸","才","","","𡕌","𡴷","𨏫","𩍘","𩍿"}
	a[50713]={"𦦺","𪃣","𪆊"}
	a[50714]={"𦦱"}
	a[50715]={"𦦾"}
	a[50717]={"轕","𩍛","𩏕"}
	a[50719]={"韉"}
	a[50721]={"㚎","㞭","冇","狞","","𠀁","𠕇","𠛞"}
	a[50722]={"夯","夺","狩","𠡊","𡗚","𡘴","𤕞"}
	a[50723]={"𡥈","𤕠"}
	a[50724]={"𢂞"}
	a[50725]={"𣙡"}
	a[50731]={"壭","柠","𠕆","𡉆","𣓚"}
	a[50732]={"击","存","寺","李","𡜚","𡥂"}
	a[50733]={"卋","𡥉"}
	a[50736]={"𣝧"}
	a[50741]={"坾","夸","奇","有","𡉉","𡗝","𡘆","𦚉"}
	a[50742]={"南","垨","孛","樒","肴","","𡙨","𡵭","𣘧"}
	a[50743]={"㺃","𠦔","𡠞","𤯃"}
	a[50744]={"寿","𠝊","𡘏"}
	a[50745]={"亊","𣏭","𣗊"}
	a[50748]={"𣠝"}
	a[50751]={"獰","𡊦","𦏷","𪘘"}
	a[50752]={"㔛","靑","𡘪","𡜷","𡝏"}
	a[50753]={"𢪿","𢫀","𣕉","𤢆","𩡱","𩢙"}
	a[50754]={"専","","𠃫","𠦟","𦝸"}
	a[50755]={"𡔥"}
	a[50756]={"毐","𣑜"}
	a[50761]={"棺","檸","","𠳮","𡘣","𣘠","𣙱"}
	a[50762]={"奝","婠","嬣","槣","青","𠚓"}
	a[50763]={"槆","橣","獦","𡔤"}
	a[50764]={"奪","𡟱","𡸸"}
	a[50765]={"專","毒","𨊥"}
	a[50766]={"耢"}
	a[50767]={"事"}
	a[50771]={"奛","奟","橁","𡔴","𣛱","𣞐"}
	a[50772]={"𡑣"}
	a[50773]={"舂","𣚥","𣛖","𤢨","𩿜"}
	a[50774]={"𠢌"}
	a[50776]={"𣫴","𩊦"}
	a[50777]={"𣫵"}
	a[50778]={"𠡸","𡢹","𣝍","𨌣"}
	a[50781]={"𣝻","𤢶","𩿟"}
	a[50782]={"𡔺"}
	a[50783]={"橗","𣝏"}
	a[50785]={"𣠷"}
	a[50787]={"𦑢"}
	a[50788]={"欂","𨍅"}
	a[50791]={"㰏","𡕉"}
	a[50792]={"壽","𠿧"}
	a[50793]={"𡚒"}
	a[50794]={"𡔽"}
	a[50796]={"夀","𡣡","𡭏"}
	a[50797]={"𣡫","𩎁"}
	a[50799]={"鞯","𪎄"}
	a[50801]={"賷","𥈜"}
	a[50802]={"𠁗"}
	a[50803]={"𧽹","𧾆"}
	a[50804]={"𧾨"}
	a[50805]={"𨍵"}
	a[50807]={"𪏟"}
	a[50808]={"𩌧"}
	a[50811]={"㚒","㶫","大","夾","灰","狖","","","𡗕","𡗜","𡙁","𡚐","𤆍","𤆰","𤡗"}
	a[50813]={"𧾲"}
	a[50815]={"䟒","爽"}
	a[50817]={"𩍮"}
	a[50821]={"柼","灻","𡔡","𡗱"}
	a[50822]={"㐪","㚐","夫","夹","𠁊","𠆴","𡘖","𤟪"}
	a[50823]={"𤕡"}
	a[50825]={"𤕤"}
	a[50831]={"㺍","坹","奒","赍","走","𡘂","𣝎"}
	a[50832]={"䴳","卖","赉","𡘥","𣔻"}
	a[50833]={"贲","","𡘙"}
	a[50834]={"𣓎"}
	a[50835]={"𡘘","𡝩","𤠉"}
	a[50841]={"椗","槟","𤉲","𤊽"}
	a[50842]={"堗","婝","嫔","责"}
	a[50844]={"夷","𤢑"}
	a[50845]={"楧"}
	a[50846]={"媖"}
	a[50847]={"𡟗"}
	a[50851]={"埞","賚","𧶘"}
	a[50852]={"畞","𤱑"}
	a[50853]={"𤋔"}
	a[50854]={"奏","獏","𣙘","𦔅"}
	a[50855]={"疌","𡎘","𡘲"}
	a[50857]={"𤡞"}
	a[50861]={"獱","真","賫","𡔰","𣙣","𤴞"}
	a[50862]={"𡔢","𡔣","𧵩"}
	a[50863]={"賁","𤴛"}
	a[50864]={"模","𥨜"}
	a[50865]={"嫫","軣"}
	a[50867]={"𦔃"}
	a[50871]={"檳","趤","𠔧","𡘼","𤏴","𧵎","𧶌"}
	a[50872]={"嬪","疐","責","𤴡"}
	a[50873]={"㻎","檱","𡐔","𧾠"}
	a[50874]={"塻","𡔱","𡚀","𤴝"}
	a[50875]={"𪍤"}
	a[50881]={"賣","𡒨","𣠺","𧷏","𧷨"}
	a[50882]={"㚄","𧽔","𨂬"}
	a[50883]={"䝴","𧶚"}
	a[50884]={"𡐢","𧾯","𪏉"}
	a[50885]={"𣟯"}
	a[50889]={"𨍞"}
	a[50891]={"奭","𥇛","𧶠","𧷗","𧸇"}
	a[50892]={"靛","𡒆","𡣑"}
	a[50893]={"𧾟"}
	a[50896]={"𧾛"}
	a[50902]={"𣠹"}
	a[50903]={"𣝷","𣟘"}
	a[50904]={"㰛"}
	a[50905]={"𡤤"}
	a[50911]={"䆐","來","夵","木","朩","𠀊","𡗔","𡗟","𣷚"}
	a[50912]={"杀","𣏂"}
	a[50914]={"㰆","纛","𣟏","𣡏","𣡖"}
	a[50915]={"𨏷"}
	a[50916]={"𣡦","𣡪"}
	a[50921]={"桼","𡭡","𣏶","𣑏"}
	a[50922]={"㚓","东","未","末","朿","来","𠐇","𣎽","𥾥"}
	a[50923]={""}
	a[50931]={"奈","柰","猔","𡉺","𡙌","𡨀","𣏄","𣑇","𥘾"}
	a[50932]={"𣏅","𣐁","𣖉","𣳕"}
	a[50933]={"㚞","㛽","㭐","束","柬","森","耒","","𠀟","𣎺"}
	a[50934]={"桒"}
	a[50941]={"尞","棕","索","𣳂"}
	a[50942]={"婃","𠦙","𡙥"}
	a[50943]={"泰","𡮃","𣓼"}
	a[50944]={"㯣","東","枽","棗","秦","𡘝","𣐇","𣒛","𣘻"}
	a[50945]={"𣏃"}
	a[50952]={"素","𤢸","𥞤"}
	a[50953]={"𣕿","𥘿"}
	a[50954]={"","𣓟"}
	a[50955]={"𣏲","𣐺","𥠼"}
	a[50961]={"檫","𠬇"}
	a[50962]={"𣓷"}
	a[50963]={"櫒","𣕣"}
	a[50964]={"㯻","𡐽","𡙸","𡣮","𣓑","𣓧"}
	a[50965]={"𣕤","𥢮","𨋈"}
	a[50966]={"𡙻","𣒚","𣝯"}
	a[50967]={"𣝾"}
	a[50972]={"槖"}
	a[50973]={"𡒩","𣙲"}
	a[50974]={"𣕫","𣕮"}
	a[50975]={"𣘯"}
	a[50976]={"𣗞"}
	a[50977]={"𡑢","𣞤","𣟒"}
	a[50981]={"𦃦"}
	a[50984]={"橐","𣠔"}
	a[50985]={"㯱","櫜","𦄯"}
	a[50991]={"𡕊","𥈸"}
	a[50994]={"𣚇","𣝐","𣠀"}
	a[50995]={"𣞈","𣞉"}
	a[50997]={"𣠮"}
	a[50999]={"𣠆"}
	a[51101]={"塸","𣞀"}
	a[51102]={"𡄂","𣜂"}
	a[51103]={"橿","櫃","櫨"}
	a[51104]={"㺢","𡣓"}
	a[51106]={"軭","𡑼"}
	a[51107]={"轣"}
	a[51111]={"𣎥"}
	a[51112]={"櫭","櫮","欞","𡓐","𤣤"}
	a[51113]={"㙺","壃","壚","𧰡","𩎨"}
	a[51114]={"㰌","𡓘"}
	a[51115]={"䡱","䩽","𣡛","𩏱"}
	a[51116]={"䡿","鑋","𨏨"}
	a[51117]={"轤","韁","𩍨","𩍼"}
	a[51121]={"狉"}
	a[51131]={"㹵","杠","杫","柸","桠","𣏴","𤞈"}
	a[51132]={"㚰","妅","娅","枢","狂"}
	a[51133]={"妪"}
	a[51141]={"㭅","㮎","㮓","䞑","圵","址","坯","垭","柩","柾","桱","𡉎","𤜷","𤝙","𤞟","𤟷"}
	a[51142]={"姃","娙","枉","","𡛘","𣐝","𣗃","𤞂"}
	a[51143]={"𡛼","𡞡"}
	a[51147]={"𤣐"}
	a[51151]={"䞓","枑","柜","栕","梪","狟","𣐛","𣐵","𣖍","𣗫"}
	a[51152]={"㛒","姖","姫","姬","桎","𡉠","𡊩","𣑙","𤝿","𤡣"}
	a[51153]={"㺡","姪","𣘰","𪌞"}
	a[51154]={"𡋖"}
	a[51155]={"𡌎"}
	a[51157]={"𤣔","𤣗","𤫏"}
	a[51161]={"坘","桓","𡍍","𣕲","𤞸"}
	a[51162]={"垤","姮","框","𣚛","𥒯","𪌖"}
	a[51163]={"㭱","櫪"}
	a[51164]={"㮒","娾","𡤌"}
	a[51165]={"𡞻"}
	a[51171]={"垣","堩","椏","𠦾","𡍷","𣒯"}
	a[51172]={"㮜","墟","婭","𡢋","𪉩"}
	a[51173]={"堐","壢","椻","耟","𣗝","𥂱","𧗑"}
	a[51174]={"堙","轾","𣘗","𤡰","𧹬","𨿗"}
	a[51175]={"嫟","𨊧","𨊺"}
	a[51181]={"埡","𣞘","𤠾"}
	a[51182]={"𣖭","𣙁","𤡝","𤣋"}
	a[51183]={"堰","𡎪","𡟽","𣚼","𩎜"}
	a[51184]={"𢿫","𪏅"}
	a[51185]={"輕"}
	a[51186]={"䡖","軖","𨋔","𩊇"}
	a[51187]={"𨌃"}
	a[51191]={"噽","壾","榧","樞","𥂇","𧯧"}
	a[51192]={"㯇","嫗","樝","𡏀","𣛼"}
	a[51193]={"㜘","獹","𣝽"}
	a[51194]={"壥"}
	a[51195]={"𨋆","𨋷","𩉱","𩉸","𩊪","𪏀"}
	a[51196]={"輊","𨌷","𩊞"}
	a[51202]={"𣡣"}
	a[51203]={"𡤲"}
	a[51205]={"𨌡"}
	a[51213]={"𩎻"}
	a[51215]={"輫","𩋂"}
	a[51221]={"𣐣","𤞤"}
	a[51222]={"㚦"}
	a[51231]={"𡉃"}
	a[51232]={"𡛃","𡝃"}
	a[51241]={"埗","栌","𡉨"}
	a[51242]={"𪌷"}
	a[51251]={"垆","𡋫"}
	a[51261]={"桺","猅"}
	a[51262]={"𣚷"}
	a[51263]={"轳"}
	a[51271]={"棑"}
	a[51272]={"婔"}
	a[51273]={"𡤴"}
	a[51275]={"𩊶"}
	a[51283]={"𣚶"}
	a[51284]={"𡡱"}
	a[51301]={"㙣","𨲗"}
	a[51302]={"橒"}
	a[51305]={"䩨"}
	a[51306]={"𨎶"}
	a[51311]={"𢦁","𤞱"}
	a[51312]={"墵"}
	a[51313]={"韔","𢥤"}
	a[51314]={"𩇣"}
	a[51318]={"韆","𧺅"}
	a[51321]={"㭬"}
	a[51322]={"椓","𡝍"}
	a[51331]={"㯌","圷","𣏇","𤝃"}
	a[51332]={"㙇","㮇","𡛨"}
	a[51333]={"婖"}
	a[51341]={"枟","桛","𡐌","𣏳"}
	a[51342]={"㤮","妘"}
	a[51343]={"𣗇"}
	a[51347]={"𡤘"}
	a[51351]={"坛","垰","桭","𡉬","𤟔"}
	a[51352]={"娠","𢜋","𤢓"}
	a[51353]={"𣜡"}
	a[51354]={"𡠇","𢢷"}
	a[51358]={"𤣝"}
	a[51361]={"棖"}
	a[51362]={"㯫"}
	a[51363]={"嫕","槱","耘","𡢅","𢟇","𤋒","𦓶"}
	a[51365]={"𨌇"}
	a[51371]={"㙊","𣛓"}
	a[51372]={"壉"}
	a[51373]={"𣚝","𩷬","𪍸"}
	a[51376]={"𩋅"}
	a[51381]={"㯑"}
	a[51382]={"㯪","𡢇"}
	a[51383]={"𩇞"}
	a[51385]={"䩘","嬺","転","鞐","𨋇"}
	a[51393]={"櫖"}
	a[51394]={"櫏","𡣭"}
	a[51395]={"𨌑"}
	a[51401]={"𤭨","𤭱"}
	a[51403]={"𣚒"}
	a[51405]={"甎"}
	a[51406]={"輒"}
	a[51411]={"壠","櫳","龓","𡓺","𪚓"}
	a[51412]={"𪚝"}
	a[51413]={"欐","𡔉","𡔓"}
	a[51414]={"孋","𤮴"}
	a[51415]={"䪊","𨏠","𪏐"}
	a[51417]={"𧈖","𨐀","𩌯","𩍋","𩎉"}
	a[51418]={"𩍊"}
	a[51419]={"𩌶"}
	a[51422]={"𡚲"}
	a[51431]={"杌","𤜸","𤝌"}
	a[51432]={"𡯞"}
	a[51441]={"杬","枙","𦓏"}
	a[51442]={"㝼","䎠","妧","𡛖","𡛣","𡯋","𡯍"}
	a[51443]={"䶭","妩","獩"}
	a[51451]={"㼪","坃","𠒐","𡋮","𣐎","𣒽"}
	a[51452]={"尪","𡐸"}
	a[51453]={"檅"}
	a[51455]={"㼽"}
	a[51461]={"𣒘","𤬪"}
	a[51462]={"㐡","㭯","䖊","槪","猇","𣒸","𦔱"}
	a[51463]={"瓻","轭","𡜯","𦓪"}
	a[51464]={"𣘝"}
	a[51471]={"兡","瓳","𡯺"}
	a[51472]={"㽍","椃","𡯴","𤭥"}
	a[51473]={"婋"}
	a[51474]={"𣛏"}
	a[51475]={"軏","靰","𣯷"}
	a[51482]={"㙈","㼥","㼬","概","虓","𡏲","𤬿","𤭝","𤭣","𧈏"}
	a[51484]={"㼯","辄","𤭴","𪎹"}
	a[51485]={"䡇","虦","軛","𧇑","𩉟","𩉯","𩉴","𩊢"}
	a[51491]={"㼭","𤭩"}
	a[51492]={"䖔","𤮓"}
	a[51493]={"𣝂","𩇗"}
	a[51494]={"兣","𤮏"}
	a[51495]={"𤭔","𤭫"}
	a[51496]={"㼮"}
	a[51500]={"𡤆"}
	a[51503]={"繛","𣀪"}
	a[51504]={"耰","𡤕","𢿣"}
	a[51505]={"𣀨"}
	a[51506]={"㪩","𨌬"}
	a[51508]={"𢆬","𨍼","𩌛"}
	a[51512]={"獿"}
	a[51513]={"𣀓"}
	a[51514]={"欇","𡓳","𡔋","𤣒","𧰘"}
	a[51515]={"㽑","𡤙"}
	a[51517]={"𣀾","𩌲"}
	a[51518]={"𨏴"}
	a[51522]={"犴","狮","𤜳"}
	a[51523]={"𤕝","𤜵"}
	a[51524]={"𢼬"}
	a[51532]={"㪎","杆","枰","𢽀","𣏽"}
	a[51533]={"㛁","奸","枅","𢼢","𣏛"}
	a[51534]={"妍"}
	a[51542]={"坪","𤞢"}
	a[51543]={"㪔","𢻫","𢻳","𢻵","𢼦","𪌃","𪌏"}
	a[51544]={"𡞾","𤞬"}
	a[51545]={"㹴","姧"}
	a[51552]={"㹿","栮","𠭅","𣒉","𣗀"}
	a[51553]={"㛅","榩","𢻴","𣖀","𤟝","𤮽"}
	a[51554]={"㪝","姸","梇","轩","𠧀","𢆐","𣀙","𤡹","𦓬"}
	a[51555]={"㛞","㺛","梗","楆","楩","𢾴","𨐆"}
	a[51556]={"㛐","㛹","婹"}
	a[51562]={"敧","棹","獅","𢼣","𢿞","𣀍"}
	a[51563]={"㪈","婥","𡎩","𢽞","𢿷","𣖳"}
	a[51564]={"𡋱","𡟣","𣔃"}
	a[51565]={"㙘","埂","𢼹"}
	a[51572]={"榎","獶","鼔","𡍎","𢾩","𣘅"}
	a[51573]={"㪛","𡍿","𡎍","𡟪","𡟺","𢾀","𢿀","𢿨","𣕩","𪍈"}
	a[51574]={"𡑬"}
	a[51575]={"㪑"}
	a[51576]={"軒","軙","軯","靬","𩉰","𩉲"}
	a[51577]={"𢍫","𨊻"}
	a[51582]={"櫌","𡏘","𢿿"}
	a[51583]={"𡢩"}
	a[51584]={"橝","𡣜","𢾁","𢾎","𢿠","𣘭","𩎒"}
	a[51585]={"㜤","𣀧"}
	a[51586]={"𡍹"}
	a[51587]={"𨍥"}
	a[51592]={"敼","𦅕"}
	a[51594]={"墰"}
	a[51595]={"𣀺","𪍵"}
	a[51596]={"𡐧","𩊐"}
	a[51597]={"𩋸","𩌻"}
	a[51599]={"鞕","鞭"}
	a[51601]={"㰁","嚭"}
	a[51602]={"㙧"}
	a[51603]={"橬","檑","𡣌"}
	a[51604]={"𡡖"}
	a[51605]={"𨍬","𩋠"}
	a[51607]={"輏"}
	a[51612]={"櫺","𤣍"}
	a[51613]={"𣠚"}
	a[51614]={"孀"}
	a[51615]={"𨏒"}
	a[51616]={"䡼","輻","𤜕","𩋨"}
	a[51617]={"𨎿"}
	a[51631]={"𣔸","𤝓","𤞜"}
	a[51633]={"𤞏"}
	a[51641]={"㹮","枮","柘","桮","檆"}
	a[51642]={"㚲","妬","娝","樐","𣐸"}
	a[51644]={"㛉"}
	a[51651]={"坧","坫","栢","𤟯"}
	a[51652]={"㹳","䴴","塷","𣕨"}
	a[51653]={"栖"}
	a[51661]={"㮌","榗"}
	a[51662]={"媔","梧","𡞎","𡠂"}
	a[51663]={"娪","梄"}
	a[51664]={"𡜳","𨟶"}
	a[51672]={"楅","麵","𠺃"}
	a[51673]={"𪎋"}
	a[51681]={"𧯻"}
	a[51682]={"堛","𤡼","𧹭"}
	a[51684]={"黇"}
	a[51685]={"䩞","𨋓"}
	a[51691]={"龼"}
	a[51692]={"橊","𣠄"}
	a[51693]={"䪓","麺","𤢗"}
	a[51694]={"辐","𦔆","𩈨"}
	a[51695]={"𩊘","𪎾"}
	a[51702]={"䞕","壖","樗"}
	a[51703]={"嫮"}
	a[51704]={"𡢵","𩥞"}
	a[51705]={"䩹","𨌳","𨍮","𪏏"}
	a[51706]={"轌"}
	a[51712]={"𣠌"}
	a[51713]={"𣠟","𪈈"}
	a[51714]={"𡓰","𪏣"}
	a[51716]={"轜","𨏎","𩍥"}
	a[51717]={"壩","欛"}
	a[51718]={"𣠽"}
	a[51719]={"𩌸"}
	a[51721]={"朾","𣐘"}
	a[51722]={"奵","犽"}
	a[51726]={"獮"}
	a[51731]={"圢","朽","杤","栭","桁","𧹙"}
	a[51732]={"䎟","杅","枒","枥","柄","𣓈","𣔯"}
	a[51733]={"㚥","𡛦"}
	a[51736]={"檷"}
	a[51737]={"嬭"}
	a[51741]={"垳","杇","柯","椼","𣏜","𣒍","𤡤"}
	a[51742]={"㛤","圩","坜","妸","𡉪","𣓣","𪋽"}
	a[51743]={"獁","耓","𡚯"}
	a[51751]={"圬","坷","𣚊"}
	a[51752]={"婀","麪","麫","𡜕","𡢉","𢎏"}
	a[51753]={"榪","𡡸","𩡪"}
	a[51754]={"媽"}
	a[51755]={"辆","𤟨"}
	a[51756]={"獼"}
	a[51761]={"㮄","㯊","槅","𠳌","𡑂","𧹸"}
	a[51762]={"嫣","槈","樰","𡏌","𡞚","𡠔","𤠙"}
	a[51763]={"㯉","婳","媷","轲","𠞲","𡠭","𩣗"}
	a[51764]={"嫭","𡢙"}
	a[51765]={"靪","𨊡"}
	a[51770]={"𩍦"}
	a[51771]={"塥","墕","𣍳"}
	a[51772]={"橱","𡐅","𡟵","𡠡"}
	a[51773]={"㙤"}
	a[51774]={"𪎿"}
	a[51775]={"輀"}
	a[51776]={"䩒","䩫","輛","鞆","𤢵","𨊱"}
	a[51778]={"𩤦"}
	a[51781]={"𡒚","𣘣"}
	a[51782]={"獳","鵟","𡎋","𡎕"}
	a[51783]={"櫉","𣛲"}
	a[51784]={"耨"}
	a[51785]={"軻","𡢓","𨊮","𩉞","𩉣","𩊆"}
	a[51786]={"櫔","輌"}
	a[51792]={"檽"}
	a[51793]={"嬬"}
	a[51794]={"㯭"}
	a[51795]={"𨎪","𩍄"}
	a[51797]={"䩻","𨎇"}
	a[51801]={"䫦"}
	a[51802]={"䫖","𧾤","𩔥","𩔩"}
	a[51803]={"䫨","𡑾","𧾧"}
	a[51804]={"䫔","𧽼","𧾬","𩓹","𪏔"}
	a[51805]={"䡠","𩒷","𩔈"}
	a[51811]={"顛","𣠢","𣡲","𩕡","𩕦"}
	a[51812]={"㰜","𧾮","𩓨","𩔄","𩔳","𩕯","𩖀","𩖎"}
	a[51813]={"顤"}
	a[51814]={"𩕗"}
	a[51815]={"𨆪","𩌌","𩎌"}
	a[51816]={"𨆧","𩕫"}
	a[51818]={"顜"}
	a[51821]={"𣏡"}
	a[51831]={"桢"}
	a[51832]={"𤉀","𤟦"}
	a[51841]={"䞜","赪","𡊕","𣘩","𧺒"}
	a[51842]={"㮕","獗","颊","𡊘","𧼙"}
	a[51843]={"媆","樮","𣒟"}
	a[51851]={"𧺠","𧺰","𧼝","𩑐"}
	a[51852]={"䞙","堧","橛","赶","顿","𩑛"}
	a[51853]={"㜧","槚"}
	a[51856]={"趰"}
	a[51861]={"䞛","䞠","䞪","楨","趈","頰","顂","颉","𧺦","𧻳","𩒏"}
	a[51862]={"㙭","㛲","䞝","媜","𣕹","𧻀","𧼞","𩖗"}
	a[51863]={"媫","𤍕","𧻺","𧽺"}
	a[51865]={"䫪"}
	a[51871]={"䞸","槓","赬","頄","頳","𧺳","𧺹","𧻙","𧻿","𩑣","𩒮","𩒿","𩕑"}
	a[51872]={"䫐","頍","頬","𡟫","𧼥","𧽸","𩑖","𩑪","𩑱","𩑵","𩑷","𩒓"}
	a[51873]={"𩒽"}
	a[51874]={"𩕒"}
	a[51875]={"𪏂"}
	a[51876]={"𩋹"}
	a[51881]={"㰋","䪺","颠","𡎴","𣛿","𣟓","𧻚","𧼟","𧽞","𩑲","𩑶"}
	a[51882]={"䟊","趠","頓","𡤉","𣝛","𣟤","𤎪","𥢙","𧻔","𧼈"}
	a[51883]={"䟐","檟","櫇","頛","頼","顢","𧽐","𧽤","𩑚","𩓠","𩓡","𩕌"}
	a[51884]={"䫙","𡢢","𧾇","𩓕","𩔵"}
	a[51885]={"䫶","𠏏","𩋀","𩌦","𩌳"}
	a[51886]={"輭"}
	a[51891]={"䫑","頡","𧼉","𩕐"}
	a[51892]={"䫏","䫴","𣝓","𤢺","𩓁","𩓐"}
	a[51893]={"𩓏"}
	a[51894]={"𧽆","𩒺","𩔑"}
	a[51904]={"𩏁"}
	a[51921]={"杯","狋"}
	a[51922]={"妚"}
	a[51931]={"坏","标","𣐹"}
	a[51932]={"𡛭","𡜔"}
	a[51933]={"𤡫"}
	a[51941]={"柡","獂","𡊆"}
	a[51942]={"𡞼","𣕊"}
	a[51943]={"𣗲","𣙽"}
	a[51944]={"𤠫","𤢂"}
	a[51951]={"榞"}
	a[51952]={"嫄","𣙏","𤡷"}
	a[51953]={"𤡑"}
	a[51954]={"㯨","𣗖"}
	a[51961]={"塬"}
	a[51962]={"槕"}
	a[51963]={"標","𡞮","𣖪"}
	a[51964]={"塛","嫖"}
	a[51966]={"𥤔"}
	a[51973]={"墂","𡠘","𡡥"}
	a[51981]={"𡀆"}
	a[51982]={"𣚡"}
	a[51998]={"𨍫"}
	a[52001]={"𤜟"}
	a[52011]={"杊","栦"}
	a[52021]={"圳","朻"}
	a[52022]={"𣒜"}
	a[52027]={"𤞹"}
	a[52041]={"𡔠","𣏖"}
	a[52042]={"𡛅"}
	a[52055]={"䡅"}
	a[52061]={"棩"}
	a[52062]={"婣"}
	a[52065]={"䡂","𣜙"}
	a[52085]={"靷"}
	a[52102]={"𡒁"}
	a[52105]={"𨎤","𩍐"}
	a[52106]={"𩊰"}
	a[52107]={"𩀧"}
	a[52111]={"檵"}
	a[52112]={"𡣦"}
	a[52113]={"𩏠"}
	a[52117]={"𤣖"}
	a[52118]={"麷"}
	a[52119]={"𪏘"}
	a[52121]={"𤜺"}
	a[52122]={"狅"}
	a[52132]={"㚱","栣","𡜣","𣓆"}
	a[52133]={"妊","姙","婬","𡝇"}
	a[52141]={"坵","𣞚"}
	a[52142]={"𡑊"}
	a[52145]={"𡌁","𡌒"}
	a[52152]={"狴","𡋨","𡍛","𪎀"}
	a[52153]={"𨧸"}
	a[52154]={"𣕭"}
	a[52156]={"棰"}
	a[52157]={"娷"}
	a[52161]={"橙","𣒄"}
	a[52162]={"嬁","梐"}
	a[52164]={"堑"}
	a[52166]={"埵"}
	a[52171]={"墱"}
	a[52172]={"㙄"}
	a[52174]={"錾"}
	a[52176]={"㮔","軠"}
	a[52177]={"媑"}
	a[52182]={"𣛽","𥃁"}
	a[52183]={"𣜁"}
	a[52185]={"𥪭"}
	a[52186]={"堹","塹"}
	a[52193]={"𡢭"}
	a[52196]={"鏨"}
	a[52198]={"𦔉"}
	a[52201]={"䵺"}
	a[52206]={"玂","𣃂","𨎧"}
	a[52207]={"䡳"}
	a[52211]={"㹞","杉"}
	a[52212]={"壣"}
	a[52221]={"析","桚","𠦉","𣂒"}
	a[52222]={"妡","彬","桥","𣙓"}
	a[52223]={"娇"}
	a[52224]={"㣋","𢒈"}
	a[52231]={"㭊","㭮","圻","𣔔"}
	a[52232]={"𪌍"}
	a[52233]={"狾","𢒞","𤠥"}
	a[52234]={"𣂗","𣂧"}
	a[52236]={"𢒍"}
	a[52241]={"𣨗"}
	a[52242]={"𡜏","𢒖"}
	a[52243]={"斩"}
	a[52244]={"轿","𡝊"}
	a[52251]={"彭","𣂦"}
	a[52252]={"㣏","斯","𤡭"}
	a[52255]={"𨊨"}
	a[52262]={"斮","斱","𩇕","𩰧"}
	a[52263]={"㯕"}
	a[52264]={"𡡒"}
	a[52265]={"斬","靳"}
	a[52266]={"獑","鞒"}
	a[52272]={"𡐶","𡠒","𤗡"}
	a[52274]={"𣃏"}
	a[52275]={"𣂷","𣂼"}
	a[52283]={"𧪷"}
	a[52286]={"斳","𡐛"}
	a[52287]={"䩢"}
	a[52291]={"檙","𡒧"}
	a[52292]={"𡐥"}
	a[52295]={"䎰","𣃕","𨎗"}
	a[52301]={"𤜶","𤞅"}
	a[52302]={"𡑜"}
	a[52305]={"䭕"}
	a[52311]={"枛","狐","𣗮","𤝑"}
	a[52312]={"㜻"}
	a[52315]={"𨏈","𨏱"}
	a[52321]={"㭛","柉","柧","长","𣏈"}
	a[52322]={"姂","𡚸","𡜁"}
	a[52331]={"㭃","坬","惁","𣔅"}
	a[52332]={"枨","𢝗","𤫷"}
	a[52333]={"𡡁"}
	a[52341]={"㼋","𢜣","𤬄"}
	a[52342]={"㼊"}
	a[52343]={"㼍","㼑","𡢆","𣒬","𧌝"}
	a[52351]={"瓠","𣐜","𤫶"}
	a[52352]={"瓡"}
	a[52353]={"蚻","蜤"}
	a[52354]={"𧉒","𧌐"}
	a[52355]={"獯","𨊩"}
	a[52361]={"𤢦"}
	a[52362]={"槬","𪍔"}
	a[52363]={"𧎀"}
	a[52364]={"𪑟"}
	a[52365]={"䩝","櫄","軱"}
	a[52371]={"檼"}
	a[52374]={"䱫"}
	a[52375]={"壎","慙"}
	a[52382]={"𤣆"}
	a[52383]={"蟚"}
	a[52384]={"蟴"}
	a[52391]={"𤬗"}
	a[52395]={"䡏","鞃"}
	a[52397]={"𧐮"}
	a[52403]={"𡰢"}
	a[52405]={"𩌋"}
	a[52407]={"橇"}
	a[52408]={"鞿"}
	a[52411]={"𡯎","𢒂"}
	a[52412]={"𡛆"}
	a[52413]={"𣰋","𣰰","𩏔"}
	a[52414]={"𣰠","𪏛"}
	a[52415]={"覱"}
	a[52416]={"㔮"}
	a[52417]={"𩎄","𩴕"}
	a[52421]={"㝽","劜","札","朼","狣","𡯆","𡯇"}
	a[52422]={"㹝","𡚧","𤜤","𤝬"}
	a[52423]={"𡛪"}
	a[52431]={"圠","桃","𤜻","𤝭"}
	a[52432]={"姚","杔","柢","犼","𡏓","𡯘","𣏚","𤢪","𪋼"}
	a[52433]={"㞂","奼","榌","𡚼","𡛜","𤝄"}
	a[52441]={"剋","垗","枇","栀","𠒙","𣐑","𣑿"}
	a[52442]={"㛂","兛","圫","坁","坻","妣","獵","𡋸","𣏺","𣒇","𣓽","𪌪"}
	a[52443]={"枆","轧","𡝦","𣭶","𣮉","𪌂"}
	a[52444]={"㚪","𡯵"}
	a[52451]={"㐖","㘩","㯒","梔","𠒟","𠒭"}
	a[52452]={"㯿","𠃱","𡒏","𡜞","𡜮","𡯢","𡰃","𡰄","𣔪","𪌈"}
	a[52453]={"㘪","𡞢","𣭳","𤯄"}
	a[52454]={"","𣬪"}
	a[52461]={"𠃸","𡓍","𤠗"}
	a[52462]={"㜉","乹","𤕥"}
	a[52463]={"㲡","𣮦"}
	a[52464]={"機","𣮾"}
	a[52465]={"耗","軋","𡡤","𣭵"}
	a[52466]={"𣮡"}
	a[52468]={"𣭘"}
	a[52471]={"橷","𡰖"}
	a[52472]={"榹","𣕅"}
	a[52473]={"兞","𣰐"}
	a[52474]={"㙨","𣭢","𣭷"}
	a[52475]={"鞉","𣯳","𨋫","𩋍"}
	a[52476]={"䩚","軝","軧","𩉬"}
	a[52481]={"亄","櫈"}
	a[52482]={"𡏚","𡰑"}
	a[52483]={"𣖏","𣰘","𤯉"}
	a[52484]={"𣮠"}
	a[52485]={"𩉫"}
	a[52486]={"尰","耭","𪎷"}
	a[52487]={"軞","𩉪"}
	a[52491]={"甏","𧰠"}
	a[52492]={"㽄"}
	a[52493]={"毻","𢀄"}
	a[52494]={"𣯆"}
	a[52495]={"𣯻","𨌌"}
	a[52496]={"䪉"}
	a[52506]={"𦗚"}
	a[52516]={"𨏝","𨏵","𨐂","𩍱"}
	a[52517]={"𩍫","𩎋"}
	a[52522]={"杄","板","柝","𣏸","𤟗"}
	a[52523]={"奷","桵","猣","𡛴"}
	a[52524]={"㹻","娞"}
	a[52532]={"圲","坂","坼"}
	a[52533]={"㯶","椶","猨","𣐪","𪌆"}
	a[52534]={"㮃","𡝟","𡞧"}
	a[52535]={"婑"}
	a[52542]={"狿","𣖅","𣜬"}
	a[52543]={"㹶","堫","嬡","楥","𡒇"}
	a[52544]={"㲍","媛","嫒","𡟡","𢂛"}
	a[52552]={"梴","𠭐"}
	a[52553]={"娫","梃","橓"}
	a[52554]={"娗","𡡞","𣞡"}
	a[52555]={"䎫"}
	a[52556]={"𦓽"}
	a[52562]={"埏","𡍰"}
	a[52563]={"𡋺","𡓌","𦖝"}
	a[52564]={"𡐕"}
	a[52565]={"䡊","𪎺"}
	a[52566]={"𨋻"}
	a[52567]={"鞖"}
	a[52574]={"𣞞","𦖨","𩎚"}
	a[52577]={"㜞","𨍈","𩊤","𩋯"}
	a[52582]={"橃"}
	a[52584]={"𢍵","𦅻"}
	a[52587]={"𩋫"}
	a[52592]={"墢","𦗭"}
	a[52593]={"𣞛"}
	a[52594]={"欉"}
	a[52595]={"𩏅"}
	a[52596]={"䩥","𡓙"}
	a[52597]={"䩠","輧"}
	a[52602]={"𧬊"}
	a[52603]={"𩎽"}
	a[52605]={"䪛"}
	a[52606]={"輴","𨌲"}
	a[52614]={"𩏋"}
	a[52615]={"𩈻","𩋧"}
	a[52622]={"㺁"}
	a[52632]={"狧"}
	a[52633]={"㛴"}
	a[52641]={"㹺","𠵍","𣒩"}
	a[52642]={"堖","姤","栝","椔","𡍗","𡜖","𤞳"}
	a[52643]={"㺕","姡","𡝜"}
	a[52651]={"㭼","垢","晳","栺","皙","𡌐","𥓊"}
	a[52652]={"㛥","桰","楿"}
	a[52653]={"橎","𡜶","𪌩"}
	a[52654]={"嬏"}
	a[52661]={"𡌩","𣇮","𩠣"}
	a[52662]={"棔","楯","𡡾","𣛝"}
	a[52663]={"墦","婚","甛","𡟈"}
	a[52664]={"䎩","辎"}
	a[52671]={"楷","𩠒"}
	a[52672]={"媘","𡎆","𩠖"}
	a[52673]={"暂","𣕻","𤳗"}
	a[52681]={"堦","𡎵","𥕽"}
	a[52682]={"𩏍"}
	a[52685]={"𠼃"}
	a[52686]={"輜","𩋝"}
	a[52695]={"暫","磛","鞜","𨌁","𨌭","𩊝"}
	a[52697]={"轓"}
	a[52699]={"輺"}
	a[52701]={"刈","𤞝"}
	a[52702]={"㺦","𠛄","𪆗"}
	a[52703]={"韜"}
	a[52711]={"㓨","刌","壪","𣏀","𣠭","𣡩","𤝾"}
	a[52712]={"划","刹","剎","猁","𠚰","𡤶","𡤻","𤝘","𤞙"}
	a[52713]={"𠜽","𤟆"}
	a[52715]={"䳻","𠞮"}
	a[52716]={"轎","鞽"}
	a[52721]={"㓼","𠛗","𠞘","𠟴","𣔜","𤞊"}
	a[52722]={"㭔","㭩","刔","刺","刾","梸","𠚷","𠚽","𠛐","𠝁","𠝱","𡜪","𤞲"}
	a[52723]={"刬","娳","𠛉","𠛟","𠜗","𡛚","𣐧"}
	a[52724]={"㓝","剗","𠛜"}
	a[52731]={"㺔","刦","栃","栵","𠛘","𣑂","𣖊"}
	a[52732]={"垀","埒","埓","桴","猺","𠜀","𣐰","𣚠"}
	a[52733]={"㓫","㭢","剌","娐","杽","𠛨","𠝚","𡟢","𪌱","𪌳"}
	a[52734]={"猘","猙","𡛊","𡜇","𤟰"}
	a[52736]={"刜"}
	a[52741]={"㓤","刳","剞","𡊻","𡌱","𡎗","𡐟"}
	a[52742]={"㭭","刲","剘","垺","嬀","榣","𠜻","𡎫"}
	a[52743]={"㛢","䴸","媱","𠞒","𤠧"}
	a[52744]={"剦","楋","轷","𠜁","𠜙","𠝝","𢃴","𪌐"}
	a[52745]={"𠜚","𡞸"}
	a[52746]={"㛵"}
	a[52751]={"槄","𠝛"}
	a[52752]={"剒","嫍","椡","𠜩","𠞓","𡏟","𡞂"}
	a[52753]={"𠝥","𡡗"}
	a[52754]={"㓶","楀"}
	a[52755]={"揧","𠜒","𠝆","𡟥","𡴣"}
	a[52756]={"𠜈"}
	a[52761]={"塪","𠟩","𠠄","𡍫","𡐫"}
	a[52762]={"㮑","獢","𠝜","𠞗","𠠈","𣞗"}
	a[52763]={"㛼","剨","嬼","檦","𠝩"}
	a[52764]={"㙖","𡢱"}
	a[52765]={"剸"}
	a[52766]={"軤","𠠅","𦓺"}
	a[52767]={"剚"}
	a[52768]={"𠞣"}
	a[52771]={"𠟒","𩿤","𪁻"}
	a[52772]={"㔈","橋","𡍪"}
	a[52773]={"嬌","韬","𪘼"}
	a[52774]={"𠟆"}
	a[52775]={"㟻","𠟷","𩊡","𩊼"}
	a[52776]={"𠞱","𢄤"}
	a[52782]={"墧"}
	a[52783]={"𠟋","𣚀","𪍷"}
	a[52785]={"㔅","鞩","𩍇"}
	a[52786]={"𠞷","𠟱","𨍳"}
	a[52787]={"㨻"}
	a[52788]={"𩋷"}
	a[52791]={"𠟜","𠟰","𠠘"}
	a[52794]={"𩏬"}
	a[52795]={"轁","靜","鞱"}
	a[52796]={"劃","𨍀"}
	a[52800]={"𨎉"}
	a[52802]={"𧾁"}
	a[52812]={"䟏","𧾓"}
	a[52815]={"𨏑","𩍵"}
	a[52817]={"𧾳","𧾶"}
	a[52822]={"枖"}
	a[52823]={"妖","𡞊"}
	a[52831]={"梹","𧺈"}
	a[52832]={"娦","猤","","𤠓"}
	a[52833]={"𪍰"}
	a[52841]={"㙃","赳","赾","𧺇"}
	a[52842]={"䞣","楑","榽"}
	a[52843]={"㜎","獛","𡞳"}
	a[52851]={"趒","趔","𧻁"}
	a[52852]={"䞯","赿","趆","𡏛","𧼶"}
	a[52853]={"㯷","樸","𧼕","𧼬"}
	a[52854]={"𡡐"}
	a[52861]={"䞧","槇","𧺲","𧺼","𧽶","𩔯"}
	a[52862]={"䞬","趏","𧽎"}
	a[52863]={"㙸","墣","𣝢","𧻸","𧻽"}
	a[52865]={"𧽃"}
	a[52871]={"塡","櫍"}
	a[52872]={"㜱","𡢍","𧼤","𧽂"}
	a[52873]={"𧽄"}
	a[52874]={"䟁"}
	a[52881]={"𡒻","𣚁","𧽨","𧾊","𨅘"}
	a[52882]={"䞺","𤣈","𥏷","𧼰"}
	a[52883]={"嬽"}
	a[52884]={"䟇"}
	a[52886]={"鞵","𤏍"}
	a[52887]={"𣮌"}
	a[52892]={"䞾","趫"}
	a[52895]={"蹔","𨎘"}
	a[52896]={"䟅","𧼩","𧽯"}
	a[52897]={"䪁","轐","𩍩"}
	a[52902]={"𡤣"}
	a[52906]={"𩏙"}
	a[52907]={"𨏋"}
	a[52911]={"𤝎","𤝣"}
	a[52912]={"𣡵","𤟖"}
	a[52916]={"轢"}
	a[52921]={"𣐚"}
	a[52922]={"柇","栎","棌","𣒡"}
	a[52923]={"姀","婇"}
	a[52931]={"栤","𣖩"}
	a[52932]={"埰","椞"}
	a[52933]={"𣙔","𪌗"}
	a[52941]={"紮","𡋔","𤔎","𤡨"}
	a[52942]={"猻","𡎽","𡡺","𡣘","𤠌"}
	a[52943]={"𡏪"}
	a[52944]={"㺐","轹","𥻌"}
	a[52951]={"橴"}
	a[52952]={"槂","檪","𡏫","𦁝"}
	a[52953]={"檏","𣓇"}
	a[52954]={"椠","樔"}
	a[52955]={"𡡊"}
	a[52956]={"棅"}
	a[52961]={"綔"}
	a[52962]={"塖","櫾","𡍥","𡑙","𣛐","𣞧"}
	a[52963]={"櫯","𡑿","𣚄"}
	a[52964]={"𡏮","𣕔","𦀱"}
	a[52965]={"𨋲","𪍨"}
	a[52966]={"鞂"}
	a[52971]={"𥛱"}
	a[52972]={"㰃","𣞿","𦁬"}
	a[52975]={"𪏦"}
	a[52976]={"槧","𣝞"}
	a[52981]={"𣟠"}
	a[52982]={"𤢴"}
	a[52983]={"𥡯"}
	a[52991]={"𣠡"}
	a[52992]={"櫟"}
	a[52993]={"㜰"}
	a[52996]={"𨍱"}
	a[52998]={"轈","𩍀"}
	a[53011]={"办","朴",""}
	a[53012]={"𡚿"}
	a[53021]={"圤","杺"}
	a[53022]={"协","柲","𠡙","𠧭"}
	a[53023]={"妼"}
	a[53033]={"𦓦"}
	a[53034]={"刱"}
	a[53042]={"卦"}
	a[53065]={"𨊳","𩊃"}
	a[53066]={"䩛"}
	a[53074]={"䪐"}
	a[53078]={"𠨊"}
	a[53101]={"檀"}
	a[53102]={"㙵","嬗"}
	a[53103]={"𣟐"}
	a[53104]={"𨿬","𩁓"}
	a[53105]={"𩀴"}
	a[53106]={"𦔛"}
	a[53108]={"難"}
	a[53110]={"𩁚"}
	a[53111]={"壇","𩁤"}
	a[53115]={"𩍕","𩏨"}
	a[53116]={"𩁀","𩏟"}
	a[53117]={"𣡻","𩁪","𩍓"}
	a[53118]={"䡴","𩀤","𩁢","𩁣","𩍅"}
	a[53119]={"㰙","𩁬"}
	a[53121]={"𤜪"}
	a[53131]={"杧","柆"}
	a[53132]={"㹥","𡌊","𡛩"}
	a[53133]={"𥁘"}
	a[53141]={"垃","盐","盚"}
	a[53142]={"柱","榓","盋","𪌁"}
	a[53143]={"㙬","垄","妵","猚","盏"}
	a[53144]={"盞"}
	a[53151]={"𥁦"}
	a[53152]={"堏","𤥲"}
	a[53153]={"䢂","椎","隿","𣛮","𨾍","𪌘"}
	a[53154]={"婎","𡝰","𡡛","𨾓"}
	a[53155]={"𣛷"}
	a[53161]={"橀","𤡙"}
	a[53162]={"𣚪"}
	a[53163]={"㯆","䧱","堆","墭","雄","𡌳","𨾅"}
	a[53164]={"䧴","盙","𣗙","𣚳","𨾕","𨾚","𨾩","𨿙","𪍇"}
	a[53165]={"𨿕"}
	a[53172]={"𡍠"}
	a[53173]={"䥭","䧸","䧺","𤢐","𤦂","𤦒","𨾬","𨿟"}
	a[53174]={"獞","雑","𣠥","𤣕","𤯯"}
	a[53175]={"𡡳","𦔤","𨋢","𩊌"}
	a[53181]={"𡐁","𤢏"}
	a[53182]={"𡒙"}
	a[53183]={"䨅","𨾺","𨿫"}
	a[53184]={"橦","𨿣","𨿲"}
	a[53185]={"黈"}
	a[53186]={"軴","𨿌","𨿢"}
	a[53193]={"㙲"}
	a[53194]={"䧿","䪒","墥","𨿨"}
	a[53195]={"㰚"}
	a[53196]={"𪏌"}
	a[53197]={"鞡","𨌴","𩋘"}
	a[53198]={"𨿩"}
	a[53211]={"𣠐"}
	a[53231]={"㺑","楌"}
	a[53232]={"椮"}
	a[53233]={"𡞋"}
	a[53241]={"槮","𡎑"}
	a[53242]={"㜗"}
	a[53251]={"墋"}
	a[53252]={"𡣙"}
	a[53261]={"櫅"}
	a[53265]={"𩊮"}
	a[53285]={"𩌰"}
	a[53305]={"欀","𩏢"}
	a[53306]={"孃","𪏤"}
	a[53307]={"轗","𤒿"}
	a[53308]={"㸐"}
	a[53310]={"𧕴"}
	a[53311]={"犿","𢖼","𢚡","𣟎","𤇍","𤈿"}
	a[53315]={"壤","𩍖"}
	a[53318]={"戁"}
	a[53319]={"𧕹","𧕾","𨏛"}
	a[53321]={"怸","𢗥","𣏣"}
	a[53322]={"𤡮"}
	a[53331]={"㹡","怷","𢠃","𣐿","𤡧"}
	a[53332]={"㛄","憖","橪"}
	a[53333]={"㜣"}
	a[53341]={"裘","𣐙","𣚈","𣛚"}
	a[53342]={"妶","袭","𡑋"}
	a[53343]={"㺘","慭","𧈩"}
	a[53344]={"𢞿"}
	a[53351]={"䬥","橠","𡊨","𡑐","𤢛","𤢭"}
	a[53352]={"惑","𡟓"}
	a[53353]={"樵","𢡫","𤠠","𧋛"}
	a[53354]={"嫶"}
	a[53356]={"嬢"}
	a[53361]={"㙥","檺","櫰","𣘨","𤡖"}
	a[53362]={"㜳","𤢼"}
	a[53363]={"榱","𡌺","𣛎","𣛴","𤍫","𤢢","𩻜"}
	a[53364]={"𡢳","𢤍"}
	a[53365]={"壌"}
	a[53369]={"𡡫"}
	a[53371]={"㭹","壕","壞","檍"}
	a[53372]={"㰅","娹","嬑"}
	a[53373]={"㙳","𡣪","𣟊","𩎭"}
	a[53374]={"㜵","𧌒"}
	a[53375]={"𨍽"}
	a[53378]={"𣟚"}
	a[53383]={"耲"}
	a[53384]={"𤒉","𤒜"}
	a[53385]={"䩙","𣟥","𣟻","𧒔","𩍑"}
	a[53395]={"獽","𨎊","𨎭"}
	a[53397]={"䘁"}
	a[53401]={""}
	a[53403]={"𩏈"}
	a[53404]={"㰇","𣟵"}
	a[53405]={"𡓖","𡣳","𩎹"}
	a[53406]={"𡚞","𨎱"}
	a[53407]={"𢨣"}
	a[53411]={"弋","𢎂","𨏖"}
	a[53412]={"戈","𢦞"}
	a[53413]={"𡰠","𢦍","𢦖","𣟅","𣠾","𤞉"}
	a[53414]={"㚀","㜲","𡤪","𢦑"}
	a[53415]={"𩀸"}
	a[53417]={"𨏪"}
	a[53418]={"𢨢","𨎵","𨏓"}
	a[53421]={"尤","弌","忒","朮","狁","𢍺","𢍻"}
	a[53422]={"㭖","尨","杙","犹","龙","","𢦟","𢦠","𢦥"}
	a[53423]={"㚤","戋","戎","栰","烖","狘","狵","","𡛲","𢦏","𢦔","𢦼","𣏾"}
	a[53424]={"戒","戔","狨","","𡛏","𡜐"}
	a[53425]={"㹽"}
	a[53426]={"𢦫"}
	a[53431]={"㭇","弍","式","犺","𢍽","𢍾","𢎉","𣏞","𤞀"}
	a[53432]={"㦯","戓","𢦙","𢦵","𢦶","𦁓"}
	a[53433]={"㘺","㚭","㢤","㦲","䴬","垅","栊","𡯮","𢦎","𣐋","𤠽"}
	a[53434]={"㦮","㭜","䴰","娍","娏","栈","栽","胾","","𡛟","𡟬","𢦒","𢦛","𢧇","𤈮","𪌙"}
	a[53435]={"娀","械","棧"}
	a[53436]={"娥"}
	a[53441]={"弎","杭","梳","贰","𡊿","𢎃","𣑁"}
	a[53442]={"妔","或","栻","𡜋","𡿿","𢎋","𢦘","𢧆","𤉨"}
	a[53443]={"㦴","㺂","哉","城","弑","弒","槭","甙","裁","𢎌","𢦦","𢦮","𢦴","𢦷","𤰭","𦀂","𧈱"}
	a[53444]={"㘽","㦳","彧","𡊸","𡠽","𢎇","𢦨","𣚸","𧛦"}
	a[53445]={"桟","楲","𡍌","𡯰","𢦣","𣒭","𦛹"}
	a[53446]={"䴼","媙"}
	a[53451]={"坑","𠒨","𤬩","𧴮"}
	a[53452]={"㜔","𢎆","𢦭","𣓸"}
	a[53453]={"㦶","墄","娬","棫","椷","𢦾"}
	a[53454]={"㛾","乶","𠳆","𢧩","𣔮","𣖋","𤱱","𧚝","𪎈"}
	a[53455]={"㙎","蛓","𠒲","𢧟","𣚙","𨐇"}
	a[53456]={"载","𡞨"}
	a[53457]={"𢧧"}
	a[53461]={"獍","𡯳","𢎈"}
	a[53462]={"㗠","𣖿"}
	a[53463]={"域","堿","戜","樴","𡯽","𢧌","𣎉","𥅤","𥅰","𧯥","𨟲"}
	a[53464]={"喸","嬂","戟","戡","臷","轼","𡢧","𢎑","𢧉","𢧑","𢧣","𢧺"}
	a[53465]={"䵧","截","𢧴","𢨇","𢨗","𨋍"}
	a[53466]={"𡣯"}
	a[53468]={"𢨖"}
	a[53471]={"樈","訄","貳","𢎐","𢨏"}
	a[53472]={"𣜐"}
	a[53473]={"䳒","槞","𡑌","𤡇","𧧬","𧹹","𨚵"}
	a[53474]={"檝","𢧜","𢧤","𢧬","𣛔","𣛸"}
	a[53475]={"㰄","橶","酨","𢧔"}
	a[53476]={"戴","𣝫"}
	a[53477]={"𢨎"}
	a[53478]={"載","𪏊"}
	a[53479]={"輚","𩋋"}
	a[53481]={"境"}
	a[53482]={"樲"}
	a[53483]={"㦽","㺤","戫"}
	a[53484]={"𨛚","𩳠","𪎵","𪎽"}
	a[53485]={"㦼","䡉","𢒰","𢧭","𩎙"}
	a[53486]={"軾","𢧨","𨠾"}
	a[53487]={"𢨚"}
	a[53489]={"𨌏"}
	a[53492]={"𢨁"}
	a[53493]={"櫼","韯","𡐒","𡒤","𢨆"}
	a[53494]={"㺣","䰥","孅","𡒾","𡰒","𤢷"}
	a[53496]={"𢧸","𢨜","𪏇"}
	a[53497]={"輱","𨎕","𨎡","𩋉"}
	a[53498]={"𪏞"}
	a[53503]={"𦆾"}
	a[53506]={"欆"}
	a[53507]={"孇"}
	a[53512]={"狡","","𠀋","𡓑","𡓣","𤝥"}
	a[53516]={"䡶","𨎙","𩌬"}
	a[53522]={"校","犮","狻","猝","𣐀","𪋿"}
	a[53523]={"妏","姣","𤝏","𤝜"}
	a[53524]={"𢌵"}
	a[53532]={"坟","柿","梭","棭","椊","𡋟","𤟾"}
	a[53533]={"㛖","㭓","柭","𡝵"}
	a[53534]={"妭","𡛞"}
	a[53542]={"埈","埣","梓","楴"}
	a[53543]={"㛙","坺","媂","桙","桳","椄","𡊯","𨐖","𪍅"}
	a[53544]={"㛌","较","𠀽","𡏜","𡞘","𢂤","𪌚"}
	a[53546]={"𡠃"}
	a[53552]={"垶"}
	a[53553]={"𢃤","𣘲"}
	a[53554]={"麰"}
	a[53555]={"韨"}
	a[53562]={"獐","𣘚","𨐒"}
	a[53563]={"聋","𣁖","𣕀"}
	a[53564]={"榫","辢"}
	a[53565]={"𪏁"}
	a[53566]={"較","𩊔"}
	a[53568]={"𠕯"}
	a[53572]={"樟","𤢣"}
	a[53573]={"嫜"}
	a[53574]={"㯠","𩎦"}
	a[53575]={"𡠐"}
	a[53576]={"𨌘","𩊻","𩋛"}
	a[53577]={"軷","𨋒","𩊊"}
	a[53582]={"墇","檘"}
	a[53584]={"𢨋"}
	a[53585]={"韍","𦗱"}
	a[53586]={"𨌍","𩋣"}
	a[53592]={"壀","𦆽"}
	a[53605]={"䩧","𨍑"}
	a[53607]={"輽"}
	a[53615]={"𨌶","𩋻"}
	a[53632]={"㹾"}
	a[53641]={"枱","𣖤"}
	a[53642]={"始","𣓌"}
	a[53651]={"坮","棓","狺","𡌮","𤟟"}
	a[53652]={"婄","砻","𡜗","𣔊","𣙴"}
	a[53653]={"𡜿"}
	a[53661]={"㯁","培"}
	a[53662]={"㛺","㜃","䴺","娮","𣚌","𤠕"}
	a[53663]={"㮥","耛","𡡿"}
	a[53671]={"堷","𧥠"}
	a[53672]={"㮷","槒","詟","𡞙","𢧋"}
	a[53673]={"㜅","䎧","𣚍","𧧿","𪍼"}
	a[53675]={"𤳡"}
	a[53682]={"𥇙","𧹴"}
	a[53683]={"𦔑"}
	a[53684]={"𦔝"}
	a[53685]={"軩"}
	a[53694]={"𧫊"}
	a[53695]={"鞛"}
	a[53700]={"𨍭","𩌏"}
	a[53701]={"𡐴"}
	a[53703]={"𣋄","𪙓"}
	a[53704]={"𧥀"}
	a[53705]={"䵍","𨌯"}
	a[53706]={"鞟"}
	a[53707]={"䪔"}
	a[53710]={"𢺋"}
	a[53711]={"𨏺"}
	a[53712]={"鸑"}
	a[53714]={"韕"}
	a[53715]={"𩌡"}
	a[53716]={"𧥑"}
	a[53717]={"𩏎"}
	a[53718]={"䪙","𡿊","𦣊","𦣚"}
	a[53719]={"臡"}
	a[53722]={"书"}
	a[53731]={"枋"}
	a[53732]={"妨"}
	a[53741]={"坊","鸢","𢎀","𢎅"}
	a[53742]={"垴","","𡊔","𣓲"}
	a[53743]={"𤡢","𤮼"}
	a[53744]={"甫","𡜫"}
	a[53751]={"梈","榜"}
	a[53752]={"姢","嫎","𤠻"}
	a[53753]={"樆","𩡷"}
	a[53755]={"㭪","尃","膥"}
	a[53756]={"猼","𡜵"}
	a[53761]={"塆","塝","墒","棛","楟","鳶","𤠖"}
	a[53762]={"㛩","婷","椁","樀","𪙤"}
	a[53763]={"嫡"}
	a[53764]={"旉","麶"}
	a[53765]={"埔","𣕛"}
	a[53766]={"博","榑","麱","𣬀"}
	a[53771]={"堉","槁","𣚓"}
	a[53772]={"埻","墑","𡠀","𡽺","𣙛"}
	a[53773]={"䵂","槜","耪"}
	a[53775]={"𦔓"}
	a[53776]={"㙛"}
	a[53777]={"辅","𣚺","𤰍","𪍡"}
	a[53781]={"塙"}
	a[53783]={"䳣","檇"}
	a[53784]={"䎮","𧤅"}
	a[53788]={"𦔍","𦔣"}
	a[53792]={"𪂵"}
	a[53793]={"𪃘"}
	a[53795]={"䩷","𨍩"}
	a[53799]={"輔","𩊬"}
	a[53802]={"𧾑"}
	a[53804]={"𧽿"}
	a[53805]={"䟈","𧾞","𨏅"}
	a[53808]={"𤓉"}
	a[53811]={"犬","𧾍"}
	a[53812]={"犾","𤝯"}
	a[53813]={"𡔎","𣡌","𧾕"}
	a[53817]={"䡾"}
	a[53821]={"𣏥"}
	a[53822]={"㹜","枤","栿","猌","𤢅"}
	a[53831]={"核","赴"}
	a[53832]={"垘","姟","狱","𡉩"}
	a[53833]={"猋","","𡯯","𤜲","𤞿"}
	a[53834]={"㹷"}
	a[53841]={"垓","𧺨","𧻏"}
	a[53842]={"䞖","𤉹","𥏳","𧺶","𧻨"}
	a[53843]={"䶮","娭","𤞷","𤯂","𧺱"}
	a[53844]={"龚","𠎶","𤠨"}
	a[53847]={"𤝟"}
	a[53851]={"貣","趇"}
	a[53852]={"㺇","䞭","埃","𤠒","𧻱"}
	a[53853]={"献","越","𡌤","𣛑","𧺺","𧻗"}
	a[53854]={"𣜀","𤡜"}
	a[53855]={"䞲"}
	a[53861]={"䟃","𧺻","𧾋"}
	a[53862]={"獄"}
	a[53864]={"樾","𧶤"}
	a[53866]={"𤣊","𨋩","𩊙"}
	a[53871]={"䞳","𡎖"}
	a[53873]={"㰗","趡","趭","𧼑"}
	a[53874]={"𩎓","𩎧"}
	a[53875]={"輆","𡙱","𧻷"}
	a[53881]={"𧾙"}
	a[53882]={"𣚕","𧽦"}
	a[53883]={"𧾔"}
	a[53884]={"𤒓"}
	a[53885]={"𧾢"}
	a[53891]={"𧼏"}
	a[53892]={"𧽣"}
	a[53893]={"𧽫"}
	a[53894]={"𧽮"}
	a[53895]={"𧾂"}
	a[53896]={"䟌"}
	a[53911]={"术"}
	a[53912]={"𤝞"}
	a[53915]={"𨎺","𨏸"}
	a[53916]={"𨎹"}
	a[53921]={"求"}
	a[53922]={"𤞰"}
	a[53923]={"𣏩"}
	a[53930]={"𤡅"}
	a[53931]={"猄"}
	a[53932]={"梂","樑","𡊍","𡌋"}
	a[53933]={"㛏"}
	a[53941]={"椋"}
	a[53942]={"墚","婛","榇","𡋠"}
	a[53943]={"媇","𡝥","𪌵"}
	a[53951]={"𡌿"}
	a[53952]={"㰑","㳼","𡍕"}
	a[53961]={"𣚎"}
	a[53963]={"辌"}
	a[53964]={"𣛜"}
	a[53966]={"𣙆"}
	a[53972]={"檁"}
	a[53974]={"㙫","𣙇"}
	a[53975]={"𩊍"}
	a[53976]={"𨎛"}
	a[53981]={"檩"}
	a[53982]={"壈","𣝩"}
	a[53984]={"𥜖"}
	a[53985]={"輬"}
	a[53986]={"𩋑"}
	a[53991]={"𡒄"}
	a[53995]={"𨍡"}
	a[54103]={"𣡂"}
	a[54105]={"㙻"}
	a[54116]={"𤾳","𨍧"}
	a[54131]={"桖"}
	a[54141]={"𡋒"}
	a[54142]={"桩","𣖵"}
	a[54143]={"㛇"}
	a[54151]={"𠦠","𡌾"}
	a[54152]={"𡎻"}
	a[54153]={"𡝬"}
	a[54162]={"榁","𡝮","𤟡"}
	a[54171]={"𠒩"}
	a[54172]={"楻"}
	a[54173]={"媓"}
	a[54182]={"堭","𨪄"}
	a[54184]={"𡏂"}
	a[54204]={"孊","𪖪"}
	a[54211]={"犷"}
	a[54215]={"𦔭"}
	a[54222]={"㚧"}
	a[54231]={"圹"}
	a[54232]={"妒"}
	a[54241]={"𡉴"}
	a[54251]={"𣓠"}
	a[54275]={"䡎"}
	a[54282]={"𤢳"}
	a[54293]={"嬶"}
	a[54300]={"𨎷"}
	a[54305]={"𩌝"}
	a[54317]={"𩍶"}
	a[54333]={"𤡍"}
	a[54341]={"狼","𤏇"}
	a[54343]={"樜","𡠴","𡣇"}
	a[54344]={"嫬"}
	a[54351]={"桹","𣖐"}
	a[54352]={"㙆","娘","樬","𡡪"}
	a[54353]={"墌"}
	a[54354]={"嬷"}
	a[54361]={"㮩","埌","槌"}
	a[54362]={"媳","𡟴"}
	a[54364]={"嬤","𤯋"}
	a[54369]={"嬚"}
	a[54371]={"塠","𦫐"}
	a[54381]={"𣡬"}
	a[54382]={"嬝","𣠣"}
	a[54385]={"𦔗"}
	a[54387]={"䩾"}
	a[54391]={"𣟴","𣠯"}
	a[54395]={"䡙","𦔩"}
	a[54396]={"䡯","𨐊"}
	a[54404]={"䰩"}
	a[54407]={"𨍹","𩌃"}
	a[54413]={"𩎾","𩴺"}
	a[54414]={"櫷","魗","𪚸"}
	a[54415]={"䶯","𩏐","𩴟"}
	a[54417]={"轆","𡔙","𩌫"}
	a[54421]={"𣏆","𤢱"}
	a[54422]={"𡛥"}
	a[54431]={"𣑒","𤝤"}
	a[54432]={"㭦","𢦕","𣒔"}
	a[54441]={"㹸","𡊫","𡋉","𡯬","𣐖"}
	a[54442]={"㛡","㭽","𡠌"}
	a[54443]={"𤡊"}
	a[54444]={"𡟉"}
	a[54451]={"梎","𣓄"}
	a[54452]={"𡊾","𡍓","𤠞"}
	a[54461]={"𠙓","𡌗","𣓛","𣖲"}
	a[54462]={"㮰","梍"}
	a[54463]={"㞈","媲","槐"}
	a[54464]={"媿","𩳃"}
	a[54471]={"𡰎","𩾛"}
	a[54472]={"𡯹","𡰆"}
	a[54473]={"塊","樚","𣟂","𩲄","𪍜"}
	a[54474]={"㜙","𡣚"}
	a[54475]={"𨋠"}
	a[54481]={"槴"}
	a[54483]={"塶","𡒵"}
	a[54486]={"𨌮"}
	a[54493]={"𩲾"}
	a[54495]={"䡚","軶","辘"}
	a[54496]={"䰤","𩳔","𩳶"}
	a[54502]={"𡓊"}
	a[54506]={"𩏂"}
	a[54514]={"𩏤"}
	a[54515]={"韟"}
	a[54516]={"𨎦"}
	a[54519]={"𢅺"}
	a[54534]={"𣔬"}
	a[54542]={"獔","𣐼","𣔳"}
	a[54544]={"猈"}
	a[54552]={"棉","榟","𡍔","𡍩","𣖸"}
	a[54553]={"婂","獆","𡒠","𤠜"}
	a[54554]={"椑","𡞌","𡞬"}
	a[54555]={"婢"}
	a[54556]={"𡣥"}
	a[54562]={"槹","獋","𡍇"}
	a[54563]={"榳","槔"}
	a[54564]={"㯅","埤","櫦","𡍨","𡟷","𡟾"}
	a[54565]={"䴽","𦔕"}
	a[54572]={"埠","橰"}
	a[54573]={"嬵","𡏉","𡠖","𣘶"}
	a[54574]={"𠬈"}
	a[54576]={"𣘍","𦓸"}
	a[54583]={"𡏻"}
	a[54587]={"𠧃"}
	a[54592]={"櫠"}
	a[54594]={"𧯿"}
	a[54598]={"䡟","䩲","鞞","𨍏"}
	a[54603]={"𡒅"}
	a[54612]={"𣎬"}
	a[54619]={"𨍴"}
	a[54631]={"狛"}
	a[54632]={"㭡"}
	a[54633]={"𡜧"}
	a[54641]={"柏","𤝼"}
	a[54642]={"𡛳"}
	a[54651]={"𡊚","𣑉","𣓡"}
	a[54652]={"𡜍"}
	a[54661]={"垍","𡌽"}
	a[54665]={"𤠯"}
	a[54673]={"𡒷","𣟖"}
	a[54675]={"榶"}
	a[54676]={"㜍"}
	a[54682]={"𡡮"}
	a[54683]={"𡡩"}
	a[54685]={"塘","赯","𩊀"}
	a[54692]={"𡓜"}
	a[54695]={"耱","𨌋"}
	a[54701]={"𪃥"}
	a[54702]={"鵲","𪂂","𪃙","𪅾","𪆁"}
	a[54703]={"𪅐"}
	a[54704]={"鵪","鷬","𪃈"}
	a[54705]={"䳞","䳬","鿂"}
	a[54706]={"鶈","𪁀"}
	a[54707]={"韀"}
	a[54711]={"鶘","鷏","鷧","𩌨","𪄘","𪄽","𪇄"}
	a[54712]={"䴏","鶄","𪃇","𪄖","𪄸","𪆘","𪇘"}
	a[54713]={"䴃","䴅","𪂹","𪅖","𪅸","𪆉"}
	a[54715]={"䡪","䡻","鷒","鷫","𪇠","𪈻"}
	a[54716]={"𪄿","𪅀","𪇼","𪇽"}
	a[54718]={"𪃺"}
	a[54731]={"枦"}
	a[54732]={"椨"}
	a[54733]={"𣑮"}
	a[54741]={"㭤"}
	a[54742]={"姠","𡜾","𡞶","𣑑"}
	a[54743]={"猵"}
	a[54745]={"𤡺"}
	a[54751]={"㮧","㮼","坞","垧","垿","桘","椖","猏","鸠","","𤡕","𩾘","𪉌"}
	a[54752]={"㘾","鸫","𡜥","𡠄","𩾾"}
	a[54753]={"㛛","楄","𢩟","𤢒"}
	a[54754]={"媥"}
	a[54755]={"辀"}
	a[54756]={"𣜏"}
	a[54761]={"䲪","垖","塢","樢","鵊","鶆","鸪","𡍀","𣓖","𣕄","𣗉","𩾔","𩾢","𩿛","𩿯","𪀬","𪉅"}
	a[54762]={"𡌏","𡍈","𡡅","𣙾","𩾷","𪀣","𪌤"}
	a[54763]={"𡎚","𣘋"}
	a[54764]={"鹔"}
	a[54765]={"鷞","𡦴"}
	a[54771]={"槝","鳩","鹩","𩾵","𩿅","𪁌","𪁖","𪄭"}
	a[54772]={"䳊","䳍","䳵","檰","鳷","鳺","鴂","鹁","鹲","𡏾","𡢠","𩾞","𩿣","𪀜","𪁪","𪄳"}
	a[54773]={"鵗","𦔁","𪉏"}
	a[54774]={"𡣴","𩾺"}
	a[54776]={"𡦭","𨋦"}
	a[54777]={"輈"}
	a[54778]={"㺎"}
	a[54781]={"櫋","鴣","𣝼","𩿹","𪀦","𪁓"}
	a[54782]={"䲺","鹊","𣞌"}
	a[54783]={"櫥","鵣","鶫","𣟡","𪁡"}
	a[54784]={"鹌"}
	a[54786]={"𡤝","𡦳"}
	a[54788]={"槦"}
	a[54789]={"嫞"}
	a[54791]={"䳑","鴮","鴶","鵸","鷯","鹕","𡒳","𩿆","𪄗"}
	a[54792]={"䳏","䳓","䳢","䴖","鵓","鵱","","𪂉"}
	a[54793]={"𣡐","𪃏"}
	a[54794]={"鴺","鵏","鶇","鶒","𪂩","𪃸","𪄐","𪅙","𪏝"}
	a[54795]={"䡧","𨋱"}
	a[54796]={"𡦲","𨌈","𪏗"}
	a[54797]={"䡢"}
	a[54798]={"墉"}
	a[54801]={"䟍"}
	a[54803]={"𡤧"}
	a[54810]={"𩎅"}
	a[54811]={"𧾫"}
	a[54813]={"𣠦"}
	a[54815]={"𧾡"}
	a[54818]={"𪏪"}
	a[54842]={"棙","𤟑"}
	a[54843]={"𡝢","𣙃"}
	a[54844]={"㜩"}
	a[54845]={"㹹"}
	a[54852]={"槉","𧼭"}
	a[54853]={"㺙","墺","嫉","𡐝","𡞃","𧻖"}
	a[54855]={"椩"}
	a[54861]={"䞟"}
	a[54862]={"𡡨","𡢌","𣗬","𣘔","𣚲","𧻧","𧼳"}
	a[54865]={"獷","𡌻"}
	a[54871]={"𧻴","𧽋"}
	a[54872]={"𧽑"}
	a[54874]={"𧼠"}
	a[54875]={"櫎"}
	a[54881]={"㯽","𧽪","𧽴"}
	a[54882]={"𡣕","𧽒"}
	a[54885]={"壙","𨌓"}
	a[54886]={"𪍿"}
	a[54892]={"䞹"}
	a[54893]={"𦤣","𧽥"}
	a[54896]={"𡤐"}
	a[54905]={"𦘢"}
	a[54908]={"𪏢"}
	a[54909]={"𨎍"}
	a[54931]={"栐"}
	a[54932]={"𡛻"}
	a[54933]={"𡜻"}
	a[54942]={"𣓅"}
	a[54944]={"嫲","𣗈"}
	a[54951]={"楾"}
	a[54961]={"𡎏"}
	a[54962]={"𤡔"}
	a[54963]={"𡣲"}
	a[54965]={"槺"}
	a[54966]={"嫝"}
	a[54972]={"㙞","𣘖"}
	a[54973]={"𡠿"}
	a[54975]={"𡐓"}
	a[54976]={"𨌟"}
	a[54982]={"𡏭"}
	a[54984]={"𣟸"}
	a[54992]={"𡓔"}
	a[55002]={"㪺","𣂏","𤜥"}
	a[55012]={"⺿","卄","廾"}
	a[55013]={"卅","","𢌭","𣂐"}
	a[55014]={"卌",""}
	a[55015]={"𪏡"}
	a[55022]={"枓","耂","","𠥻"}
	a[55023]={"枡"}
	a[55024]={"𠦌","𡛈"}
	a[55032]={"㘰","","𡈿"}
	a[55033]={"𡉧","𪌉"}
	a[55044]={"𣁮","𪍎"}
	a[55052]={"𡉜"}
	a[55053]={"㪸","𠦧"}
	a[55056]={"𢍤","𩉠"}
	a[55062]={"𣙞"}
	a[55063]={"卙","斟"}
	a[55064]={"槲"}
	a[55065]={"斢"}
	a[55079]={"斠"}
	a[55094]={"𣂍"}
	a[55102]={"檶"}
	a[55103]={"檯","𣟁","𪔣"}
	a[55104]={"䥢","嬯","𣝄","𩁂"}
	a[55106]={"𣍈","𧯮","𨍰","𩌍"}
	a[55107]={"𨍜"}
	a[55112]={"𥃕"}
	a[55113]={"鼟","𩇠","𪔶"}
	a[55114]={"鼞","𡒲","𪔮"}
	a[55116]={"𡅤","𢑹","𪔢","𪔴"}
	a[55117]={"𡅸"}
	a[55122]={"","𠃒"}
	a[55123]={"𠀍"}
	a[55124]={""}
	a[55132]={"杜","𠀤"}
	a[55133]={"世","狌","𡚳"}
	a[55134]={"","𠀎"}
	a[55142]={"","𠡃","𣖁","𥁹","𦒳"}
	a[55143]={"埜","栍","𠡘","𡋍","𡛿","𣑖","𣒣","𤞇"}
	a[55144]={"姓","枻","𣛍"}
	a[55145]={"坓","𡑀","𡛶"}
	a[55152]={"梉","猹","甚","𡊌","𡎌","𤠡"}
	a[55153]={"桂","𡝂","𣔭","𦒼","𨨗"}
	a[55154]={"㛬","娃","𡉘","𡍁","𣕸","𣗎"}
	a[55155]={"鐢"}
	a[55162]={"楂","榼","𣖻","𤯅","𥂅","𧯴"}
	a[55163]={"㛸","㜁","基","壄","椹","耊","𡋣","𡎃","𡐨"}
	a[55164]={"媅","楏"}
	a[55165]={"㛻","𡏳"}
	a[55172]={"植","𡏖","𤡬"}
	a[55173]={"堪","耋","𡎉","𣘇","𤦢"}
	a[55174]={"㯼","堼","樭","𤯾"}
	a[55175]={"𡐳","𦓯"}
	a[55176]={"堇","靯","𡎸"}
	a[55182]={"埴","𥂊"}
	a[55183]={"䑓","嬄","𣜯","𣠅","𦥄"}
	a[55184]={"𡓨","𦔏"}
	a[55185]={"𨤳"}
	a[55186]={"𡒣"}
	a[55187]={"槿"}
	a[55188]={"㯵","嫤","靾"}
	a[55192]={"㙪","㯛"}
	a[55193]={"𡡰","𣠩"}
	a[55194]={"𡢪","𣜉","𪔋"}
	a[55196]={"黊"}
	a[55197]={"䡜","墐","鞋"}
	a[55212]={"𡓀","𣞳"}
	a[55213]={"鼘","𪔱"}
	a[55222]={"𣓴"}
	a[55223]={"","𡗾"}
	a[55232]={"梦","棽","𣙄"}
	a[55233]={"枾","𣔁"}
	a[55234]={"𡝅"}
	a[55252]={"𣔷","𣜓"}
	a[55262]={"䎞"}
	a[55265]={"鬰"}
	a[55286]={"𢒻"}
	a[55294]={"鬱"}
	a[55303]={"𪔎"}
	a[55304]={"䵽"}
	a[55305]={"𪔖"}
	a[55306]={"慧","轅","𧒤"}
	a[55308]={"𡣺","𡤦","𩍠"}
	a[55310]={"轋","𧕐","𨎥"}
	a[55311]={"䡺","𧖤"}
	a[55312]={"𤝁"}
	a[55313]={"鼚"}
	a[55314]={"𦘏","𧑭"}
	a[55316]={"䘄","鼜","𢦊","𩏭"}
	a[55317]={"櫘","韢","𪔲"}
	a[55318]={"㚂","欜","韃","𣡢"}
	a[55319]={"𩏲"}
	a[55322]={"㷊","恭","𤈉"}
	a[55323]={"𡛕","𣒏","𣓙","𣔀"}
	a[55324]={"𢡟","𧹘"}
	a[55332]={"㹤","梺","椘","𡊀","𢙄","𢛓","𢠘","𣕯"}
	a[55333]={"𡡌","𢚈","𣑆","𣔰","𣕵","𣕾"}
	a[55334]={"𡝳","𢠖"}
	a[55335]={"𢢐"}
	a[55342]={"㭕","垯","梽","赫","𡉞","𡘋"}
	a[55343]={"塨","娡","𡊖","𡛠","𢟮","𣏢","𣓻"}
	a[55344]={"𡟀"}
	a[55346]={"𤢻"}
	a[55352]={"惎","懋","煮","猿","𡊛","𢛖","𢝖"}
	a[55353]={"麮","𢜯","𢣬","𣓕","𣗠"}
	a[55354]={"㯈","婊","梿","蛬","𢜨","𢣡"}
	a[55355]={"䙪","𣞢"}
	a[55362]={"㯖","榬","辳","𢝬","𣟆","𧞉"}
	a[55363]={"媴","𡠻"}
	a[55364]={"㜇","㥨","㺚"}
	a[55365]={"慸","转","𠦽","𧉺","𧌔"}
	a[55366]={"軚","𡞍","𢜎","𤣇"}
	a[55367]={"蠜"}
	a[55372]={"壊","燕","𤢍"}
	a[55373]={"𡐿","𣟛","𧛜","𧹨"}
	a[55374]={"橽","蜝","𡢫","𣚢","𣜚"}
	a[55375]={"橞"}
	a[55376]={"䡌","槤","鞑","𡞤","𢣱","𩉦"}
	a[55377]={"㜕"}
	a[55382]={"𣚅","𤢩"}
	a[55383]={"𣁩","𨑋","𪔟"}
	a[55384]={"䎭","墶","嬿","辕","鼕","𡐉","𡐬"}
	a[55386]={"𨘑","𩊴"}
	a[55387]={"㰈","𡓽","𪍦"}
	a[55388]={"櫣"}
	a[55392]={"㰐"}
	a[55393]={"𠬑"}
	a[55394]={"𢤵","𣞝"}
	a[55396]={"䗣","𡒹"}
	a[55397]={"㯾"}
	a[55398]={"𦔖"}
	a[55404]={"墝","𠓆"}
	a[55405]={"𪔯"}
	a[55406]={"𦓈"}
	a[55407]={"𣚆","𩊲"}
	a[55409]={"𨌧","𩋊"}
	a[55412]={"𢌬","𤝂"}
	a[55413]={"𪔷"}
	a[55414]={"𠓘","𪔘"}
	a[55415]={"𪔩"}
	a[55416]={"㚁"}
	a[55418]={"𡔚","𦓋","𨎬"}
	a[55422]={"杹"}
	a[55423]={"𡚨","𡚪","𤜨","𤠛"}
	a[55424]={"椛",""}
	a[55425]={"婲"}
	a[55432]={"㐗","㞀","老","𠃟","𡯏","𡯐","𣎹","𣏕","𣏟","𣑽"}
	a[55433]={"㹠","狫","𣏱"}
	a[55434]={"埖","奿","𣕢"}
	a[55435]={"𣕚"}
	a[55442]={"㭠","兙","梵","𠒚","𣒖"}
	a[55443]={"㭝","姺","杶","栳","桡","𡉒","𡋎","𡯤"}
	a[55444]={"姥","娆","𠒔","𡝴","𡟃"}
	a[55445]={"𡛋","𣕺","𣗩"}
	a[55452]={"㐞","㝾","尅","巷","棾","𡉵","𢀼","𣗡","𦒲"}
	a[55453]={"坉","娔","𤞯"}
	a[55454]={"𠒧","𡡶","𦒷","𪌋"}
	a[55455]={"𣝱","𤲅"}
	a[55456]={"𤕩"}
	a[55462]={"㞆","㯄","乽","𠙨","𡋰","𡋼","𢁀","𣒆","𣗗","𣛾"}
	a[55463]={"𣝥"}
	a[55464]={"檒","耄","𣜕"}
	a[55465]={"㭺"}
	a[55466]={"㛪","靴","𠒹"}
	a[55467]={"𣟝"}
	a[55472]={"㗯","䢽","𡍡","𢁂","𣓘","𧠩"}
	a[55473]={"塂"}
	a[55474]={"䎜","䬡","櫆","𣝹","𣯕","𩲘"}
	a[55475]={"㞄","埯","嬔"}
	a[55476]={"𪎴"}
	a[55477]={"𨊯"}
	a[55482]={"㐤","兢","𠙯","𣜺","𤭦","𨚻"}
	a[55484]={"獟","麓","𡭄"}
	a[55485]={"嬎","𨟄"}
	a[55486]={"𪋤","𪎶"}
	a[55487]={"䎨","軘"}
	a[55488]={"𣮝"}
	a[55493]={"𩇜","𪔛"}
	a[55494]={"橈"}
	a[55495]={"嬈","欌"}
	a[55499]={"䡸"}
	a[55500]={"䡛","䩬","𣞶","𨍝"}
	a[55504]={"㸚"}
	a[55505]={"𪔙"}
	a[55506]={"𪔍","𪔔"}
	a[55507]={"䡤"}
	a[55508]={"鞤","𣋕"}
	a[55510]={"𨏆","𨏬","𨏰"}
	a[55511]={"𨏟","𨏲","𨏿"}
	a[55513]={"𣏠"}
	a[55514]={"𦗺","𧂘","𧅍","𨑀","𪔪"}
	a[55516]={"鼙","𩏴"}
	a[55517]={"𣍚","𩍳","𪔞"}
	a[55518]={"韚","𦧄","𪔨"}
	a[55523]={"杖","柹","犻","𠂀","𤞗"}
	a[55524]={"丼","井","奻","姊","狶","","","𡚹","𢌰","𢺽"}
	a[55526]={"𢌽"}
	a[55533]={"㠻","㭌","杮","枝","柨","桦","𡉋","𣐈"}
	a[55534]={"㚴","妓","姉","婪","带","枿","桸","𡛀","𡛷","𣲜"}
	a[55535]={"㛓","㹬","𠦈","𡜘","𡝄","𡝋","𢍌","𣏨","𣒢","𤡶"}
	a[55536]={"妌","𡡴"}
	a[55543]={"㘵","桝","棱","𡉯","𣔏","𧹛"}
	a[55544]={"㭋","婈","","𢂏","𢺷","𢺸","𢺻","𣗚"}
	a[55545]={"㘫","妦","","𡞴","𪌹"}
	a[55546]={"𡝈"}
	a[55547]={"𠦒"}
	a[55548]={"㐩"}
	a[55553]={"堎","𡜩","𢃛","𤯀"}
	a[55554]={"婞","𡐵","𢃄","𣖂","𣖓"}
	a[55555]={"㩽","帶","革","","𠮂","𡍋","𢂸","𢺿","𣞜"}
	a[55556]={"𡟘","𡡷","𤠇","𤠹"}
	a[55557]={"䡈","耕","𣝴","𦓮","𩉤"}
	a[55559]={"𨌸"}
	a[55563]={"攲","𡕮","𢻢","𥮌"}
	a[55564]={"幇","𢄬","𢻏","𢻦","𤚁"}
	a[55565]={"㜂","𡟌","𩎔"}
	a[55566]={"㮖","㯂","嫐","棒","𣒞"}
	a[55567]={"棲","𡝀","𡟍","𡠹"}
	a[55573]={"橭","鼓","𡍲"}
	a[55574]={"嫴","樷","𢻎","𦨀","𨐞"}
	a[55575]={"犎","𥀂"}
	a[55576]={"埲","墆","𡌄"}
	a[55577]={"䡋","輂","辇","𨋞","𩉨"}
	a[55578]={"𠦱"}
	a[55583]={"𠦶"}
	a[55584]={"嬊","𡤈"}
	a[55585]={"韩"}
	a[55587]={"輘"}
	a[55588]={"檋","𣡜","𩉧","𩊈"}
	a[55594]={"幫"}
	a[55596]={"𨤺"}
	a[55598]={"𨌐"}
	a[55599]={"㯬","輦"}
	a[55602]={"㬫","𣋅"}
	a[55603]={"䵿","䶀","𪔑","𪔓"}
	a[55604]={"鼛","𣊣","𣟟","𪔐","𪔗"}
	a[55606]={"𣊛","𪏈"}
	a[55607]={"𩊿","𩋵"}
	a[55610]={"𨣹"}
	a[55611]={"𣌠","𨎝","𨐄"}
	a[55612]={"囍","𣞸"}
	a[55613]={"䶁","櫧","瞽","𡕇","𪔧"}
	a[55614]={"𡄝","𡅕","𧭃","𩏫"}
	a[55616]={"轖","𡆐","𡆒","𡤮","𣊄","𩍙"}
	a[55617]={"囏"}
	a[55618]={"𣍘","𨎈"}
	a[55619]={"𣡘"}
	a[55632]={"狜"}
	a[55642]={"㖈","䎛","枯","狤","𠵂","𣐞","𣒙","𣞖","𤞺","𤽠"}
	a[55643]={"姑","𡛮","𡜺","𣒅"}
	a[55646]={""}
	a[55652]={"昔","桔","梏","者","𡊜","𣈅","𦒻"}
	a[55653]={"㯴","姞","榃","猎","猪","𡜲","𤰻","𤱺"}
	a[55654]={"𣙊","𣛃","𥖎"}
	a[55655]={"𡟻"}
	a[55662]={"耆","𠳬","𡌃","𣜞","𣞋","𥆇","𦒾"}
	a[55663]={"棤","楮","𠹝","𣚫","𪌧"}
	a[55664]={"㛭","媎","轱","𥖯"}
	a[55665]={"礬"}
	a[55671]={"𤢀"}
	a[55672]={"㫷","樯","檣","碁","𡒜","𣚬","𣞱","𥖥","𦒿","𦓀"}
	a[55673]={"堵","嫱","嬙","榰","赭","𡣰","𣛇","𣛋"}
	a[55674]={"替","椿"}
	a[55675]={"媋"}
	a[55676]={"曹"}
	a[55677]={"𣞦","𤡐"}
	a[55682]={"喆","墙","墻","橲"}
	a[55683]={"嬉","槠","𡒝"}
	a[55684]={"堾","𤯈"}
	a[55685]={"耤","𡤑","𣚽"}
	a[55686]={"軲","𩊉"}
	a[55687]={"槽"}
	a[55688]={"㜖"}
	a[55692]={"諅","𥈄"}
	a[55694]={"𡣗","𣞩","𤾞"}
	a[55695]={"𣟞","𦔌"}
	a[55696]={"鞊","𨌒","𩊵","𪍲"}
	a[55697]={"𡐋"}
	a[55698]={"𨠷"}
	a[55703]={"檮","𣡱"}
	a[55704]={"嬦","𪔕"}
	a[55705]={"欍"}
	a[55706]={"𤣢"}
	a[55707]={"槥","轛"}
	a[55708]={"𩋮"}
	a[55709]={"鞴"}
	a[55710]={"轉","𨍛","𨏼"}
	a[55711]={"轊","鞲","韝","𡔘","𡤛"}
	a[55712]={"犲","鷰","𡬝","𤜮","𤝔","𤝦","𦓃","𦓆","𪈏"}
	a[55713]={"壔","𤓨","𦉠","𪇀","𪔤","𪔦"}
	a[55714]={"𡤃","𣡡","𣡸"}
	a[55715]={"𪔜","𪔝"}
	a[55716]={"𨎄","𩌚"}
	a[55717]={"輤","韛"}
	a[55719]={"𩏚"}
	a[55722]={"廿","材","村","柎"}
	a[55723]={"丗","","","𠀠"}
	a[55732]={"坿","棼","甘","𡹚","𣑣","𣟈","𦒱","𦒶"}
	a[55733]={"㒼","䴭","树","𣑗","𣔄","𦙩"}
	a[55734]={"﨓","𡝱","𣓃","𤡁"}
	a[55742]={"猗","考","𣑓","𦒴","𦒸"}
	a[55743]={"㟚","㭙","㭶","柑","栫","𡍆","𣒶"}
	a[55744]={"㭏","姏","孝","帯","拲","樠","𠦜","𡜒","𣑥","𣓿","𣚭"}
	a[55745]={"㹲","𡝿","𡠪","𡡣"}
	a[55746]={"㛿"}
	a[55752]={"栯","桍","椅","耇","耉","𣕽","𤠭","𤢃","𦚴"}
	a[55753]={"㮁","坩","姱","姷","婍","封","栲","桲","楠","𠢵","𡝻","𣗦","𣜎"}
	a[55754]={"㙢","㛈","㛘","婻","𤰇"}
	a[55755]={"㭳","梼","𠢠","𣑛"}
	a[55756]={"𣔎"}
	a[55757]={"攀","𡬭"}
	a[55758]={"𣡋"}
	a[55762]={"垮","埘","埼","尌","椭","榭","耈","𡬾","𣗳","𣝿","𤠬","𦒽"}
	a[55763]={"㘼","猜","𡋌","𡋯","𡎜","𣝉","𦝙"}
	a[55764]={"𢮜","𣖥","𪌰"}
	a[55765]={"𡌉","𣖾","𣚐"}
	a[55766]={"軵","𣝮","𦔚","𨊭"}
	a[55767]={"𣠧"}
	a[55768]={"冓","𣡄"}
	a[55770]={"媾"}
	a[55772]={"䎝","塮","墛","朞","楕","槗","𣚂","𣛅","𣟑","𤡪"}
	a[55773]={"媠","棈","榯","樹","𣝪","𣟜"}
	a[55774]={"㯹","婧","𡎈","𡐺","𣞨","𣠫","𩎠"}
	a[55775]={"㨍","𡣋","𣠈","𣡇"}
	a[55776]={"槫","𣕬","𣜜","𦉤"}
	a[55777]={"嫥"}
	a[55778]={"𣓊"}
	a[55779]={"構"}
	a[55782]={"㚡","堶","橢","𡭌","𣡨","𦓁","𪀧"}
	a[55783]={"埥","塒","嫷","𠔵","𡽌","𣠵","𪂅"}
	a[55784]={"樁","𦑓"}
	a[55785]={"欎"}
	a[55786]={"塼","𩋰"}
	a[55789]={"𡏞"}
	a[55790]={"耩","𩌴"}
	a[55792]={"翥","𡐦","𦓂"}
	a[55793]={"𣡑","𦉚","𪍳"}
	a[55794]={"𣡮","𩰿"}
	a[55795]={"䵋","欝","𡤄"}
	a[55796]={"䩭","彗","輢","𩊓"}
	a[55803]={"䟄","趱","𠔶","𨆊"}
	a[55805]={"耫"}
	a[55806]={"𪔭"}
	a[55809]={"䪄","輳","𨎩"}
	a[55812]={"㒹","㙽","狹","𠔀","𧰊","𧾥"}
	a[55813]={"欑","趲"}
	a[55814]={"㜺","趬","韥"}
	a[55815]={"䟎"}
	a[55816]={"䡩","韇","𨏔","𩌙","𩍟","𪔵"}
	a[55817]={"䡹","䡽","𨏘","𨏡","𩌪","𩍭","𩎈"}
	a[55818]={"䩿","轒","𨎾"}
	a[55819]={"𩍴"}
	a[55822]={"共","夶","杕","梜","炗","焚","𤆯","𤈈"}
	a[55823]={"㛍","狭","𡚻"}
	a[55824]={"燓"}
	a[55826]={"樉"}
	a[55832]={"㺆","埉","赵","𠔏","𡉑"}
	a[55833]={"㮉","枎","柣","栱","","𡘽","𣚵","𤍾"}
	a[55834]={"妋","妷","娂","𠔝","𡗿","𡞁"}
	a[55835]={"樊"}
	a[55836]={"塽","𣜪"}
	a[55842]={"䞗","其","楚","﨣","𤢙","𧻵","𧼛"}
	a[55843]={"垬","椟","猉","贳","趀","𧺜"}
	a[55844]={"㚘","僰","轪","麩","𣙑","𤏡"}
	a[55845]={"㹫"}
	a[55847]={"𡑽","𡗻"}
	a[55852]={"䞰","䠂","煑","𧺑"}
	a[55853]={"䞚","棋","檚","趃","趎","𡢴","𣖌","𧺡","𧺧","𧻕","𧼖"}
	a[55854]={"娸","黄","","𡢟","𧻶"}
	a[55855]={"桋","獚","轶","𠓶","𦓳"}
	a[55856]={"姨","𤟃"}
	a[55862]={"㷼","𤠶","𧴹","𧺷"}
	a[55863]={"㙋","𧼔"}
	a[55864]={"獖","趚","黃","𧺿","𪍀"}
	a[55865]={"䵌","楱","横","麸"}
	a[55866]={"䩡","嫹","軑","","𣓉"}
	a[55867]={"婕","𤡉"}
	a[55872]={"䞥","䞽","槙","趌","𧻰","𧽽"}
	a[55873]={"㺓","䞨","嫃","貰","𣜇","𣠇","𧼡"}
	a[55874]={"橨","𡢲","𩎱"}
	a[55875]={"墴","橫","𤴟","𧻑","𧼓","𧽅","𧽕","𨃢"}
	a[55876]={"䵃"}
	a[55877]={"䡍","軼","輁","𨋸"}
	a[55878]={"嫨"}
	a[55882]={"填"}
	a[55883]={"樍","趞"}
	a[55884]={"墳","嫧","賛"}
	a[55885]={"䠠","趪","𧼎"}
	a[55887]={"辏"}
	a[55888]={"𤒖"}
	a[55892]={"櫝","𧽍"}
	a[55893]={"嬻","𧾜"}
	a[55894]={"𤓮","𧽭"}
	a[55895]={"櫕"}
	a[55896]={"熭","𡚙","𡣶","𧽢"}
	a[55899]={"䎯","䩟","𧽝"}
	a[55907]={"韘","𩎴","𩏖"}
	a[55908]={"𪔬"}
	a[55910]={"𣍖"}
	a[55911]={"𩎎"}
	a[55912]={"㹯","狇","猍"}
	a[55913]={"𤞠"}
	a[55915]={"𣠻","𩏮"}
	a[55916]={"𧥆"}
	a[55918]={"𩏏"}
	a[55922]={"㯤","㳟","林","棶","𠍳","𣐾","𣒑","𣠬"}
	a[55923]={"婡","𡜨","𤝹"}
	a[55924]={"棥",""}
	a[55932]={"㯃","椕","𣙉","𣴐"}
	a[55933]={"㭑","㭟","枺","栋","栜","株","梾","麳","𣏼","𣑔","𣓏","𪌎"}
	a[55934]={"㛦","妹","妺","姝","汬","𣗅","𣗪"}
	a[55935]={"𤟬"}
	a[55942]={"㮈","㮊","㮏","楙","獠","禁","𡎓","𣗟","𤴜"}
	a[55943]={"某","𡊉","𡞏","𡞫"}
	a[55944]={"㮠","䴲","枼","梀","棘","楝","","𣗂","𣗘","𣘐","𦓹","𪎂"}
	a[55945]={"娕","媡","獉","𤟈"}
	a[55952]={"㮟","㮦","橑","𣓜","𣙳"}
	a[55953]={"㯲","嫽","棊","𡏏","𣕎","𣛂","𤠚"}
	a[55954]={"堜","楳","榤","𣕪","𧹯"}
	a[55955]={"媒","棟","楪","榛","𪌶"}
	a[55956]={"娻","媟","嫀"}
	a[55957]={"𣓝","𥺠"}
	a[55962]={"㙩","㯟","綦"}
	a[55963]={"榡","𣕑","𣗢","𪍟"}
	a[55964]={"㯦","嫊","橥","𡏝","𣸕"}
	a[55965]={"埬","堞","樄","𣕁","𧹩"}
	a[55966]={"𣗥","𣚨","𣡕","𪍐"}
	a[55968]={"𡢬"}
	a[55972]={"㯎"}
	a[55973]={"塐","櫀","𣝒","𦂌"}
	a[55975]={"𣛻"}
	a[55977]={"靺","𣓵","𣝬","𩊣"}
	a[55978]={"𡣒"}
	a[55979]={"𡠑"}
	a[55982]={"𣝺"}
	a[55983]={"𣝔"}
	a[55985]={"韎","𣙈","𣡎","𤯏","𩎟"}
	a[55988]={"㯥","𣡍","𣡽","𩊯","𩋞"}
	a[55995]={"𣟄","𧯾"}
	a[55996]={"㰉","欁","轑","𩌈","𩎯"}
	a[55998]={"𩌉"}
	a[55999]={"䪂","轃","鞢","𨌿","𨍕","𩌘"}
	a[56013]={"𧰒"}
	a[56031]={"加","𤝍"}
	a[56032]={"㹢","如","𤝗","𤝱"}
	a[56033]={"㹨"}
	a[56041]={"㮯","柶","𣏬","𣐤"}
	a[56042]={"枷","栶","梱","棞","𣐏","𣐬","𣑝","𣑟","𣕳"}
	a[56043]={"㚳","㚼","姻","柚","𡉥","𡞈"}
	a[56044]={"妯"}
	a[56051]={"相","𡉭","𣑩","𣒦","𣓭"}
	a[56052]={"㘻","椥","𡊗","𡊰","𡛸","𡜼","𧹢"}
	a[56053]={"𡊡","𣓐","𪍁"}
	a[56054]={"榊"}
	a[56056]={"麯","𣒠"}
	a[56061]={"𡊟","𡋙"}
	a[56062]={"棝","椢","𣕦","𪌔"}
	a[56063]={"㜀","婟","𤡓"}
	a[56064]={"耞","𡟏","𦓾"}
	a[56065]={"轴","𦓲"}
	a[56071]={"𣒪"}
	a[56072]={"堌"}
	a[56073]={"槶","𣙢"}
	a[56081]={"𥆅","𥈷"}
	a[56083]={"𥡮"}
	a[56085]={"𨍲"}
	a[56086]={"䡒","鞇","𩊏"}
	a[56087]={"䩜","軸"}
	a[56094]={"𩎪"}
	a[56096]={"檲"}
	a[56103]={"檉","𩁒"}
	a[56104]={"𡢨","𣛀","𪎆"}
	a[56105]={"輼","鞰"}
	a[56106]={"鞓"}
	a[56113]={"欋","韞","𤣓"}
	a[56114]={"㜹","𡑆","𣡟","𣡭"}
	a[56115]={"𡔁","𣠠","𦓍","𦔬","𨎅"}
	a[56117]={"𣊼","𩎊"}
	a[56118]={"𨐁","𪏨"}
	a[56119]={"䪆"}
	a[56141]={"狚"}
	a[56151]={"柦","榲","𤞾"}
	a[56152]={"妲","媼"}
	a[56154]={"狸"}
	a[56161]={"坦","榅","𣒋","𣗵"}
	a[56162]={"媪","桯","𡟄"}
	a[56163]={"猩","𡝚","𤥏"}
	a[56164]={"梩","𤯥"}
	a[56165]={"娌"}
	a[56171]={"堽","塭"}
	a[56172]={"㘿","埕","𪍝"}
	a[56174]={"埋","𡟙","𣞪","𨾵"}
	a[56175]={"𡣫"}
	a[56181]={"𥂸"}
	a[56182]={"𣙐"}
	a[56183]={"玀","辒","韫"}
	a[56185]={"榸","𤣁"}
	a[56186]={"𦓵"}
	a[56192]={"㯰"}
	a[56193]={"欏"}
	a[56194]={"𡤢"}
	a[56195]={"轀","靼","𩊹"}
	a[56196]={"䵄"}
	a[56212]={"𡤀"}
	a[56231]={"猡"}
	a[56241]={"㔖","椤"}
	a[56242]={"楐"}
	a[56252]={"堺"}
	a[56254]={"𡞑"}
	a[56261]={"㭿"}
	a[56262]={"𡌸"}
	a[56272]={"𡣏"}
	a[56291]={"檌"}
	a[56303]={"壝","𡒌"}
	a[56305]={"𢤙"}
	a[56312]={"壜"}
	a[56313]={"𩏰"}
	a[56315]={"轘","韅","𨏀","𨏌","𩍡"}
	a[56316]={"𨏙"}
	a[56317]={"䪈","䪋","𩌾"}
	a[56331]={"𢚤"}
	a[56333]={"独"}
	a[56341]={"㤎","𣝋"}
	a[56342]={"恕","𤟧"}
	a[56351]={"袈"}
	a[56352]={"䘫","楒","猥"}
	a[56353]={"媤","赨","𡟯","𣔴"}
	a[56354]={"嫼"}
	a[56355]={"𤡟"}
	a[56361]={"想","獧"}
	a[56362]={"椳","𡟠","𪍭"}
	a[56363]={"㛱","𧉪"}
	a[56364]={"𡟎","𢟆","𧊟"}
	a[56365]={"槵"}
	a[56366]={"𡠛 "}
	a[56371]={"檈","𡏁","𤡠"}
	a[56372]={"㙗","嬛"}
	a[56373]={"𩶯"}
	a[56374]={"勰","𣜛"}
	a[56375]={"㺜"}
	a[56376]={"𡢿"}
	a[56381]={"𡑡","𣟳"}
	a[56382]={"𣞲","𪍺"}
	a[56383]={"𡣱"}
	a[56384]={"䎬",""}
	a[56385]={"檂"}
	a[56386]={"𦔧"}
	a[56391]={"㙷","𧹽"}
	a[56393]={"","𣚦","𣟧"}
	a[56394]={"𡠤"}
	a[56401]={"𧡮"}
	a[56402]={"覩","𧡥","𧡪","𧡵","𨜞"}
	a[56404]={"䚉","𨜀","𨜣"}
	a[56405]={"䩤","𥌵","𧢚","𩊷"}
	a[56407]={"𧢣"}
	a[56411]={"覿","𧡚"}
	a[56412]={"䚍","靚","𧡺","𧢔"}
	a[56413]={"䎱","䚎","𥋈","𧢬"}
	a[56415]={"欟","輥","𧑣","𩋲","𩎏"}
	a[56416]={"覲","𩴿"}
	a[56418]={"覯"}
	a[56435]={"㹭"}
	a[56440]={"𧠔"}
	a[56441]={"乫","柷","𡯟","𤞭"}
	a[56442]={"㚾"}
	a[56445]={"栧"}
	a[56446]={"𡜄"}
	a[56451]={"㖙","㠰","旭","𠃳","𡯙"}
	a[56452]={"㖲","𣑢","𤰙"}
	a[56453]={"𡯥"}
	a[56461]={"㞁","䚅","堒","梘","榥","猑","𣒨","𧡂"}
	a[56462]={"㛕","娊"}
	a[56463]={"毠"}
	a[56464]={"㞅","𣭠"}
	a[56471]={"䚂","垷","棍","𡋳","𡯻","𨙾"}
	a[56472]={"㞇","䙿","婫","規","麲","𠒠","𧠉","𧠎","𧠥","𧠵","𧡅","𧡙"}
	a[56474]={"𧢎"}
	a[56476]={"𧠤"}
	a[56481]={"覟","𨝼"}
	a[56482]={"𨚠","𪌽"}
	a[56483]={"槻","邫","𡤅","𧡴"}
	a[56485]={"軦","𧢜"}
	a[56486]={"𨚭"}
	a[56489]={"𡰌","𨋯","𩊒"}
	a[56491]={"𣞻","𤭪","𧠯","𧠶","𧡘"}
	a[56492]={"櫬","郌","𧠹"}
	a[56493]={"尵","辊","","𦓼"}
	a[56494]={"𧡍"}
	a[56495]={"𩊸"}
	a[56496]={"𧡔","𩙐"}
	a[56497]={"𩎥"}
	a[56503]={"櫻"}
	a[56504]={"墠","孆","𡢞"}
	a[56508]={"𦘤"}
	a[56510]={"韠"}
	a[56511]={"鞸","鞻","𦔪","𩏝"}
	a[56512]={"𣡠"}
	a[56513]={"壧","欕","玁","𡓫","𣠨"}
	a[56514]={"孍","欔","玃"}
	a[56515]={"𡤬","𩏪"}
	a[56516]={"䡬","䩰","奲","輯","𣞹","𩏥","𩏺"}
	a[56517]={"䵐","𩍜"}
	a[56518]={"䡲","𨏹","𩍍"}
	a[56523]={"狆"}
	a[56533]={"狎"}
	a[56534]={"妕","𤝚"}
	a[56542]={"𤞋"}
	a[56543]={"妿","帤","柙","𤠎"}
	a[56544]={"柛"}
	a[56545]={"妽"}
	a[56552]={"猂","𣑬"}
	a[56553]={"㮨","𡊠","𤙄"}
	a[56554]={"坤","𤟺"}
	a[56555]={"梙"}
	a[56562]={"桿","獌","𢻋"}
	a[56563]={"娨","𡌨","𣗤","𤢟"}
	a[56564]={"𡌹","𪌸"}
	a[56566]={"𣍃"}
	a[56568]={"𤠺"}
	a[56569]={"㺏"}
	a[56570]={"㜢"}
	a[56572]={"垾","楫","槾"}
	a[56573]={"嫚","檡"}
	a[56574]={"嬕"}
	a[56575]={"𦔎"}
	a[56578]={"㮿","𡡎"}
	a[56579]={"樓","𡠚"}
	a[56580]={"𪍣"}
	a[56582]={"墁","𡎎","𡑇"}
	a[56583]={"墿","𡣅","𪍩"}
	a[56584]={"㺗","嫢"}
	a[56587]={"𩉾"}
	a[56588]={"𨋙","𩉼"}
	a[56589]={"塿","𦾏","𪍪"}
	a[56590]={"耬"}
	a[56593]={"樶","𤣎"}
	a[56594]={"樿","辑","𡡔","𦔔"}
	a[56595]={"嬋","𦔥"}
	a[56597]={"𨌦"}
	a[56601]={"橸"}
	a[56604]={"櫑"}
	a[56611]={"㺧","𤣠","𤣣"}
	a[56613]={"𡄲","𡅦"}
	a[56614]={"㙼"}
	a[56615]={"𨍆"}
	a[56616]={"𨎏"}
	a[56617]={"𨍟"}
	a[56618]={"轠"}
	a[56631]={"㔔"}
	a[56651]={"梠"}
	a[56652]={"㛎"}
	a[56661]={"䂟","猖"}
	a[56665]={"𡞐"}
	a[56671]={"椙","榀"}
	a[56672]={"娼"}
	a[56681]={"䪪"}
	a[56682]={"𡟤","𧧏"}
	a[56684]={"𡣈"}
	a[56692]={"𡐻"}
	a[56693]={"𥔏"}
	a[56694]={"𤢹"}
	a[56701]={"𪂼"}
	a[56703]={"𦔨"}
	a[56705]={"輰","輵","鞙","鞨","𨌉","𩋬"}
	a[56711]={"鸉"}
	a[56712]={"鬹","𪄯"}
	a[56713]={"䪚","𦡾","𩏌","𪈌"}
	a[56715]={"韣","𣡧","𩍗"}
	a[56716]={"𩋤"}
	a[56717]={"䪅"}
	a[56718]={"𩍌"}
	a[56741]={"枴","𤝐","𤟍"}
	a[56742]={"柺","𡛱","𣑐","𣒌","𦙲"}
	a[56743]={"娲"}
	a[56751]={"枵","楞","狷","猲","𣓾"}
	a[56752]={"㛫","埚"}
	a[56753]={"㧝","㭷","𦨦"}
	a[56754]={"娚","挐","𤟹"}
	a[56761]={"哿","埸","塄","梋","楊","楬","驾","𡌕","𤟕","𦙺"}
	a[56762]={"娟","婸","棏","猬","𣕶","𣘱"}
	a[56763]={"嗧","梬","獨","𡣃","𣗨"}
	a[56764]={"娉","𣕃"}
	a[56765]={"媀","𣖹"}
	a[56771]={"埍","堨","場","𡾎","𣓍","𤠐","𤢞","𪗬"}
	a[56772]={"𡝭","𣖜","𣙵","𪌭"}
	a[56773]={"㯮","媦","駕","𡭂","𦓻"}
	a[56774]={"堣"}
	a[56781]={"㮙","㯞","朅","榻","鴐"}
	a[56782]={"㙕","鴽","𡢚"}
	a[56784]={"䎪","𪍹"}
	a[56786]={"耦"}
	a[56791]={"堮","塌","𡑦"}
	a[56793]={"𡦑","𤢰"}
	a[56795]={"𩋌"}
	a[56801]={"𧽰","𧾈"}
	a[56802]={"趮"}
	a[56805]={"鞮"}
	a[56813]={"䪘","𧾱"}
	a[56814]={"𧾵","𪏚"}
	a[56815]={"𩍃","𩏡"}
	a[56817]={"鞼","𨎨"}
	a[56821]={"𤝖"}
	a[56831]={"㹱","枳","𤇞"}
	a[56832]={"𡛰"}
	a[56841]={"狽","贺"}
	a[56842]={"㚙","㛣","娖","𣙠","𤝲"}
	a[56843]={"𡘗"}
	a[56851]={"埙","梖","𤟥","𧻍"}
	a[56852]={"㛝","娯","𣑀","𣔑"}
	a[56853]={"娛","娱","轵"}
	a[56859]={"𣛫"}
	a[56861]={"㮛","垻","趗","𤠔","𧺝"}
	a[56862]={"媞","𡡍","𤍮","𧼐"}
	a[56864]={"𣚣","𤲱"}
	a[56865]={"𡠲"}
	a[56871]={"䞡","䞶","堤","賀","𠢋","𣗼","𧻃"}
	a[56872]={"㜏","㜥","𡠕"}
	a[56873]={"𡢊","𡣬","𤡱"}
	a[56874]={"𡤗"}
	a[56875]={"軹"}
	a[56881]={"塤","趧","𧼊","𧼨","𧼮"}
	a[56882]={"趕","𧻼","𧽀","𧽲","𧾉"}
	a[56883]={"樻","𡙭","𣉄","𦔂","𧽉","𩏿"}
	a[56884]={"嬇","樌","趩","𦔈","𧻲"}
	a[56886]={"𦔜"}
	a[56891]={"𧽱","𧾎"}
	a[56892]={"䟂","𧼫"}
	a[56893]={"䟉","墤","𡐾","𣞥","𦔐"}
	a[56898]={"䟆"}
	a[56902]={"𣝇"}
	a[56906]={"𩌹"}
	a[56914]={"欙","𩏞"}
	a[56915]={"𡤯"}
	a[56931]={"𣗶"}
	a[56932]={"𤞥"}
	a[56942]={"架","椺","𥹌"}
	a[56943]={"媬","桇","𥹡"}
	a[56944]={"猓"}
	a[56951]={"𥿃"}
	a[56952]={"㙅","堢","絮","𤡂","𥙦"}
	a[56953]={"𣕧"}
	a[56954]={"棵"}
	a[56955]={"婐"}
	a[56962]={"樏","𣕱"}
	a[56963]={"嫘"}
	a[56964]={"堁"}
	a[56965]={"䴹"}
	a[56972]={"𡏱","𡡡","𤢖","𧹶"}
	a[56973]={"𣞺","𪍯"}
	a[56981]={"𡐹"}
	a[56982]={"橾"}
	a[56983]={"嬠","槼"}
	a[56985]={"𩌐"}
	a[56993]={"𪍽"}
	a[56998]={"輠","𩋗"}
	a[57001]={"𦑽"}
	a[57002]={"𠠐","𣜝","𧯼"}
	a[57003]={"翸","𣜊","𦑻"}
	a[57005]={"𣟬"}
	a[57006]={"輖","𩋙","𩋺"}
	a[57011]={"力","墹","犳","𣡴","𤜩","𤝧"}
	a[57012]={"翿","𡕑","𣎠","𤜜","𤜽","𨷎"}
	a[57013]={"𡕐","𡣟"}
	a[57015]={"䎘","輣","輷","鞫","𠢾","𣡒","𩋒"}
	a[57016]={"䩴"}
	a[57018]={"𨏭"}
	a[57021]={"朷","杒","杓","𤜼"}
	a[57022]={"㔹","㭎","㹼","勑","妁","朸","枘","","𠠴","𠠸","𡛁","𡜃","𣏯"}
	a[57023]={"妠","妫","𤟋"}
	a[57031]={"切","圴","圽","枃","构","狗","𡉍","𣏊"}
	a[57032]={"㘦","㘨","㚬","䴯","椈","狕","𠡟","𣑤"}
	a[57033]={"婅","枬","","𠡠","𣐠","𪋾","𪌅"}
	a[57034]={"肀","𠛝","𡛓","𤝕"}
	a[57035]={"㹪","柵",""}
	a[57036]={"姍"}
	a[57039]={"狦"}
	a[57040]={"𡜜"}
	a[57041]={"㘬","㭣","㮝","刧","刼","均","枂","枸","棡","狥","狪","𣐒","𣑈"}
	a[57042]={"劫","妇","姁","柪","𠡉","𡉳","𡝆","𡟅"}
	a[57043]={"㓞","坍","轫","韧","麴","𠡭","𠣩","𡛙","𣏵","𪍆"}
	a[57044]={"勅","栂","𡛾","𩏼"}
	a[57045]={"姆","枏","柟","栅","𠂴","𡛂"}
	a[57046]={"㚩","姌","姗","𦓭"}
	a[57047]={"㔗"}
	a[57049]={"𣑭"}
	a[57051]={"㘭","坰","坸","埛","堈","柌","栒","栩","桐","桕","棢","𡊐","𣛬"}
	a[57052]={"㚸","㛠","㭵","劼","勀","坳","姛","姰","𠛽","𠜤","𠣷","𣒗","𦐁"}
	a[57053]={"劸","勃","勎","𠡾","𠢱","𡊤","𣖣"}
	a[57054]={"勚","坶"}
	a[57055]={"㘱","𠡫","𡉱","𡊢"}
	a[57061]={"䞒","垇","垌","榈","翃","胡","𡋕","𡌇","𣗭","𤟼"}
	a[57062]={"㮶","䋤","椆","猢","翉","𡍒","𡟧","𣖑","𦐋","𪌢"}
	a[57063]={"䢁","勘","婤","𠳫","𡠶","𣔒","𪌼"}
	a[57064]={"麹","𡙳"}
	a[57065]={"軔","靭","靮","𠜥","𠢀","𨋊"}
	a[57066]={"䡃","勒","軜","靹","𨊾"}
	a[57067]={"靱","𦘓","𨋹"}
	a[57071]={"䎁","棚","椚","𣔂","𦐼"}
	a[57072]={"期","楜","𠢳","𡌲","𡞇"}
	a[57073]={"媩","辋","韌","𦐞","𦐫","𦐾"}
	a[57074]={"䪏","𡍧","𡎧","𢱬"}
	a[57075]={"䩓","𨊵","𨊷"}
	a[57076]={"鞠","𡭇"}
	a[57077]={"𡤂"}
	a[57078]={"𠡯"}
	a[57079]={"𠢉"}
	a[57081]={"堋","樃","翓","𡐐"}
	a[57082]={"朝","𡎁","𣚾","𦐰","𦑍"}
	a[57083]={"勣","𡠳","𡢄","𢮮","𪍒"}
	a[57084]={"䪕","勩","墈","耡"}
	a[57085]={"䩗","軥","𨊸","𩉷","𩉿"}
	a[57086]={"軪","靿","𡓕","𨋝"}
	a[57087]={"勤","𠢥","𩍔"}
	a[57091]={"㙟","𠠔","𠠠","𡎾","𣙎"}
	a[57092]={"䎐"}
	a[57094]={"𡡲"}
	a[57095]={"輞","𦑜","𦑵","𨋮","𨋾","𩊗"}
	a[57096]={"䡘","𨌨","𩋃"}
	a[57102]={"䪣","𡟳","𣫆","𣫒","𣫝"}
	a[57103]={"䪟","鏧","𩀉"}
	a[57104]={"橻","𩀠"}
	a[57105]={"𨬝"}
	a[57106]={"䩯","𥂛"}
	a[57107]={"𡐊","𣛛"}
	a[57108]={"嫿"}
	a[57112]={"𣫤","𣫨","𥃟","𩐊"}
	a[57113]={"𡒼","𡤋","𩐋","𩐒"}
	a[57114]={"𩏊"}
	a[57115]={"䀌","𤲯","𦒰","𧗙","𩁡","𩐑"}
	a[57116]={"衋","𤩯","𥀼","𨰌"}
	a[57117]={"墼","𧗚","𩋓","𩍪"}
	a[57121]={""}
	a[57132]={"狃","𡉂"}
	a[57133]={"㹩"}
	a[57141]={"狙","𣐕","𣑕","𤝺","𤠏"}
	a[57142]={"杻","爼","猛","","𣒝","𣕝"}
	a[57143]={"㭴","妞","柽","𡎼","𢎶"}
	a[57144]={""}
	a[57151]={"柤","𣐓"}
	a[57152]={"姐","𣓶","𤟣","𤣬"}
	a[57153]={"𡝹","𣖮","𥁨"}
	a[57154]={"𨥬"}
	a[57155]={""}
	a[57161]={"坥","𡉶","𥃃"}
	a[57162]={"䤰","極","楹","𡍭","𡏒","𥂌"}
	a[57163]={"轻","𠢫","𡌰","𡟚"}
	a[57164]={"䀆","榷","盡","𡊷","𣙝"}
	a[57165]={"𡎀","𨾯"}
	a[57171]={"𣕕","𣙶","𣚟","𣟇"}
	a[57172]={"楃","鋆","𡡟","𣗕"}
	a[57173]={"媉","耝","𣔖","𤠿","𥂎"}
	a[57174]={"𠢦","𥂕"}
	a[57175]={"㯸","墊","𥁞","𦘕","𧗊"}
	a[57176]={"嬧","𧗁"}
	a[57182]={"𡍤","𡎔"}
	a[57183]={"㺟","樫","𡑚","𡒔"}
	a[57184]={"𡠩","𪎻"}
	a[57185]={"䡕","䥍","壗","𨫔","𩊨"}
	a[57186]={"靵","𨋀","𩉶"}
	a[57187]={"軽"}
	a[57191]={"𧰕"}
	a[57192]={"𥂩"}
	a[57193]={"櫂","𡎷","𡐖"}
	a[57194]={"嬥","𡒢","𣜖"}
	a[57195]={"㜼","晝","靻","𦥎"}
	a[57196]={"畫"}
	a[57197]={"𤨙"}
	a[57201]={"𧸷"}
	a[57202]={"𪖒"}
	a[57206]={"𤲿"}
	a[57221]={"𣏐","𤝻"}
	a[57222]={"𡚵","𣘀"}
	a[57223]={"𡟞"}
	a[57231]={"厀","枊","柳","栁","栘","𡖳"}
	a[57232]={"㕁","㚹","姼"}
	a[57233]={"𠨚"}
	a[57234]={"肃"}
	a[57241]={"㺒","却","垑","𡊁","𡊧","𣒂"}
	a[57242]={"𣘵","𣛺","𪌫"}
	a[57243]={"𦓥"}
	a[57245]={"粛"}
	a[57251]={"樛","𡊶"}
	a[57252]={"嫪","𡜢"}
	a[57255]={"㙌"}
	a[57261]={"楖"}
	a[57272]={"夦","𠄆","𡗀","𣘪"}
	a[57275]={"䡔","䩕","𦘜","𨋕","𨋖","𩊅","𩊟","𩊥"}
	a[57285]={"肅","𩊕"}
	a[57286]={"𩋶"}
	a[57292]={"𣫘"}
	a[57294]={"䵏"}
	a[57295]={"轇","𩊎","𩌭"}
	a[57296]={"橚","𨌞"}
	a[57301]={"䭌","懿"}
	a[57302]={"𢡱"}
	a[57303]={"𢢿","𩎤"}
	a[57304]={"螜","𧏌"}
	a[57305]={"欚","𤓘","𩏦"}
	a[57306]={"艱","𢢞","𦫒"}
	a[57307]={"輾","𧑨","𨎢"}
	a[57309]={"䡫","䩼"}
	a[57310]={"𨏂"}
	a[57311]={"𢖰","𣡃","𧕒"}
	a[57312]={"㹣","𢦆","𤣜"}
	a[57313]={"𡤵","𢤶","𩟚"}
	a[57314]={"𧐜","𩽓"}
	a[57315]={"𧞺"}
	a[57316]={"𣫣","𩎂"}
	a[57317]={"𧕱"}
	a[57318]={"蟿"}
	a[57321]={"㺀","𢗧","𢠗"}
	a[57322]={"柊","𤍂"}
	a[57323]={"㚵"}
	a[57331]={"厹","梕","猭","𢘰"}
	a[57332]={"愸","𡝲","𧹝"}
	a[57333]={"怒","楤","𢞒"}
	a[57334]={"𡟟"}
	a[57337]={""}
	a[57341]={"椽","狠","𤋐"}
	a[57342]={"塚","橡","𡞷","𪍃"}
	a[57343]={"恏","𢛱","𤍁","𧘽"}
	a[57344]={"𡟼","𢗱","𤠘"}
	a[57346]={"𠔘","𢘍"}
	a[57351]={"堟","塜","根","梞","袃","𡏈","𣔲","𣗔","𤈔"}
	a[57352]={"䴿","𡜱","𢜌"}
	a[57353]={"恝","𡠮","𡠵","𢠱"}
	a[57354]={"㮻","熱","𤍠"}
	a[57355]={"𡠁","𧉭"}
	a[57361]={"垠","櫞","𢢶"}
	a[57362]={"櫲","𤢲"}
	a[57363]={"愂","榐","樋","𢡯"}
	a[57364]={"㜊","慹","𡠙","𢟯","𪒅"}
	a[57365]={"槰","𡤥"}
	a[57371]={"橼","檛","𣚉","𣜠","𩛳"}
	a[57372]={"𡢤","𢣯"}
	a[57373]={"𡐆","𦫎"}
	a[57374]={"褺","𢡶","𧜼","𩎷"}
	a[57375]={"塳","蛪","𡐡","𤌲","𩊫","𩋚"}
	a[57376]={"𤏊"}
	a[57377]={"𡋶","𨍉"}
	a[57381]={"𡑟","𢤥"}
	a[57382]={"㜯","㲆","愨","檭","𣘴"}
	a[57383]={"㲇","𢟥","𢢢","𣟙","𧎹","𩞌"}
	a[57384]={"㙯","𠅀","𢡴","𪒨"}
	a[57385]={"辗","𩌁"}
	a[57386]={"蟄"}
	a[57387]={"𤐂"}
	a[57391]={"㦤","𧞹"}
	a[57392]={"慤"}
	a[57393]={"𢤿","𧍵","𧞒","𧹷"}
	a[57394]={"𧐡","𧒕"}
	a[57395]={"䲀","鞎","𨋨","𩻉"}
	a[57397]={"懃"}
	a[57401]={"𠓏"}
	a[57402]={"靘"}
	a[57403]={"𩎘"}
	a[57405]={"輗","𥀻","𩌟","𩘚"}
	a[57406]={"𩌑"}
	a[57407]={"𨍠","𩋭"}
	a[57411]={"𤜦","𪓒","𪕮"}
	a[57412]={"㺥","䵷","欃","𡓦","𡢘","𪕷","𪚣"}
	a[57413]={"犱","翹","𡤎"}
	a[57414]={"𡤞","𤲽"}
	a[57415]={"𡤹","𣰺","𥀽","𧈌","𩙏"}
	a[57416]={"䪌","𡤩","𤮈","𤮛"}
	a[57417]={"𧈗"}
	a[57418]={"𡤸","𦘣"}
	a[57421]={"㐇","乜","九","犯","𤜝"}
	a[57422]={"丸","也","枫","犰","𠃙","𠠵","𡚫","𤜢","𤜴","𤜿"}
	a[57423]={"㚯","𠂃","𣏒","𤜣"}
	a[57424]={"𡚺","𢦗"}
	a[57431]={"尥","机","杋","枧","狔","𠠾","𡯌","𡯖","𤜱"}
	a[57432]={"㭄","朹","枕","𠫗","𡚱","𡯄","𡯉","𡯦"}
	a[57433]={"㐐","㚨","妉","杝","𣏫","𤜾","𤞁"}
	a[57434]={"她","𠫷"}
	a[57441]={"杞","杷","柅","狍","𡉏","𡯡","𣏌","𣏝"}
	a[57442]={"㐜","㚮","勊","妃","妑","妮","规","𠙆","𣐡","𣑲"}
	a[57443]={"㝿","地","姵","猦","𠒘","𠫲"}
	a[57444]={"飙","𡘺","𢦚","𢦻","𣑪"}
	a[57451]={"圮","圯","坈","坭","枹","栬","桅","猊","𣞠","𦫜"}
	a[57452]={"㚿","㭸","垊","姽","尮","梚","觌","𠙏","𠙜","𡜆","𣐊","𪌄"}
	a[57453]={"姄","娩","婏","楓","𣒤"}
	a[57454]={"㜄","埶","執","轨"}
	a[57455]={"乸","𣭄","𦎃"}
	a[57461]={"㯡","垉","垝","尯","棿","赩","𠣼","𠤃","𠤙","𡯣","𣗽","𤢡","𦫞","𧡽"}
	a[57462]={"㐝","㘲","堍","婗","嫓","麭","𡏎","𦫕","𩵛"}
	a[57463]={"䫺","堸","梶","耙","𡊬","𡟰","𦓨","𪎉"}
	a[57464]={"㛯","娓","𠙐","𡙕","𩖬"}
	a[57465]={"槸","𣙀"}
	a[57466]={"𡰀"}
	a[57467]={"𩉝"}
	a[57471]={"堄","𠣻","𡯿","𦫚","𩨔"}
	a[57472]={"翘","𠓈","𠷏"}
	a[57473]={"㽎","䞔","艳","𩱼"}
	a[57474]={"䏋","𡎐","𣚻"}
	a[57475]={"䡄","軓","飆","黆","𣭭","𨊠","𩉜"}
	a[57476]={"艴","軌","軐"}
	a[57477]={"𨋛"}
	a[57481]={"匏","尳","𣘛","𣝲","𧹧"}
	a[57482]={"靓","𦫛","𦫡"}
	a[57483]={"㜶","㼤","𩙂"}
	a[57484]={"𪎸"}
	a[57485]={"靶","𢣞","𨊶","𨊹","𨋗","𩉹","𩊁"}
	a[57488]={"觏"}
	a[57493]={"𣝊","𩎝","𩛥"}
	a[57494]={"𠢩","𡙺","𤮅"}
	a[57495]={"軳","鞄","𨋭","𩊋","𩊛"}
	a[57496]={"䡑","觐","輓","鞔","𩙁"}
	a[57497]={"𩌿"}
	a[57500]={"𤯽"}
	a[57502]={"䐨","嘏","彀","檓","𣫠","𥔳","𧯸","𪃟"}
	a[57503]={"䍍","攳","瑴","皾","𡒂","𣪭","𣪸","𣫀"}
	a[57504]={"𡤒","𣟱","𦎯","𩐀","𪍥"}
	a[57506]={"毄"}
	a[57507]={"輙","𣫂","𨍺","𩋄"}
	a[57508]={"𡢖"}
	a[57509]={"𨎌","𨎐"}
	a[57510]={"䡣","䩵"}
	a[57511]={"轚","鞬"}
	a[57512]={"夊","瞉","鷇","𤜫","𤝇","𪕸"}
	a[57513]={"櫸","聲","𡓹","𣫐","𣫜"}
	a[57514]={"䪗","觳","𣫁","𣫈","𦎼"}
	a[57515]={"韓","𤯒","𩏇","𩏜","𩏻","𪔰"}
	a[57516]={"𥀷","𨍪","𩋥","𩌅","𪏙"}
	a[57517]={"䡰","轂","𩋦","𩌊","𩌥","𩍤"}
	a[57518]={"韗","𣫦","𩋾"}
	a[57519]={"𩍝","𪏕"}
	a[57522]={"权","杈","","𣏑","𣏘","𤜯"}
	a[57523]={"奴","狓","𡗒"}
	a[57524]={"𤿓"}
	a[57532]={"卆","极","𠬚","𤝈","𤞶"}
	a[57533]={"㚫","叏","攰","枠","柀","𣔓","𤝊","𤝠"}
	a[57534]={"帑","𡕞","𡛡","𢂬","𢃂","𤝢","𤝳","𤝷"}
	a[57536]={"弗"}
	a[57537]={"狒"}
	a[57539]={"𢎵"}
	a[57542]={"圾","杸","椒","赧","𢻈","𣒃"}
	a[57543]={"坡","婌","樱","殺","皳","𡚾","𣖒","𧹞"}
	a[57544]={"栙","樧","麬","","𡞽","𣑚","𣪩","𤿖"}
	a[57545]={"姭","帇","𡜠","𡜬","𡝓","𦘒"}
	a[57547]={"柫"}
	a[57552]={"叝","坄","埱","","𠫳","𠬫","𡊓","𣐔","𣝦","𣪋","𤟚","𧹠"}
	a[57553]={"㮽","獀","𠮁","𡊋","𡙈","𡣝","𣖕","𤠈","𤠍","𤿜","𤿞","𪌓"}
	a[57554]={"榝","","","𡞉","𡟛"}
	a[57555]={"㛃","桻","棳","耚","𡝾","𢍆"}
	a[57556]={"㛔","娺","聿","𤟻","𦘔"}
	a[57557]={"坲","𤝽"}
	a[57562]={"梫","棴","翅","","𡊈","𣔈","𣕒","𣪇"}
	a[57563]={"㮴","㿲","報","塀","婦","棷","樨","舝","韋","𡍅","𡞭","𡟭","𢍇","𣫃","𤛉","𤿠","𦒺"}
	a[57564]={"㜒","㜨","娵","嫂","𡠧","𤿹","𤿺","𥀇","𨐅"}
	a[57565]={"㙍","㸷","埄","𢄢","𣁞","𤿲"}
	a[57566]={"䴶","靫","𡠗","𡠦","𢍠","𤟤","𩏽"}
	a[57567]={"𣑵","𣕖"}
	a[57572]={"㱿","㷤","埐","埽","殸","猳","𣪊","𣪒","𣪗","𣪛","𣪺","𣫇"}
	a[57573]={"墀","椴","殽","皶","皷","𡒛","𣖽","𣪚","𣫄"}
	a[57574]={"㿴","椲","皵","𣟗","𤙼","𤛖","𥀁","𦔀","𦡨"}
	a[57575]={"媁","獬","𥀀"}
	a[57576]={"楎","靸","𢻝","𤟴","𨋁","𨋃"}
	a[57577]={"垏","媈","辍","鞁","𨊿"}
	a[57580]={"𨋥","𩉽"}
	a[57582]={"椵","殻","豰","嗀","𡎰","𣪎","𣪳","𣹬","𦖜"}
	a[57583]={"㺉","塅","婽","榖","殾","穀","糓","𠽠","𡎹","𡐄","𡔮","𣪝","𣪨","𣫔","𪌛"}
	a[57584]={"㙔","㜌","㨌","㰘","𡠆","𣪬","𤛓","𥀎","𦕴","𧎅","𩎕"}
	a[57585]={"檞","𣛵","𣫧","𥀢","𦕥","𩏃"}
	a[57586]={"䩔","堚","軗","𡡘","𡢁","𡢂","𦎷","𨋚","𩊧"}
	a[57587]={"𠮑","𡖁","𩌽"}
	a[57588]={"楗","𨊼","𨋪","𩉥"}
	a[57589]={"𡞹","𡣐"}
	a[57592]={"㲉","嗀","殼","縠","赮","𣞭","𤡘"}
	a[57593]={"㝅","㲄","皼","𡠸","𡤜","𣪹","𣫌","𣫗","𤚼","𧹲"}
	a[57594]={"𡓻","𡢰","𡢶","𣪡","𣫅","𣫓","𤚲","𤛗","𩎶","𪍠","𪍱"}
	a[57595]={"毂","𣚯","𣫎","𦗙"}
	a[57596]={"𣜘","𣪠"}
	a[57597]={"𡢡","𤚹","𨍍","𪔏"}
	a[57599]={"輟","𩊩","𩋁","𩎛","𩎡"}
	a[57602]={"㲈","㿦","磬","𣍆","𥔼"}
	a[57603]={"𡄈","𣫊","𥖫"}
	a[57604]={"謺","𣊮"}
	a[57605]={"𡣁","𩏄"}
	a[57606]={"𨍸","𩋜"}
	a[57607]={"𦔢","𦘠","𩌀"}
	a[57608]={"輑","𩌤"}
	a[57611]={"𡄻"}
	a[57612]={"謦","韾","𥊧","𥖗"}
	a[57613]={"䪜","馨","𣫪","𥌒","𥗚","𥗣","𨡷"}
	a[57614]={"𡄒","𧬓","𨢋","𨢤"}
	a[57615]={"韂","𨎻","𩋿"}
	a[57616]={"礊","𠿉","𥖳","𨍌","𨎲","𨏗"}
	a[57617]={"𥌕"}
	a[57618]={"𨣗"}
	a[57631]={"㹦","𤟁"}
	a[57632]={"狢"}
	a[57641]={"叴","柖"}
	a[57642]={"妱","姳","格","𠮫","𤰛"}
	a[57643]={"𡜴"}
	a[57651]={"㮞","旮","𣓗"}
	a[57652]={"垎","𡟔","𤠑","𤰚","𪌕"}
	a[57653]={"砮","𠢷","𣓂","𣗛","𪌣"}
	a[57661]={"猸"}
	a[57662]={"㮭","塯","椐","榴"}
	a[57663]={"婮","媹","轺","𡍉","𣆕","𥅄"}
	a[57664]={"桾","辂","𠲱","𦓱","𪌾","𪍞"}
	a[57665]={"𡝗"}
	a[57671]={"楣","𣔺"}
	a[57672]={"䂲","媚","𡍄","𤢊","𤣃","𦃆"}
	a[57673]={"䂮"}
	a[57674]={"㗉"}
	a[57675]={"𨽶","𪌺"}
	a[57676]={"𥄱"}
	a[57681]={"堳","槢","檐","𣉑"}
	a[57682]={"㜬","㯝","媢","櫓","𣛒","𣪥","𥊨"}
	a[57683]={"㛰","𦃅"}
	a[57684]={"暬","𣊓"}
	a[57685]={"書","軺","鞀","𥒠"}
	a[57686]={"輅","𩊚"}
	a[57688]={"𤱪"}
	a[57691]={"㙴","𡒸","𡕆"}
	a[57692]={"橹","𠹢"}
	a[57693]={"䛚","𠔴","𧫷","𩎣"}
	a[57694]={"𥊍","𩎬"}
	a[57695]={"𨍢"}
	a[57697]={"𩌎"}
	a[57701]={"榋","𣚑","𣝗"}
	a[57702]={"𡏷","𡑎","𢐙"}
	a[57703]={"欘","罄"}
	a[57704]={"㙾","孎","鷙","𡔐","𪏖"}
	a[57705]={"輡","静","𨍋","𨍐","𩍆"}
	a[57706]={"𩌠"}
	a[57711]={"鶦","𡑏","𦘨"}
	a[57712]={"𦣓","𪅏","𪆪","𪇂"}
	a[57713]={"欅","毊","𥀾","𪇗","𪇞","𪈐","𪈞"}
	a[57714]={"𡤖","𡳼","𦔘","𧤴"}
	a[57715]={"𨍾","𩌇","𩼮"}
	a[57716]={"𨎎"}
	a[57717]={"罊"}
	a[57718]={"擊","轏"}
	a[57721]={"𡴴","𣎸","𤜛","𤝉","𤝩"}
	a[57731]={"㭁","杨","杼","柕","桞","犸","𣐶","𨙿"}
	a[57732]={"奶","妤","杍","𡜙","𣒒","𪌀"}
	a[57733]={"劦","好"}
	a[57734]={"努","胬",""}
	a[57741]={"㘧","㮀","场","杛","杩","𠦢","𡉁","𡋓","𡋝","𣓱","𣔆","𤟳","𤠸","𨚫"}
	a[57742]={"妈","峱","𡉗","𤟎","𨟆"}
	a[57743]={"媯","𡥒","𣐨","𤞴","𤠮","𨝛","𪌠"}
	a[57744]={"協","孥","栛","狰"}
	a[57745]={"势","拏","𤞍"}
	a[57747]={"梻","𠡂"}
	a[57748]={"𡛯"}
	a[57751]={"㭒","猧","獝","獡","𠦗","𤟅","𤟠"}
	a[57752]={"㚶","㛀","㭾","㯍","桪","樇","𣐢","𣒥","𣓹","𤠀"}
	a[57753]={"㚺","㮲","弩","桶","桷","驽","𢮟"}
	a[57754]={"㛚","媰","棦","耔","𠢂","𡝛","𡬨","𦚨"}
	a[57755]={"婙","𦘛"}
	a[57756]={"𢙻"}
	a[57761]={"梮","楇","楈","榍","橘","猾","𡊊","𡍾","𣕋","𣚔","𣚹","𤡡","𤡯"}
	a[57762]={"堀","婿","媧","𡌝","𡏺","𡑥","𡟂","𡟩"}
	a[57763]={"䵁","埆","埇","脅","𡌈","𡞿","𢭋","𪗭"}
	a[57764]={"埩","𤣀","𦘡","𪌻"}
	a[57765]={"勢","挈","駑"}
	a[57766]={"𢏇","𢏒","𤠵"}
	a[57767]={""}
	a[57771]={"䲥","埳","堝","壻","榾","𡌟","𡎮","𡏿","𡹹","𣓓","𣖼","𣜼","𤢧"}
	a[57772]={"𡌞","𡒈","𡞄","𣖆","𪄪","𪍌","𪍛"}
	a[57773]={"耜","鴑","𡌷","𡞦","𡞲"}
	a[57774]={"𣚚","𣝰","𤡒","𦜚"}
	a[57775]={"𡠟","𣗧","𣜗","𦘚","𦘝","𨋋"}
	a[57776]={"㮮","摯","摰","𦐡"}
	a[57781]={"𪙈"}
	a[57783]={"䎤","齧","𣪤","𪀮","𪄅"}
	a[57784]={"㙝","𤣌"}
	a[57785]={"䩑","觢"}
	a[57786]={"𡦊","𢴷"}
	a[57789]={"𥝃"}
	a[57791]={"榒","𡑹"}
	a[57792]={"嫋","樳","鬶","𨟒","𪁍","𪄎"}
	a[57793]={"㜦","𣫉","𪀡"}
	a[57794]={"㰒","撀","樼"}
	a[57795]={"𦘘","𦘙"}
	a[57796]={"畵","騺","驇","𢴸","𨌖","𩋎"}
	a[57797]={"𣜔","𩊺","𩌄"}
	a[57798]={"撃","𨌢"}
	a[57801]={"䟋"}
	a[57802]={"𡓤","𣤫","𧾣","𧾩"}
	a[57803]={"𧽡"}
	a[57804]={"歡","𡓒"}
	a[57806]={"𣤢","𧷄"}
	a[57811]={"狈","𣍜","𣠪","𣤶","𣤺","𣤼","𤝆","𧹌","𧾚","𨎔"}
	a[57812]={"嬹","𣤷","𧾴"}
	a[57813]={"趯"}
	a[57814]={"𣡿","𧾰"}
	a[57815]={"𣤾","𨃲","𩍾"}
	a[57816]={"𣥁","𦔫","𧽷"}
	a[57818]={"𩎑"}
	a[57821]={"㰰","杦","杴","𤜹"}
	a[57822]={"夬","奺","𤕟"}
	a[57823]={"㹟","㹧"}
	a[57831]={"㭥","坎","坝","栨","赥","𠡥","𡉌","𣏧","𣐌","𣔙"}
	a[57832]={"𡛄","𡛫","𣢓","𪌒"}
	a[57833]={"㭈","柍","欷"}
	a[57834]={"妜","姎"}
	a[57835]={"猠"}
	a[57836]={"𤇝"}
	a[57841]={"㘮","㰦","棂","歀","赼","趂","𣣙","𣣥","𧺐","𧺓"}
	a[57842]={"㺅","猴","赲","𣖬","𣢟","𣣋","𤠣"}
	a[57843]={"㛟","㰥","块","坱","欶","软","𡞵","𣢩","𣤛","𤉟","𤡃"}
	a[57844]={"贽","𪌊"}
	a[57845]={"椣"}
	a[57846]={"婰","费"}
	a[57847]={"𡘉"}
	a[57851]={"㰭","欯","欹","款","猽","赹","趍","趑","𧴥","𧺥","𧺫"}
	a[57852]={"㮢","㰪","㰲","㱈","楰","欺","趓","趜","𣔹","𧺎","𧺟"}
	a[57853]={"赖","赽","𡞥","𡟑","𤴚","𧺏"}
	a[57854]={"契","樕","獭","𣤁","𣤂","𤍽"}
	a[57855]={"㙉","嫰","猰","𤡻"}
	a[57856]={"㶳"}
	a[57861]={"㰻","䞤","䞼","椇","榠","起","超","𡑨","𣣩","𣣹","𤢔","𧺸","𧻠","𧼜"}
	a[57862]={"㯘","䞦","堠","媍","嫇","歁","𠦰","𡎇","𣕍","𣤘","𧷖","𧺢","𧺤","𧻞"}
	a[57863]={"𧻯"}
	a[57864]={"𣣚","𤮡","𧻒","𧼦"}
	a[57865]={"楔","軟","𠜵","𡘱","𩉢"}
	a[57866]={"𡘢","𤡋"}
	a[57867]={"䞞"}
	a[57871]={"㱇","埧","塓","橮","趄","趋","趐","趢","趦","𣣿","𧺽","𧻛","𧻜","𧻾"}
	a[57872]={"㯧","㷫","䞷","𣝅","𣤐","𧻎","𧼵","𪍏"}
	a[57873]={"䝱","歕","趨","𣣲","𧻹","𧼲","𩎗"}
	a[57874]={"𤎮","𤴢","𧻘"}
	a[57875]={"䞵","𨋰"}
	a[57876]={"歎","費"}
	a[57877]={"㜛","軮","鞅"}
	a[57881]={"㱅","㺞","歖","𧽻"}
	a[57882]={"䞴","𣤈","𧼒","𧽓","𧽖"}
	a[57883]={"賴","趘","趣","𡒕","𣤥","𧷕","𧽏"}
	a[57884]={"㯯","䞫","䞻","䠟","獺","賮","𣤟","𤒒","𧷇","𨄧"}
	a[57885]={"𧼪"}
	a[57886]={"歏","𧽁"}
	a[57887]={"𣙿","𣞔"}
	a[57891]={"𣤯","𧻫","𧽌","𧾒"}
	a[57892]={"嬩","𣟨","𣠙","𧰇","𧾝"}
	a[57893]={"㯢","𡤚","𣠜","𣤳","𤠼"}
	a[57894]={"䞇","櫴","贄","𡢀"}
	a[57895]={"嬾","歗"}
	a[57896]={"𣤖"}
	a[57897]={"𨾂"}
	a[57898]={"𩌱"}
	a[57902]={"𧲇"}
	a[57904]={"𪏧"}
	a[57906]={"𪏠"}
	a[57907]={"檕","𩍧"}
	a[57911]={"狝"}
	a[57913]={"𣫙"}
	a[57915]={"𡕏 ","𣝝","𣡆"}
	a[57916]={"繫"}
	a[57922]={"妳"}
	a[57923]={"𤞎"}
	a[57931]={"𠌊","𡊑"}
	a[57932]={"杂","棎","猱","𣑫","𤡸"}
	a[57933]={"㛊","樤","𣔌"}
	a[57934]={"𡠊"}
	a[57941]={"猕","𣑧","𤟘"}
	a[57942]={"㰀","堔","桗","楺","𡟇","𣒺"}
	a[57943]={"㛆","䋈","媃","椝"}
	a[57944]={"隶","𠡷","𡜉","𪏷"}
	a[57946]={"𡝯","𣲴"}
	a[57951]={"椂","𣘤","𥿚"}
	a[57952]={"垛","垜","娽","𡝘","𣐟"}
	a[57953]={"洯","𡑕","𣜩","𪍚"}
	a[57954]={"媣","栔","𥻦"}
	a[57955]={"棣","槡"}
	a[57956]={"𡠏","𥿏"}
	a[57958]={"𥡀"}
	a[57961]={"𡍖","𣝵"}
	a[57962]={"㮪","𪍄"}
	a[57963]={"絜","𣔘"}
	a[57964]={"漐","𡣞","𤢘","𦅬","𦔇"}
	a[57965]={"埭","槷","𣙗","𨋎"}
	a[57972]={"𣼘"}
	a[57974]={"縶","𣘑","𣚃","𣝠","𣟍"}
	a[57975]={"隸"}
	a[57977]={"𣞰","𩌜"}
	a[57982]={"漀","𣝌"}
	a[57983]={"㯏","䅽","𣖫","𥡛","𥼆"}
	a[57984]={"䂋","𡐤"}
	a[57985]={"隷"}
	a[57986]={"輮","鞣","𩊜"}
	a[57988]={"𨽼"}
	a[57994]={"韖","𩎫"}
	a[57995]={"䩮","𣞙","𨌠"}
	a[57996]={"繋","𣟌"}
	a[57999]={"䡦"}
	a[58001]={"𤜞"}
	a[58011]={"朲","朳","杁","枞"}
	a[58012]={"𠐱","𡚭"}
	a[58021]={"圦","","𡉇"}
	a[58022]={"姒","娰"}
	a[58033]={"𦓧"}
	a[58043]={"䎣"}
	a[58052]={"倝"}
	a[58101]={"𣞯","𣡓"}
	a[58104]={"雗","鳌"}
	a[58107]={"𩌢"}
	a[58111]={"𣟢"}
	a[58112]={"𣡶"}
	a[58113]={"𣡔"}
	a[58114]={"𩐎"}
	a[58115]={"轞"}
	a[58118]={"䡭"}
	a[58121]={"猃"}
	a[58131]={"检","椪","獈"}
	a[58132]={"㭫","","𣐍"}
	a[58133]={"㛗"}
	a[58141]={"栏","榏","槛","𡌶"}
	a[58142]={"㜋","栓","𡌚","𡑻","𡟆","𣔋"}
	a[58143]={"姾","𡑃"}
	a[58151]={"塧","𣕆"}
	a[58152]={"𡋄"}
	a[58153]={"𤠝","𤨣"}
	a[58162]={"𣙖"}
	a[58163]={"槎","𢿋","𣔫"}
	a[58164]={"嫅","辁","𦓰"}
	a[58165]={"𡏴"}
	a[58171]={"㺝","塩","𥂁"}
	a[58172]={"𠔫"}
	a[58173]={"盩","𣛈","𥂢","𨩧"}
	a[58174]={"䴾","整","権","𣙚"}
	a[58176]={"𡑁"}
	a[58181]={"檻"}
	a[58182]={"㜮","䀇","䀋","𪉹"}
	a[58183]={"𥂪","𨭻"}
	a[58184]={"鏊"}
	a[58186]={"輇","𣦔"}
	a[58191]={"壏"}
	a[58196]={"釐"}
	a[58211]={"𣏎","𤜰"}
	a[58212]={"妎","𡛧"}
	a[58221]={"圿","枔","𤞆"}
	a[58222]={"妗"}
	a[58231]={"坅"}
	a[58233]={"轸"}
	a[58241]={"柞"}
	a[58242]={"妰"}
	a[58243]={"𠩺"}
	a[58252]={"𢒨","𪌟"}
	a[58253]={"𡏆"}
	a[58255]={"軫","𩉡"}
	a[58264]={"黅"}
	a[58265]={"軡","靲"}
	a[58273]={"𩎖"}
	a[58285]={"𨋘"}
	a[58292]={"𦅫"}
	a[58311]={"狑","𤝅"}
	a[58312]={"㛋"}
	a[58316]={"𩞎"}
	a[58321]={"松","柃","𣔾"}
	a[58322]={"妐","姈","𡟝"}
	a[58331]={"㭚","坽","棇","棜","棯","檖","狯"}
	a[58332]={"嬘","憗","𡜅"}
	a[58341]={"埝","桧","𡌧","𡑞","𣖯"}
	a[58342]={"㮸","㺊","慦","榚","𢟻","𪌥","𪌿"}
	a[58343]={"𢡷"}
	a[58345]={"橅"}
	a[58346]={"嫵"}
	a[58348]={"㺌"}
	a[58351]={"楡","𣖺","𣜭"}
	a[58352]={"婾","𢜉","𣗹"}
	a[58353]={"熬","𢟤","𤎦","𧌻","𧜌"}
	a[58354]={"慗","𤐳"}
	a[58355]={"墲"}
	a[58356]={"𤏠"}
	a[58358]={"槏"}
	a[58359]={"嫌","𤍻"}
	a[58361]={"𣕜","𣜑"}
	a[58362]={"嬨","𡞰","𣛶","𣞮","𩸝"}
	a[58363]={"㥿","𢠜","𣜃","𣞬","𩻯"}
	a[58364]={"螫"}
	a[58365]={"䡆","軨","𢠛","𨍨","𩉭","𩊂"}
	a[58366]={"𨌕"}
	a[58367]={"𨌝"}
	a[58368]={"𡏊"}
	a[58371]={"檤"}
	a[58373]={"𣝡","𣞼","𧹳"}
	a[58374]={"𩞕"}
	a[58375]={"䡵","𨌪","𩋏","𩍚"}
	a[58379]={"㽐"}
	a[58383]={"𡒶","𦔒"}
	a[58384]={"螒","𩺸"}
	a[58385]={"懯","螯","𩺾"}
	a[58393]={"𩹼"}
	a[58394]={"鰲"}
	a[58398]={"𧰋"}
	a[58400]={"轙"}
	a[58403]={"墘","靝"}
	a[58406]={"𣡅"}
	a[58411]={"㰖","欖","𠄊","𤣟"}
	a[58412]={"𡤱","𨝝","𪓴"}
	a[58413]={"鼇"}
	a[58414]={"𡤷"}
	a[58416]={"𨝩"}
	a[58419]={"𨏢"}
	a[58421]={"尬","𠆷","𡯈","𡯔"}
	a[58422]={"𤞄"}
	a[58431]={"枪","梲","犵","","𡯕"}
	a[58433]={"狏"}
	a[58441]={"兝","杚","棁","榄","𣏙"}
	a[58442]={"娧","𡯨"}
	a[58443]={"柂","猐","轮","𣕗"}
	a[58451]={"㙂","圪","尴","𡉛","𣝳"}
	a[58452]={"麧","𪌇"}
	a[58453]={"䢀","獇","𠄁","𡊇","𣘎","𤟽"}
	a[58454]={"㛨"}
	a[58462]={"𣒻"}
	a[58463]={"䎢","椸"}
	a[58464]={"𡠎","𢧢","𪍙"}
	a[58465]={"㲠"}
	a[58466]={"檥"}
	a[58467]={"嬟","𡌖"}
	a[58468]={"尲"}
	a[58471]={"馗","𡍻"}
	a[58473]={"㞉","𡯾","𣠉"}
	a[58474]={"𩙶"}
	a[58475]={"㰕","氂"}
	a[58476]={"𠬗"}
	a[58482]={"乾","亁","𡒞","𡣛"}
	a[58484]={"㲦"}
	a[58485]={"㙿","䩐","𨊰","𨌔","𩉳","𩊭"}
	a[58487]={"𩉻"}
	a[58491]={"尷","𠄃"}
	a[58492]={"靔"}
	a[58493]={"𠓎","𩎰"}
	a[58495]={"𩘮"}
	a[58500]={"𨍓","𩋱"}
	a[58503]={"𡔄","𣀘"}
	a[58506]={"輹","𩋟"}
	a[58507]={"𩋩"}
	a[58510]={"𨏚"}
	a[58513]={"𢼂","𢼥","𤉧"}
	a[58514]={"䪖","𢼫"}
	a[58515]={"𩏑"}
	a[58516]={"轍"}
	a[58517]={"䪃","𨏁","𩍉"}
	a[58522]={"枚","𢽟","𤝪"}
	a[58523]={"獙","𡛇","𡝒","𤝴","𦭇"}
	a[58525]={"𤕢"}
	a[58532]={"坆","救","杵","赦","𢃪","𢻾"}
	a[58533]={"敇","栟","𡡹","𢻱","𢼆","𢼋","𢼡","𢼭","𢽳","𣁒","𣘮","𦍕","𪌑"}
	a[58534]={"姘"}
	a[58542]={"㮘","故","𡉦","𣟷","𤠦","𤢄"}
	a[58543]={"㮆","垪","样","梯","𠭷","𢽓","𣗣"}
	a[58544]={"䴵","姩","娣","敕","𡠬","𤟲"}
	a[58545]={"敎","𡟋","𢍛","𤟸"}
	a[58547]={"㪄"}
	a[58551]={"𢽽"}
	a[58552]={"","𣕌","𣚿"}
	a[58553]={"㪍","垟","敖","𢽔","𪍘"}
	a[58554]={"媕","椫","獓","𠭰","𡝺","𡟁","𢄡","𣁛","𣁟","𣕞"}
	a[58555]={"㹈","婵","嫠","教","𡟜","𢽊","𣙙"}
	a[58556]={"嫩","𡠼","𤡳","𨊽"}
	a[58562]={"椱","獥","","𣡁","𤡏","𤢉"}
	a[58563]={"㜫","㪚","㮹","㺖","媺","散","斡","獤","𡞪","𡠾","𢾤","𢾳","𢿰","𢿱"}
	a[58564]={"㯳","","𠧂","𡟹","𡡵","𢿂","𢿍","𢿯"}
	a[58565]={"㜜","嫯","犛","𢽬","𢽱","𣙕"}
	a[58566]={"𡠯","𢾭","𨊴","𨋼","𩉩"}
	a[58567]={"𤡄"}
	a[58572]={"㙏","㯙","檄","𡏯","𡐣","𡡠","𣟺","𤡈"}
	a[58573]={"嬓","幹","橄","橔"}
	a[58574]={"㙚","㜟","嬍","橵","𡏼","𡡬","𢾜","𢾝","𥀐"}
	a[58575]={"䵅","敷","𢾾","𩀼","𪍮"}
	a[58577]={"軿","𩊖"}
	a[58578]={"𡣆"}
	a[58580]={"櫢"}
	a[58582]={"墽"}
	a[58583]={"墩","𡑒","𣝶","𣠊"}
	a[58584]={"檊","𡢝","𢿲","𣜒","𣟣","𣟲"}
	a[58586]={"𣞒"}
	a[58587]={"𡣷","𨋽","𩊑"}
	a[58592]={"㬼","𤣙"}
	a[58594]={"聱","辙","𦔞"}
	a[58597]={"鞥"}
	a[58603]={"謷","警"}
	a[58604]={"𨢈"}
	a[58605]={"𨍣","𩍈"}
	a[58606]={"𩠶"}
	a[58607]={"輶","鞧"}
	a[58614]={"𨣻"}
	a[58615]={"𩌞","𩌼"}
	a[58616]={"𦧶"}
	a[58621]={"𤞞"}
	a[58631]={"㭲","柗","𤝰"}
	a[58641]={"㭘","梒","﨏","𠎙","𧮯"}
	a[58642]={"姶","娢","猞"}
	a[58651]={"垥","獊","𤠁","𧹣"}
	a[58653]={"䎥","猶","𡞆"}
	a[58661]={"槍","橧","獪","𣚴"}
	a[58662]={"𡞝","𡡑","𡡝"}
	a[58663]={"楢","耠","𡣊","𦔡"}
	a[58664]={"媨"}
	a[58671]={"增","檜","𡐭","𣚞"}
	a[58672]={"嬒","𩠙"}
	a[58673]={"嗸","橏","𠺛","𡣔","𣘞","𣚰"}
	a[58674]={"㜝","嫸","𪍑"}
	a[58675]={"輍"}
	a[58681]={"𡑭"}
	a[58682]={"墖","増","𣉙"}
	a[58683]={"墡","𣊁","𧩥"}
	a[58684]={"𪍶"}
	a[58685]={"鞈",""}
	a[58691]={"𡐈"}
	a[58692]={"𣜆","𥉏"}
	a[58693]={"韐","𦔦","𧫬"}
	a[58694]={"𧫣"}
	a[58703]={"鷔","𩱏"}
	a[58705]={"䩺","𩌵"}
	a[58711]={"𪇟"}
	a[58712]={"鶾"}
	a[58713]={"𩪋"}
	a[58715]={"𨎰","𩌒"}
	a[58721]={"枌"}
	a[58722]={"妢","𡛐"}
	a[58731]={"坋","枍"}
	a[58732]={"𢺺"}
	a[58741]={"㺄"}
	a[58742]={"㘯","𡌜","𡟸","𣛉"}
	a[58743]={"栴","棆","𡜊","𣛌","𤢌"}
	a[58744]={"婨"}
	a[58751]={"㺋","椧","椾","榆"}
	a[58752]={"媊","媮","𠔡"}
	a[58753]={"剺","埨","檎"}
	a[58754]={"㧳","梅","𡥽"}
	a[58755]={"娒","𣒰","𤢋"}
	a[58760]={"𩍲"}
	a[58761]={"㮬","堬","𡌙"}
	a[58762]={"𡡽","𣛆","𪍍"}
	a[58763]={"㮵","嶅","𠞪","𣗯"}
	a[58764]={"㙁","孷","𠢕","𡠨","𡣤"}
	a[58765]={"耣","𨋂","𩉵"}
	a[58766]={"𡠫"}
	a[58770]={"𨏤"}
	a[58771]={"塕","櫤","𪁿"}
	a[58772]={"𦒙","𪂜"}
	a[58773]={"输","𠢇","𪘻"}
	a[58774]={"壿","樽","𤘒"}
	a[58775]={"摮","𦔟","𦪈","𨌺"}
	a[58781]={"㯓","塲"}
	a[58782]={"嬆","檹","𦒋"}
	a[58783]={"骜","𡒺","𪉑"}
	a[58784]={"墫","𦩻"}
	a[58786]={"𣟔"}
	a[58787]={"輪"}
	a[58792]={"翰","𣎍"}
	a[58793]={"𪅗","𪙠"}
	a[58794]={"䮧","鷘"}
	a[58795]={"䩱","輸","驁"}
	a[58801]={"㰓"}
	a[58803]={"𩕀"}
	a[58811]={"𤡆"}
	a[58813]={"䟑","𩏩"}
	a[58821]={"樅",""}
	a[58822]={"㜡"}
	a[58831]={"㙡","趁","𧺣"}
	a[58832]={"栚"}
	a[58841]={"赺","𣒀","𧽵"}
	a[58842]={"垁"}
	a[58843]={"検","𢖗"}
	a[58851]={"䞱","獫","趝"}
	a[58852]={"䞮","趖","𡟐","𤌹","𤎅","𧺴"}
	a[58853]={"𣖙","𧻓"}
	a[58854]={"媄"}
	a[58855]={"𤢮"}
	a[58861]={"㯀","䞘","䞢","䞩","檢","𧾀"}
	a[58862]={"㮳","嫙","嬐","檨","趛"}
	a[58863]={"赘","𣗍","𧻝"}
	a[58864]={"獒"}
	a[58865]={"䡮","𨌰"}
	a[58871]={"𡑯","𧺞","𧼯"}
	a[58872]={"𣛘","𧼘"}
	a[58873]={"𤐈"}
	a[58874]={"橂"}
	a[58881]={"𧾏"}
	a[58882]={"𧼱"}
	a[58883]={"䟀","趥","𨅚"}
	a[58886]={"𩌣"}
	a[58892]={"𧾐"}
	a[58893]={"贅"}
	a[58894]={"𧽳","𧽾"}
	a[58897]={"𩋼"}
	a[58901]={"𤝝"}
	a[58911]={"𣐐"}
	a[58912]={"㚷"}
	a[58918]={"𩎆"}
	a[58921]={"𡊒"}
	a[58922]={"狳","𠇠"}
	a[58932]={"梌","𡝙"}
	a[58933]={"𡝐"}
	a[58942]={"𡌘"}
	a[58943]={"𣸗","𥹛"}
	a[58952]={"様","𤡀","𥻳"}
	a[58953]={"漦"}
	a[58954]={"斄","𣘬","𥼋"}
	a[58955]={"𡢥","𨋏"}
	a[58962]={"樣"}
	a[58963]={"榦","𡡂"}
	a[58964]={"𣘢"}
	a[58972]={"𣘒"}
	a[58973]={"𠏉"}
	a[58975]={"𣞫"}
	a[58976]={"䩣","𨌎"}
	a[58982]={"𡣵"}
	a[58997]={"𨎸"}
	a[59011]={"㭂"}
	a[59022]={"狲"}
	a[59106]={"鞺","𨎋"}
	a[59107]={"𩌩"}
	a[59115]={"𩏘"}
	a[59144]={"𤝵"}
	a[59152]={"𣙌"}
	a[59153]={"獕","𣒈"}
	a[59161]={"榿"}
	a[59162]={"㜐","樘"}
	a[59163]={"槯","𡠠"}
	a[59164]={"㜠","堘"}
	a[59171]={"塏"}
	a[59173]={"墔"}
	a[59197]={"𨌂"}
	a[59211]={"杪","猀"}
	a[59212]={"妙"}
	a[59221]={"桫","𤞃"}
	a[59222]={"麨","𪍉"}
	a[59231]={"梣","𠫴"}
	a[59232]={"𡛢","𪌮"}
	a[59233]={"耖"}
	a[59241]={"埁"}
	a[59243]={"𪎊"}
	a[59252]={"尠"}
	a[59255]={"䩖"}
	a[59276]={"㝻","𡮦"}
	a[59308]={"䩶"}
	a[59311]={"悐"}
	a[59317]={"𨏻"}
	a[59333]={"㜆"}
	a[59351]={"𣛹"}
	a[59352]={"𡣖","𢞪"}
	a[59354]={"㺈"}
	a[59365]={"媸","𣝙"}
	a[59373]={"𤣞"}
	a[59374]={"𣠍"}
	a[59383]={"欓"}
	a[59384]={"𡤭"}
	a[59405]={"𩎸"}
	a[59411]={"㹰"}
	a[59418]={"𩍽"}
	a[59431]={"桄"}
	a[59432]={"姯","𠘿"}
	a[59433]={"猟"}
	a[59441]={"垙","橩","𣜧"}
	a[59446]={"𡟶"}
	a[59451]={"桤","𡯩","𣗋"}
	a[59453]={"棬","𡯪","𡯭","𨐈"}
	a[59454]={"婘"}
	a[59461]={"垲","𣙍"}
	a[59462]={"𡠰"}
	a[59463]={"埢","𣛄"}
	a[59473]={"𡐃","𡰋"}
	a[59475]={"輄"}
	a[59482]={"靗"}
	a[59497]={"𨌫"}
	a[59516]={"𩎃"}
	a[59523]={"桜","𣒁","𣒹"}
	a[59532]={"𣑹"}
	a[59533]={"柈","𤢯"}
	a[59534]={"姅","楼"}
	a[59535]={"𡞱"}
	a[59542]={"𣖱","𤟉"}
	a[59543]={"坢","榉"}
	a[59544]={"獜","𣕂"}
	a[59546]={"𡟒"}
	a[59552]={"𣙟"}
	a[59553]={"婩","嫦","𢅮"}
	a[59554]={"橉","𡏰"}
	a[59555]={"嫾","𩏾"}
	a[59556]={"耧"}
	a[59562]={"堓"}
	a[59563]={"𡤇","𣠴"}
	a[59565]={"𣗏","𪍴"}
	a[59572]={"㰔"}
	a[59573]={"𡔷"}
	a[59576]={"辚"}
	a[59577]={"靽"}
	a[59584]={"𩎢"}
	a[59587]={"𨏏"}
	a[59598]={"轔"}
	a[59616]={"𨎴"}
	a[59651]={"㮐"}
	a[59652]={"㛧","𡞞"}
	a[59661]={"櫿"}
	a[59662]={"𤢎"}
	a[59671]={"𠧁"}
	a[59672]={"檔"}
	a[59673]={"㜭","𦔄"}
	a[59674]={"𡡀"}
	a[59682]={"壋","𡡻"}
	a[59686]={"𡣣"}
	a[59692]={"𧰀"}
	a[59697]={"𨎚"}
	a[59711]={"𠜓"}
	a[59717]={"䪎","𨏳","𩍺"}
	a[59718]={"𩎇"}
	a[59721]={"杣"}
	a[59722]={"㭞","奾","𣔐","𤝒"}
	a[59731]={"圸","梤","猯","𤞚"}
	a[59732]={"䴮","柮","橯","𡵎"}
	a[59733]={"𡛛","𡡯"}
	a[59741]={"㭻","档","梢","椯"}
	a[59742]={"娋","媏","𡑍","𡞀"}
	a[59743]={"﨔"}
	a[59744]={"椦"}
	a[59751]={"㙐","垱","埫","𡌔","𣖷","𣙋"}
	a[59752]={"𪌯"}
	a[59753]={"𢅲"}
	a[59754]={"耮","𡠱"}
	a[59761]={"塉"}
	a[59762]={"橕"}
	a[59763]={"耥","𡐇","𣛟","𦓴"}
	a[59764]={"𢸧"}
	a[59765]={"軕"}
	a[59766]={"𩋇"}
	a[59771]={"𤢠"}
	a[59772]={"𡤰"}
	a[59773]={"𡑄"}
	a[59774]={"橳"}
	a[59782]={"𡡈"}
	a[59783]={"𤣑"}
	a[59784]={"䵎"}
	a[59785]={"輎","輲","鞘","鞝","𨌩"}
	a[59791]={"塴"}
	a[59793]={"㰎","欈","韒"}
	a[59794]={"孈","𡣸"}
	a[59796]={"𩌮"}
	a[59801]={"狄","𤟇"}
	a[59811]={"棪","𣏹"}
	a[59812]={"婒","梑"}
	a[59821]={"埮"}
	a[59822]={"楸","𪌌"}
	a[59823]={"𡟊"}
	a[59831]={"赻","𣕴"}
	a[59832]={"𤯇"}
	a[59833]={"㛶","䎦","𪍗"}
	a[59841]={"赸","𡎅"}
	a[59842]={"燅"}
	a[59852]={"㰊","趉"}
	a[59853]={"𧺾"}
	a[59854]={"𪏋"}
	a[59855]={"𨌹"}
	a[59861]={"趙","趟","𧼴"}
	a[59862]={"䵀","𣠃"}
	a[59866]={"鞦","𨍊"}
	a[59871]={"𡏶","𧽧"}
	a[59873]={"𧼚","𧽟"}
	a[59875]={"𣠂"}
	a[59877]={"𧼗"}
	a[59881]={"𧽊"}
	a[59883]={"𧽠"}
	a[59884]={"𪏩"}
	a[59885]={"𡓴"}
	a[59895]={"𩌆"}
	a[59912]={"𤝸"}
	a[59917]={"𪏫"}
	a[59922]={"𣟕"}
	a[59932]={"𣞁"}
	a[59933]={"嬫","𪌬"}
	a[59952]={"橖","𡮱"}
	a[59953]={"𡡢"}
	a[59954]={"𡢾"}
	a[60000]={"○","〇","䠬","曏","𡈟","𡈨"}
	a[60001]={"䁨","𠽫"}
	a[60002]={"𧷿","𨟙"}
	a[60003]={"𡈦","𨞽"}
	a[60004]={"躏"}
	a[60005]={"𧓸"}
	a[60010]={"㗴","㗿","嚪","瞯","瞷","躢","𡂛","𡅭","𡆏","𡈸","𡈻","𣊺","𨅍","𨇝","𨇡","𨇲"}
	a[60011]={"圞","瞤","𡈰","𡈵","𥊺","𨇧","𨇮"}
	a[60012]={"㘚","矙","躙","𡃦","𡄢","𨆇","𨟠"}
	a[60013]={"㘓","䣤","躑","躝","𥌻"}
	a[60014]={"躪"}
	a[60015]={"囒","𧖆","𨈆"}
	a[60020]={"口","囗","囚","𠮚","𡆣","𡆥","𡆦","𡆧","𡆱","𡇂"}
	a[60021]={""}
	a[60030]={"四","囜","囦","囧","囨","囫","囵","囹","圂","日","曰","𡆾","𡇇","𡇋","𨙫"}
	a[60031]={"㘝","㘞","㘠","因","团","囮","困","囷","图","田","甴","𡇒","𡇫","𡈍"}
	a[60032]={"囡","由","","𠁤","𡆪","𡆼"}
	a[60033]={"毌"}
	a[60034]={"曲"}
	a[60035]={""}
	a[60040]={"㘢","囙","回","囬","圀","目","郧","𡆠","𡆤","𡆩","𡆲","𡆽","𡇁","𡇅","𡇏","𡇕","𡇘","𡇺","𡈖"}
	a[60041]={"囝","囶","𡆿","𡇛 ","𡈛"}
	a[60042]={"邮","𡇄","𡇊"}
	a[60044]={"囲","𡇔"}
	a[60050]={"囥","囩","园","囸","囼","圆","圌","郘","郥","𡆨","𡆳","𡆷","𡆸","𡆻","𡇃","𡇈","𡇎","𡇗","𡇞","𡇩","𡇬","𡇴","𣅍","𨚙"}
	a[60051]={"囯","固","国","𡇀","𡇍","𡇜","𡇣","𡇰","𡇲","𡈣","𨚰","𨜍","𨜐"}
	a[60052]={"㘡","囤","圇","𡆰","𡆴","𡈌"}
	a[60053]={"围","𡇯","𡇿"}
	a[60054]={"𡇭"}
	a[60060]={"圐","𡆵","𡇆","𡇉","𡇌","𡇑","𡇖","𡇚","𡇝","𡇟","𡇠","𡇧","𡇳","𡇵","𡈎","𡈒","𨛡","𨜵"}
	a[60061]={"囻","囿","園","郢","郹","𡇓","𡇪","𡇸","𡇹","𡈏","𨛎","𨛴","𨜑"}
	a[60062]={"哪","圈","圉","國","𡇨","𡇮","𡈊","𡈐","𡈢"}
	a[60063]={"𠳐","𡈉","𨛋","𨜖"}
	a[60064]={"圃","𡇦"}
	a[60070]={"㘣","啷","圁","圎","圙","鄖","𡇢","𡇱","𡇼","𡈘","𡈙","𨀯"}
	a[60071]={"㖿","㘥","䣞","喐","圄","圔","踯","鄤","𡈪","𡈫","𨝪"}
	a[60072]={"𡇾","𡈑","𨞕"}
	a[60073]={"𡇽","𡈗","𡈞"}
	a[60074]={"𡈇"}
	a[60075]={"圑","𡈹"}
	a[60078]={"䣚"}
	a[60080]={"㘤","圓","圜","鄂","","𡈀","𡈴","𨁴"}
	a[60081]={"㗥","圗","鄙","鄵","𡈓","𡈠","𥆧","𨞱"}
	a[60082]={"嘟","圊","圛","螂","𡈕","𡈭","𨁌","𨞍"}
	a[60083]={"圍","𡈮","𨅬","𨝑"}
	a[60084]={"鄷"}
	a[60085]={"團"}
	a[60090]={"𡈆","𡈚","𨞚"}
	a[60091]={"圖"}
	a[60092]={"㘎","圚"}
	a[60093]={"鄲","𡈳"}
	a[60095]={"𨞎"}
	a[60100]={"睻","𣋣"}
	a[60101]={"𦋾"}
	a[60102]={"㘕"}
	a[60103]={"𣊹","𤳏"}
	a[60104]={"䍦"}
	a[60110]={"㬪","曡","𡀉"}
	a[60112]={"囖","曐"}
	a[60113]={"疉","疊","𤴁","𥃇"}
	a[60114]={"䠰","嚾","壘","矔","𣌓","𨯔"}
	a[60116]={"蠱","蠸"}
	a[60118]={"㬮","𦍀"}
	a[60130]={""}
	a[60132]={"","𠀐"}
	a[60134]={""}
	a[60140]={"旦","显","","𠮡","𣅂","𣅋","𥁕","𦉾","𦊢"}
	a[60141]={"","","𠲉","𦉷"}
	a[60142]={"盅"}
	a[60144]={"𥁖"}
	a[60150]={"㫔","㫫","啌","昱","昷","罡","𠯕","𣄾","𣅖","𣌬","𥁯","𥁰","𧖸","𨂞"}
	a[60151]={"呈","圼","罜","𤰵","𤱗","𦊄","𦋶"}
	a[60152]={"塁","蛊","𡋘"}
	a[60153]={"里"}
	a[60160]={"噬","昰","罝","𣅣","𥃿","𦊂","𦊐","𦊥"}
	a[60162]={"䍜","星","罣","罹","𡋵","𤰣","𥂮","𧌆"}
	a[60163]={"墨"}
	a[60165]={"㻃"}
	a[60170]={"𣆞","𦋳"}
	a[60171]={"㗌","㗧","𣌷"}
	a[60172]={"䍥","𤰴"}
	a[60174]={"豊","𠿅","𤲲"}
	a[60180]={"喧","𠹜","𣆹","𣈍","𦋠","𦋽"}
	a[60181]={"畳","疂","置","𡍸","𥋱"}
	a[60182]={"羅","𠾰","𣌅","𧏏"}
	a[60183]={"螲","𡀽","𡒀","𦌋","𧍱","𨤥"}
	a[60185]={"噻"}
	a[60190]={"暃","暄"}
	a[60191]={"𡔌","𣇣","𥉺"}
	a[60192]={"蝖","𠻖"}
	a[60193]={"罿","量","𣋞"}
	a[60194]={"𡄳"}
	a[60202]={"䗻"}
	a[60217]={"𧹀"}
	a[60219]={"蠨"}
	a[60230]={"罗","𣅕","𣌤","𣌮","𦊃"}
	a[60231]={"界"}
	a[60240]={"𢘖","𣌲","𦊑","𦋒"}
	a[60241]={"昦","畀","𣌻"}
	a[60242]={"畁","𠁦","𠁧","𠰱"}
	a[60250]={"昂","昴","𣆚","𥄊","𦌀"}
	a[60252]={"𡱋"}
	a[60260]={"㫹","䀚","𠻝","𣈈"}
	a[60262]={"𠷆"}
	a[60270]={"䍤","𣇓","𣇯","𥇴","𦊿"}
	a[60272]={"䁀","𡂕"}
	a[60278]={"蟏"}
	a[60280]={"罪","𣇅"}
	a[60281]={"𣉛"}
	a[60290]={"㘉","曑","𣉦"}
	a[60292]={"𥌋"}
	a[60300]={"𢣉","𦌾","𩜻"}
	a[60303]={"𧝖"}
	a[60305]={"䘆"}
	a[60306]={"𧒛"}
	a[60310]={"曟","𣊕"}
	a[60311]={"曇","𦍆"}
	a[60312]={"曧","𦌻","𦍄"}
	a[60313]={"𨑌"}
	a[60314]={"曩"}
	a[60316]={"囈","𤴂"}
	a[60317]={"囆"}
	a[60320]={"罖","𠮰","𠯁","𤆗"}
	a[60321]={"𠗀"}
	a[60322]={"𤆪"}
	a[60330]={"罛","𠯣","𡿯","𢗀","𣅭","𦊓","𦊽","𦌣"}
	a[60332]={"忠","虫","𤰰"}
	a[60340]={"慁","𠷖","𠹁","𠺢","𢗭","𢚊","𣌪","𥄧","𦋯","𧘗","𧰮"}
	a[60341]={"㫡","䍔","思","恩"}
	a[60342]={"黑","𢜧"}
	a[60344]={"㤟","𧏥"}
	a[60350]={"㤙","䍗","惖","𢘇","𢙍","𢝝","𤋁","𥅀","𦊷"}
	a[60351]={"㫱","畏","罢","罴","𠴈","𦋆"}
	a[60352]={"虽","𢝕"}
	a[60353]={"褁","黒","𤲐"}
	a[60354]={"䍢","患","𤊌"}
	a[60360]={"䍚","䠚","昙","睘","𢝮","𣆂","𦌦"}
	a[60361]={"㬄","罳","𠘀","𢙶","𤲆","𤲡","𩶊"}
	a[60362]={"罫","𡁏"}
	a[60363]={"愚"}
	a[60367]={"𦋰"}
	a[60370]={"㬎","晨"}
	a[60371]={"瞏","𢜹"}
	a[60372]={"曚","𢠝"}
	a[60373]={"㘃","𧋯"}
	a[60374]={"蠓","農","𠘗"}
	a[60376]={"𧑚"}
	a[60380]={"羆","𤐍"}
	a[60382]={"矇"}
	a[60383]={"𧌪"}
	a[60384]={"𧏒"}
	a[60386]={"𡂫"}
	a[60394]={"𪑿"}
	a[60395]={"𪒕"}
	a[60396]={"蟲"}
	a[60398]={"𧓶"}
	a[60402]={"𣍑","𪓕"}
	a[60403]={"鼌"}
	a[60404]={"𡅆","𤳍","𪒹"}
	a[60410]={"躥","鼂","𣋍","𦌡","𪓲"}
	a[60411]={"𥍄"}
	a[60412]={"𥌯","𦌿"}
	a[60413]={"𢁐","𣰱"}
	a[60414]={"贜"}
	a[60415]={"𣰭","𣰸","𩴻"}
	a[60416]={"𧕨","𪓅"}
	a[60421]={""}
	a[60430]={"兄","𣅬"}
	a[60431]={"䍕","𠰨"}
	a[60432]={""}
	a[60434]={"曳"}
	a[60436]={"𤕣"}
	a[60440]={"㫐","𠯚","𦊫"}
	a[60441]={"𦊵"}
	a[60442]={"㐕","㕀","𣆭","𣬦"}
	a[60443]={"电","𠲁"}
	a[60444]={"𦋈"}
	a[60450]={"㫕","晁","晃","見","邑","𠻩","𣅸","𣌫","𥃩","𦊁","𦊳","𨚋"}
	a[60451]={"咤","旯","𣌯"}
	a[60452]={"呓","晟","蛇","𦊻","𧉡"}
	a[60460]={"䍖","唍","啘","昆","跎","𣅷","𣆍","𥃯","𥃺","𥄀","𥄻"}
	a[60461]={"毘","罠","𣆠","𦌅"}
	a[60462]={"罭","𣆎","𤲈","𥅛","𦋓"}
	a[60463]={"㫣","䖳","黾"}
	a[60464]={"𠺜","𧂓"}
	a[60470]={"晥","晼","𢛝","𣆧"}
	a[60471]={"畹","𦋍","𨀸"}
	a[60472]={"蜿","𣈳","𣉪","𣊀","𦋤"}
	a[60474]={"罨","𠽱","𤱲"}
	a[60476]={"蠛"}
	a[60480]={"㫯","䝹","睆","睕","罷","踠"}
	a[60482]={"䍡","黦","𣆷","𥉂"}
	a[60484]={"䁾","䘊","𣋔","𦋋"}
	a[60496]={"𦋸","𪒯"}
	a[60502]={"𥊁","𨄒"}
	a[60503]={"𣊴"}
	a[60505]={"矆"}
	a[60506]={"𣌏"}
	a[60507]={"𨍯"}
	a[60511]={"𡅝"}
	a[60512]={"𡅾"}
	a[60513]={"𨇨"}
	a[60515]={"𥍜"}
	a[60516]={"𨅗"}
	a[60519]={"𦍈"}
	a[60522]={"中"}
	a[60523]={"史"}
	a[60526]={"𠁴"}
	a[60531]={"吊","曱","𦉴"}
	a[60532]={"甲","𠮽","𡜰","𤱀"}
	a[60533]={"㕜","哎","申",""}
	a[60534]={""}
	a[60541]={"䍐","早","旻","𣅐","𣅝"}
	a[60542]={"㫒","䍟","咹","妟","昇","畟","𡜸","𤰞","𤰯","𤿌"}
	a[60543]={"㚻","","𡕦","𢌿"}
	a[60544]={"串","𠦆","𡛽","𢍁"}
	a[60548]={"丳"}
	a[60551]={"旱","𠭁","𠰎","𡕥","𥃪","𥄐"}
	a[60552]={"㫨","哰","昪","晏","罤","𠵶","𡜑","𢍧","𣅹","𣊚","𤘵","𤰠","𤲋","𥃲","𥇡","𦌃","𦌖"}
	a[60553]={"㽚","䗏","𢄖"}
	a[60561]={"咠","曼","𣆉","𥄎","𥈟"}
	a[60562]={"㬊","晜","曻","睪","𠷛","𣅼","𥅥","𥊽","𧠋","𧵨"}
	a[60563]={"𠚙","𠦤","𡝎","𣈠"}
	a[60564]={"嘦","罬","𣌦","𦌉"}
	a[60565]={"㬒"}
	a[60566]={"𤰶","𤱓"}
	a[60567]={"畢","蟒","𡝤","𡞔"}
	a[60568]={"婁"}
	a[60570]={"𤲃"}
	a[60571]={"晸","罩","𠭒","𠵀","𠵬","𢑢","𣈨","𦋁","𦋉","𦋲","𦋷"}
	a[60572]={"𡕭","𥇝","𦌢"}
	a[60573]={"晕","𠹊","𣉱","𣋦","𤲜","𦌙"}
	a[60574]={"䗗","䝸","𢍰","𦌈"}
	a[60575]={"䁳","𧐞"}
	a[60576]={"𡢑"}
	a[60577]={"嘩"}
	a[60578]={"蠎","𣫻"}
	a[60581]={"𣇗"}
	a[60582]={"最","𠻕","𥅳"}
	a[60583]={"𡀜","𦎝"}
	a[60584]={"曓","羃","𦌩","𦌭"}
	a[60585]={"嚄","𧎣"}
	a[60586]={"曅","𦌬","𦌹"}
	a[60587]={"曄","罼","𩊄"}
	a[60588]={"𦌁"}
	a[60589]={"𧑍"}
	a[60591]={"羄","𦌠"}
	a[60592]={"𥉛"}
	a[60593]={"䠜","𨆳"}
	a[60594]={"䗴","蹿","𣋥"}
	a[60595]={"㬦","暈"}
	a[60596]={"𠽩","𤳅","𦌂"}
	a[60597]={"瞱","蠖"}
	a[60599]={"𧑑"}
	a[60602]={"謈","𧬉"}
	a[60603]={"瞎"}
	a[60604]={"躇"}
	a[60610]={"瞐","𦌽","𧭿"}
	a[60612]={"䍣","矒"}
	a[60613]={"礨","𡄅","𦌵"}
	a[60614]={"𨅱"}
	a[60616]={"蠴"}
	a[60617]={"躤"}
	a[60640]={"吕","呂","𠯮"}
	a[60650]={"𠯭","𠰝","𠹍","𠺀","𣅊","𦊴","𦊾"}
	a[60651]={"罟","𠱑","𦊔","𦊲"}
	a[60652]={"𠰬"}
	a[60656]={""}
	a[60660]={"䍝","品","昌","𣆗","𥄲","𦊸","𦊼","𦋹"}
	a[60661]={"喀","晷"}
	a[60662]={"嗒","畕","畧","𣆊"}
	a[60663]={"喏","喵"}
	a[60664]={"𠴿"}
	a[60670]={"㗳","㬁","罯","罾","詈","𠷰","𠹒","𣆢"}
	a[60671]={"䍛","啚","罶","𣌿"}
	a[60672]={"署","𤲉","𥅌","𧎧","𧑲"}
	a[60675]={"𧍗"}
	a[60680]={"噾","𠽨","𥅏","𥊉"}
	a[60681]={"𨂥"}
	a[60682]={"暑","𥉌","𧎡","𧐴","𨃚"}
	a[60683]={"嗐","睰","瞄","蹃"}
	a[60690]={"晶","碞","蹜","𥈾","𧠮","𧪔","𨅞"}
	a[60691]={"𦌕"}
	a[60693]={"畾","𡈲"}
	a[60695]={"螛"}
	a[60696]={"𦋿"}
	a[60700]={"𧸿"}
	a[60702]={"𢸇","𨆍"}
	a[60703]={"𡾔"}
	a[60704]={"𠢿"}
	a[60705]={"羁","贎"}
	a[60706]={"𡅶"}
	a[60707]={"𪒪"}
	a[60710]={"𣋶","𦍇","𩉉"}
	a[60711]={"𡦩","𡦬"}
	a[60712]={"𨈋"}
	a[60713]={"䴎","𤴍"}
	a[60714]={"嚿","罍","𨇿","𨈅"}
	a[60716]={"羇"}
	a[60717]={"羈"}
	a[60719]={"𤰋"}
	a[60720]={"𦋺"}
	a[60730]={"叧","罽","𠮠","𡶩","𦉬","𦉶","𦉹","𦋴","𦌧"}
	a[60731]={"另","呙"}
	a[60732]={"𠛸"}
	a[60740]={"号","咛","旵","易","罚","罞","𠳽","𡶸","𣄿","𣌥","𦊤"}
	a[60741]={"㝶","䍓","甼","罦","𠯂","𠯊","𠱔"}
	a[60742]={"男","𠰅","𠰖"}
	a[60743]={"𠯧"}
	a[60750]={"昘","昜","曷","肙","𠰡","𣆃","𥃬","𥅫","𦊈","𦊒","𦋞","𦋥","𦚋","𨙨"}
	a[60751]={"㝵","㫗","嘧","昺","𠮲","𠰇","𣅽","𥃷","𦋝","𦞅"}
	a[60752]={"㽕","甹","𡥔","𤰤","𤱤","𧉞"}
	a[60753]={"唠","禺","𠷅","𤳝","𦊏"}
	a[60754]={"𠚎"}
	a[60755]={"蜹","𣍓"}
	a[60760]={"昻","晑","眝","貯","𠱮","𣃸","𣅻","𣆪","𣋓"}
	a[60761]={"䙷","昮","胃","𥅙","𦊯","𦋂","𦌥","𧵤","𨈗"}
	a[60762]={"㫭","䍠","冑","嗬","罱","罵","胄","蜀","𠶾","𤰉","𧉎"}
	a[60763]={"䍙"}
	a[60766]={"螨"}
	a[60770]={"㬅","喦","嚀","嵒","罥","罰","𠴨","𣇬","𣈯","𣌸","𦐇"}
	a[60771]={"罻","𠾮","𡀙","𣌰","𥉴","𦋣","𦌫","𧷦"}
	a[60772]={"𠳋","𣆽","𦋅"}
	a[60774]={"瞒","蹒"}
	a[60780]={"𠵛","𡁮","𣆵"}
	a[60781]={"勗","罸","𦌰"}
	a[60782]={"䗆","䗿","噶","朂"}
	a[60783]={"𣈦"}
	a[60784]={"𠢮","𤲳","𧑗","𧑶"}
	a[60785]={"噧","𧒠"}
	a[60788]={"𤲥"}
	a[60790]={"䠉","暠","矃","羂","𡃂","𣆻","𣇎","𣇵"}
	a[60791]={"𣍉"}
	a[60792]={"嚆","𠼧","𧓺"}
	a[60793]={"𨃖"}
	a[60794]={"䗶","𥝆"}
	a[60797]={"蠇"}
	a[60800]={"矉","𨆦"}
	a[60801]={"𣊖","𥋰","𦌷"}
	a[60802]={"𦌔","𧓍"}
	a[60803]={"𡁃"}
	a[60804]={"㘔","𤣂","𤳦"}
	a[60810]={"贔"}
	a[60811]={"𧹈"}
	a[60812]={"𦍂"}
	a[60814]={"𨇥"}
	a[60820]={"只","眾","𦉵","𦋎","𪐗"}
	a[60830]={"员","炅","足","𦌇","𦌗","𧹒","𧿮"}
	a[60831]={"㕦","𦉼"}
	a[60832]={"𧈾"}
	a[60833]={"㬰",""}
	a[60840]={"昃","昗","貝","𠯵","𠶵","𣈩","𤇀","𦌪"}
	a[60841]={"吳","吴","旲","𠸂","𦊊"}
	a[60842]={"贵","𠔓","𠔔","𠱵","𧉢"}
	a[60843]={"贯"}
	a[60850]={"啶","是","𣊂","𥄴"}
	a[60851]={"㗛","昊","狊","𠔛","𠺑"}
	a[60852]={"𣇪","𤱫"}
	a[60853]={"異"}
	a[60854]={"𠸄"}
	a[60860]={"㬃","員","買"}
	a[60861]={"𡙷","𣉉","𤲊","𧻻","𩼄"}
	a[60862]={"𠴩","𦋊","𧏖"}
	a[60863]={"𦌊"}
	a[60864]={"𠔱"}
	a[60865]={"𧋞"}
	a[60866]={"蝧"}
	a[60870]={"𥇓","𦋨","𧴴"}
	a[60871]={"奰","𦌸"}
	a[60872]={"貴","𠻤","𣇳","𣊜"}
	a[60873]={"嗼","貫"}
	a[60874]={"䁐"}
	a[60880]={"𠽰","𡀹"}
	a[60881]={"𧵞"}
	a[60882]={"𣊇"}
	a[60883]={"暯","𦌚"}
	a[60884]={"螾"}
	a[60885]={"蟆","𧕥"}
	a[60890]={"𠽷","𨆑","𨆬"}
	a[60891]={"𣉮"}
	a[60892]={"瞚","蠙"}
	a[60893]={"瞙","𡚤"}
	a[60894]={"𣋷"}
	a[60904]={"櫐"}
	a[60910]={"羉","𣌚","𥍙"}
	a[60911]={"𦌮","𦍁"}
	a[60913]={"纍","𥍐"}
	a[60919]={"𣡗"}
	a[60920]={"眔"}
	a[60930]={"罘","𣌢","𥄳"}
	a[60931]={"䍒","䍘","呆","𠰓","𣐮","𦊜"}
	a[60932]={"𡁐"}
	a[60940]={"𡭨","𦊎"}
	a[60941]={"㫧","杲","𠳼"}
	a[60942]={"罧","𦊧"}
	a[60943]={"嗏","果"}
	a[60944]={"𧍠"}
	a[60950]={"㫤","𠵻","𦋏"}
	a[60951]={"累","𣇆","𣐥","𥅼"}
	a[60952]={"𣇰","𣈎","𣷛"}
	a[60953]={"𠻬","𤳂","𪐺"}
	a[60960]={"景"}
	a[60961]={"𠾯","𦀤","𦌒"}
	a[60962]={"暴","𦅔"}
	a[60963]={"罺","𦋡","𨃓"}
	a[60965]={"蝾"}
	a[60970]={"㬌","嚓","賩","踪","𣊡","𦌟"}
	a[60971]={"喿"}
	a[60972]={"𡂠","𡂾","𦃙"}
	a[60973]={"㬥","𣊻"}
	a[60976]={"𠿚"}
	a[60980]={"𦌶"}
	a[60982]={"㬧"}
	a[60983]={"𣉰","𨅈"}
	a[60984]={"囌","𤳥"}
	a[60988]={"蠂"}
	a[60990]={"𥌀","𨆾"}
	a[60994]={"𪒼"}
	a[60996]={"瞸"}
	a[61100]={"嘔","𥇪","𨁶"}
	a[61101]={"㗺"}
	a[61102]={"䞁","𠻺","𠽧","𥈔"}
	a[61103]={"䁥","𨂷"}
	a[61104]={"𣌜"}
	a[61110]={"瞘","𣉾","𨄅"}
	a[61111]={"䁦","䠡","𡃢","𡄊","𣉓","𣌟","𥉢","𧇼","𧰑"}
	a[61112]={"㙱","嚧","曥","矑","𧏺","𨇖"}
	a[61113]={"嚯","曤","疅","矐","𧐅","𧖜"}
	a[61114]={"䗵","蠦","黸","𧈕","𧸪","𨇎","𨇠"}
	a[61116]={"𧓋","𧔹"}
	a[61140]={"叿","呸","哑","𠮵"}
	a[61141]={"呕"}
	a[61150]={"𠯔","𠰪","𠲮","𠳍"}
	a[61151]={"㕵","㕶","咂","𠰧","𠲏"}
	a[61152]={"虹","蚽","𡏔","𧉀"}
	a[61160]={"㗏","哣","趾","𠯞","𠰐","𠰠","𠱸","𠲬","𠳔","𣇁","𣈶","𥃽","𥅊"}
	a[61161]={"咥","旺","眍","𠸳"}
	a[61162]={"蛵","𠳏","𠶖"}
	a[61163]={"蚟","𧉣"}
	a[61164]={"唖"}
	a[61170]={"䀴","咺","昛","眐","踁","𠷐","𣅥"}
	a[61171]={"哐","嘘","晊","𤱥","𤱻","𧿷"}
	a[61172]={"啀","嚦","蚷","𦥁"}
	a[61173]={"㖶","蛭"}
	a[61180]={"啞","晅","暅","距","𠾜","𣉖","𥄷","𥆖","𧿟","𧿽","𨁋"}
	a[61181]={"噓","眰","跮","𥆚"}
	a[61182]={"𠸯","𠺚","𧊳"}
	a[61183]={"䖱","喱","𡂥"}
	a[61184]={"𧔝"}
	a[61185]={"䗎"}
	a[61190]={"𣇥","𥅨"}
	a[61191]={"眶","𠹿","𥇞","𥋖","𨀕"}
	a[61192]={"㖸","䝽","睚","𣈿","𥌮","𨂉","𨇗"}
	a[61193]={"暱"}
	a[61194]={"蝘","𠽥","𪓀"}
	a[61195]={"黫"}
	a[61200]={"䠊"}
	a[61202]={"𠼕"}
	a[61211]={"𡅿","𥍗"}
	a[61213]={"𧖋"}
	a[61240]={"𠯪","𠳤"}
	a[61250]={"𠰷","𧴷","𧿄"}
	a[61260]={"䟚","踄"}
	a[61280]={"啡"}
	a[61290]={"㫵"}
	a[61291]={"𡁭"}
	a[61292]={"噖","𧍃"}
	a[61301]={"㬡"}
	a[61302]={"𥌠","𧑕"}
	a[61303]={"𢤃"}
	a[61305]={"𧒓"}
	a[61310]={"𨄰","𨅥"}
	a[61311]={"饕","𥋞","𩞂"}
	a[61312]={"𤳟","𧐊","𧖙"}
	a[61313]={"躚","辴","𨆙","𪒝"}
	a[61314]={"𧓻"}
	a[61330]={"吓","𡆡"}
	a[61331]={"啄"}
	a[61340]={"咔",""}
	a[61341]={"㖭","𠻹"}
	a[61342]={"䖶","虾"}
	a[61350]={"呍","𠯝","𠱚","𥆋"}
	a[61351]={"𠴴","𨁿"}
	a[61352]={"𤲖","𧏿"}
	a[61360]={"㖘","𨄃"}
	a[61361]={"𢙸","𤱂"}
	a[61362]={"𧉛"}
	a[61370]={"眃","𥄆","𧵇","𧿠"}
	a[61371]={"噱","𤱼"}
	a[61372]={"㸃","蜄"}
	a[61380]={"䀼","䟴","賑"}
	a[61381]={"𣊯","𤲘"}
	a[61382]={"䗅","𡃖"}
	a[61383]={"𧏽"}
	a[61390]={"䠆","噁","賬","𠾦","𥇔","𧶊"}
	a[61391]={"躆"}
	a[61393]={"𠿗"}
	a[61400]={"𤭳","𥉿"}
	a[61401]={"號","𨂜"}
	a[61402]={"𤮋","𨆱"}
	a[61403]={"𠿜"}
	a[61408]={"甊"}
	a[61410]={"嚨","曨","矓","贚","躘","𡅃"}
	a[61411]={"𠿙","𡅗","𤮦","𥍕","𧇷","𧈐"}
	a[61412]={"囇","曬","矖","蠬","躧"}
	a[61413]={"蹮"}
	a[61414]={"𡅺","𧈍","𧑜","𧑡","𧕯"}
	a[61440]={"𠮾","𡆶"}
	a[61450]={"呃","𠯡"}
	a[61451]={"呒"}
	a[61452]={"𧈭"}
	a[61460]={"咓","𠳠","𥄙","𧿁"}
	a[61461]={"𠳟"}
	a[61462]={"噦","蚅","蚖"}
	a[61463]={"𠱏","𧎞"}
	a[61470]={"盶","貦","𠰆","𥆆","𧿊","𧿙"}
	a[61471]={"𢽕"}
	a[61472]={"𪐬"}
	a[61473]={"黖"}
	a[61480]={"𠳧","𨀄"}
	a[61481]={"唬","𤭋"}
	a[61482]={"䠩","嘎","嘠","𧸗"}
	a[61483]={"㼫","𥝂","𧋖"}
	a[61484]={"𪒩"}
	a[61490]={"瓹","𤭺"}
	a[61491]={"嘅","踂","𡁓","𡄼","𤮉","𥆍","𥆮","𧶋"}
	a[61492]={"𣘫","𥆦"}
	a[61493]={"㼴","䗂"}
	a[61501]={"𣀕","𪔆"}
	a[61503]={"曋","蹑"}
	a[61504]={"𡁁","𨅅"}
	a[61505]={"蟫","𣊢","𨃅","𪒤"}
	a[61510]={"𧔅"}
	a[61511]={"𨇄","𨈉"}
	a[61512]={"𡄟","𣌊"}
	a[61513]={"囁","瞫","贉","躡","𣌍","𥍉","𨅭"}
	a[61514]={"𣀜","𣌘"}
	a[61515]={"𧓴","𧕡","𧕩","𩎍"}
	a[61541]={"呯","𠯗"}
	a[61542]={"咞"}
	a[61551]={"旰","𠰑","𠱢","𠳰"}
	a[61552]={"𤰟"}
	a[61553]={"虷","蚲","蛳"}
	a[61554]={"蚈"}
	a[61555]={"𢼰"}
	a[61561]={"咡","哶","敡","盰","𣆙","𧿂","𧿋"}
	a[61562]={"䀘","趼","𠴟","𠶺"}
	a[61563]={"䵟","哢","𪑉"}
	a[61564]={"哽","喓","敤","𠷊"}
	a[61571]={"啅","𠹶","𢆜","𢾙"}
	a[61572]={"㗔","㪋"}
	a[61573]={"䖹","𧊗"}
	a[61574]={"蝆","𣆳","𣉋"}
	a[61575]={"𠼰"}
	a[61576]={"𧋑","𧍔","𧍲"}
	a[61581]={"嗄","晫","眲","𠹘","𥆊"}
	a[61582]={"𢿕","𤲤","𦖷"}
	a[61583]={"嗫","斀","𣀇","𣀛"}
	a[61584]={"䁏","𡁉","𨁈","𨂯"}
	a[61585]={"㗑"}
	a[61586]={"𡂣"}
	a[61589]={"𢿘"}
	a[61591]={"嚘","踔","𡁇","𥇍"}
	a[61592]={"𡂩","𢿾","𨂶"}
	a[61593]={"嘾","螄"}
	a[61594]={"𢿒","𪑷"}
	a[61595]={"𣀂"}
	a[61600]={"䞅","𧸥"}
	a[61601]={"踾"}
	a[61602]={"𠼘"}
	a[61610]={"𥌑","𧸩"}
	a[61611]={"㘊","䞊","𥌼"}
	a[61612]={"䁮","噆","𨅔","𩉘"}
	a[61613]={"𧕅"}
	a[61614]={"𧒽"}
	a[61650]={"呫","𠰴","𠳝"}
	a[61651]={"𠳱"}
	a[61660]={"咟","𠵠"}
	a[61661]={"㖔"}
	a[61662]={"䖨","哂","蛅"}
	a[61670]={"䀡","喕","貼","跕","跖","踎","𧵓"}
	a[61671]={"唔"}
	a[61672]={"唒","晒","蛨","點","𡀂"}
	a[61680]={"㬐","𠸸","𡈔"}
	a[61681]={"晤","𧵳","𨁇"}
	a[61682]={"嗮","蝒","跴","𧎽"}
	a[61683]={"𧋋"}
	a[61690]={"𥅭","𥈅"}
	a[61691]={"𥆐"}
	a[61692]={"嚸"}
	a[61693]={"蝠"}
	a[61701]={"嚅","蹰"}
	a[61703]={"嚹","𠿛","𡁑"}
	a[61704]={"𡅈","𧓠"}
	a[61705]={"曞","𧒘"}
	a[61707]={"蠣"}
	a[61711]={"曘","𠻢","𤳠","𥌎"}
	a[61712]={"㽭","𨆼","𨇙"}
	a[61713]={"蠕","𣋮","𧔸","𧔽"}
	a[61714]={"𩧚"}
	a[61715]={"矋","𧸱","𨇆","𩧡"}
	a[61716]={""}
	a[61730]={"叮"}
	a[61740]={"㖇","哘","𠯸","𡆭","𡆹"}
	a[61741]={"吁","呀","呖","啢","町","𠰳"}
	a[61742]={"唡","虰"}
	a[61745]={"𡁠"}
	a[61750]={"䟓","呵","哬","啮","盯","𠮱","𣆝"}
	a[61751]={"旴","昞"}
	a[61752]={"咑","𧉋","𧊽"}
	a[61753]={"虶","蚜","蛃","蜽"}
	a[61760]={"䀎","䀪","䟰","啊","嚙","𠽴","𥄝","𥅡"}
	a[61761]={"䠃","噛","盱","眪","趶","𠶲","𥇑"}
	a[61762]={"嗎","蚵","蛎","𧉄","𧎘","𧿓","𪐚"}
	a[61763]={"𧈯"}
	a[61764]={"𠱻"}
	a[61765]={"躎","𥌃"}
	a[61770]={"啃","嗝","嘕","眄","跒","𣊵","𧵛"}
	a[61771]={"㗸","㘅","嗕","𠵾","𠶪","𠼫","𠽌","𤳜","𥃳","𧿉"}
	a[61772]={"嘑","𧑮","𪘅"}
	a[61773]={"䵦"}
	a[61774]={"螞","𠼥"}
	a[61775]={"𠻔","𡄣"}
	a[61780]={"㬏","𠹭","𠼉","𥋃","𧸀","𪘏"}
	a[61781]={"𠷋","𠷢","𠾇","𠾑","𠾟"}
	a[61782]={"䗡","螎","𣈺","𥉊"}
	a[61783]={"𧌧"}
	a[61788]={"𨅲"}
	a[61790]={"𥉅"}
	a[61791]={"𥊕"}
	a[61792]={"𠿎","𡀛","𧍹","𧎺"}
	a[61793]={"蟵","𪑾"}
	a[61795]={"𡂖"}
	a[61800]={"䫘","題","𥈿","𩔰"}
	a[61801]={"嚈","𡄶","𥌨","𩕃"}
	a[61802]={"噳","噸"}
	a[61803]={"顒"}
	a[61810]={"䁰","䫟","蹞","顎","顥","顯","𩕩","𩕪","𩖇"}
	a[61811]={"𡅅","𡅥","𨈀","𩕾"}
	a[61812]={"䫭","䫳","𥋣","𨆆","𨆵","𨇪","𩔠","𩖍"}
	a[61818]={"䫫"}
	a[61830]={"𠯬"}
	a[61842]={"𧉆"}
	a[61850]={"唝","嘥"}
	a[61851]={"𠷀"}
	a[61852]={"","𧏦"}
	a[61853]={"𧉂"}
	a[61861]={"㬉","䀖","噘"}
	a[61862]={"𣊥","𤲬"}
	a[61863]={"蝡","颗"}
	a[61870]={"㖽","煚","蹝","题","𠾫","𥊂","𨁾"}
	a[61871]={"䞂","𠸝","𢆝","𥈇"}
	a[61873]={"蟩","颙","𧌭"}
	a[61880]={"㷡","嗊","暊","颢","𩒇","𩒳","𩒻","𩓺"}
	a[61881]={"蹶","𨂑","𩒱","𩓽"}
	a[61882]={"蝢","頔","𣊠"}
	a[61890]={"㘖","㼵","䪽","嚬","顕","颚","𥈗","𧶸","𨂠","𨅑","𨆌","𩑰","𩒁","𩒝"}
	a[61891]={"顋","𥈤","𩓓","𩓢"}
	a[61892]={"𠿪","𥋄","𨅟","𪑳","𪑸"}
	a[61893]={"顆"}
	a[61894]={"𣊰"}
	a[61930]={"吥"}
	a[61940]={"呩","𠱙"}
	a[61942]={"𧉈"}
	a[61943]={"𧌮"}
	a[61950]={"𠳃","𥄚","𧿤"}
	a[61960]={"眎","𧵋","𨀚"}
	a[61963]={"㗚","𧋝"}
	a[61972]={"嘌","螈","𡈜"}
	a[61980]={"𨂽"}
	a[61982]={"㬓"}
	a[61983]={"𨃙"}
	a[61984]={"螵"}
	a[61992]={"瞟","𣜍","𨄏"}
	a[61993]={"蟝"}
	a[62020]={"㖄","","𠮝","𠯀"}
	a[62030]={"叫"}
	a[62031]={"甽"}
	a[62040]={"𥃹"}
	a[62042]={"虯"}
	a[62050]={"吲","𥃧","𧾻"}
	a[62062]={"蚓"}
	a[62070]={"䀕","𧿯"}
	a[62080]={"𣉤"}
	a[62082]={"蜵"}
	a[62090]={"瞓"}
	a[62101]={"𠿓"}
	a[62105]={"踵"}
	a[62107]={"䵯"}
	a[62110]={"䠪"}
	a[62111]={"𨆂"}
	a[62112]={"𧓓"}
	a[62140]={"𠰋"}
	a[62141]={"𠴯","𠾊","𡋏"}
	a[62151]={"𠽲","𡋾"}
	a[62152]={"蚯"}
	a[62160]={"䟬","𥅔"}
	a[62161]={"𤳶","𥋍"}
	a[62165]={"唾"}
	a[62170]={"咝","噔","𨇏"}
	a[62171]={"𥅸"}
	a[62175]={"𣇦"}
	a[62177]={"𧌯"}
	a[62180]={"𥂄"}
	a[62181]={"𨲻"}
	a[62182]={"䗳"}
	a[62183]={"蜌","𤳘"}
	a[62185]={"喠","睡"}
	a[62190]={"瞪","蹬"}
	a[62191]={"𥆯"}
	a[62192]={"𪒘"}
	a[62196]={"畽"}
	a[62197]={"蝩"}
	a[62205]={"䁪"}
	a[62210]={"𨇰"}
	a[62212]={"𣃖"}
	a[62213]={"𣃓"}
	a[62220]={"㖎","罒"}
	a[62230]={"听","𢒧"}
	a[62240]={"䀐","昕","𠯯","𢒗"}
	a[62241]={"唽"}
	a[62242]={"蚚","𣂿"}
	a[62243]={"𢒙"}
	a[62250]={"盺","𣂨","𧿧","𨀨"}
	a[62251]={"晰","𢒠","𤰽"}
	a[62252]={"哳","𧈼"}
	a[62253]={"蜥"}
	a[62260]={"影","𣂰"}
	a[62261]={"噺","𢒡","𥇦"}
	a[62262]={"晣"}
	a[62263]={"𧌨"}
	a[62264]={"𧋍"}
	a[62270]={"㫀","𣃊"}
	a[62271]={"嘭"}
	a[62272]={"䀿","䟷","嘶","𢒯","𣂽","𧶇"}
	a[62283]={"蟛","𥇢"}
	a[62284]={"蟖"}
	a[62285]={"𠼗"}
	a[62295]={"𣊙"}
	a[62297]={"螹"}
	a[62300]={"𨆲"}
	a[62301]={"𨆛"}
	a[62310]={"𡆕","𨈌"}
	a[62312]={"䂅"}
	a[62313]={"𩞣"}
	a[62314]={"𧖣"}
	a[62315]={"𧔆"}
	a[62317]={"𢥽","𧖈","𧖎"}
	a[62320]={"𠮺"}
	a[62330]={"呱","哌","𠰏"}
	a[62331]={"𤰕","𤰝","𤱰"}
	a[62332]={"䖣"}
	a[62340]={"吆","𠸁","𠺅","𣆅","𥄄"}
	a[62341]={"㗭","畖","𤔗","𤰜"}
	a[62342]={"䖰","蛌"}
	a[62343]={"𤔖","𤔝"}
	a[62350]={"䟪","眨","眽","貶","𢝔","𥃼","𥄼","𧵬","𧿼"}
	a[62351]={"𠲍"}
	a[62353]={"蟋","𤬁"}
	a[62360]={"㼔","𠰈","𢞈","𥇐"}
	a[62361]={"跹","𤋇"}
	a[62362]={"爴","𠻯"}
	a[62363]={"𧑳"}
	a[62368]={"𤬏"}
	a[62370]={"𤬆"}
	a[62374]={"嚑"}
	a[62380]={"𡁋","𨃆"}
	a[62384]={"曛","𣊳"}
	a[62386]={"䗼"}
	a[62394]={"矄"}
	a[62400]={"𨃳"}
	a[62401]={"蹏","𥉘"}
	a[62402]={"毾"}
	a[62403]={"氉"}
	a[62404]={"𥇾"}
	a[62406]={"𣰊"}
	a[62410]={"𢀍"}
	a[62412]={"𧔀","𧕓"}
	a[62414]={"氍"}
	a[62415]={"氎"}
	a[62416]={"𠽶"}
	a[62430]={"𠮜"}
	a[62432]={"𠃦"}
	a[62434]={"𠃪"}
	a[62440]={"咷","𠮪","𠱁","𣅪"}
	a[62441]={"吒","呧","𠲐","𣅒"}
	a[62442]={"虬"}
	a[62450]={"䀝","吡","呲","晀","𠴄","𠵺","𥃤","𧠘","𧾹"}
	a[62451]={"㫝","吼","啂","𠳶","𣈃","𤱩"}
	a[62452]={"㕰","䖴","䵝","𠯩","𤰦"}
	a[62453]={"虴","蚔","蚳","𠱹","𧉔","𧉹","𧊑"}
	a[62460]={"眺","跳","𧡒"}
	a[62461]={"䟗","䟡","毗","眂","眡","貾","𡂏","𧵄","𧵮","𧿌"}
	a[62462]={"蚍","𣯉","𣱍"}
	a[62463]={"𪐞"}
	a[62464]={"蚝"}
	a[62470]={"嗈","眦","跐","𠲷","𣋲","𥄩","𥆎","𧿥"}
	a[62471]={"𨀭"}
	a[62472]={"㲘","眊","𣭖","𣭻"}
	a[62473]={"嘰","蠟"}
	a[62475]={"𣮔"}
	a[62480]={"𠹌","𥊋","𨁓"}
	a[62481]={"䁽","嗁","躐","𧡷"}
	a[62482]={"毼","𣊉","𣯎","𧐎","𧠑","𩙽","𪒐"}
	a[62483]={"𣭸","𣮊","𣮰"}
	a[62485]={"蟣","𠵣"}
	a[62490]={"氀","𣰟"}
	a[62491]={"𡅘"}
	a[62493]={"螔"}
	a[62503]={"𡅇"}
	a[62511]={"蹳","𥋀","𥍚"}
	a[62531]={"吀","","𠯘"}
	a[62532]={"哸"}
	a[62541]={"㖟","噯","昄"}
	a[62542]={"畈"}
	a[62543]={"唩","蚸"}
	a[62551]={"䀒","眅","販","跅","𠷴","𧿨"}
	a[62552]={"喛","嗳","𨁡"}
	a[62553]={"𠼐","𧉲","𧌅"}
	a[62554]={"蝬"}
	a[62555]={"蜲","𣭂"}
	a[62561]={"哔","唌","曖","𠷑"}
	a[62562]={"䁓","䟦","暖","暧","𡃲","𢒳","𥅢"}
	a[62563]={"蝂","踒","𤲫","𧎲","𧓁","𪒱"}
	a[62564]={"蝯"}
	a[62565]={"𠼈"}
	a[62571]={"瞹","𣆴","𧶶"}
	a[62572]={"䁔","𠶽","𣊬","𣚤","𦋪"}
	a[62573]={"蜒","𤲒"}
	a[62574]={"蜓","𨃦"}
	a[62581]={"䀽","跸","𨁆","𨂩"}
	a[62582]={"瞬","𥆑","𨁗"}
	a[62583]={"𠁶"}
	a[62584]={"𡕺"}
	a[62585]={"𨄖"}
	a[62591]={"㗶"}
	a[62592]={"𥈒","𨄪"}
	a[62593]={"𣉡"}
	a[62600]={"𥋮"}
	a[62602]={"𥈧"}
	a[62612]={"𡆓"}
	a[62615]={"䡡","𡃞"}
	a[62650]={"㖃","𠳇","𥆞"}
	a[62651]={"咶"}
	a[62660]={"𠴲","𠷒"}
	a[62661]={"㗍","𠳂"}
	a[62662]={"噃","𧊛"}
	a[62663]={"蛞","𧋣"}
	a[62670]={"𥅠"}
	a[62671]={"㖧","䀨","䟯"}
	a[62672]={"𠹗","𡈄","𣊩","𧊙","𧌏"}
	a[62674]={"蟠","𡃓"}
	a[62676]={"𩋈"}
	a[62680]={"喈","踏","𠽹"}
	a[62681]={"𣇲","𥆠"}
	a[62682]={"䵬","蹯"}
	a[62684]={"𧎴"}
	a[62690]={"𥋎"}
	a[62691]={"睧","瞃","踲"}
	a[62692]={"蝔"}
	a[62693]={"𪑕"}
	a[62700]={"𡃸","𪅚"}
	a[62701]={"㬭","蹻","𨄩"}
	a[62702]={"𧍺"}
	a[62704]={"蟕"}
	a[62710]={"躖","𨇔","𨈊","𨈎","𪈉"}
	a[62711]={"䂃","𡆝","𥋊","𪙶"}
	a[62712]={"䘎","𧖖"}
	a[62713]={"𠠯"}
	a[62714]={"𧖘"}
	a[62720]={"𠮧"}
	a[62730]={"別","哛","𠜟","𧿀"}
	a[62731]={"㕳","别","剐","呼","哷","唎","𠛭","𠜠","𠝹"}
	a[62732]={"𠛿","𠞵","𧋈"}
	a[62740]={"則","剔","咧","𠰗","𠰤"}
	a[62741]={"哹","𠰙"}
	a[62742]={"㽟","䵞","𠞅","𡆺"}
	a[62743]={"蛶","蜊","𠜴"}
	a[62750]={"㓭","㓻","剈","噅","𠞍","𠸑"}
	a[62751]={"䟹","哵","唀","唰","嗂","𠜹","𠟘","𠵯","𠸷","𠺓","𧿖"}
	a[62752]={"蛚","𧍼"}
	a[62753]={"喇","蜉","𪑋"}
	a[62754]={"𧊞","𧌥"}
	a[62760]={"㔀","㖰","㗖","㬙","𠷌","𠺣","𣋌"}
	a[62761]={"嚠","暚","𠟎","𠴼","𥅒","𥆬","𧷊","𧸅","𧸕"}
	a[62762]={"劅","蟡","𠞋","𠞫","𠟔","𠶜","𧵃"}
	a[62763]={"㫼","蜏","𧎼"}
	a[62764]={"𣉁"}
	a[62765]={"蝲"}
	a[62768]={"𠞭"}
	a[62770]={"㓵","㗀","䞈","𠞈","𠟟","𠠁","𣉇","𨅌"}
	a[62771]={"㘌","䁘","䠛","劋","喢","𠟑"}
	a[62772]={"𠹮","𧍡"}
	a[62773]={"睜","𣈭","𥇕","𥈙","𧌼"}
	a[62774]={"𥈦"}
	a[62775]={"蝺"}
	a[62780]={"䠌","蹈","𠟻","𥉰"}
	a[62781]={"嘺"}
	a[62782]={"𧍘"}
	a[62783]={"踽","𥈋"}
	a[62785]={"𪑴"}
	a[62791]={"嚼","𣌄","𥈊","𧶵","𨂵"}
	a[62792]={"嘴","𠠡","𥋠"}
	a[62793]={"蟜","𨅳","𨇕"}
	a[62800]={"躓","𧸲"}
	a[62831]={"㕭"}
	a[62840]={"𠴇","𥉚"}
	a[62850]={"㓳","𤐁"}
	a[62851]={"嗘","跃"}
	a[62860]={"匙"}
	a[62861]={"暌","踬"}
	a[62862]={"噗","𡂈","𤲺"}
	a[62863]={"螇","𤳃","𧍜"}
	a[62870]={"𠺍"}
	a[62871]={"䠏","睽","蹊","𡚇","𥉐"}
	a[62872]={"𣊪"}
	a[62873]={"𧏕"}
	a[62874]={"䗱"}
	a[62880]={"𡂒"}
	a[62881]={"𠼠","𦧪"}
	a[62882]={"瞨","贌","蹼","𨆯"}
	a[62883]={"𧷑"}
	a[62884]={"𪒢"}
	a[62892]={"𧓳"}
	a[62901]={"嚛","𥌣"}
	a[62905]={"𥣷"}
	a[62910]={"圝","𥌭","𨇼"}
	a[62911]={"䁻","躒","𣋵"}
	a[62913]={"𧔉"}
	a[62931]={"咊","啋","𠷘"}
	a[62940]={"喺"}
	a[62941]={"𠱟","𣈄","𤱄"}
	a[62942]={"𠼝","𤱛","𤲎"}
	a[62951]={"䀥","睬","跞","踩","𥟙","𥟟"}
	a[62953]={"𧑓"}
	a[62954]={"蟍"}
	a[62960]={"噝","𣋡"}
	a[62961]={"喍","𠹀","𡀚"}
	a[62962]={"㗼","𡁖","𥊈"}
	a[62963]={"𠻥"}
	a[62970]={"㗪","𠹦"}
	a[62971]={"𡈱","𨃮"}
	a[62972]={"曗","𤳁"}
	a[62973]={"𧎤"}
	a[62975]={"𧑀"}
	a[62981]={"䠕","𥈐"}
	a[62982]={"𥋙"}
	a[62983]={"𠾋","𥊌","𧷣","𨄓","𪑽"}
	a[62984]={"𣚧","𪒲"}
	a[62990]={"𨄐"}
	a[63020]={"卟"}
	a[63030]={"吣","𠰻","𣅃"}
	a[63031]={"咇","𤰘"}
	a[63032]={"虲"}
	a[63040]={"䟔","𥃨","𧴤"}
	a[63042]={"𪐙"}
	a[63043]={"䖩"}
	a[63051]={"䀣","䟤"}
	a[63052]={"𠨃"}
	a[63062]={"啩"}
	a[63100]={"𩀮"}
	a[63102]={"𩀏","𩀺"}
	a[63103]={"曈","𡒦"}
	a[63104]={"囄","疃","𧒱","𩁇","𩁍","𩁠"}
	a[63105]={"𧑆"}
	a[63110]={"䁴","𠿞","𡅹","𣋊","𨆁"}
	a[63112]={"蟺","𡄸","𨿪","𩀇","𩀭"}
	a[63113]={"瞳","蹱","𡆎"}
	a[63114]={"䨉","𡃵","𥍃"}
	a[63115]={"𩁜"}
	a[63116]={"𧕮"}
	a[63118]={"𣌖"}
	a[63140]={"㕸"}
	a[63150]={"𠴹","𣅇"}
	a[63151]={"甿","𠰍"}
	a[63152]={"虻"}
	a[63160]={"盳","𥅈"}
	a[63161]={"暀"}
	a[63162]={"唯","啦","盢","𩀚"}
	a[63163]={"蛀"}
	a[63170]={"𠴧"}
	a[63171]={"䝬","跓","𥅖","𥆜","𥉓"}
	a[63172]={"㫿","𧏑"}
	a[63173]={"𠻿","𪐴"}
	a[63174]={"蜼"}
	a[63175]={"𨾡"}
	a[63176]={"𨾳"}
	a[63182]={"睢","踓","𥊱","𨿎"}
	a[63183]={"囃"}
	a[63184]={"𩁯"}
	a[63190]={"䠁"}
	a[63192]={"噰","𡑅","𥊓","𨄉","𨿔"}
	a[63193]={"噇","𨿑","𩀎"}
	a[63194]={"䨃","雖"}
	a[63195]={"𩀍"}
	a[63231]={"哜"}
	a[63240]={"喭","𠲗"}
	a[63241]={"𠳻"}
	a[63243]={"蛴"}
	a[63250]={"嘇","𠴽"}
	a[63251]={"跻"}
	a[63260]={"𨂪"}
	a[63261]={"㽩"}
	a[63263]={"黪"}
	a[63270]={"嚌","贂","𡄡","𣋠","𥊀"}
	a[63272]={"黲"}
	a[63282]={"蠐"}
	a[63290]={"躋"}
	a[63300]={"𡄯","𧸫"}
	a[63311]={"𩞹"}
	a[63313]={"𪒞"}
	a[63314]={"嚷","躟","𧖗"}
	a[63316]={"蠰","𪓃"}
	a[63330]={"𠯴","𠲔"}
	a[63340]={"𠲖","𠵱","𠼁"}
	a[63341]={"嘫","畩"}
	a[63342]={"𧊤"}
	a[63350]={"呟","跡","𣆬"}
	a[63351]={"㬗"}
	a[63352]={"𧏹"}
	a[63360]={"㗒","昡","𠷂","𧛧","𨄄"}
	a[63361]={"蹨","𤳒","𥊶"}
	a[63362]={"㗹","噍","蚿","𡂔","𧑫"}
	a[63364]={"黙"}
	a[63370]={"䝮","嚎","眩","𡃩","𨅶"}
	a[63374]={"蟭"}
	a[63380]={"噫","𠻫"}
	a[63381]={"㦔","𡂓"}
	a[63382]={"瞧","蠔"}
	a[63384]={"䗯","𪒌"}
	a[63392]={"䗷"}
	a[63394]={"𧐌"}
	a[63395]={"蠈"}
	a[63397]={"𧸜"}
	a[63400]={"𧠻"}
	a[63402]={"𡄑"}
	a[63403]={"𥊬","𧑰","𨆎","𨈄"}
	a[63408]={"𧔼"}
	a[63411]={"𧸐"}
	a[63412]={"㬯","贓","𥍀","𨇦"}
	a[63413]={"嚱","𡃣","𢎖"}
	a[63414]={"䘋","戵","𧕳"}
	a[63415]={"䘂","𧕆"}
	a[63416]={"𧕺"}
	a[63431]={"𠰺"}
	a[63432]={"𠯫","𠲌","𠲎"}
	a[63434]={"曵"}
	a[63440]={"吮"}
	a[63441]={"㕱","𠴆"}
	a[63442]={"㖅","咙","哤","𠷧","𠷼","𣆈","𣆒"}
	a[63443]={"蚮","𠻏","𤱢","𧈺"}
	a[63444]={"㖑","哦","𠵖","𧉦"}
	a[63450]={"吭","𠵷"}
	a[63451]={"㽘","㽙","𠵉"}
	a[63452]={"嘁","戝","昽","晠","眬","𠸴","𣇈","𥅩","𧉃","𧶂","𨀳"}
	a[63453]={"蚘","黓"}
	a[63454]={"喴","蛖","𣇕","𧊥","𪐶","𪑆"}
	a[63455]={"𧊕"}
	a[63456]={"䗃","蛾","𠹷"}
	a[63460]={"䟲","𣆖","𥆨"}
	a[63461]={"𧠭"}
	a[63462]={"㖪","㦹","䖻","䟠","喊","眓","蚢","𠿑","𢧫","𥅜","𥆏","𥆙","𧍄","𧵝","𧵪","𨀁"}
	a[63463]={"戢","賊","践","𢧀","𢧄","𣉝","𥅯","𧊖","𪐤"}
	a[63464]={"䗩","䵨","睋","賤","踐","𠸹","𧶕","𨁟"}
	a[63466]={"蝛"}
	a[63470]={"䀮","䟘","䟽","貥","𥄦","𥅻"}
	a[63471]={"噈","𥅞","𧵻"}
	a[63472]={"䠞","𠽦","𥉷","𧶍","𪐦"}
	a[63473]={"㽣","𡃰","𣈻"}
	a[63474]={"㘍","戥","蜮","賎","𢧷","𧍧","𨃭"}
	a[63480]={"喨"}
	a[63481]={"䟼","賦"}
	a[63482]={"䁍","𠺠","𥇿","𨃂"}
	a[63483]={"睵","賳","𧑙","𧸄"}
	a[63484]={"蟙","黬","𠽤","𧷲","𪑝"}
	a[63485]={"𡁶"}
	a[63486]={"𨇳","𪒃"}
	a[63489]={"𡰓"}
	a[63491]={"蹴","𠽬"}
	a[63492]={"𡁧","𢨐","𥋏","𧷢","𧸉"}
	a[63493]={"𠿠","𧸔"}
	a[63494]={"𧐢"}
	a[63495]={"戰","𧒿"}
	a[63497]={"蠘"}
	a[63501]={"瞕","𥋑"}
	a[63503]={"𥌍","𧓄"}
	a[63504]={"𨢽"}
	a[63505]={"𡁳"}
	a[63511]={"䁹","躃","𡃥","𥌲"}
	a[63512]={"𡅼"}
	a[63515]={"𧔫","𨇯"}
	a[63516]={"𨈂"}
	a[63517]={"𧕟"}
	a[63531]={"呅","咬"}
	a[63532]={"𠲲"}
	a[63541]={"㖡","唆","啐","旼","晈","𠱪","𠵒"}
	a[63542]={"㕹"}
	a[63543]={"蚊","蛟"}
	a[63551]={"㖕","啼","晙","晬","盿","賋","跤","𠶴","𣇚","𣈋","𥅟"}
	a[63552]={"哞","唼","畯","𤲠"}
	a[63553]={"蜶","𧌊"}
	a[63554]={"蛂","𧉤"}
	a[63561]={"睃","睟","賐","賥","踆","踤","𥄜","𨂒"}
	a[63562]={"跋"}
	a[63563]={"黢","𧍝"}
	a[63564]={"蛑","𧌃"}
	a[63571]={"蹄","𠻜","𨁅"}
	a[63572]={"眸","踥","𠻎","𣁜","𥇒","𨁐"}
	a[63573]={"㘐"}
	a[63574]={"𪑗"}
	a[63581]={"𠼀","𨃛"}
	a[63582]={"𡁈"}
	a[63583]={"蟀"}
	a[63585]={"𠿆"}
	a[63591]={"噼","暲","𨄮"}
	a[63593]={"蟑","𧐛"}
	a[63595]={"𪒊"}
	a[63600]={"𥇋"}
	a[63601]={"𨃕"}
	a[63611]={"𩉂"}
	a[63650]={"咍"}
	a[63651]={"𠳺","𠴰"}
	a[63652]={"𠁯"}
	a[63660]={"㖣","𣅿"}
	a[63661]={"喒","𠷳"}
	a[63662]={"𧉟"}
	a[63670]={"唁","喑","眙","貽","跆"}
	a[63671]={"𠽜","𧶆"}
	a[63674]={"𧏓"}
	a[63680]={"暗","賠","踣","𠽪"}
	a[63681]={"㗜"}
	a[63690]={"𥈛"}
	a[63691]={"𨅙"}
	a[63692]={"䗈","黯"}
	a[63693]={"䁿","𥊷","𪑥"}
	a[63700]={"𨃤"}
	a[63702]={"𡁫"}
	a[63703]={"𤳬"}
	a[63710]={"䯫"}
	a[63712]={"鷕"}
	a[63740]={"㕫"}
	a[63750]={"昉"}
	a[63751]={"𤲁"}
	a[63752]={"蚄"}
	a[63760]={"哼","嗙","眆","趽","𠱝","𠼬"}
	a[63762]={"𠻗"}
	a[63764]={"哺"}
	a[63770]={"唷"}
	a[63771]={"啍","嘀"}
	a[63772]={"螃","螪","𣉽"}
	a[63774]={"晡","螭"}
	a[63775]={"㗘"}
	a[63776]={"蜅"}
	a[63780]={"䠙","嗃","𥉣","𥊔","𨂺"}
	a[63781]={"㬀"}
	a[63782]={"瞝","蜟","蝏"}
	a[63783]={"蜳","𧏸"}
	a[63784]={"䀯","䝵","𨁏","𪒔"}
	a[63785]={"㬍"}
	a[63786]={"𠽢"}
	a[63787]={"䗚"}
	a[63790]={"䁎","𠿽","𣉞","𧶺"}
	a[63791]={"䁤","蹢","𡄘","𥇜"}
	a[63792]={"𠿘","𡂗","𧎸","𪑬"}
	a[63793]={"𪑒"}
	a[63795]={"嚩","賻"}
	a[63812]={"囐","獸"}
	a[63830]={"𠯿"}
	a[63831]={"吠"}
	a[63840]={"咳"}
	a[63841]={"𣅤"}
	a[63842]={"畎"}
	a[63850]={"晐"}
	a[63851]={"䟮","唉","畡","𠴃","𧿡"}
	a[63852]={"𧊏"}
	a[63853]={"默"}
	a[63860]={"䀭","賅","𨀖"}
	a[63863]={"𠾲","𤟩"}
	a[63865]={"𤠢"}
	a[63871]={"䀵","猒"}
	a[63873]={"䁭","贆","𤢕","𤢜"}
	a[63875]={"𧑅"}
	a[63882]={"𡄱"}
	a[63883]={"蟘","𤡴","𧎢"}
	a[63885]={"𧐃"}
	a[63895]={"𪒥"}
	a[63896]={"𧑦"}
	a[63931]={"𠰲"}
	a[63943]={"𧉱"}
	a[63951]={"䟣","𠴬","𥄵"}
	a[63953]={"蛷"}
	a[63960]={"晾"}
	a[63961]={"䟵","賕","𤳑","𨄈"}
	a[63962]={"𧌬"}
	a[63970]={"䁁","䝶"}
	a[63971]={"𥇱","𨁻"}
	a[63972]={"黥"}
	a[63973]={"㗱","𪑘"}
	a[63975]={"𠾍"}
	a[63980]={"𥈘"}
	a[63983]={"𡅁","𡅓"}
	a[63990]={"𡀀","𥊻"}
	a[64114]={"躔"}
	a[64116]={"𧔊"}
	a[64151]={"𠲕"}
	a[64160]={"賉","𥅧"}
	a[64170]={"𠵌"}
	a[64171]={"賍","賘","𣈐","𥅾","𨀵"}
	a[64174]={"𧐷","𧒐"}
	a[64180]={"𨂇"}
	a[64181]={"喤"}
	a[64191]={"𠹡","𣈷"}
	a[64193]={"蝗"}
	a[64201]={"嚊"}
	a[64210]={"𥌗"}
	a[64212]={"𨇻"}
	a[64240]={"旷","𠯖"}
	a[64250]={"昈","𧿈"}
	a[64260]={"𥄅","𥉡"}
	a[64261]={"𡈝"}
	a[64302]={"𥌜","𥌾"}
	a[64310]={"𨇱"}
	a[64350]={"昿"}
	a[64352]={"嗻","𧑄"}
	a[64360]={"哴","𥈚"}
	a[64362]={"𡂪","𡂭"}
	a[64363]={"𤳌","𧏀"}
	a[64364]={"蟅","𤳐"}
	a[64370]={"㗓","㫰","𠺒","𠺘"}
	a[64372]={"嚒","蜋","蹠"}
	a[64373]={"蟌"}
	a[64376]={"𧓼"}
	a[64380]={"䀶","踉"}
	a[64382]={"螅","𡂘","𡄖","𣋟","𨆽"}
	a[64384]={"𧐳"}
	a[64389]={"蠊"}
	a[64390]={"𨃡"}
	a[64392]={"𣊊","𣋳","𧒬","𨄭","𨆩"}
	a[64394]={"𧕄"}
	a[64397]={"𧸖"}
	a[64402]={"蹗","𥉶","𥋦"}
	a[64404]={"𪒏"}
	a[64412]={"𧕻","𩳺"}
	a[64413]={"𪚩"}
	a[64414]={"𩴈"}
	a[64430]={"咜"}
	a[64440]={"𠰽","𠳓"}
	a[64451]={"𠴺"}
	a[64452]={"𤲏"}
	a[64460]={"㖢","呝","𠲪","𠴡","𥃶"}
	a[64462]={"䖾","𠺌"}
	a[64470]={"𠹂","𣆿"}
	a[64471]={"唣","𠹇","𨀟"}
	a[64472]={"𣉨","𣊈","𧉵"}
	a[64473]={"𠿾","𧏩"}
	a[64480]={"𥆒"}
	a[64482]={"𡂷","𥋨"}
	a[64483]={"螕"}
	a[64484]={"螝","𩲣"}
	a[64491]={"䠘"}
	a[64492]={"䁛","𧷛"}
	a[64494]={"螰"}
	a[64501]={"矊"}
	a[64541]={"𠷃"}
	a[64552]={"𠻦","𠿬"}
	a[64561]={"唕","𥈃"}
	a[64563]={"啤","喥","蝷"}
	a[64571]={"噑","𨀠","𨂫"}
	a[64572]={"嗥","𥊙"}
	a[64573]={"𡂻"}
	a[64574]={"㗗","㽡"}
	a[64575]={"蜱"}
	a[64581]={"嘷","暭","曍"}
	a[64582]={"暤"}
	a[64583]={"䠋","睥","踱","𧌓","𧶴"}
	a[64585]={"𠺟"}
	a[64602]={"𨇢"}
	a[64604]={"瞊","𨃠"}
	a[64641]={"𠱖"}
	a[64650]={"㕷","𠶧"}
	a[64660]={"咱","𣆆"}
	a[64663]={"𧋙"}
	a[64671]={"𠷪"}
	a[64672]={"啪","𡂹"}
	a[64680]={"踮","𠾘"}
	a[64682]={"嚰"}
	a[64684]={"𠹔"}
	a[64691]={"𠾙"}
	a[64696]={"螗"}
	a[64700]={"矈","鵑","鶡","鹗","𧸨","𨆭","𪃌"}
	a[64701]={"䳚","鶪"}
	a[64702]={"䳙","鷃"}
	a[64703]={"𪃍"}
	a[64704]={"𧔋"}
	a[64705]={"𦪣"}
	a[64709]={"䗤"}
	a[64710]={"䳟","䴉","䴍","矏","鵾","鶚","鶰","鷐","鷶","𪂇","𪄊","𪄚","𪆌"}
	a[64711]={"𪄍","𪅺","𪆽","𪈱"}
	a[64712]={"躕","鸀","鸅","鸚","鸜","𡅂","𪄼","𪇰","𪈰"}
	a[64713]={"鷤","鸓","𪈀","𪈚","𪈴"}
	a[64714]={"𪆯","𪈦"}
	a[64717]={"鷝"}
	a[64718]={"鷜"}
	a[64719]={"𪒒"}
	a[64750]={"呜","响","鸣"}
	a[64752]={"𣆔"}
	a[64754]={"𧊓"}
	a[64760]={"嗚","晌","𨀉"}
	a[64761]={"𠲳","𠷄","𨁵"}
	a[64762]={"䖮","鸭","𠷨"}
	a[64770]={"䳴","鳴","鸮","𩿦"}
	a[64771]={"𠹓","𠿋"}
	a[64772]={"螐","𩿀"}
	a[64774]={"嚤","蝙"}
	a[64780]={"鹃","鹍","鹖","𡄽","𧷘","𨃩"}
	a[64781]={"䴗","鴫","","𪁣"}
	a[64782]={"䳋","蹁","鴨","𧍮","𩿬"}
	a[64783]={"𪀙","𪉐"}
	a[64784]={"𪀕"}
	a[64790]={"瞗","鴞","鴠","鵙","鶍","鹮","𡄠","𨄙","𪀟","𪃦"}
	a[64791]={"𪃄"}
	a[64792]={"䳛","𧎥"}
	a[64793]={"𪂠"}
	a[64797]={"嘃","𡀑"}
	a[64800]={"鶗"}
	a[64801]={"𦤪"}
	a[64804]={"矌","𨇁"}
	a[64805]={"𥊆"}
	a[64814]={"𧓝"}
	a[64851]={"唳"}
	a[64852]={"噢"}
	a[64861]={"𠹋"}
	a[64862]={"蝊","𣋉"}
	a[64863]={"蜧"}
	a[64864]={"𧐚"}
	a[64871]={"嗅","睙","𨁸"}
	a[64873]={"螏"}
	a[64874]={"㗷"}
	a[64876]={"𧍁"}
	a[64880]={"𡁟"}
	a[64883]={"螑"}
	a[64884]={"嚝"}
	a[64890]={"𣋪"}
	a[64891]={"䠗"}
	a[64894]={"曠","𡄓","𧏃","𨄀"}
	a[64901]={"𥉼"}
	a[64940]={"咏"}
	a[64941]={"𠳹"}
	a[64950]={"昹"}
	a[64952]={"嘛"}
	a[64960]={"眿","𣇼","𧵾"}
	a[64961]={"𠼎","𨁤"}
	a[64964]={"䗫"}
	a[64971]={"𠹑"}
	a[64972]={"𧍭"}
	a[64974]={"𠻞"}
	a[64981]={"嘄","暞","曢","𡂢"}
	a[64982]={"𡈷"}
	a[64986]={"䗧"}
	a[64991]={"𥉒","𥌢","𨃔"}
	a[64993]={"蟂"}
	a[64994]={"𥉽","𨄗"}
	a[65021]={"図",""}
	a[65031]={"叶","呌","𠯰"}
	a[65032]={"呏"}
	a[65033]={"蚁","𠯢"}
	a[65041]={"旪"}
	a[65042]={"𠺫","𣅮"}
	a[65043]={"蚪"}
	a[65044]={"𣁱"}
	a[65051]={"䀞","𧾽","𧿫"}
	a[65052]={"𧿘"}
	a[65053]={"唞"}
	a[65054]={"蝌"}
	a[65072]={"𠦫"}
	a[65073]={"嘝","斣"}
	a[65079]={"㪹"}
	a[65083]={"𡀃","𧐝"}
	a[65101]={"曀","𨁷"}
	a[65103]={"𨄎"}
	a[65105]={"𧰚"}
	a[65108]={"螼"}
	a[65111]={"𡀄","𣌐"}
	a[65112]={"㘆","𡃏"}
	a[65113]={"𪒇"}
	a[65114]={"𨅣","𪒴"}
	a[65115]={"𧰟"}
	a[65117]={"嚡","𥋾"}
	a[65141]={"吐","𡆮","𡎯"}
	a[65151]={"㗐","咗"}
	a[65152]={"𠰮","𠱽"}
	a[65153]={"呭","𡌍"}
	a[65161]={"𥃾"}
	a[65162]={"哇","甠","𠵕","𣇭"}
	a[65163]={"𤯠"}
	a[65164]={"﨡"}
	a[65171]={"喳","嗑","𠷸"}
	a[65172]={"啿","晆","貹","𨀬"}
	a[65173]={"喹","畦","跇","𥅋","𨁠"}
	a[65174]={"㽒","蛙","𧌉"}
	a[65182]={"眭","睦","跬","踛"}
	a[65183]={"䗘","𠼻","𥈻"}
	a[65185]={"蝰"}
	a[65191]={"噎","瞌","蹅"}
	a[65192]={"踸"}
	a[65193]={"䠑","睳","𠾵","𣈹","𨅆"}
	a[65194]={"黮"}
	a[65195]={"𪑭","𪒖"}
	a[65196]={"𠻨"}
	a[65197]={"𡀇"}
	a[65201]={"𡁩"}
	a[65216]={"𪓊"}
	a[65261]={"𠴢"}
	a[65301]={"𡃨","𡃴"}
	a[65302]={"曣"}
	a[65303]={"躂"}
	a[65304]={"𧔦"}
	a[65305]={"蹥","𥊩"}
	a[65306]={"𪒜"}
	a[65312]={"𥍂","𨇟"}
	a[65313]={"𤴃"}
	a[65314]={"𨅫"}
	a[65316]={"㬩","嚖","𪔊"}
	a[65317]={"囔"}
	a[65319]={"𧖒"}
	a[65322]={"𠳢"}
	a[65331]={"呔","𠹎"}
	a[65341]={"吰","哒","哧"}
	a[65342]={"㖁","呠","𠸖","𠹅","𡇐"}
	a[65343]={"𧉑"}
	a[65344]={"𠵢"}
	a[65351]={"呿","𠳷","𡈂","𣇌","𣇐"}
	a[65352]={"𨁕"}
	a[65353]={"𠳜","𠺂","𤱙","𤲻","𧈽","𧋒","𪐥"}
	a[65354]={"𧎦"}
	a[65361]={"㫢","跶"}
	a[65362]={"嚇","𧵧","𧿾"}
	a[65363]={"𠻣","𧉧"}
	a[65371]={"䟩","𠻛"}
	a[65372]={"㬨","𠹤"}
	a[65373]={"𠼭","𡀖"}
	a[65375]={"𧐒"}
	a[65381]={"𠺆"}
	a[65382]={"䁃","𥋿"}
	a[65383]={"䗢","噠"}
	a[65384]={"𠽡"}
	a[65385]={"啭","嗹"}
	a[65391]={"𥊸","𥌩"}
	a[65392]={"嚥","𥉖"}
	a[65395]={"蟽","𪒻"}
	a[65396]={"蟪","𣌕"}
	a[65397]={"𡂴","𧐖"}
	a[65402]={"𥉱","𥍇"}
	a[65403]={"嘵"}
	a[65412]={"𣋢"}
	a[65413]={"䁱","曉","蹺"}
	a[65414]={"𤳭"}
	a[65415]={"蟯","𤴀"}
	a[65431]={"叱","吪","𠮟","𡬣"}
	a[65441]={"𡬩"}
	a[65451]={"𥄒","𧿕"}
	a[65452]={"吨","咾","哓","覐"}
	a[65453]={"𠒛"}
	a[65454]={"蛯","𡀌","𪑂"}
	a[65461]={"䙸","𠳭"}
	a[65462]={"旽","晓","跷","𧡉"}
	a[65464]={"蛲","𠺄","𪐠"}
	a[65471]={"跣"}
	a[65472]={"盹","𥆈"}
	a[65473]={"暁","𤳙"}
	a[65474]={"唵","黗"}
	a[65479]={"𡰍"}
	a[65481]={"𣉊"}
	a[65482]={"𧠴"}
	a[65484]={"晻"}
	a[65485]={"㽢"}
	a[65486]={"㗾","𧌄"}
	a[65492]={"𥈩"}
	a[65494]={"䁆","𨂁"}
	a[65496]={"黤"}
	a[65503]={"𢻣","𥀦"}
	a[65506]={"𩌺"}
	a[65511]={"𡆀"}
	a[65512]={"𪔈"}
	a[65513]={"𢻪"}
	a[65515]={"𧓞"}
	a[65516]={"𡆇"}
	a[65519]={"𨇍"}
	a[65532]={"㘟","𠯆"}
	a[65542]={"吱","吽","咘","哗","嘜","𠰼","𣅓"}
	a[65543]={"唏","𠱥","𡜭"}
	a[65544]={"𠯤"}
	a[65552]={"㖫","昁","晔","𠲊","𠵃","𣅫","𧿲"}
	a[65553]={"㕩","晞","𤰼"}
	a[65554]={"喯","蚑","𠼖","𧉩"}
	a[65555]={"䖷","畊","𠾭"}
	a[65556]={"𢻅"}
	a[65562]={"䟛","啈","跂","𠻱","𣇾","𥄏","𥄔"}
	a[65563]={"唛","睎","","𠶿","𧶖"}
	a[65564]={"䗀","𠵮","𠺈","𠿺","𣆘"}
	a[65565]={"蚌","𢻔"}
	a[65566]={"䗖","𧎔"}
	a[65568]={"𠵡"}
	a[65572]={"睖","踜","𠸊","𢻌","𧴶","𨂛"}
	a[65573]={"盽","𠺊","𧿣","𨀗"}
	a[65574]={"𠻶","𥊊","𨁼"}
	a[65575]={"㗆","㗣","唓","唪"}
	a[65576]={"啛","𪑖"}
	a[65582]={"䁄","𠽿"}
	a[65583]={"𥈖","𨂨 "}
	a[65584]={"𢻧"}
	a[65586]={"𠾴","𧶩"}
	a[65587]={"蛼","蜯","螮"}
	a[65593]={"𠿤","𢻡","𢻥","𨂧","𨅢","𪍻"}
	a[65595]={"蹛","黭","𡃈","𪒈"}
	a[65597]={"𨅯"}
	a[65601]={"暿"}
	a[65602]={"𠽻","𥉙 "}
	a[65603]={"睶","蟢","賰","踳","𨅓"}
	a[65605]={"圕","𧑠"}
	a[65606]={"𣉿"}
	a[65608]={"螬"}
	a[65611]={"瞦","𨅩"}
	a[65612]={"𡄋","𥊏","𥌳"}
	a[65613]={"䵱"}
	a[65614]={"蠩","𥋋","𧑱","𨅕"}
	a[65615]={"𨆮"}
	a[65616]={"蹧","𡅰"}
	a[65651]={"咕"}
	a[65652]={"𠳈"}
	a[65661]={"咭","哠","𠽳","𣇏"}
	a[65662]={"喖"}
	a[65663]={"蛄","𠵎","𠸏"}
	a[65671]={"䀦","晧","跍","𥆪","𧵑"}
	a[65672]={"唶","啫","𠻧"}
	a[65673]={"蛣","𣈴","𧋓"}
	a[65681]={"𡀁","𨀙","𨁒"}
	a[65682]={"嗜","暏","𣈏","𣉟"}
	a[65683]={"㖺","黠","𠾏"}
	a[65684]={"蜡","蝫","𡈥"}
	a[65691]={"嘻"}
	a[65692]={"睹","賭","踖","踷","𥈣","𨄘"}
	a[65693]={"暙","𧒗","𪒂"}
	a[65694]={"䵭","螧","𠾱"}
	a[65695]={"蝽"}
	a[65696]={"嘈"}
	a[65701]={"𨃧"}
	a[65702]={"䝼","睛","","𡀗","𨃯","𨅒"}
	a[65704]={"𣋭","𨄔","𪓁"}
	a[65705]={"䁣","𧐍","𨂭"}
	a[65708]={"購","𥉇"}
	a[65710]={"囀"}
	a[65711]={"𡁦","𨆚"}
	a[65712]={"嚋","躊","𣋬","𥌆","𨅤"}
	a[65713]={"疇","蹖","𥊎"}
	a[65714]={"𡅲","𡆜"}
	a[65716]={"嘒","暳"}
	a[65717]={"𪓉"}
	a[65731]={"吋","咐","団","𠮹"}
	a[65732]={"𠮼","𠰜"}
	a[65741]={"时"}
	a[65742]={"㖴","𤰥"}
	a[65743]={"䖞","蚹"}
	a[65744]={"𡬤"}
	a[65751]={"財","跗","𠷵","𧴫"}
	a[65752]={"咁","𠱜","𠱾","𠾞"}
	a[65753]={"𠵝","𪐻"}
	a[65761]={"咵","哊","𠵇","𡬺"}
	a[65762]={"哱","喃","時","𠱼","𠴳","𣇷","𧿰"}
	a[65763]={"暪","畤","𤲔","𤲵","𥆶"}
	a[65764]={"哮","蚶"}
	a[65765]={"蟎"}
	a[65771]={"晇"}
	a[65772]={"㫲","䝰","嚉","暔","畸","跱","𥅅","𧵊","𧶱","𨀛","𨂄"}
	a[65773]={"䗁","瞞","蛕","蹣","𠷻","𡭀","𧊘"}
	a[65774]={"㫴","蝻","黚","𡁣","𧋢"}
	a[65775]={"畴"}
	a[65781]={"賄","跨","踦","𥅚","𥇚"}
	a[65782]={"㬣","啨","𠾢","𨁝","𨂾"}
	a[65783]={"𧐇"}
	a[65784]={"踌","踍","𡁯","𥆔","𪑮"}
	a[65785]={"𠷮"}
	a[65788]={"㗕"}
	a[65791]={"𨚼"}
	a[65792]={"晴"}
	a[65793]={"𡁔","𡭈","𤲟"}
	a[65794]={"蜻","𪒶"}
	a[65795]={"暷","𡆋"}
	a[65797]={"蝳","𧐕"}
	a[65798]={"𣫹"}
	a[65801]={"瞋","蹎","𡂝","𧷒"}
	a[65802]={"𧷻","𨇇"}
	a[65803]={"黰","𤳎"}
	a[65804]={"𡂐","𧐐"}
	a[65805]={"𪒰"}
	a[65806]={"䁧"}
	a[65811]={"贖","𡄙","𣋺","𥋢","𥌚","𥌪","𧹎"}
	a[65812]={"囋","瞔","蹟","躜","躦","𧹏","𨆫","𨇈","𨈃"}
	a[65813]={"黷","𧔖","𧸊"}
	a[65814]={"𨇃","𪒑","𪒦"}
	a[65831]={"咴","唊","𠯈","𠰵"}
	a[65835]={"𠼙"}
	a[65841]={"𣇍"}
	a[65842]={"㽠","呋","呹","哄"}
	a[65843]={"蛺","𤲍"}
	a[65847]={"䗮"}
	a[65851]={"䀹","唗","鿃","𨀡","𨁂"}
	a[65852]={"㫙","昳","晎"}
	a[65853]={"喷","畉","𠼄","𤱨","𪐝","𪑀"}
	a[65854]={"蚨","蛈","蛱","𤱁"}
	a[65862]={"䀧","唭","啧","眣","趺","跌","","𠿝","𣈡","𥄑","𥅴"}
	a[65864]={"咦","暎"}
	a[65871]={"跿","𡀅","𡃄","𥆥","𨃝"}
	a[65872]={"𢻖","𣉺"}
	a[65873]={"𣋒"}
	a[65874]={"蜞","黩","𠾛"}
	a[65875]={"啑","𥌞"}
	a[65876]={"蛦"}
	a[65881]={"嗔"}
	a[65882]={"踑","𣊒","𨆄"}
	a[65883]={"噴","韪"}
	a[65884]={"曂","眱","跠","𣉅","𥆭","𨁜"}
	a[65885]={"㫸"}
	a[65886]={"嘆","蟥"}
	a[65887]={"蜨","𤲣"}
	a[65892]={"嘖","嚏","嚔","𡁲"}
	a[65894]={"𧍩","𨂡"}
	a[65895]={"睫","蟦","踕","𧏂"}
	a[65896]={"暵","𧰅"}
	a[65897]={"𤳉"}
	a[65904]={"𧓜"}
	a[65916]={"𧔬"}
	a[65931]={"㕲","咻","唻"}
	a[65941]={"𠻟"}
	a[65942]={"味","咮","啉","𠰌","𠲋","𤱃","𤲓"}
	a[65943]={"蚞"}
	a[65951]={"㖠","睞","𠶫","𧶛","𨂐"}
	a[65952]={"昧","昩","晽","𠵟","𣆦"}
	a[65953]={"𠱤","𠲿","𠷬","𠾣","𪑚"}
	a[65954]={"蛛","","𠵈"}
	a[65961]={"嗦","嘹"}
	a[65962]={"䟱","噤","眛","眜","睐","跊","跦","𥅲","𧿴"}
	a[65963]={"㖼","暕","𠹳"}
	a[65964]={"㖦","䵢","喋","嗪"}
	a[65965]={"𧋐","𧍴"}
	a[65966]={"朄"}
	a[65971]={"暸","𥇧","𥈡"}
	a[65972]={"嗉"}
	a[65973]={"䀳","蟟","踈","𥅦","𧎳","𨀤","𨂏","𪑨"}
	a[65974]={"𠼂","𣈽"}
	a[65975]={"䗋","𤲚","𧎩","𪑞"}
	a[65976]={"蝀","蝶","螓"}
	a[65977]={"𣌾"}
	a[65981]={"瞭","蹽"}
	a[65982]={"𨆃"}
	a[65983]={"𨃥"}
	a[65984]={"䁋","螦","蹀","𣊝","𥉜"}
	a[65985]={"𢆦"}
	a[65986]={"𪑧","𪒆"}
	a[66002]={"𧏈"}
	a[66005]={"𡁴"}
	a[66010]={"𣋗"}
	a[66012]={"𧒪"}
	a[66017]={"𧓘"}
	a[66040]={"吅"}
	a[66041]={"𠷝"}
	a[66050]={"呬","𠯐"}
	a[66051]={"㖥","咖","咽","啝","𠳁"}
	a[66054]={"㖆"}
	a[66060]={"昍","𠰸","𠱠","𠲛"}
	a[66062]={"蚎","𥄡"}
	a[66063]={"蜠","𧉫","𧊀","𧊭","𧋕"}
	a[66064]={"䖬","蚰"}
	a[66065]={"𧊋"}
	a[66066]={"蛐"}
	a[66071]={"䟧","䠅","啯","嗰","睏","跏","𠴱","𠷹","𥇘","𧶞","𨁉"}
	a[66072]={"蛔","蜖","𤲴"}
	a[66073]={"蜘","𤲭"}
	a[66074]={"𨀪"}
	a[66080]={"䀠","𣇖"}
	a[66081]={"踟","𥇭"}
	a[66082]={"嘓"}
	a[66083]={"蝈","𧋡","𪑜"}
	a[66090]={"𥌘"}
	a[66093]={"𥆤"}
	a[66094]={"蟈"}
	a[66100]={"𠼛"}
	a[66101]={"𡁢","𨂈"}
	a[66102]={"囉","睲"}
	a[66103]={"䁼"}
	a[66104]={"𡅏"}
	a[66110]={"瞾","𠻰","𣋖"}
	a[66111]={"鑍","𡅚","𡓶","𡓿"}
	a[66112]={"㘗","㬬","䂂","曪","瞿","躣","𧹐","𨆨","𨇽"}
	a[66113]={"𨈈"}
	a[66114]={"蟶","蠷","𡆆"}
	a[66115]={"㽮","壨"}
	a[66116]={"𡆛","𧕫"}
	a[66160]={"呾","𠱯"}
	a[66161]={"𡋐","𡋑"}
	a[66170]={"㫜","喅","嗢"}
	a[66171]={"㖏","𠸶","𥂍"}
	a[66172]={"䖧","𠶬","𪐪"}
	a[66173]={"哩"}
	a[66174]={""}
	a[66180]={"㬈","𠷚","𣈫"}
	a[66181]={"𡀓","𣇒"}
	a[66182]={"䗑","䵣","蝹","𠵆","𨾴"}
	a[66183]={"嚜"}
	a[66185]={"𧋎"}
	a[66191]={"睈","𤦉","𧶔","𨁎"}
	a[66192]={"暒"}
	a[66193]={"𠹈"}
	a[66194]={"䗌","䘃","𠹺"}
	a[66210]={"𣃒","𥋬"}
	a[66240]={"喌"}
	a[66250]={"啰"}
	a[66251]={"𠷟"}
	a[66263]={"𧎁"}
	a[66270]={"𠵫"}
	a[66273]={"𤲦","𪑹"}
	a[66281]={"睤"}
	a[66291]={"𥉁"}
	a[66300]={"㬤","䁵"}
	a[66302]={"䗾","𠼢"}
	a[66303]={"𧔘"}
	a[66304]={"𣋏"}
	a[66310]={"𥌁","𧢅","𨆰"}
	a[66311]={"𥌡"}
	a[66312]={"𥌰","𧸽"}
	a[66313]={"𪓂"}
	a[66314]={"䁸","𧔥","𧔷"}
	a[66315]={"𧕛"}
	a[66316]={"𡄿","𪒬"}
	a[66317]={"𧕦"}
	a[66350]={"嚃","𠾪","𡈃","𧱄"}
	a[66360]={"嚺","𡃱"}
	a[66361]={"嗯","𠷉","𠼊"}
	a[66362]={"嘿","𣆣"}
	a[66364]={"䖵"}
	a[66370]={"𠶼","𠸵","𧵐"}
	a[66371]={"喂"}
	a[66372]={"𠷣"}
	a[66373]={"𧍤"}
	a[66374]={"蟔"}
	a[66375]={"𧏎"}
	a[66376]={"䗭"}
	a[66380]={"噮","𤑄"}
	a[66382]={"䁫"}
	a[66383]={"𧍥","𧍨"}
	a[66384]={"瞣","𧒭"}
	a[66390]={"愳","𡀾","𡄤","𣊐","𨆈"}
	a[66391]={"𨃄"}
	a[66392]={"蠉","𧑩"}
	a[66393]={"𢠸"}
	a[66394]={"噥","贃","𨄲"}
	a[66400]={"䚋","䣈","覞","𥇊","𧡆","𧡰","𨛜"}
	a[66401]={"嚫","𧡈","𨜯"}
	a[66402]={"䵪","𣰣"}
	a[66405]={"𪒎"}
	a[66410]={"䚑","甖","覨","𧡭","𧡻","𧢛","𨜝"}
	a[66411]={"䞋","鼉","𡄞","𥋥","𨝚","𨞰","𨞸"}
	a[66412]={"瞡","𡁥","𡃁","𥋁","𧡶","𧢩","𨞔","𨞠"}
	a[66413]={"𣰧","𧢭","𨞏","𪛄"}
	a[66414]={"鼍"}
	a[66418]={"𧢃"}
	a[66450]={"呪"}
	a[66452]={"𢦸"}
	a[66454]={"㖂"}
	a[66460]={"㒭","㫛","咒"}
	a[66463]={"𧊫"}
	a[66466]={"𧊣"}
	a[66470]={"哯","唈","眖","貺","𣈀"}
	a[66474]={"跩"}
	a[66480]={"晛","𥆰"}
	a[66482]={"蜆","𣰡"}
	a[66483]={"𡀋"}
	a[66484]={"𠼅"}
	a[66490]={"䁜","睍","𠺐","𠻌","𥆢","𥉎","𥉨","𧠦","𨁍","𨁞"}
	a[66492]={"蜫","𢧮","𧡇","𪑈"}
	a[66493]={"𣈣"}
	a[66495]={"蝇"}
	a[66497]={"蝿"}
	a[66501]={"䁒","𡃃","𥊑"}
	a[66502]={"䁺","嘬","𥈪","𥈫","𨆅"}
	a[66503]={"嘽"}
	a[66507]={"蹕"}
	a[66508]={"瞜","𧷡","𨄜"}
	a[66509]={"𤳣"}
	a[66511]={"𡃫","𡅔","𥊿"}
	a[66512]={"㘙","嚴","嚶","曮","𡄉","𡅮","𡅴","𡆉","𥊴","𥌽","𥍓","𨅎"}
	a[66513]={"䂄","䠤","暺","矍","躩","𡂽","𣌗"}
	a[66514]={"蠳","𪒙"}
	a[66515]={"蟬","蠼"}
	a[66518]={"𤳵"}
	a[66521]={"𡆢"}
	a[66551]={"𠳣","𠳦","𠳵"}
	a[66552]={"呷","𡜓"}
	a[66553]={"呻"}
	a[66554]={"蚛","𠳴"}
	a[66555]={"𧊍"}
	a[66561]={"㖾","斝","𠵪","𢃋","𢆔"}
	a[66563]={"𤕧"}
	a[66566]={"𠶭"}
	a[66571]={"哻","𠷙","𠸅","𠹣"}
	a[66572]={"𠹵","𧿵"}
	a[66573]={"㖐","眒","𥆓"}
	a[66574]={"𧏧"}
	a[66581]={"晘","𠶻","𠷾","𠼦"}
	a[66582]={"㘁","䑝","暥"}
	a[66583]={"單","𣈾"}
	a[66584]={"賗"}
	a[66587]={"嗶"}
	a[66588]={"嘍","𠁷"}
	a[66590]={"螻"}
	a[66591]={"睅","𥆣","𥈍","𨁄"}
	a[66592]={"䁙","嬰","曎","𠽽","𡀈","𡀞","𤕦","𥋭"}
	a[66593]={"蟃","𡅵","𧍚"}
	a[66594]={"蠌"}
	a[66596]={"𡁘","𡣠"}
	a[66599]={"𧏻"}
	a[66600]={"噐","嚣","𠾅","𥉞"}
	a[66601]={"嘼"}
	a[66602]={"曙","𡄛"}
	a[66604]={"𥋅"}
	a[66610]={"嚚","嚻","囂","譻","𡂨","𣊫","𣊭","𧮣"}
	a[66611]={"䠦","𡄹"}
	a[66612]={"𡃷","𡄗","𡅜","𡅻","𡅽","𣌈","𥌓","𧮥"}
	a[66614]={"","𤳳","𤳹","𤴇","𤴌","𤴐","𤴒","𧖌"}
	a[66615]={"蠝","𣡺","𤴄","𤴊","𦉩","𪉀"}
	a[66616]={"𡅱","𤴑","𨤷"}
	a[66664]={"𠳡"}
	a[66671]={"㽞"}
	a[66680]={"㗊","唱","𡈶"}
	a[66690]={"嘂","晿","𠼨","𡼚"}
	a[66691]={"器","𠾖"}
	a[66692]={"䗉"}
	a[66694]={"𧐋"}
	a[66700]={"𦦄"}
	a[66701]={"䁌"}
	a[66702]={"躅","𡄃","𥋛"}
	a[66703]={"𧍞"}
	a[66706]={"𥝉"}
	a[66710]={"蹋","鷪","鸎","𠚠","𡁰","𡆔","𥈭","𥋡","𥌂","𥌖","𦡺","𩫳","𩱴","𪄙"}
	a[66711]={"罌","𥊐","𦉍"}
	a[66712]={"𤳴"}
	a[66715]={"𥍈"}
	a[66720]={"𠄷"}
	a[66750]={"𡷇"}
	a[66751]={"㖞",""}
	a[66760]={"㕺","㗄","呺","𠴭"}
	a[66761]={"𠵄"}
	a[66762]={"𠲸"}
	a[66763]={"蜗","𧊅"}
	a[66770]={"咢","啺","喝","晹","骂"}
	a[66771]={"㘄","嘚","𠳲","𠵨","𠿥","𦈯"}
	a[66772]={"蜴"}
	a[66773]={"喁","𣈱"}
	a[66774]={"𧋱","𧌾"}
	a[66780]={"暍","暘","睗","賜","踢","𠵭","𡁪","𣊷","𥈮"}
	a[66781]={"喟","畼"}
	a[66782]={"噣","蜎","蝎","蝪","駡","𠳯","𡂼"}
	a[66783]={"㬂","暢"}
	a[66784]={"𤲀","𤲶"}
	a[66785]={"𧍪"}
	a[66790]={"㗁","䁑","睊","踼","𠹥","𠿐","𥈎","𧶽","𨀮","𨃃"}
	a[66791]={"𡃶","𣉌","𣉬","𦢆","𨁽"}
	a[66792]={"䀻","䵮","𠸮","𪑦"}
	a[66793]={"蝟","𠾧","𡃉","𡼯","𥈬","𧒞"}
	a[66794]={"蠋","𢣲"}
	a[66796]={"嬲","𣜢"}
	a[66800]={"䁚","䁲","䠝","𧡨"}
	a[66803]={"𨤱"}
	a[66805]={"䗰"}
	a[66810]={"𡅙","𥋫"}
	a[66812]={"瞶","蹪","𧸃","𧸯"}
	a[66813]={"躀","𥊫","𪒾","𪓆"}
	a[66814]={"𧑋"}
	a[66815]={"𡄷"}
	a[66840]={"呮"}
	a[66850]={"哫"}
	a[66851]={"哭","𠲂","𡘜"}
	a[66852]={"𧊄"}
	a[66860]={"唄","焸","𤑽"}
	a[66861]={"𠱐"}
	a[66862]={"𧋥","𧌚"}
	a[66864]={"𨀲"}
	a[66865]={"𧊠"}
	a[66868]={"𤒍"}
	a[66870]={"㖷","踀","𠸭","𥇏"}
	a[66872]={"蛽","𠷓"}
	a[66873]={"蜈"}
	a[66874]={"𠽝"}
	a[66880]={"䟺","嘪","煛","賏","𠹚","𣉆","𥆘"}
	a[66882]={"瞆","蝭"}
	a[66885]={"𧑌"}
	a[66890]={"睼","踶","𠽸"}
	a[66891]={"䠐","瞁","𠽯","𥈀","𥈏"}
	a[66892]={"嘳","𠽮"}
	a[66893]={"𨅜"}
	a[66902]={"𨇅"}
	a[66903]={"𧒮"}
	a[66911]={"矂","躁","𣡾"}
	a[66913]={"䵲","𣌑","𤳻","𥍔"}
	a[66914]={"𤴈"}
	a[66951]={"𠳳"}
	a[66960]={"𠸱","𥉀"}
	a[66962]={"㗎","槑","𠷽","𧎖"}
	a[66963]={"𠵩"}
	a[66971]={"𠼱","𣈁","𥆫"}
	a[66973]={"𣇫"}
	a[66975]={"蜾"}
	a[66980]={"𠾶"}
	a[66982]={"嚗"}
	a[66983]={"螺","踝","𥇬"}
	a[66986]={"𣛕"}
	a[66990]={"暻"}
	a[66991]={"噪","𥉹","𧷳","𨄱"}
	a[66992]={"曝","𧑊"}
	a[67000]={"䁡","翾","𠼋","𣊱","𦑉","𨂃"}
	a[67001]={"䠒"}
	a[67002]={"嘲","𦒡"}
	a[67004]={"㔣"}
	a[67010]={"𦡉"}
	a[67011]={"𡀊","𡁡","𡁤","𦒬","𨄑"}
	a[67012]={"","𣌙","𧒄"}
	a[67018]={"䘈"}
	a[67030]={"叨","吻","𠮭","𠯄","𠰭","𠹕"}
	a[67031]={"叻","吶","呐","𠯠","𡆫"}
	a[67033]={"𠰯"}
	a[67040]={"叼","呁","旫","旳","昒","𠯜","𠲃","𣅉"}
	a[67041]={"㕼","㫑","勋","哅","𠯦","𣅚","𤰿"}
	a[67042]={"㽖","虭","虳","𤱅","𧈳"}
	a[67043]={"畃","蚋","𧈿"}
	a[67044]={"蛧"}
	a[67050]={"䀔","䀛","呴","喲","昀","趵","𠯲","𠯻","𠵹","𠾠","𧴬"}
	a[67051]={"䟜","呦","畇","𠢃","𠺶","𥄋","𥅇","𧴧"}
	a[67052]={"㽤","䵠","蚐","𠰩","𤱆","𪐛"}
	a[67053]={"䗇","呣","𣌨"}
	a[67054]={"呥","蚒","𠯍"}
	a[67058]={"𠱡"}
	a[67060]={"䝧","呞","咰","哃","哟","啲","喞","明","昫","朙","盷","𠱃","𠵜","𦑲","𧵈"}
	a[67061]={"㔠","㽛","啕","踘","𠳞","𣅺","𤰾","𥄞"}
	a[67062]={"蚏","蚼","𠲵","𤱎","𥇟","𧿜","𪐯"}
	a[67063]={"蚴"}
	a[67064]={"𣅧","𣆀","𤱋"}
	a[67065]={"畘","𧉯"}
	a[67066]={"蚦","蚺","𪑃"}
	a[67070]={"㫬","䝭","晍","眀","眗","跀","跔","𠲾","𥄠"}
	a[67071]={"䀙","䟙","勛","啁","嗍","眑","𤱬"}
	a[67072]={"䖲","翈","蛡","蝄","𧉠","𧊚"}
	a[67073]={"蜔","蜪","黝","","𠷺","𧋤","𧿹"}
	a[67074]={"蜐","跚","𥅆","𧵡","𨀅"}
	a[67078]={"𨀢"}
	a[67080]={"眮","眴","𠵘","𥄶","𥅬","𧵣","𨀜","𨀴"}
	a[67081]={"㗅","晭","𠟯","𨂆"}
	a[67082]={"䀷","嗣","翤"}
	a[67083]={"蜩","𨀦"}
	a[67084]={"𠺔"}
	a[67086]={"嘞","𧊨"}
	a[67090]={"𠺉","𠻴","𦐽"}
	a[67091]={"㔥","睭","賙","𠻻","𨂊"}
	a[67092]={"","𧌇"}
	a[67093]={"蝴"}
	a[67096]={"㗢"}
	a[67101]={"䠎"}
	a[67102]={"嚁","𨂓"}
	a[67103]={"𪑱","𪑺"}
	a[67104]={"贐"}
	a[67110]={"𥉝"}
	a[67111]={"𩐉"}
	a[67112]={"曜","矅","躍","𥉸"}
	a[67113]={"𩁐"}
	a[67114]={"蠗"}
	a[67116]={"㗲","𥊮"}
	a[67140]={"𠰘","𠱎"}
	a[67143]={"𠱱"}
	a[67150]={"𠱺","𥁴"}
	a[67151]={"吜"}
	a[67152]={"𡊙"}
	a[67160]={"咀"}
	a[67161]={"𠵼","𣅴"}
	a[67162]={"𠹃","𧊴"}
	a[67163]={"䖡"}
	a[67164]={"蛏"}
	a[67170]={"唨","𠳉","𠷍","𣆓","𣆜","𨀧"}
	a[67171]={"𠻾","𤱌","𥁻","𥄨","𧿔"}
	a[67172]={"㙒","蛆","𣉗"}
	a[67173]={"蜢","𠷶","𨀔"}
	a[67180]={"盟","跙","𠱲","𠽼","𥂗","𥄿","𥅣","𧖽"}
	a[67181]={"䁅","喔","𣈂"}
	a[67182]={"𠴾","𤦼","𤧩","𪐵"}
	a[67183]={"𠾐","𣉒"}
	a[67184]={"嚍"}
	a[67185]={"𧍰"}
	a[67190]={"曌","𠴀","𠽵","𣊏","𨂀"}
	a[67191]={"琞","𥈂"}
	a[67192]={"𠼤","𡂑","𪑎"}
	a[67193]={"𥉑"}
	a[67194]={"墅"}
	a[67195]={"𧑟"}
	a[67205]={"嘯"}
	a[67212]={"𡗏"}
	a[67215]={"㬘","𨅋"}
	a[67217]={"蟰"}
	a[67218]={"𧑛"}
	a[67230]={"叩"}
	a[67240]={"㕧","哆"}
	a[67242]={"𦑬"}
	a[67250]={"𠶸"}
	a[67251]={"𠼪","𤰨","𥈌"}
	a[67252]={"蛥","𠴷","𧌞"}
	a[67254]={"啸"}
	a[67260]={"嘐","眵","跢","𥄸"}
	a[67262]={"黟","𧍕"}
	a[67263]={"夥"}
	a[67265]={"嘨","𧎙"}
	a[67270]={"㬔","唧"}
	a[67271]={"啣","疁"}
	a[67272]={"蟉"}
	a[67273]={"䖼"}
	a[67280]={"卾","賿","蹘","𡀒","𥉾"}
	a[67281]={"㗦","踋"}
	a[67282]={"蝍","𧌫"}
	a[67283]={"𧌋"}
	a[67288]={"𡗆"}
	a[67300]={"𣊤"}
	a[67301]={"𢢤","𥌐"}
	a[67303]={"𧓪"}
	a[67304]={"𡂞"}
	a[67305]={"𧐓"}
	a[67315]={"囅"}
	a[67316]={"𧕌"}
	a[67330]={"𢙟"}
	a[67331]={"咚"}
	a[67340]={"唿","𤈌"}
	a[67341]={"哝","昸"}
	a[67342]={"𤱞"}
	a[67350]={"喙","喣","𢜏","𣇤"}
	a[67351]={"𤉏"}
	a[67352]={"𥈝"}
	a[67354]={"䗓"}
	a[67360]={"䝲","哏","喼","煦","照","𠲹","𠿔","𥇰"}
	a[67362]={"蝝","𨂴"}
	a[67363]={"蟓","𠹏"}
	a[67364]={"𤋰"}
	a[67370]={"䬭","跽","𠺙","𥈈","𥈥","𥉕","𥉤","𨂦"}
	a[67371]={"𤏩"}
	a[67372]={"嗵","蛝","螁","𠹖"}
	a[67373]={"䗨","𣉔"}
	a[67375]={"𧎇"}
	a[67380]={"㗻","眼","跟"}
	a[67381]={"䁩","𡁂","𡄄"}
	a[67382]={"𡂙"}
	a[67383]={"𨃣"}
	a[67384]={"曃"}
	a[67386]={"䗦","𢢨","𧑔"}
	a[67390]={"蹆","𡁄","𡁱"}
	a[67391]={"𡁬"}
	a[67392]={"䠫","蹍","𤒭","𧒖","𧓃"}
	a[67394]={"𥊒","𥊵","𧐯"}
	a[67396]={"𪒡"}
	a[67400]={"𠤁","𦫮","𧶹"}
	a[67401]={"𦫩"}
	a[67402]={"𡁅"}
	a[67404]={"𠾁"}
	a[67410]={"𣋋","𥋝","𧡜","𨇫","𪓮"}
	a[67411]={"䂁","嚵","𡂟","𡅛","𨇩"}
	a[67412]={"䵴","蠅","𥉗","𦦿","𨇴"}
	a[67413]={"𧕃","𪓄","𪓽"}
	a[67414]={"艶"}
	a[67440]={"㕨","叽","𠮙","𠯟"}
	a[67441]={"㕤","㕪"}
	a[67442]={"吔","咃","𠮬"}
	a[67444]={"𧈮"}
	a[67450]={"㕴","吧","呢","","𠲅","𣄻"}
	a[67451]={"𠲫","𠴶","𣅟"}
	a[67452]={"䀓","䖠","虮","蚬","𠱨","𠲙","𧈝","𧿇"}
	a[67453]={"𤰷"}
	a[67454]={"虵"}
	a[67460]={"咆","昵","晩","𠰾","𠱓","𣆡","𥃵","𧾾","𧿏"}
	a[67461]={"呡","眈","𠲶","𠶩","𤱯","𥃴","𧴸","𧿅","𧿒"}
	a[67462]={"蚆","蚭","貤","𠯎","𠷕","𤱕","𥃸","𥅂","𪐘"}
	a[67463]={"哋","黕"}
	a[67464]={"𪐟"}
	a[67470]={"唲","眤","跁","跜","𠾼","𧠐","𧵅","𧿆"}
	a[67471]={"晚","覎","𣈟"}
	a[67472]={"蚫","蛫","𠳿","𣈼","𪐨"}
	a[67473]={"𧉬"}
	a[67474]={"𧋜","𧋦","𧌡","𧍯"}
	a[67475]={"𨤤"}
	a[67480]={"晲","跑","跪","𤓅","𥄹","𥅺","𧵢","𧵥","𨀓"}
	a[67481]={"䟨","眠","睌","𧿻"}
	a[67482]={"䵥","蜺","𠹆","𧌳","𪐼","𪑍","𪑣"}
	a[67484]={"𠙫","𧡝"}
	a[67490]={"睨"}
	a[67491]={"𤭲"}
	a[67492]={"䬗","𣜣","𧒑"}
	a[67493]={"𪑲","𪒣"}
	a[67495]={"𠼓"}
	a[67501]={"暇","𥋉"}
	a[67503]={"蝦","𠮊","𣋙","𧓬"}
	a[67505]={"睴","賱","𨂱"}
	a[67506]={"蠏"}
	a[67511]={"䠍","睱","矎"}
	a[67512]={"𨃿"}
	a[67513]={"𡄔","𥀴"}
	a[67515]={"𤜔","𪒮"}
	a[67516]={"𠿊","𡁒"}
	a[67517]={"睷","踺"}
	a[67518]={"𡀿","𧒼"}
	a[67519]={"𪑼"}
	a[67531]={"叹"}
	a[67541]={"吸","𠸀"}
	a[67542]={"𠬱","𠯥","𠱀","𠳩"}
	a[67543]={"呶"}
	a[67551]={"䀑","䟕","吺","昅","𠳾","𠴫","𥃫","𥄗"}
	a[67552]={"啵","嘤"}
	a[67553]={"吚","咿","𠲓","𤱍"}
	a[67554]={"蚾","𧉐"}
	a[67556]={"咈","𠲽"}
	a[67561]={"趿","𠺻","𡃀","𥄫","𥆉"}
	a[67562]={"䟸","貱","跛","𠴪","𣅢","𥅗","𥅹"}
	a[67563]={"𠳖","𠾆","𧈻"}
	a[67564]={"㖓","啜","嘙","𠵿"}
	a[67565]={"蛜","𧉅","𧊵"}
	a[67566]={"昲"}
	a[67571]={"㖬","䟝","唚","踧","𠴵","𣪆","𣪉","𣪓","𧿎","𧿸"}
	a[67572]={"㖩","㗞","嗖","𥄌"}
	a[67573]={"晖","跭","𠲴","𤿧","𤿮","𨀆","𨀝","𪐮"}
	a[67574]={"𡳧","𣇔","𣇽","𧏘","𧐲","𧑷"}
	a[67575]={"畷","𧌰","𧏫","𪐿","𪑁"}
	a[67576]={"㖀","䀟","蜂","蝃","𠷈","𧿳"}
	a[67581]={"㫶","噿","𠻍","𣆲","𥋂"}
	a[67582]={"𠺏","𢄾","𨂲"}
	a[67583]={"喡","𣉜","𥀗","𧌈","𧎨"}
	a[67584]={"㿺","䀱","䟾","螋","𧌗","𧎚","𪑰"}
	a[67585]={"喗"}
	a[67588]={"𧊐","𧍶"}
	a[67589]={"𥀕"}
	a[67591]={"㗇","𣉥","𥆷","𥇳"}
	a[67592]={"瞍","踙","𡁕","𥈨","𥉟","𧷌","𨃟"}
	a[67593]={"暐","𠿍","𥀚","𧓾"}
	a[67594]={"𠿇","𪒋"}
	a[67595]={"暉","𧍫"}
	a[67596]={"𨀞"}
	a[67597]={"𠸻"}
	a[67598]={"𪑯"}
	a[67600]={"曕","睸","𨅧"}
	a[67601]={"㬆","噜"}
	a[67602]={"蝐","蟾","𤲰","𧐔","𪒧"}
	a[67610]={"䠨","瞻","賵","贍","𥈆","𥋯","𧸸","𨄌"}
	a[67611]={"䁕","𥉦","𧸚"}
	a[67612]={"䠧","黵","𡄇","𣋐"}
	a[67614]={"𡄵"}
	a[67616]={"𡂜","𧕪"}
	a[67650]={"𠰉","𠱷","𠳪"}
	a[67651]={"咯"}
	a[67660]={"㫟","㫥","㷖","昭"}
	a[67661]={"𤱠"}
	a[67662]={"略","蛁","𠺝"}
	a[67663]={"蛒"}
	a[67670]={"䠖","眧","眳","𠾈"}
	a[67671]={"䀩","啹","賂","路","𠹄","𠺕"}
	a[67673]={"𠲰"}
	a[67680]={"𠷯","𠻙","𠿌"}
	a[67682]={"𠻐"}
	a[67683]={"䗜","蜛","𣇉"}
	a[67690]={"㗩","㿢","噡","𡃆","𣈲"}
	a[67691]={"㗃","䁊","䝻","嚕","踞","蹓","𡀔","𥇄","𥉳"}
	a[67692]={"蝞","𥇗"}
	a[67694]={"𠼣"}
	a[67700]={"𡆟","𥇩","𥉄","𨃴"}
	a[67701]={"噚","賯","鹭","𤲮"}
	a[67702]={"𤳚","𩣶","𪅵"}
	a[67703]={"囓","瞩","𡄆","𨅛"}
	a[67710]={"𣊧","𥉧","𨅡","𨅵","𪂡"}
	a[67711]={"鷺","𤲹","𪅅"}
	a[67712]={"䠱","囑","曯","矚","𧹇"}
	a[67713]={"蟳","𤴉"}
	a[67714]={"蠮","蠾"}
	a[67730]={"𠮩"}
	a[67740]={"𠮤","𠮨","𠯹","𠰄","𠲄"}
	a[67741]={"吇"}
	a[67750]={"㖤","吗","旸","𠯷"}
	a[67751]={"𠼮","𡁷","𤰩"}
	a[67752]={"䣒"}
	a[67753]={"畅","虸","𠱿","𠻑"}
	a[67754]={"𠴂"}
	a[67760]={"䟥","𠱂","𥃥","𥄛","𥆲","𥇯"}
	a[67761]={"㖊","啒","𠼇","𡥕","𧴯"}
	a[67762]={"㗙","唃","蚂","蜬","𠲚","𠳀","𪐧"}
	a[67763]={"","𠲜","𪐣"}
	a[67764]={"𤱷"}
	a[67765]={"蛠","𠸎"}
	a[67768]={"𧉸"}
	a[67770]={"啗","喎","噊","𠲼","𨀇","𨀩"}
	a[67771]={"𠱣","𠷭","𥊪"}
	a[67773]={"㗈","䗛","野","𢯲","𧌑"}
	a[67774]={"蛹","𢣢","𧎷","𧐙"}
	a[67780]={"嗗","𠱳","𠴁","𠵑","𠺁","𠿭","𡁜","𥅑","𧵫"}
	a[67781]={"䠇","蹡","𠷲","𥇣","𥉈","𨄋"}
	a[67782]={"蜭","蝑","蝸","踊","𥆌","𧑐","𨃘"}
	a[67783]={"嗋","嘱","睁","踭","𡂸","𧶄"}
	a[67784]={"㨼","𧍂"}
	a[67785]={"𠹙","𧍛"}
	a[67790]={"瞲","跼","踻","蹫","𣉃","𥇌","𥈓","𧶳","𧷾","𨁳"}
	a[67791]={"㬑","𠽣","𥇵","𨂹"}
	a[67792]={"螖","𥇤"}
	a[67793]={"嘢","踴"}
	a[67795]={"𧑏"}
	a[67800]={"𡁎"}
	a[67801]={"𡄺","𢅨"}
	a[67802]={"噀","𣤵"}
	a[67803]={"𡃤","𧓗","𧓩"}
	a[67806]={"曊","𣋸"}
	a[67807]={"𧓛"}
	a[67808]={"𧑈"}
	a[67810]={"𡂿","𡃳","𥌔","𥌝","𨂳"}
	a[67811]={"㘋","𡃪","𥌶","𧷥","𨇚"}
	a[67812]={"䠣","𥍌"}
	a[67813]={"䠭","韙"}
	a[67814]={"蟤"}
	a[67815]={"𧔣"}
	a[67830]={"㗵","㰨","吹","呗","焁","𠮻","𠶨","𣢱","𣣦","𣣴"}
	a[67840]={"呎","欥","𠰊","𡇥","𣇧","𣊞"}
	a[67841]={"欭","畂"}
	a[67842]={"㰩","吷","咉","𣢗"}
	a[67843]={"𣢘","𣢧"}
	a[67850]={"䟳","𠲭","𠺡","𠾗","𤉵","𤋚","𧿞","𨂂"}
	a[67851]={"唤","喚","","𤈳","𤱐","𨁣"}
	a[67852]={"㱄","映","蚇","𣅡"}
	a[67853]={"𤰮"}
	a[67854]={"唺","蚗","𤱉"}
	a[67860]={"䝪","歇","焽","𠿮","𣤞","𤋗","𤋜","𨀥"}
	a[67861]={"㗋","㬇","喉","𠸰","𠾬","𣣆","𧷉"}
	a[67862]={"䀗","眏","趹","𧏗","𧐄","𧵌"}
	a[67863]={"嗽"}
	a[67864]={"晪"}
	a[67866]={"𧌎"}
	a[67870]={"㖵","𢁈","𣇴","𣣘"}
	a[67871]={"㬋","㱎","𠺖","𠺬","𣈵","𥈉"}
	a[67872]={"歜","歝"}
	a[67873]={"䗔","𠺋","𤍓","𧍳"}
	a[67874]={"䠄","喫","睓","賟","𥆸"}
	a[67875]={"𧐁"}
	a[67878]={"𣤋"}
	a[67880]={"噷","暝","歞","𠿒","𡄥"}
	a[67881]={"㘈","䞀","睺","𡁀","𡃧","𥈑","𨂸"}
	a[67882]={"蝜","螟","𠿖"}
	a[67883]={"𠿣","𢾔","𪑻"}
	a[67884]={"𧓏","𪑩"}
	a[67885]={"𧎯"}
	a[67890]={"瞑","𠸃","𡁌","𦑡","𨁺"}
	a[67891]={"𠸇"}
	a[67892]={"蠀","蠍","𥋻","𧤘","𪒄"}
	a[67893]={"𡀺","𡁍"}
	a[67894]={"𧓒","𨂰"}
	a[67896]={"𠾚"}
	a[67903]={"𥊯"}
	a[67905]={"㘑"}
	a[67914]={"𥌤"}
	a[67915]={"𥌿"}
	a[67930]={"𠰚"}
	a[67940]={"𠰿"}
	a[67941]={"𠳸","𡇙"}
	a[67942]={"𧉰"}
	a[67950]={"䟢","𥅘"}
	a[67951]={"㖻","哚","嚟"}
	a[67952]={"𠱞","𤱧"}
	a[67953]={"𧊶","𧔌"}
	a[67954]={"螩"}
	a[67960]={"㖨","㗫","𠵸","𣈬"}
	a[67961]={"賝","𨃜"}
	a[67962]={"㽥","𡀐","𥉉"}
	a[67963]={"蝚","𧊱"}
	a[67964]={"嗓","𧑇","𨾄"}
	a[67970]={"㫽","暩","𨄛"}
	a[67971]={"㘀","跥","跺","蹂","𠹠","𥌛"}
	a[67972]={"𧌍"}
	a[67973]={"𪑶"}
	a[67974]={"𣇨","𣉕"}
	a[67976]={"𪑠"}
	a[67980]={"䟿","睩","𥇎","𥉻","𨄊"}
	a[67982]={"䌎","𪑔"}
	a[67983]={"噄"}
	a[67984]={"䠈"}
	a[67991]={"𡁵"}
	a[67995]={"𧓙"}
	a[68020]={"㕥","叭","叺",""}
	a[68030]={"㕽","𠳎","𣅁"}
	a[68031]={"㽗"}
	a[68032]={"𧈢"}
	a[68040]={"趴","𧴩","𧿛"}
	a[68110]={"𡅞","𥌈","𧸦"}
	a[68140]={"㖉","𠵔"}
	a[68141]={"㘴","唑"}
	a[68150]={"㖹","嗌"}
	a[68151]={"唫","𠱴","𤱝"}
	a[68152]={"䗒"}
	a[68160]={"睑","踫","𨀣"}
	a[68161]={"䟶","睉"}
	a[68162]={"螠"}
	a[68163]={"𧊲"}
	a[68170]={"賹","𥂺"}
	a[68171]={"䀬","跧","𤱴"}
	a[68172]={"嗟"}
	a[68173]={"𪑙"}
	a[68180]={"𥈕"}
	a[68181]={"𣉼"}
	a[68182]={"暛"}
	a[68183]={"㽨"}
	a[68190]={"嚂"}
	a[68192]={"䁟","蹉"}
	a[68205]={"𡅣"}
	a[68220]={"吖","吤"}
	a[68230]={"吟","昣"}
	a[68231]={"畍","畛"}
	a[68232]={"蚧"}
	a[68240]={"䝩","昑","眕","跈","𠸐","𥄍","𧿩"}
	a[68241]={"嗲"}
	a[68242]={"蚙","𪐱","𪐲"}
	a[68243]={"䗄"}
	a[68250]={"咋","趻"}
	a[68251]={"𡈅"}
	a[68252]={"黔","𧍿"}
	a[68260]={"昨","𠵴"}
	a[68262]={"蚱"}
	a[68270]={"䝫","䟭","𥅁","𨁔"}
	a[68304]={"𧓲"}
	a[68330]={"㕬","呤","唥"}
	a[68340]={"唸","唹","昖","昤","𠴮","𠹸"}
	a[68341]={"𡀝"}
	a[68342]={"蚣","蛉"}
	a[68350]={"䠔","哙","跉"}
	a[68351]={"㗝","𠸺"}
	a[68352]={"𪑫"}
	a[68353]={"蜙"}
	a[68354]={"嘸"}
	a[68360]={"喩","喰","踗","𠷿","𠿏","𡀍","𣈮","𧸙","𨆏"}
	a[68362]={"𠼒","𪑄","𪒛"}
	a[68363]={"𢣮"}
	a[68364]={"𢡑","𣊲"}
	a[68366]={"蟱"}
	a[68367]={"嗛"}
	a[68370]={"嗞"}
	a[68371]={"𠻠","𠿼","𥉥"}
	a[68372]={"𪑅"}
	a[68374]={"瞴"}
	a[68379]={"螊"}
	a[68380]={"㘂","飸"}
	a[68381]={"㬠","㽧"}
	a[68382]={"螆","𡂺"}
	a[68385]={"𧐟"}
	a[68387]={"䁠","賺","𨃰"}
	a[68391]={"𥋧"}
	a[68392]={"䗹","𪒓"}
	a[68404]={"䂀"}
	a[68410]={"㘛","囕","𨈇"}
	a[68440]={"呛","𠱕"}
	a[68441]={"𢼙"}
	a[68450]={"吃","哾","𠵰","𣇋"}
	a[68452]={"蛻","𠰹"}
	a[68460]={"㫓","跄","𠯏","𣅠"}
	a[68461]={"𠺪","𤰢"}
	a[68462]={"唴","嗴","虼","蜕","𠴻","𤱘"}
	a[68464]={"𧉮"}
	a[68470]={"盵","趷","𠶹","𥆟","𧿦","𨁑"}
	a[68471]={"暣"}
	a[68472]={"䝯","𠷇","𥅓","𧿶","𪐜"}
	a[68473]={"𧎵"}
	a[68474]={"蜣"}
	a[68475]={"𠿿"}
	a[68480]={"𨀫"}
	a[68481]={"𨂟"}
	a[68482]={"暆","𥇉"}
	a[68483]={"𪒉"}
	a[68484]={"𧏙"}
	a[68485]={"㬢"}
	a[68487]={"蟻"}
	a[68492]={"𧷆"}
	a[68494]={"曦","𣌀"}
	a[68495]={"𥋟"}
	a[68496]={"𧔠","𨆋"}
	a[68501]={"䁶","瞮","覹","躈","𨅊","𨇂"}
	a[68502]={"瞰","蹾","𣀌","𣀬","𥋆","𧸂"}
	a[68503]={"𡆅","𥋌","𨅖"}
	a[68504]={"𣀡","𪒠"}
	a[68505]={"𧕇"}
	a[68506]={"豑","躌","𥌇"}
	a[68511]={"躨"}
	a[68513]={"𨇤"}
	a[68521]={"㕮"}
	a[68531]={"呚"}
	a[68533]={"蚥"}
	a[68541]={"吘","𠱘"}
	a[68542]={"畋"}
	a[68543]={"𢼓"}
	a[68551]={"敗","旿","𥄖"}
	a[68552]={"㖒","咩","哖","𠹐","𠻲","𣊶"}
	a[68553]={"䖫","𧊜","𪐫"}
	a[68554]={"㪙","蛢","𡃇","𢽛","𧒀"}
	a[68561]={"敭","𠭲","𡀎","𡀏","𥄺","𥅪"}
	a[68562]={"䠥","啽","賆","跰","𠹞","𠼏","𢽎","𥋗"}
	a[68563]={"啴","𠷩","𣀠","𧎄"}
	a[68564]={"蛘","𠻳","𣋹","𤲧","𧋘","𧐭"}
	a[68571]={"𠼍","𠼚","𢿃"}
	a[68572]={"㬕","眻","睇","𠼌","𢿜","𣉂","𨀘","𨁃"}
	a[68573]={"嗷","斁","𣀈","𣉫","𧒰"}
	a[68574]={"𧍬"}
	a[68575]={"嘋","蝉"}
	a[68577]={"𢿙"}
	a[68578]={"㪤"}
	a[68579]={"數"}
	a[68581]={"噭","𠾀"}
	a[68582]={"噉","噋","𣀉","𣉚"}
	a[68583]={"曔","蝮","𠾎","𠾝","𨃇"}
	a[68584]={"黭"}
	a[68591]={"㬚","曒","矀","贁"}
	a[68592]={"䞃","暾","𣊟","𨂤","𨄨"}
	a[68593]={"𠿨"}
	a[68594]={"𧑒"}
	a[68599]={"𡂡"}
	a[68600]={"瞺"}
	a[68601]={"𥊳"}
	a[68602]={"䵳","𧷶"}
	a[68610]={"囎"}
	a[68615]={"𨈁"}
	a[68640]={"唂"}
	a[68650]={"哈","唅"}
	a[68652]={"𧋉"}
	a[68660]={"䀰","晗","𡇡","𨁖"}
	a[68661]={"啥"}
	a[68662]={"蛤","蛿","𪑌"}
	a[68670]={"䀫","嗆","噌","跲","𠼟","𥆡","𧶗","𨅦"}
	a[68672]={"𪑇"}
	a[68673]={"𧌖"}
	a[68680]={"㬝","噲","𠽾"}
	a[68681]={"㬖","㽪","𧶟"}
	a[68682]={"螥"}
	a[68683]={"𧕉"}
	a[68684]={"蝤"}
	a[68690]={"䁬","賶","贈","蹌","蹭","𣋘"}
	a[68692]={"䠓","𧒯","𪒟"}
	a[68694]={"蟮"}
	a[68700]={"㬛","𨄆"}
	a[68702]={"䵰","𡃝"}
	a[68703]={"蹲","𥊭"}
	a[68710]={"䁯","蹹","𡃮"}
	a[68712]={"䠯","𥌉","𥌺","𧹊"}
	a[68713]={"𤴆"}
	a[68714]={"𧕋"}
	a[68730]={"吩"}
	a[68740]={"昐","𠯋"}
	a[68741]={"𤰪"}
	a[68742]={"蚡"}
	a[68750]={"盼","𠴣","𧿚"}
	a[68752]={"㖮","𠹹"}
	a[68760]={"喻","盻","𠷁","𧿝","𧿪"}
	a[68762]={"㫻","噙","𪐭"}
	a[68763]={"𠳨","𤲕","𧊦"}
	a[68764]={"蜦"}
	a[68770]={"嗡","𠿫","𣈥","𥅎","𧷜"}
	a[68771]={"𨄫"}
	a[68772]={"嗱","睔","蝓","踚","𠾡","𧌤"}
	a[68773]={"嗨","晦"}
	a[68774]={"畮","蠄"}
	a[68775]={"𧋟"}
	a[68780]={"暡","睮","踰"}
	a[68781]={"𠾌"}
	a[68782]={"螉"}
	a[68783]={"䀲","噂","蝣","踇","𧶅"}
	a[68784]={"𪒭 "}
	a[68785]={"黣","𡈬","𧌕","𧒆"}
	a[68790]={"噏","瞈","𥋘"}
	a[68791]={"𤳈"}
	a[68792]={"𧐀"}
	a[68813]={"嚽"}
	a[68820]={"","𠯱"}
	a[68830]={"㗰"}
	a[68831]={"𡘈"}
	a[68840]={"暰"}
	a[68841]={"咲"}
	a[68842]={"䗥"}
	a[68850]={"瞛","踨","蹤"}
	a[68861]={"䀢","眹","𣉧"}
	a[68862]={"蜁","𠸍"}
	a[68870]={"嗿","噞","𨁁"}
	a[68871]={"嗾","𠹻","𠿢","𥏬"}
	a[68872]={"𣈸"}
	a[68880]={"暶"}
	a[68882]={"𥈢","𧐗"}
	a[68890]={"䁢","瞼","𧸘"}
	a[68891]={"𣌎","𨄕"}
	a[68892]={"𪒫"}
	a[68920]={"𠰒"}
	a[68930]={"𠲇","𠲈","𠸌"}
	a[68940]={"𣆋","𨀀"}
	a[68941]={"唋","𤱏"}
	a[68942]={"𪐳"}
	a[68950]={"𡂊","𧵉"}
	a[68952]={"畭"}
	a[68953]={"蜍"}
	a[68960]={"賒"}
	a[68961]={"䟻","賖"}
	a[68963]={"𪑏"}
	a[68999]={"𦇆"}
	a[69020]={"","𠮶"}
	a[69102]={"𥊅"}
	a[69150]={"𠳥"}
	a[69161]={"𡃅","𥇆"}
	a[69162]={"𠻘"}
	a[69170]={"𠹛"}
	a[69171]={"嘡"}
	a[69172]={"嗺","𣈧"}
	a[69174]={"畻"}
	a[69180]={"暟"}
	a[69182]={"嘊","螘"}
	a[69183]={"螳"}
	a[69190]={"䁗"}
	a[69191]={"瞠","蹚"}
	a[69192]={"𨄍"}
	a[69220]={"吵"}
	a[69230]={"唦"}
	a[69231]={"𤰬"}
	a[69232]={"䖢","𠴕"}
	a[69234]={"𣌱"}
	a[69240]={"㖗","䟞","哕","眇"}
	a[69242]={"𠳕"}
	a[69250]={"𣇂","𥇇"}
	a[69260]={"𥆱","𨁊"}
	a[69302]={"曭"}
	a[69312]={"矘"}
	a[69320]={"𠯙"}
	a[69332]={"𧉍"}
	a[69340]={"𠵙"}
	a[69341]={"𠺗","𠿈"}
	a[69351]={"𣉢"}
	a[69360]={"𢡸"}
	a[69361]={"瞇","矁"}
	a[69373]={"嗤"}
	a[69382]={"𥌴"}
	a[69385]={"𧏬"}
	a[69386]={"𧑞"}
	a[69393]={"𥉍"}
	a[69440]={"咣"}
	a[69441]={"𤱦"}
	a[69450]={"晄","𠵗"}
	a[69451]={"𤱳"}
	a[69460]={"𧵦"}
	a[69462]={"啳","圏"}
	a[69464]={"蝋"}
	a[69472]={"𣰍"}
	a[69473]={"𤲨"}
	a[69474]={"蜷"}
	a[69482]={"睠","踡"}
	a[69492]={"𨅏"}
	a[69494]={"𧑵"}
	a[69501]={"躞","𥍆"}
	a[69512]={"𡆑"}
	a[69517]={"𧰢"}
	a[69542]={"𠰢","𡀘","𡀼","𡁊"}
	a[69543]={"喽"}
	a[69551]={"𠲺"}
	a[69552]={"㫞","㫠","𡁆","𥆵"}
	a[69553]={"畔"}
	a[69555]={"蝼"}
	a[69561]={"𠵚","𣉀"}
	a[69562]={"眫","跘"}
	a[69563]={"䁖","噒","","𤳩","𧊩","𧋏"}
	a[69565]={"𧉳"}
	a[69572]={"𥌌","𨆴"}
	a[69573]={"暽"}
	a[69574]={"疄"}
	a[69575]={"䗲"}
	a[69581]={"𡄕"}
	a[69583]={"瞵","蹸"}
	a[69593]={"𧕊"}
	a[69601]={"𨆉"}
	a[69660]={"㗂","啱","𠼜"}
	a[69661]={"𠸉"}
	a[69670]={"𡂚"}
	a[69671]={"𣇿"}
	a[69672]={"𧍖"}
	a[69681]={"噹"}
	a[69682]={"𧕍"}
	a[69690]={"嚐","𥋐"}
	a[69693]={"蟷"}
	a[69702]={"𡄴"}
	a[69704]={"䠮"}
	a[69706]={"𪒿"}
	a[69710]={"蹦"}
	a[69712]={"𥍋"}
	a[69713]={"㽯"}
	a[69714]={"蠵","𧔍"}
	a[69730]={"𠮿","𡆯"}
	a[69741]={"咄","嘮","𣇢"}
	a[69743]={"𧌽"}
	a[69750]={"䟖","哨","喘",""}
	a[69751]={"昢","𨂅"}
	a[69752]={"𤱟"}
	a[69753]={"䖦","蟧"}
	a[69760]={"㫾","𣆺"}
	a[69761]={"𠼔","𧿺"}
	a[69762]={"蛸","𠼩","𧍒"}
	a[69763]={"黜"}
	a[69770]={"䠀","睄","踃","踹","𠾩","𧶈","𧶲"}
	a[69772]={"𡥺","𧐬","𪐹","𪑊"}
	a[69773]={"蟐"}
	a[69780]={"蹐"}
	a[69781]={"𠿩"}
	a[69782]={"𧔇"}
	a[69784]={"𨃪"}
	a[69790]={"㬞","嘣","𪃧"}
	a[69791]={"𥊼","𨅝"}
	a[69792]={"𥋇"}
	a[69794]={"𧒩"}
	a[69796]={"𧔟"}
	a[69802]={"䞉"}
	a[69810]={"贘"}
	a[69820]={"吙","啖"}
	a[69821]={"唙"}
	a[69830]={"唢","晱","炚","𠻪","𡂋"}
	a[69831]={"啾","𤰹","𤲩"}
	a[69832]={"䗊"}
	a[69840]={"睒","賧","𡀕","𥄣","𧷼","𨁹"}
	a[69841]={"𥇃"}
	a[69842]={"𧓌","𪐩","𪑓"}
	a[69850]={"尟"}
	a[69851]={"瞅","踿"}
	a[69860]={"嗩","𡺔","𤏒"}
	a[69872]={"𠾨","𧎫"}
	a[69876]={"𧏉"}
	a[69880]={"䞆","𠽭","𥊰"}
	a[69881]={"𡁻"}
	a[69890]={"𥍏","𨇾"}
	a[69891]={"𤓐"}
	a[69892]={"𨆐"}
	a[69931]={"咪"}
	a[69941]={"㘇"}
	a[69951]={"眯","𨀷"}
	a[69953]={"蠑"}
	a[69960]={"𡁸"}
	a[69961]={"𥇫"}
	a[69962]={"𧎾","𧐑"}
	a[69965]={"𧏪"}
	a[69972]={"𥉋","𨄇"}
	a[69981]={"𥊲","𨅨"}
	a[70000]={"膷","","𨜹"}
	a[70004]={"幱"}
	a[70010]={"⺆","鄳","","","","","𠔿","𠕎","𦉫","𦠥","𦢨","𨞾"}
	a[70011]={"內","𢅰"}
	a[70012]={"𨶽","𩦂"}
	a[70013]={"䑌","𩦃","𩦴"}
	a[70016]={"𢆄"}
	a[70020]={"䍏","邤","","","","","","𠃜","𠕈","𠕚","𨙪"}
	a[70021]={"","𨛇"}
	a[70022]={"","",""}
	a[70030]={"⺝","䢳","邱",""}
	a[70031]={"邥","邸",""}
	a[70032]={"郕","","𦉳"}
	a[70034]={""}
	a[70038]={""}
	a[70040]={"郈",""}
	a[70041]={""}
	a[70044]={"𨙻","𨚗"}
	a[70048]={"𨚿 "}
	a[70050]={"䢸","䢹","䢻","䣅","𨚯","𨛞","𨜇"}
	a[70052]={"䣕","𨞐"}
	a[70053]={"郓"}
	a[70060]={"郳","鄍","𨜊"}
	a[70061]={"邼","郮","鄏","𨛮"}
	a[70062]={"鄋","𨟑"}
	a[70063]={"𠕛"}
	a[70070]={"郿","鄮","𨞌","𨟊"}
	a[70071]={"𨜘"}
	a[70072]={"郾","𨟟"}
	a[70073]={"䣑","𦜅"}
	a[70075]={"鄆"}
	a[70081]={"𧨣"}
	a[70082]={"䣝"}
	a[70083]={"𨟋"}
	a[70085]={"𨞋","𨞺"}
	a[70092]={"𦡄"}
	a[70094]={"𨞬"}
	a[70101]={"𡳆"}
	a[70104]={"𤬠"}
	a[70106]={"𡬉"}
	a[70110]={"𠄏"}
	a[70112]={"𡳬"}
	a[70113]={"𩪝"}
	a[70114]={"㒿","䑏","𩪒","𩪼"}
	a[70116]={"驩"}
	a[70118]={"騹"}
	a[70120]={"皿","𠀃"}
	a[70121]={"𠄔"}
	a[70130]={"贮","𠀇","𠖃","𠤬","𣥙","𦉺","𦊀"}
	a[70132]={"𦉽"}
	a[70134]={""}
	a[70140]={"㞐","且","","𡰥","𡰱"}
	a[70141]={"𡳈","𡳑","𢃐"}
	a[70142]={"盎","𡉮","𤣼"}
	a[70143]={"𢂾","𦊝"}
	a[70150]={"冝","𡰩","𡲀","𣌩","𦊨"}
	a[70151]={"","𡉷","𡊴","𦊕"}
	a[70152]={"𥁎","𦊍","𦊩","𦊱"}
	a[70153]={"屉","屜","隺"}
	a[70154]={"𥁉","𦋜","𦌐"}
	a[70160]={"昼","腔","","𧖳"}
	a[70161]={"垦","屋","𡱮","𤥔"}
	a[70162]={"𨾈"}
	a[70170]={"𡱌","𡳂"}
	a[70171]={"㡧","𡲃"}
	a[70172]={"𡳸","𦋛","𩣼"}
	a[70173]={"𡲙","𦋘"}
	a[70174]={"𢅤","𦌴"}
	a[70180]={"𡱻"}
	a[70181]={"腟","膣"}
	a[70183]={"𡳫"}
	a[70185]={"𦌜"}
	a[70190]={"𠖚","𩩝"}
	a[70192]={"𩤒"}
	a[70197]={"𦡂"}
	a[70210]={"⺵","㐃","冖","卩","卪","","","𠁾"}
	a[70211]={"罓",""}
	a[70217]={"𦢩"}
	a[70219]={"𩧓"}
	a[70220]={"尸","","","𡰹"}
	a[70221]={"","𠕀"}
	a[70224]={""}
	a[70230]={"⺜","","","","𠁣","𠃢","𡱳"}
	a[70240]={"㞔","𡰲"}
	a[70248]={"𠕢"}
	a[70250]={"𠕝","𦁒"}
	a[70260]={"𡳇"}
	a[70271]={"𠖛"}
	a[70280]={"屝"}
	a[70281]={"幯"}
	a[70282]={"䑅"}
	a[70290]={"鼏","𪔃"}
	a[70300]={"乀"}
	a[70303]={"𦢐"}
	a[70304]={"𧔲"}
	a[70305]={"蟁"}
	a[70306]={"𧒝"}
	a[70310]={"㓀","㞡"}
	a[70312]={"𦊡"}
	a[70313]={"𠖪"}
	a[70314]={"𧕵","𧖅","𧖉"}
	a[70315]={"𧓹"}
	a[70316]={"𧔡"}
	a[70320]={"尽","𠕺"}
	a[70321]={"农","冢"}
	a[70322]={"𠖼","𢘲","𦊶"}
	a[70330]={"㞏","冡","","𠖔","𡱰","𢚪"}
	a[70331]={"㞘","幏","𢗐","𦊬"}
	a[70332]={"𢘁"}
	a[70340]={"艮","𡱽","𢗯","𢘒"}
	a[70342]={"𤉂"}
	a[70343]={"袰","𢘓","𦋮"}
	a[70344]={"𢘼"}
	a[70350]={"县","层","恳","𡱦","𢚞","𦞭"}
	a[70351]={"𠖓","𡱅"}
	a[70352]={"展","𡱗","𦌲","𩖳"}
	a[70353]={"幪","𡲦"}
	a[70360]={"䬤","屒","悬"}
	a[70361]={"𢛇","𢛥"}
	a[70370]={"𢝯","𩛻"}
	a[70372]={"朦"}
	a[70373]={"𧊈"}
	a[70374]={"𪒍"}
	a[70382]={"𡳋","𢞰","𦍃"}
	a[70384]={"幰","𧎰","𩦺"}
	a[70386]={"𩦊"}
	a[70393]={"𠖧","𪑪"}
	a[70394]={"𧎱"}
	a[70400]={"䯘","䯛","黽"}
	a[70402]={"臗","髋"}
	a[70403]={"𣋯"}
	a[70404]={"䯦"}
	a[70405]={"𦡽"}
	a[70410]={"⺇","⺴","㔾","㶡","","","","𠖥","𠘱","𡳟","𨳅","𪓙","𪓩"}
	a[70411]={"䥚","风","𦌼"}
	a[70412]={"髖","𩪻","𪓛"}
	a[70414]={"臟","𩙓","𩙛"}
	a[70415]={"𪚷","𪚻"}
	a[70416]={"飍"}
	a[70417]={"𩙠"}
	a[70419]={"𩙚"}
	a[70420]={"几","凡","见","","","","𠕶","𠘧","𠘳","𡖆"}
	a[70421]={"冘","凤","凧","凩","𠕿","𠘯","𠘴","𦉮"}
	a[70425]={"𠃾"}
	a[70430]={"冗","凪","夙","尼","巳","巴","𠕵","𠘵","𡰭","𡱘","𡱹"}
	a[70431]={"","𠕴","𠘪","𠘼","𠙄"}
	a[70432]={"㞍","","𠂡","𦊉"}
	a[70440]={"凥","凨","巼","","𠕻","𠘻","𡱂","𡱜","𡱲","𡲵","𦉭"}
	a[70441]={"尻","民","𠘾","𠙈","𠙗","𡰽"}
	a[70442]={"甩","風","𠙌","𦊠"}
	a[70443]={"𦊞","𦌓"}
	a[70444]={"𡱫"}
	a[70449]={"𠙘"}
	a[70450]={"㞎","冟","凬","凮","屁","屍","𣍥","𤬦","𦊦","𦚐"}
	a[70451]={"冠","冤","帵","𠖂","𠖆","𠙊","𠙕","𡰼","𡱧","𡲐","𦊗"}
	a[70452]={"㓂","尾","","𠕠","𦋼","𩡫"}
	a[70453]={"㡛","㬸","𦊣"}
	a[70454]={"䍞","𡲕","𦌏"}
	a[70455]={"幭","𦋙"}
	a[70457]={"凲"}
	a[70460]={"㖯","㞑","鳯","𠖍","𠙒","𠙔","𠨕","𡲏","𡲩","𦥨","𧠓"}
	a[70461]={"㓘","冦"}
	a[70462]={"㼜","䬁","駝","𡱤","𣬷"}
	a[70463]={"䬒","𠱰","𢅵","𩲛"}
	a[70465]={"𩤉"}
	a[70466]={"𥀯"}
	a[70470]={"脘","腕","鳳","𡱓","𧠊"}
	a[70471]={"冕","凰","𠕤","𡱕","𡱷","𡲮","𣱈","𦋌"}
	a[70472]={"㒽","㬻","𣎑"}
	a[70473]={"𡲔","𢅘","𣮈","𩢵"}
	a[70474]={"𡲿","𩥒"}
	a[70475]={"𦌌"}
	a[70476]={"𩘑"}
	a[70480]={"㒻","鼧","𩨭"}
	a[70481]={"㓃"}
	a[70482]={"㒾","𠙬","𩣵"}
	a[70484]={"𩘡"}
	a[70491]={"䯔","𡳅"}
	a[70492]={"𩘎","𩘰"}
	a[70503]={"𡳷"}
	a[70505]={"䡞"}
	a[70511]={"巾"}
	a[70514]={"髒","𢆆"}
	a[70515]={"𩪭"}
	a[70516]={"羼"}
	a[70521]={"𠕸","𠬝","𦉲"}
	a[70522]={"皮","𠕷","𠬥","𢁝","𢌺"}
	a[70523]={"𢌷"}
	a[70531]={"㞋","殳","罕","𠬩","𡰫","𡰯","𡰷","𡰿","𡱙","𡳉"}
	a[70532]={"𡝼","𡰾","𡱚","𡲾","𤘰"}
	a[70533]={"䍑","𦛅"}
	a[70534]={"𡛬"}
	a[70541]={"𠖊","𡰵","𡱃","𡱞","𡱥","𡲲"}
	a[70542]={"屏","屐","异","𡰸","𡱪","𡲁"}
	a[70543]={"㞜","军","屡","屦","𡲹"}
	a[70551]={"屌","屖","𠬸","𡲯","𡳌"}
	a[70552]={"䯃","犀","胺","𡱝","𡲱","𡳡","𢍀","𢍔"}
	a[70553]={"𡲅","𡲛","𡳐","𦉻"}
	a[70554]={"𠖎"}
	a[70556]={"𦋖"}
	a[70561]={"𡱡","𦋃","𦋐"}
	a[70562]={"冣","屛","幂","𡲆","𦋇","𦌤"}
	a[70563]={"䮟","𡱯","𡲎","𡲣","𡳞","𦋚"}
	a[70564]={"𩣑"}
	a[70565]={"軍","𦟮"}
	a[70570]={"𦌑"}
	a[70571]={"履","𠖢","𦞤"}
	a[70572]={"𠖗","𡱾"}
	a[70574]={"冪"}
	a[70577]={"𦌎"}
	a[70578]={"𦌳"}
	a[70581]={"𡲻","𦥼"}
	a[70582]={"𤚌"}
	a[70583]={"䮨"}
	a[70584]={"𡲄"}
	a[70586]={"𡲓"}
	a[70587]={"雘","𦠜"}
	a[70588]={"屢","屨"}
	a[70592]={"𠕭","𨲡"}
	a[70595]={"臒","騲","𠫌","𩪎"}
	a[70596]={"𩦦"}
	a[70599]={"驊"}
	a[70601]={"髂"}
	a[70605]={"𩥌"}
	a[70610]={"𡳻"}
	a[70611]={"𦍊"}
	a[70612]={"𦢧"}
	a[70613]={"𩪃"}
	a[70630]={"","𠉁"}
	a[70640]={"𠕾","𡰪","𦊭"}
	a[70641]={"𠖋","𡲖","𦊙","𦊹"}
	a[70642]={"𦊪","𦋑"}
	a[70643]={"𦊟"}
	a[70650]={"𡰶","𡱇","𣅩"}
	a[70651]={"居","屇"}
	a[70652]={"届"}
	a[70653]={"𠰔"}
	a[70654]={"𣌧"}
	a[70660]={"㞒","㞓","㞛","眉","𦌘","𦌛","𦤋"}
	a[70661]={"𠖐"}
	a[70662]={"𦋫","𦌝","𧧧"}
	a[70663]={"𡲢"}
	a[70664]={"𣅾","𣇺","𦋧"}
	a[70668]={"𣆩"}
	a[70670]={"冒","層","𡱔"}
	a[70671]={"冨","昬","𦝣"}
	a[70672]={"屠","𡲚","𥀝","𦞂"}
	a[70675]={"𢅔"}
	a[70676]={"𦌱"}
	a[70680]={"𦞨","𦟱","𨲟"}
	a[70682]={"𠖠","𩥥"}
	a[70683]={"𧦥"}
	a[70684]={"𩥠"}
	a[70690]={"𡳄"}
	a[70692]={"𩥿"}
	a[70693]={"羀","𢅴","𦟈"}
	a[70700]={"𡲳","𨲸"}
	a[70701]={"屫"}
	a[70704]={"𩦞"}
	a[70707]={"𦢸"}
	a[70710]={"㒳","冂","𠕘","𠕲","𠥫"}
	a[70711]={"内","冈","肉"}
	a[70712]={"网"}
	a[70714]={"𠥬"}
	a[70715]={"𦣈"}
	a[70720]={"⺼","円","冚","𠔼","𠔽","𡴺","𡵠","𤆙","𦉪"}
	a[70721]={"禸","𠕒","𦘫"}
	a[70722]={"丹","𠕁","𡶬","𦉯","𦌞"}
	a[70724]={"冊"}
	a[70730]={"㒺","冃","冋","冎","冏","岡","月","","𠃛","𠕃","𠕊","𠕏","𡰨"}
	a[70731]={"㕯","𠕐","𠖌","𡱎","𢁼","𦛂"}
	a[70732]={"用","𦉸"}
	a[70733]={"母","𦋄"}
	a[70734]={"冄","冉"}
	a[70735]={"毋","𣫬"}
	a[70738]={"𠕋"}
	a[70740]={"㠯","写","凸","同","囘","岊","罔","肎","","𠕄","𠕌","𠕑","𠕕","𡰳","𡱊","𡱣","𡳘","𡵒","𤕪","𥀿","𦋩"}
	a[70741]={"㞌","导","屈","屚","𠄗","𠖅","𠡋","𡱆","𡱟","𡲒","𡶘","𦉿"}
	a[70742]={"𡰴","𡲜","𡲟","𢃹","𦊖","𦋟","𦋵"}
	a[70744]={"𡘦"}
	a[70750]={"㞕","咼","局","屑","","𠕔","𠕡","𠕬","𠖄","𠥓","𡰬","𡱈","𡱺","𡲺","𣍟","𦊰","𦙎","𦜸"}
	a[70751]={"周","屆","𠖏","𡲬","𣍸","𦊌"}
	a[70752]={"鸯","𠖖","𡲗"}
	a[70753]={"𦜬"}
	a[70754]={"𡥘","𦋻"}
	a[70755]={"𠕰","𡥳"}
	a[70758]={"𣫳"}
	a[70760]={"冐","冩","屙","骨","𠕙","𡱑","𡱿","𦋀"}
	a[70761]={"𡲶","𡸧","𢃙","𦋢","𦌍"}
	a[70762]={"𠖟","𦜜"}
	a[70763]={"属","脇","𠱬","𡱄","𡱬","𡲇"}
	a[70764]={"䐌"}
	a[70768]={"𣫯"}
	a[70770]={"䲩","𠕦","𡳍","𡸭"}
	a[70771]={"㞚","冔","𠕥","𠕮","𠵁","𡲍","𦀒"}
	a[70772]={"鴦","𦋬"}
	a[70774]={"𦌯"}
	a[70775]={"𦋱"}
	a[70780]={"𠕣","𠥧","𦜐","𦡲"}
	a[70781]={"屩","𦌄","𦡆"}
	a[70783]={"孱","𧐰"}
	a[70790]={"𠕪","𠥪","𦜳"}
	a[70792]={"屬","臈","𠖜","𠥩","𡳚","𡳯","𩘵"}
	a[70796]={"𤰌"}
	a[70797]={"𦡰"}
	a[70802]={"驞"}
	a[70803]={"𡳮"}
	a[70810]={"㓁","屭","贝","髕","𠕳","𨲺","𩪯"}
	a[70811]={"𠖩","𠖫"}
	a[70813]={"𠔸","𦍅"}
	a[70816]={"䮿"}
	a[70820]={"㒷","尺","","","𠕼","𡰦","𦊇"}
	a[70821]={"𦊅"}
	a[70822]={"央"}
	a[70830]={"㞞","屃","屄","赑","𣢂"}
	a[70831]={"𠕹","𠖁","𡗺","𡱱"}
	a[70833]={"𡗽"}
	a[70834]={"典"}
	a[70840]={"𡱍","𦙮"}
	a[70841]={"𡱁","𡲑"}
	a[70842]={"𡱒","𤑇"}
	a[70843]={"𠖉","𤏷"}
	a[70845]={"㡕"}
	a[70850]={"具","冥","屣","𧿃"}
	a[70851]={"𠖇","𡱢","𦝬"}
	a[70852]={"𧵽"}
	a[70860]={"屓","腚","膑"}
	a[70861]={"𥏈"}
	a[70862]={"𦋭"}
	a[70864]={"幙","朠","𡱐","𦟦"}
	a[70865]={"𠖣"}
	a[70870]={"䧬","𪕏"}
	a[70871]={"㡦","𠖕"}
	a[70880]={"𡳠"}
	a[70881]={"鼵"}
	a[70882]={"𦟘","𨃨"}
	a[70883]={"㞟","膜","𦌨"}
	a[70885]={"𩦟"}
	a[70890]={"臏","髌","𩩏"}
	a[70893]={"𧷅"}
	a[70895]={"䮬"}
	a[70903]={"𠖦"}
	a[70920]={"𠕽"}
	a[70921]={"冞","罙","𣎻","𣎾"}
	a[70922]={"𦊋"}
	a[70923]={"𦊘","𦊮"}
	a[70930]={"尿","𠖀","𡱴"}
	a[70931]={"屎","朵","杘","𡲴","𣎿","𣐷"}
	a[70932]={"冧","𣏷"}
	a[70934]={"𦋗"}
	a[70940]={"𡱏","𡲘"}
	a[70941]={"㞗","𠕖","𡲰","𢃏","𣐉","𣑍"}
	a[70942]={"㞖"}
	a[70950]={"𦋔"}
	a[70951]={"𠕨","𣐻","𣑸"}
	a[70952]={"𡱵"}
	a[70954]={"𡲷"}
	a[70960]={"腙"}
	a[70961]={"㞠","㮂"}
	a[70962]={"㞙"}
	a[70963]={"𡱼","𥹹","𦌆"}
	a[70964]={"屟","屧"}
	a[70970]={"䋰"}
	a[70971]={"屪"}
	a[70972]={"騌"}
	a[70973]={"𥼿"}
	a[70974]={"𡳙"}
	a[70980]={"𨲇"}
	a[70983]={"𥛛"}
	a[70994]={"𦣑","𩧇"}
	a[71100]={"𠥡"}
	a[71101]={"㱘","匵","𠥞","𠽺","𠿦","𦞥","𧗖"}
	a[71102]={"㔵","壓","𠫀","𤬜","𩤃"}
	a[71103]={"匰"}
	a[71104]={"𠥥"}
	a[71110]={"膒","𠥺","𩩤","𩪍"}
	a[71111]={"暨","𠥝","𦟚","𦟰","𦠿","𨽲"}
	a[71112]={"㔶","匷","臚","驅","髗","鼴","𠥚","𠫎","𨲢","𨲣","𩪸","𪖌","𪖍"}
	a[71113]={"臛","𠥦"}
	a[71114]={"匶","驢","𩽟"}
	a[71115]={"𩧏"}
	a[71116]={"𠥨","𩧥"}
	a[71120]={"匚","匸","𠤭"}
	a[71121]={"区"}
	a[71130]={"㔰","㕇","匛","匠","匢","匹","","𠤮","𠤯","𠤰","𠤺","𠥭","𠥳"}
	a[71131]={"匝","匧","压","圧","","𠤻","𠤼","𠥮","𠩜","𠩟","𠪪","𢃀"}
	a[71140]={"匞","叵","巨","臣","","","","𠤴","𠤽","𠥰","𠥴","𦣝","𦣞"}
	a[71141]={"㔷","㕋","医","𠥂","𠥯","𠥱","𠩈","𠩽","𢁚","𢁿"}
	a[71142]={"匜","匥","𠤱","𠥌","𠥑","𢃫"}
	a[71144]={"𠥲"}
	a[71150]={"匟","匼","肛","胚","𠤾","𠤿","𠥁","𠥗","𠩎"}
	a[71151]={"匡","匤","厔","𠤳","𠤸","𠤹"}
	a[71152]={"匣","厓","歴","歷","雁","𠤲","𠤵","𠤶","𠤷","𧈟"}
	a[71153]={"𠥃","𠪖","𡐰"}
	a[71155]={"厜"}
	a[71160]={"㔯","䏘","匫","匬","脛","𠥋","𠥍","𠥒","𠪈","𣍭","𣎄","𦙫","𦚹"}
	a[71161]={"㔱","㔲","㕎","匨","𠥆","𠩥","𠪒","𢂡","𦙗","𦣠"}
	a[71162]={"匩","匮","匽","匾","駓","𠥅","𠥊","𠥔","𠪉"}
	a[71163]={"㻺","匿","厘","駆","𠥉","𨬑"}
	a[71170]={"匳","脰","𠥇","𠥐","𠥵","𦙁","𦚟","𦚠"}
	a[71171]={"胵","𠥕"}
	a[71172]={"匯","𨬐","𩢩","𩣕","𩣪"}
	a[71173]={"㔴","㕓","𩢤"}
	a[71174]={"匦","𠪤","𣱐"}
	a[71175]={"𠥖"}
	a[71180]={"㔳","匪","區","𠥘","𠥜","𠪶","𦚸","𦞌","𦣦"}
	a[71181]={"㔸","𠥏","𠥶","𦚞"}
	a[71182]={"駏","𠥛","𠥟","𡍱","𡏃","𡐷","𣦯","𩢘"}
	a[71183]={"駤","𠥎","𠥙","𡓸","𤧤","𦝪","𩀾"}
	a[71184]={"𠪨"}
	a[71186]={"厪","𠥢"}
	a[71190]={"𠥣","𦜖","𦠊","𩩋","𪕣"}
	a[71191]={"䀈","䇒","匲","𢄠"}
	a[71192]={"匱","匴","塈","𠫂"}
	a[71193]={"驉","𦝟","𩢼"}
	a[71196]={"匭"}
	a[71197]={"𠪵"}
	a[71202]={"騑"}
	a[71210]={"厂","𠨴"}
	a[71213]={"𩧤"}
	a[71220]={"㕂","𠨳"}
	a[71240]={"厏","厛","𠀞"}
	a[71250]={"巪","𣧚"}
	a[71252]={"䭶"}
	a[71260]={"胪"}
	a[71262]={"䭼","厮","𩣝"}
	a[71270]={"厞","陫"}
	a[71290]={"腓"}
	a[71292]={"駵"}
	a[71300]={"𢥧"}
	a[71303]={"𧐆"}
	a[71304]={"螶","𧒏","𧔞"}
	a[71307]={"𧓽"}
	a[71310]={"𠨸","𦢄"}
	a[71311]={"饜","𩪥"}
	a[71312]={"㕔","鱀","𠫊","𦢛","𩼴"}
	a[71313]={"黶"}
	a[71316]={"𧓨","𧓱"}
	a[71317]={"䘌"}
	a[71319]={"𧖄"}
	a[71321]={"𠩁"}
	a[71330]={"㕈","𠗁","𡿰","𨑄"}
	a[71331]={"𨱗"}
	a[71332]={"𠪾","𢟍"}
	a[71340]={"㕄","豚","辰","𠩐","𡿴","𢙞","𤇴","𤇸","𤔋","𦟙","𨑃"}
	a[71341]={"㥦","䐁","𠩂"}
	a[71342]={"厯","𠪱","𢟀"}
	a[71343]={"𠪏"}
	a[71350]={"愿","胩","赈","長","镸","𠩸","𢛚","𦟥"}
	a[71351]={"㥈","帪","悘","憠","𦤻"}
	a[71352]={"𠪩","𤎝","𧝏"}
	a[71353]={"𤔮"}
	a[71357]={"𠪊"}
	a[71360]={"𠪰","𤋧","𤬅","𦙘","𦝿","𧹔"}
	a[71361]={"帳","餍","𢟲","𤔜"}
	a[71362]={"䮍","䮱"}
	a[71363]={"黡"}
	a[71370]={"脤","𢡪","𩩒"}
	a[71372]={"蜃","𠫄","𧏐","𩞨"}
	a[71373]={"慝","蟨","𩢧"}
	a[71380]={"脹"}
	a[71381]={"臄","𢟪"}
	a[71384]={"瓥"}
	a[71385]={"𠪿 "}
	a[71390]={"𩨤"}
	a[71391]={"懕","𢢸"}
	a[71392]={"𠪼","𠫇","𩪪"}
	a[71395]={"𧏾"}
	a[71402]={"𡳕","𦡑","𦡻","𩗽"}
	a[71403]={"𩘆"}
	a[71405]={"飋"}
	a[71410]={"朧","甌","龎","𤭼","𨳁","𪓧"}
	a[71411]={"𦡕"}
	a[71412]={"䮾","𩙘","𪚘"}
	a[71413]={"飅","魘"}
	a[71414]={"驪","𩙙"}
	a[71420]={"𠨽"}
	a[71421]={"𠩇","𠩔"}
	a[71422]={"厐"}
	a[71430]={"䏓","厄","𠑶","𠩅","𠩓"}
	a[71431]={"厇","厎","𠨿"}
	a[71432]={"厖","𠨱"}
	a[71434]={"𠩙"}
	a[71440]={"㒫","兏","厑","𠨷","𠩆"}
	a[71441]={"飐","𤬾"}
	a[71442]={"","𠨰"}
	a[71444]={"𠩑"}
	a[71450]={"乬","𣍠"}
	a[71451]={"㼙"}
	a[71452]={"𠪍","𩗛"}
	a[71454]={"𠪎"}
	a[71460]={"朊","𠩫","𠩳","𦘸"}
	a[71461]={"瓭","瓯","","𠖑","𤬵","𤭄","𦘵"}
	a[71462]={"㡇","㼩","䫹","𠫈","𤬺","𩙩"}
	a[71463]={"颬","𡱭","𩗾","𩗿"}
	a[71464]={"𠪑","𩤴"}
	a[71465]={"㕒"}
	a[71470]={"𠹬","𣍴","𤭛"}
	a[71471]={"䖐","既"}
	a[71472]={"㽁","颭","𤬶","𤮖","𩗢","𩢄","𩣄"}
	a[71473]={"魇"}
	a[71474]={"𠪹"}
	a[71480]={"㼢","𤬴","𤭁"}
	a[71481]={"厩","旤","𠪽","𦛖","𧆡"}
	a[71482]={"𤭹"}
	a[71484]={"䬚","䮹","𦡏","𩴣"}
	a[71485]={"𡳊","𩘟"}
	a[71486]={"𩥸"}
	a[71490]={"䯈","瓺","𦢫","𪕀"}
	a[71491]={"𡲽"}
	a[71493]={"𩘀","𩣘"}
	a[71494]={"飃","𩗸","𩙖"}
	a[71501]={"敺","𠪘","𢾻","𪕔"}
	a[71502]={"𩩄","𩩹"}
	a[71503]={"䐺","𥀬","𩥐"}
	a[71504]={"斅","骾"}
	a[71505]={"𠪷"}
	a[71512]={"𢅼","𦖫"}
	a[71513]={"厴","𣀻","𦣀","𩦎"}
	a[71515]={"䯀","驔"}
	a[71517]={"𣁀"}
	a[71521]={"","𠨹","𡕒"}
	a[71531]={"厈","𠨺","𠩋","𠩹","𠬡","𢼱","𨸶"}
	a[71532]={"㕃","𠨭","𠩀","𢁗","𢁵"}
	a[71541]={"厗","𠨻"}
	a[71542]={"㕅","㪆","𠩍","𢻼"}
	a[71543]={"厍","皯","𠨵"}
	a[71551]={"厰","肝","胓","𠩒","𠩴","𢻰","𢻷","𢼀","𢼐","𢽜","𦜒","𧱔"}
	a[71552]={"䑞","𠩢","𠩯","𠩶","𠪔","𡕣","𡝌","𢼞"}
	a[71553]={"䭴","厣","𠩲","𡡕"}
	a[71554]={"馵"}
	a[71555]={"𢃽"}
	a[71561]={"㕏","𠩰","𢼖","𢼧"}
	a[71562]={"𠪇","𠪭","𢾂","𦕌"}
	a[71563]={"䮆","厫","馯","駍","𩡸"}
	a[71564]={"馽","𩢏"}
	a[71565]={"厙","𤿬"}
	a[71566]={"𠩿"}
	a[71571]={"㪒","䏪","厦","𠪀","𦚺"}
	a[71572]={"𠩻","𠪚","𠪯","𢽧","𢾯"}
	a[71573]={"㪢","𠪣","𣀥"}
	a[71574]={"腰","𦛟"}
	a[71575]={"𡠷"}
	a[71581]={"䶄","骭","𠪅","𠪮","𡲠","𢽢","𢽩","𢾌","𦕁","𦜰","𪔿"}
	a[71582]={"𠪫","𠪬","𦞬","𪔾"}
	a[71583]={"駬","𠪳"}
	a[71584]={"𢅀","𩤳"}
	a[71586]={"騕"}
	a[71591]={"㪞","𦞶"}
	a[71592]={"敯","𢅠","𦖞"}
	a[71593]={"䮓","嬮","𨲀"}
	a[71594]={"𩤾"}
	a[71600]={"䢈","𦟧"}
	a[71602]={"𨼐"}
	a[71603]={"䮠"}
	a[71611]={"靨","鼯","𥌅","𦠝","𧫜","𩩑","𪕲"}
	a[71612]={"䐶","𤳪"}
	a[71613]={"驑","𠫁"}
	a[71614]={"驦","𥀸"}
	a[71630]={"𠩛"}
	a[71632]={"𠩌"}
	a[71640]={"㕉","贴","𠩡","𠪞","𣅛","𥐖"}
	a[71641]={"㕆","帖"}
	a[71642]={"䧈"}
	a[71650]={"𠥀","𠩊","𥐘"}
	a[71651]={"帞"}
	a[71652]={"𧯏"}
	a[71653]={"𠪄"}
	a[71660]={"唇","胋","脴","𠵧","𦚈"}
	a[71661]={"厢","𠩮","𠪐","𢃮"}
	a[71662]={"厝","暦","曆","磿","𠩚","𦚵","𩡳"}
	a[71664]={"𠕟"}
	a[71670]={"㫳","𠪃","𦜷","𦟢"}
	a[71671]={"厬","靥","𣍽","𥕳"}
	a[71672]={"幅","𩣚"}
	a[71680]={"脜","腼","𨱬"}
	a[71681]={"䏸"}
	a[71682]={"𠪡","𩢷"}
	a[71683]={"𩤹"}
	a[71690]={"鼫","𪕐"}
	a[71691]={"腷","𦟕"}
	a[71693]={"䮏"}
	a[71696]={"𨡶","𩣙"}
	a[71700]={"𩪲"}
	a[71701]={"䐴","𩪜","𩪰"}
	a[71702]={"𩤬"}
	a[71703]={"擪","𥀭"}
	a[71711]={"臑","𣎩","𪄵"}
	a[71712]={"𦢚"}
	a[71714]={"𩦣"}
	a[71716]={"驫","𠫑","𩧢"}
	a[71717]={"𧥚","𩧃"}
	a[71720]={"厅","厕","𠩄"}
	a[71721]={"历","帄"}
	a[71730]={"厉","𤇟"}
	a[71731]={"厊","𠨯","𠩉"}
	a[71732]={"𠨾","𠩪","𤿆"}
	a[71740]={"𣃞","𦘭","𨺂"}
	a[71741]={"厒","𡴈"}
	a[71742]={"馬","","𠟄","𠪺","𢁢"}
	a[71743]={"𠨼","𦠩"}
	a[71750]={"厠","胹","胻","𦘰"}
	a[71751]={"䏏","脼","辱","𠩝","𠩞","𣍪","𣍷","𣍾"}
	a[71752]={"𠢤","𠪂","𩡯"}
	a[71754]={"㕊","𠩨"}
	a[71755]={"𦢈"}
	a[71756]={"𩡧"}
	a[71760]={"㕐","肟","胢","鳫","鴈","𠵲","𡸡"}
	a[71761]={"㕌","䢆","厚","厨","𠩭"}
	a[71762]={"𠪠","𦠓","𩢓"}
	a[71763]={"𠪆","𢴺"}
	a[71764]={"𤯍"}
	a[71770]={"脣","𠪋","𦠌","𩨑"}
	a[71771]={"𠡿","𠪦","𦞹","𦠒","𨑅"}
	a[71772]={"㕑","㡡","騭","𪙪"}
	a[71775]={"厲","镾"}
	a[71780]={"䯒","膈","𦜨","𦜶"}
	a[71781]={"膤","骬","𠪟","𩨠"}
	a[71782]={"𩱔","𪅼"}
	a[71783]={"𢅥","𩣹","𩥖","𪓍"}
	a[71784]={"騳","𩥋"}
	a[71790]={"䯊","𪙇","𪙌"}
	a[71791]={"鷢","𨽚","𩨗"}
	a[71792]={"䮥","𩤐"}
	a[71797]={"𠪲"}
	a[71800]={"䫚","䫤","贗","𩕮"}
	a[71801]={"䫒","𩒑","𩓔","𩔲","𩪗"}
	a[71802]={"䫲"}
	a[71810]={"仄","顝","𠫍","𨲙","𩔡","𩔸","𩕁","𩕿","𩖄","𩖒","𪕚","𪕯"}
	a[71811]={"䫗","䫢","𩔉"}
	a[71812]={"𩖑"}
	a[71813]={"𩥰"}
	a[71814]={"𩦢"}
	a[71815]={"顐"}
	a[71820]={"𠩦","𠪌"}
	a[71821]={"厌","𠩘","𠩾"}
	a[71830]={"颀","𠩗"}
	a[71831]={"帧","𠨮","𠩱","𠪁","𥎦"}
	a[71832]={"㷴","𠨶","𠪛"}
	a[71840]={"𣅦","𣥉","𦙻"}
	a[71841]={"厥"}
	a[71842]={"颇","𠩼","𢃾","𤈲"}
	a[71843]={"𡙽"}
	a[71844]={"𠩷"}
	a[71850]={"顾","𠩠"}
	a[71851]={"𠪢","𡘡"}
	a[71852]={"㷳","𠪴"}
	a[71853]={"㿵"}
	a[71860]={"厱","頎","颐","𤑤"}
	a[71861]={"幀","幁","腝","𠩩"}
	a[71862]={"赝","𩒃"}
	a[71863]={"𠪙"}
	a[71864]={"𤟐"}
	a[71870]={"𠪗","𤋝","𩑏","𩑝","𩒒","𩒣","𩓒"}
	a[71871]={"䪴","厧","幊","蹷","𦠑","𩑥","𩑾","𩒜"}
	a[71872]={"䫆","頗"}
	a[71873]={"𠪝"}
	a[71874]={"𩒄"}
	a[71880]={"䐓","頋","𣣾","𩑜","𩒥","𩓥"}
	a[71881]={"厭","𩓃"}
	a[71882]={"顣"}
	a[71883]={"𩦒"}
	a[71884]={"𩑞","𩑺"}
	a[71890]={"䪶","䫀","䫃","頣","頤","願","𩑼","𩒗","𩒦","𩒫","𩓆"}
	a[71891]={"䪸","𩒲","𩓦","𩔟"}
	a[71892]={"贋","顑","𩕠"}
	a[71894]={"𩦈"}
	a[71910]={"厵","𠫐","𠫒"}
	a[71912]={"𩪊"}
	a[71917]={"䯂","𥤡 "}
	a[71920]={"𣱷"}
	a[71921]={"𠩬"}
	a[71930]={"𠩏"}
	a[71932]={"厤","","𠩵"}
	a[71940]={"原","肧","𠩤"}
	a[71941]={"𣐃"}
	a[71942]={"𡭳"}
	a[71950]={"䏡","厡","𠪥","𥘐"}
	a[71952]={"橜"}
	a[71953]={"𠪓"}
	a[71962]={"㮣"}
	a[71963]={"幖"}
	a[71970]={"䦊"}
	a[71973]={"𠫃","𦞰","𩤋"}
	a[71974]={"𠫋"}
	a[71981]={"𦃢"}
	a[71982]={"䊠","槩","膘","騵"}
	a[71992]={"檿"}
	a[71994]={"驃"}
	a[71995]={"𩧌"}
	a[72010]={"鬜","鬝"}
	a[72030]={"𦘶"}
	a[72041]={"𦙢"}
	a[72042]={"馴","駲"}
	a[72060]={"䏖"}
	a[72100]={"𩮖","𩯇"}
	a[72101]={"𩬹","𩮎"}
	a[72102]={"䰈","𩮲","𩮴","𩯺"}
	a[72103]={"𩭇","𩯬"}
	a[72104]={"𩮞"}
	a[72105]={"𩩞"}
	a[72110]={"䰐","","𨲦","𩭯","𩯤"}
	a[72111]={"䯗","𩮢"}
	a[72112]={"䰔","䰕"}
	a[72115]={"𩩳"}
	a[72116]={"𦣂"}
	a[72120]={"丘","","𠀉"}
	a[72121]={"坕"}
	a[72130]={"𠀈"}
	a[72131]={"𣂓"}
	a[72132]={"𢂧"}
	a[72140]={"𠂩"}
	a[72141]={"𡊣","𡌌"}
	a[72151]={"䏕","垕"}
	a[72152]={"𩣌","𩦁"}
	a[72160]={"𡲌"}
	a[72161]={"㡠","𦣨"}
	a[72162]={"駈","𦡘"}
	a[72170]={"䰃","髬","𥪨","𩬡","𩬬","𩬾"}
	a[72171]={"髽","𡏐","𩫽"}
	a[72175]={"腄"}
	a[72176]={"㡖"}
	a[72180]={"膯","𩬣","𩭙","𩭴","𩯸"}
	a[72181]={"䏶","𩬎"}
	a[72182]={"𨲚"}
	a[72183]={"髰"}
	a[72185]={"𦥻"}
	a[72187]={"䮔"}
	a[72190]={"䯶","𩪳","𩮗"}
	a[72192]={"䮴","𩯎"}
	a[72195]={"腫","𨲉","𩭦"}
	a[72200]={"斲","","","𠂆"}
	a[72202]={"斸"}
	a[72210]={"斤","","𠂋","𠂑","𣂥"}
	a[72211]={"𢁘"}
	a[72212]={"𪖉"}
	a[72220]={"乒","斦",""}
	a[72221]={"㠼"}
	a[72222]={"彤"}
	a[72230]={"所","肜"}
	a[72240]={"肵"}
	a[72250]={"䏒","䯯","䯰","髟","𣂜","𩫾","𩬖"}
	a[72251]={"彫","𣃋"}
	a[72252]={"馸"}
	a[72260]={"髿"}
	a[72262]={"䏳","𦠀","𩢝"}
	a[72270]={"𣂤","𣃃","𦠔"}
	a[72273]={"𣃁"}
	a[72274]={"𩣩"}
	a[72280]={"鬖","𢒵","𩬟","𩬵"}
	a[72281]={"膨","𦠠","𩮅"}
	a[72282]={"𦠟","𦠭"}
	a[72290]={"斵","𣂻"}
	a[72300]={"爪","","","","𤓰","𤔙","𤬑","𩭨"}
	a[72302]={"𧔤"}
	a[72304]={"鬔"}
	a[72310]={"瓜","鬟","𠂢","𦣛","𧞐"}
	a[72311]={"𢁤","𢁬","𢗪"}
	a[72313]={"𩯲"}
	a[72314]={"鬞","鬤","𩪱"}
	a[72320]={"㼌","乓","贬","𠃄","𢗹"}
	a[72321]={"𤇡"}
	a[72330]={"𥁔"}
	a[72331]={"账"}
	a[72332]={"帐"}
	a[72340]={"胍","脈","𢇏","𦘯"}
	a[72341]={"𤫵"}
	a[72342]={"𨹤","𩡬"}
	a[72350]={"𤌩","𦘷","𩬐"}
	a[72351]={"胀"}
	a[72352]={"𩢍"}
	a[72353]={"𧉜"}
	a[72360]={"䯳","𩨢","𩬔","𩭐"}
	a[72361]={"𢤐","𦜙"}
	a[72362]={"𣱋"}
	a[72370]={"𩨶","𩭤","𩭳","𩯙"}
	a[72371]={"㡥","鬆","𩭑"}
	a[72372]={"𩮀","𩮰"}
	a[72380]={"懸","𩮡","𩯑"}
	a[72382]={"𧌟","𩭃"}
	a[72384]={"臐"}
	a[72385]={"𧎪","𧐏"}
	a[72391]={"䰄","𤬡"}
	a[72392]={"䰒","𩯗"}
	a[72393]={"𩮚","𩺄"}
	a[72394]={"𩮪"}
	a[72397]={"鬑"}
	a[72400]={"","𩯕"}
	a[72402]={"㲯","毷","𩘗","𩯈"}
	a[72403]={"𣮱","𩤽"}
	a[72404]={"𩯰"}
	a[72407]={"𢁎"}
	a[72408]={"𣰝"}
	a[72410]={"脁","","𣰢","𩮷","𩰀"}
	a[72411]={"鼶","𠨬","𩰃"}
	a[72412]={"𨲝","𩯩","𩰁"}
	a[72413]={"𣱄","𦢍","𩯆","𩯶"}
	a[72414]={"𩯋","𩰅"}
	a[72415]={"䰏"}
	a[72416]={"膬"}
	a[72420]={"𠃘","𠖒","𠨗"}
	a[72421]={"㠲","氏","氐",""}
	a[72430]={"卮","𠂘","𠂬","𠂮","𠃤","𢀴"}
	a[72431]={"沊","𤫯"}
	a[72440]={"乺","巵","𠑿","𠜍"}
	a[72441]={"𢁦"}
	a[72442]={"颩","𢂮","𣯅"}
	a[72450]={"朓","𢒝","𦙜","𦡳"}
	a[72451]={"胝","𤬕","𦘴","𦙆"}
	a[72452]={"𣱎","𩖱"}
	a[72453]={"䬆","𣮥","𩗞"}
	a[72460]={"肶","𦚚","𦛐","𧠨","𩮻"}
	a[72461]={"虒","𣃅","𦜘","𩫷"}
	a[72462]={"颲","駣","𣬮","𣭼","𩗦","𩘃","𩘛","𩬕"}
	a[72463]={"馲","𩗱"}
	a[72464]={"騛"}
	a[72465]={"䬐"}
	a[72466]={"𣬭"}
	a[72470]={"䯆","髠","髡","𨚬","𨱵","𩫻","𩬌","𩬱"}
	a[72471]={"臘","髧","𢅃","𨱡","𩫴","𩬁","𩭒"}
	a[72472]={"㡗","髢","𣭽","𦠼","𩗇","𩢭","𩣤","𩬤"}
	a[72473]={"䬙","䯷","颳","𣮵","𩗮"}
	a[72474]={"䫽","䭷","𩗙","𩗝","𩭝"}
	a[72475]={"𩘊"}
	a[72480]={"䯲","髨","髭","𦞡","𨱲","𩬈"}
	a[72481]={"骶","𨱷","𩨛"}
	a[72482]={"髦","𨱞","𩙑","𩧆"}
	a[72483]={"𦠄","𩣛"}
	a[72484]={"㲣","𩤗","𩬲"}
	a[72485]={"𩘉"}
	a[72487]={"𩗰","𩙵"}
	a[72490]={"骴","髱","𩨨","𩬛","𩯡","𪕑"}
	a[72491]={"鬛","鬣","𩬜","𩬰"}
	a[72492]={"䮭","鬈","𣮮","𩘈","𩘼","𩮊","𩮏","𩮓","𩯓"}
	a[72493]={"䬟","𩙗","𩮄"}
	a[72495]={"𡳲","𩦋"}
	a[72501]={"䯹","𩭟","𩮉"}
	a[72502]={"䯕","䰉","䰋","鼮"}
	a[72503]={"𩮙","𩮯"}
	a[72506]={"𩬶"}
	a[72511]={"反","斥","鬘","𣂑","𩯌","𩯛","𪖆"}
	a[72512]={"𩮾","𩯻","𩰆","𪕽"}
	a[72513]={"驋","𩰇"}
	a[72514]={"𩯍"}
	a[72521]={"贩","𣂙"}
	a[72531]={"","𢁹"}
	a[72532]={"帋","氒","𠦛"}
	a[72533]={"乕"}
	a[72541]={"𠬿","𦙀"}
	a[72542]={"脮","𦡝"}
	a[72552]={"朡","𣍶","𦡙","𩬃"}
	a[72553]={"帲","腇","𩡴"}
	a[72554]={"𩢚"}
	a[72561]={"䯭","𩫹"}
	a[72562]={"䐘","𩭏"}
	a[72563]={"𩢈"}
	a[72564]={"騣","𩦲"}
	a[72571]={"䯿","脠","𩨩","𩨯","𩫿","𩬒","𩬓","𩬴","𩬸","𩮃"}
	a[72572]={"脡","腁","骽","髪","髮","髲","鬉","𨱩","𨱳","𨲔","𩬋","𩯣"}
	a[72573]={"䯵","䰀","𩭉"}
	a[72575]={"𩥴"}
	a[72581]={"䯴","𠭙","𩭾"}
	a[72582]={"㡪","鬀"}
	a[72583]={"駳","𩮫"}
	a[72584]={"騈"}
	a[72586]={"髴","𩭬"}
	a[72591]={"髶","𩭢"}
	a[72592]={"𩮤","𩯉"}
	a[72593]={"𩭧"}
	a[72594]={"髼","𩮸"}
	a[72600]={"䭮","鬙","𩭈"}
	a[72601]={"𩩎"}
	a[72602]={"䰇","𩤠","𩭓","𩭡","𩮈","𪖇"}
	a[72604]={"𦡅","𨢏"}
	a[72610]={"鬠","𩩰","𩯠"}
	a[72611]={"𩩻","𩭺","𩯅","𩯢","𩰂"}
	a[72612]={"鬐","𩠷","𩭱","𩯼"}
	a[72613]={"鬊","𩮝"}
	a[72614]={"𩯐"}
	a[72615]={"𩠫"}
	a[72630]={"后","𠯓"}
	a[72631]={"𦧍"}
	a[72640]={"啠"}
	a[72641]={"䞌","𠯑"}
	a[72642]={"𦧘"}
	a[72650]={"𣍬"}
	a[72651]={"昏","盾","腦","𢃕"}
	a[72653]={"㿳","幡"}
	a[72661]={"䏦","䐉","𥄇"}
	a[72662]={"㡒"}
	a[72663]={"𩤘"}
	a[72670]={"脂"}
	a[72671]={"𦞉"}
	a[72672]={"膰"}
	a[72680]={"髫","𩬑","𩬠","𩭍","𩮠"}
	a[72681]={"腯","髺","𩬼","𩭋"}
	a[72682]={"𩣯"}
	a[72684]={"䮳","髷"}
	a[72690]={"䯽","骺","𦝨","𩠞","𩠢","𩬞","𩬺","𩭣"}
	a[72691]={"䯏","䯺","䯻","髻","𩭰","𩭻","𩭽"}
	a[72692]={"𦞖","𩮟"}
	a[72696]={"𨢹"}
	a[72700]={"鬡","𩩼","𩭊","𩭠","𩭥","𩮂","𩮑","𩮬"}
	a[72701]={"䯾","𢆂"}
	a[72703]={"驕"}
	a[72705]={"䰊"}
	a[72710]={"㓹","䯚","䰓","则","鬅","","","𠛒","𠛧","𩭿","𩮘","𩯪"}
	a[72711]={"䰑","刚","鬌","鬍","𨲭","𩮺","𩯘","𩯚","𩯾"}
	a[72712]={"𠛔","𨲰","𩯝","𩯦"}
	a[72713]={"𩧒","𩮱","𩯄","𩯜","𩯧"}
	a[72716]={"𠠮"}
	a[72720]={"戶","","𠚾","𠛓","𠛾","𠝴"}
	a[72721]={"𠛅","𠛊"}
	a[72722]={"㓟","刐","𠝾","𦛷"}
	a[72724]={"刪"}
	a[72730]={"刖","剛","岳","","𠛋","𠛰","𠛵","𠜛"}
	a[72731]={"刷","剁","𠚹","𡥭","𢂥"}
	a[72732]={"𨸴"}
	a[72733]={"𠂰","𢁺"}
	a[72734]={"删"}
	a[72738]={"𠜂"}
	a[72740]={"㐆","刞","𠜃","𠝑","𦛁","𦥝"}
	a[72741]={"刡","劂","孵","脟","脷","𠂣","𠜜","𠜾","𤬔","𦙞"}
	a[72742]={"𠝭","𢮣"}
	a[72744]={"𦢣"}
	a[72748]={"𠛹"}
	a[72750]={"剮"}
	a[72751]={"㓮","剧","劉","幍","脬","𠞂"}
	a[72752]={"㓾","𠠝","𩣃","𩣫","𩥨"}
	a[72753]={"䮑","𤯁","𨺲"}
	a[72760]={"劕","𠜳","𦚌","𩫶","𩫺","𩬉","𩬷"}
	a[72761]={"剭","鬁","𠞄","𦞼","𩫸","𩬀","𩬙","𩬳","𩿔"}
	a[72762]={"䮋","𣎂"}
	a[72763]={"㔉","𢅚","𦜋","𦞿","𩤪"}
	a[72770]={"㔋","䯮","髣","髳","髵","𢑚","𦢕","𩩀","𩭔"}
	a[72771]={"𩬝","𩬢","𩭫","𪕉"}
	a[72772]={"𢄹","𩦰 ","𩬅","𩭘"}
	a[72773]={"𦞇","𩥣"}
	a[72775]={"𠠏","𩤲","𩯨"}
	a[72780]={"剾","髩","髾","𠠇","𩬆","𩬏","𩮇"}
	a[72781]={"𠠧","𦝥","𩬗","𩭎"}
	a[72782]={"𦡓","𩥅","𩬚","𩬮"}
	a[72783]={"鬎","鬗","𠟉"}
	a[72784]={"髥","髯","𩬍","𩬥"}
	a[72790]={"㓸","鬄","鬋","𨲞","𩭅","𩭲","𩮆","𩮒","𩮜","𩮮","𪃻"}
	a[72791]={"𦠚","𦣅","𦦈","𩭪"}
	a[72792]={"劚","𩭛","𩮣"}
	a[72793]={"䮢","鬇","𩮐"}
	a[72794]={"𩦠"}
	a[72800]={"䰅","鬚","𩪇"}
	a[72802]={"𩧄","𩪛","𪖈 "}
	a[72803]={"鬕"}
	a[72804]={"𩮁","𩯒"}
	a[72810]={"鬢","𩯫","𩯿"}
	a[72811]={"鬒"}
	a[72812]={"䰎","䰖"}
	a[72813]={"𩯽"}
	a[72814]={"𩯳"}
	a[72815]={"驥"}
	a[72816]={"𩮽","𩯃"}
	a[72820]={"兵","𠔊"}
	a[72821]={"质"}
	a[72822]={"𢁱"}
	a[72842]={"𢃯","𩥗"}
	a[72850]={"𦛼","𩫵","𩬊"}
	a[72851]={"䯼","貭"}
	a[72853]={"幞","𩡻"}
	a[72860]={"䰌","質","𩬂"}
	a[72861]={"膎","镺","鬏","𦝢","𩬇","𩭌"}
	a[72870]={"䯸","鬂","𩬫"}
	a[72872]={"髸","𩬭"}
	a[72873]={"騤","騱"}
	a[72874]={"𩤻"}
	a[72880]={"鬓"}
	a[72882]={"䑑","𦢂"}
	a[72890]={"䑇"}
	a[72891]={"鼷"}
	a[72892]={"𩯏"}
	a[72893]={"𩮶"}
	a[72900]={"⺥"}
	a[72901]={"𩮹"}
	a[72902]={"𩪤","𩮳","𪖊"}
	a[72903]={"𩪑"}
	a[72910]={"𦣋"}
	a[72911]={"䑈","乐","𥝌","𩯟"}
	a[72912]={"𩯱"}
	a[72913]={"𩧂"}
	a[72920]={"阥"}
	a[72930]={"𤫺"}
	a[72931]={"𥾩"}
	a[72940]={"𦆩","𦙙","𦚝"}
	a[72941]={"䐆","𣍩"}
	a[72950]={"𩬯"}
	a[72953]={"㡤"}
	a[72960]={"䯱","𩬘"}
	a[72961]={"䰂","髤","髹","𨲁","𩭄","𩭷","𩮥"}
	a[72964]={"𩦀"}
	a[72970]={"縣"}
	a[72971]={"䰍","𦟇","𩬻","𩬽"}
	a[72972]={"𦡧","𩥷"}
	a[72973]={"𦟳","𩧖"}
	a[72980]={"鬃","𩩌"}
	a[72981]={"䰆","𩭚","𩭼"}
	a[72982]={"𦢦"}
	a[72983]={"騬"}
	a[72984]={"驜"}
	a[72990]={"䰁"}
	a[72991]={"𩮛","𩯊"}
	a[72992]={"𩯞"}
	a[72994]={"𩭞","𩭩"}
	a[73022]={"𢁽"}
	a[73040]={"卧"}
	a[73041]={"䏟","胁"}
	a[73053]={"駜"}
	a[73060]={"𩨓"}
	a[73101]={"𠥸","𢅒"}
	a[73102]={"䶆","璧","臃","鐾","𤩹","𨲨","𩀜"}
	a[73103]={"朣","𥽱"}
	a[73104]={"𩀀"}
	a[73105]={"𩦼"}
	a[73110]={"膻","𨲵"}
	a[73112]={"驙","𩀫"}
	a[73113]={"𩀃","𩁊","𩪘"}
	a[73115]={"䮵"}
	a[73131]={"𢁣"}
	a[73133]={"𡋊"}
	a[73142]={"盛"}
	a[73150]={"䏠"}
	a[73153]={"帷"}
	a[73161]={"𥁾","𦙴","𦞟"}
	a[73162]={"隡","𨾋"}
	a[73163]={"䧵","𨾛","𨾦"}
	a[73172]={"脽","𣹹"}
	a[73173]={"駐"}
	a[73175]={"𨾥"}
	a[73182]={"䐮","雎","𨾹"}
	a[73183]={"膧","𨾧"}
	a[73184]={"幢","騅","𩦝"}
	a[73191]={"𣦢","𩨻"}
	a[73192]={"壁","𨲈"}
	a[73193]={"雕","𩀐"}
	a[73194]={"𩥤","𩥮"}
	a[73232]={"㡎"}
	a[73241]={"幓","脐"}
	a[73261]={"䶓"}
	a[73272]={"驂"}
	a[73280]={"臍","𩩷"}
	a[73291]={"𣩩"}
	a[73292]={"䮺"}
	a[73302]={"𧲜"}
	a[73304]={"𤬞"}
	a[73310]={"𩪣"}
	a[73312]={"𨳀","𩧝"}
	a[73314]={"䑋","𨳃"}
	a[73316]={"驤"}
	a[73321]={"㼎"}
	a[73322]={"𤌔"}
	a[73323]={"㥻"}
	a[73331]={"𢂩"}
	a[73340]={"𢛶","𤫳"}
	a[73341]={"𢂄","𢜑"}
	a[73342]={"慼"}
	a[73351]={"𢄴","𦣥"}
	a[73352]={"感","𩡼"}
	a[73353]={"㸕","𢄺"}
	a[73357]={"𤬚"}
	a[73360]={"胘","𦠤","𦠨"}
	a[73364]={"𧐶"}
	a[73368]={"𢅖"}
	a[73370]={"𦠸"}
	a[73371]={"㡉","𩨲"}
	a[73372]={"䮄","膲"}
	a[73378]={"𢅳"}
	a[73380]={"䭆","𨲱"}
	a[73381]={"憵"}
	a[73382]={"𦣳"}
	a[73383]={"𧌌"}
	a[73384]={"𢤖"}
	a[73386]={"𩦪"}
	a[73390]={"臆","𩨬"}
	a[73391]={"襞"}
	a[73401]={"䖙","膩"}
	a[73402]={"䬘","𩩴"}
	a[73404]={"𩯷"}
	a[73405]={"𨲹","𩥳","𩦤"}
	a[73407]={"𩦷"}
	a[73411]={"甓","鼊"}
	a[73412]={"䑉","䑎","戊","戍","𢘱","𤋆","𩦳","𪖎"}
	a[73413]={"𦢙","𩧣"}
	a[73414]={"䯁","𩧑"}
	a[73415]={"𪖋"}
	a[73416]={"驖","𩧀"}
	a[73421]={"𢁲"}
	a[73422]={"戉","戌","成","烕","𢦓","𢦲"}
	a[73432]={"戚","𢦹","𤬹"}
	a[73433]={"贱","贼","𢄅","𢦡","𢦩","𩙥"}
	a[73434]={"威","𢧓"}
	a[73435]={"帴","𢂵"}
	a[73441]={"㡆",""}
	a[73442]={"咸","𠧮","𢂑","𢦽","𢧒"}
	a[73445]={"𢧯"}
	a[73450]={"𦚳"}
	a[73451]={"㢥","肬","脦","赋"}
	a[73452]={"䏵","戙","胧","𢦿","𦛙","𦣣"}
	a[73453]={"䫾","𡲈","𢃎","𢅪","𩖮","𩖰","𩗒"}
	a[73454]={"䏼","䮅","駹","𩢅"}
	a[73456]={"𢧦"}
	a[73460]={"肮"}
	a[73461]={"𦥣"}
	a[73462]={"䬃","馻","𢧘","𦟠"}
	a[73463]={"㦺","幟","駀","𡳔","𢧕","𢧿","𩖶","𩗕","𩗶"}
	a[73464]={"䬂","䬄","颰","𩣊"}
	a[73465]={"駥"}
	a[73466]={"駴","騀","𩤊"}
	a[73471]={"腻","骮","𩙮"}
	a[73472]={"䭺","颱","𡲼","𣍻","𦢑","𩗁","𩗬"}
	a[73473]={"𦞁","𨱿","𩗎","𩘱"}
	a[73474]={"𠙤","𩥼"}
	a[73475]={"飇"}
	a[73481]={"𠒱","𠙮","𠙱","𦠢"}
	a[73482]={"䬏","膱","𢄽"}
	a[73484]={"䬎","䬜","䮙","𩤥"}
	a[73486]={"𩤭"}
	a[73487]={"𢧰"}
	a[73490]={"骯","𦠦","𩩁","𪕇"}
	a[73492]={"䬓"}
	a[73493]={"㡨","𢨛","𦠾"}
	a[73501]={"䑀","𦡍","𨐫"}
	a[73503]={"騿","𨐴"}
	a[73506]={"𢅻"}
	a[73511]={"𩪧"}
	a[73521]={"𨹍"}
	a[73531]={"脧"}
	a[73532]={"𢃒"}
	a[73533]={"帗"}
	a[73541]={"㬵","胶"}
	a[73543]={"帹"}
	a[73551]={"朘","脺","腋"}
	a[73552]={"胈"}
	a[73553]={"馼","駮"}
	a[73554]={"𡞣"}
	a[73561]={"腣","𦛛","𨐛"}
	a[73562]={"䏬","𦟨"}
	a[73563]={"駿","𩤏"}
	a[73564]={"䮁","䮂"}
	a[73571]={"辟","骹","鼤","𨲄"}
	a[73572]={"䢃","幛"}
	a[73573]={"瞂","騂","𩣰","𩤢"}
	a[73581]={"膟","𩩠","𪕞"}
	a[73582]={"䯋","幦","鼥","𠮃"}
	a[73583]={"嬖","𦞠","𨐢"}
	a[73584]={"𩤑"}
	a[73591]={"𨐧","𪕬"}
	a[73595]={"𨐨"}
	a[73601]={"礕"}
	a[73611]={"譬","𩪙"}
	a[73612]={"𩪟","𩪩"}
	a[73631]={"𣍵"}
	a[73640]={"贻"}
	a[73650]={"赔"}
	a[73652]={"㗤"}
	a[73660]={"胎","𦜟"}
	a[73661]={"𢄈","𦜵"}
	a[73670]={"䏽"}
	a[73672]={"駘","𥠻","𥡞"}
	a[73673]={"𩣖","𪉳"}
	a[73680]={"腤","𧦗"}
	a[73681]={"膪"}
	a[73690]={"䛗","𧧃"}
	a[73700]={"髈"}
	a[73701]={"臂","𢐦"}
	a[73702]={"䮦","臇","𪖂"}
	a[73704]={"䯙"}
	a[73710]={"髇","𣎪","𩩣"}
	a[73711]={"鷿"}
	a[73714]={"𩦩"}
	a[73715]={"䶈","髆"}
	a[73750]={"肪"}
	a[73751]={"脑","𢄎"}
	a[73752]={"㞝"}
	a[73760]={"𣂴"}
	a[73764]={"𠃃"}
	a[73765]={"赙"}
	a[73766]={"𤿭"}
	a[73770]={"脝","膀"}
	a[73771]={"𦜢"}
	a[73774]={"脯"}
	a[73780]={"𦝑","𦝞","𩨣","𪕃"}
	a[73781]={"䐱","劈","朜","𨐯"}
	a[73782]={"䶠","騯","𦡜","𩢺","𩥔"}
	a[73784]={"觱","𩥬"}
	a[73785]={"膊","𠪻"}
	a[73786]={"䮒"}
	a[73790]={"䐧"}
	a[73791]={"𣃐"}
	a[73792]={"䐪","孹","𦞾","𩤙"}
	a[73793]={"䮰","擘","𢵤"}
	a[73795]={"𦦐"}
	a[73801]={"躄"}
	a[73822]={"𤜧"}
	a[73823]={"𤝮"}
	a[73830]={"赅"}
	a[73841]={"肰"}
	a[73842]={"𤊸"}
	a[73850]={"胲"}
	a[73853]={"䭾","𩢰"}
	a[73862]={"蹙","駭","𤟢","𦚫"}
	a[73863]={"𦠎"}
	a[73870]={"骸"}
	a[73871]={"鼣","𪕟"}
	a[73873]={"騃"}
	a[73881]={"𤟶"}
	a[73891]={"𤴣"}
	a[73921]={"赇"}
	a[73951]={"脙"}
	a[73952]={"𦄉"}
	a[73961]={"𦜈"}
	a[73971]={"𦟅"}
	a[73972]={"𩥵"}
	a[73981]={"㵨"}
	a[73982]={"檗","糪"}
	a[73991]={"繴"}
	a[73995]={"䮶","𩦆"}
	a[74103]={"騜"}
	a[74113]={"𩥧"}
	a[74130]={"𧖴"}
	a[74141]={"赃"}
	a[74150]={"𦚡"}
	a[74161]={"脏"}
	a[74190]={"𦝻"}
	a[74211]={"䑄"}
	a[74212]={"𦣆"}
	a[74250]={"𦙅"}
	a[74262]={"馿"}
	a[74280]={"𢩗"}
	a[74300]={"䯖"}
	a[74302]={"𩦫"}
	a[74304]={"䮽"}
	a[74310]={"𩪀"}
	a[74312]={"𩪮"}
	a[74314]={"𩙢"}
	a[74315]={"𧕸"}
	a[74317]={"𩪬"}
	a[74331]={"䧭"}
	a[74352]={"幒","𣎗"}
	a[74361]={"𣍱"}
	a[74368]={"𢅏"}
	a[74370]={"朖"}
	a[74380]={"膇","𦞜"}
	a[74382]={"駺"}
	a[74383]={"驄","𩣴"}
	a[74387]={"臁"}
	a[74392]={"臕"}
	a[74400]={"𦣲","𩩕"}
	a[74403]={"䬖"}
	a[74404]={"騼"}
	a[74406]={"𩘜"}
	a[74410]={"𩩾"}
	a[74411]={"𩪅"}
	a[74412]={"𦤲","𩪁","𩪉"}
	a[74417]={"䶲","𪚮"}
	a[74431]={"㠶"}
	a[74441]={"𩙦"}
	a[74450]={"𪕎"}
	a[74451]={"𢂹"}
	a[74460]={"𦛮"}
	a[74462]={"㡙","𩖻"}
	a[74463]={"𢄊","𦞱"}
	a[74464]={"𩗋"}
	a[74472]={"𡳓","𦟟","𩗀"}
	a[74473]={"𩗭","𩤖"}
	a[74475]={"𩘙"}
	a[74481]={"膍"}
	a[74482]={"𦞙","𩗖","𩘘"}
	a[74485]={"𩗫"}
	a[74492]={"膔","𩘲"}
	a[74494]={"騩"}
	a[74502]={"𦢝"}
	a[74503]={"髀","𩩮"}
	a[74554]={"𢃍"}
	a[74562]={"𦟣"}
	a[74573]={"脾","𠕩"}
	a[74581]={"𥋜"}
	a[74582]={"𦞵","𦞷"}
	a[74591]={"𦟞"}
	a[74593]={"𠧅","𨲋","𩣸"}
	a[74606]={"𩥁"}
	a[74614]={"𪕹"}
	a[74641]={"帕"}
	a[74660]={"胉","𦞳"}
	a[74673]={"𩣢"}
	a[74682]={"𩤎"}
	a[74694]={"膅"}
	a[74700]={"䳭","䳮","鶂","𩨽","𪃷"}
	a[74701]={"䴙","鵩","鵰","鶋","鶞","鶹","","𪂆","𪃫","𪆱"}
	a[74702]={"騸","𪄡","𪆒"}
	a[74703]={"鶴"}
	a[74707]={"𦟛"}
	a[74710]={"鵬","鶥","鶻","鷗","𠥹","𨲾","𪃑","𪅉","𪇖","𪇬"}
	a[74711]={"鷉","鸊","𪃮","𪃯"}
	a[74712]={"鶠","鷵","𩩯","𪈺"}
	a[74713]={"𪅱","𪈔"}
	a[74715]={"鶤"}
	a[74740]={"𣂝"}
	a[74741]={"𪉄"}
	a[74750]={"鸤"}
	a[74751]={"腑","鸥","鸩","鸱","𢄓"}
	a[74752]={"𤬊"}
	a[74760]={"𩾨","𩾸"}
	a[74761]={"䲭","𢄦","𩿪"}
	a[74762]={"鹦","𩿰"}
	a[74764]={"𩢸"}
	a[74770]={"䏨","鳲","﨩","𩿨"}
	a[74771]={"鴆","鴎","鴟","","𢄒"}
	a[74772]={"䐔","鴅","𪁋"}
	a[74780]={"鴄","𩿊","𪀘"}
	a[74781]={"鹠","𦜛","𩿫","𪉎"}
	a[74782]={"𩿾","𪕄"}
	a[74783]={"䳇","幮","鹤"}
	a[74784]={"騙"}
	a[74790]={"䲿","䳎","鴡","鵖","鹏","鹘","鹛","𩿝","𪀭","𪁧","𪄁"}
	a[74791]={"䴘","鴖","鶌","𪁝","𪃪","𪆙"}
	a[74792]={"𨲜","𪂶"}
	a[74806]={"𩧉"}
	a[74842]={"𢃨"}
	a[74860]={"𦛤"}
	a[74861]={"𦜏"}
	a[74862]={"䐿"}
	a[74863]={"𢄨"}
	a[74894]={"𦢎"}
	a[74932]={"𢃅"}
	a[74950]={"脉"}
	a[74970]={"腺"}
	a[74982]={"騡"}
	a[74990]={"𩩺"}
	a[74992]={"髍"}
	a[75021]={"𣂀"}
	a[75031]={"肞","𠥿"}
	a[75041]={"𦙒"}
	a[75052]={"斞"}
	a[75061]={"𣁸","𣂄"}
	a[75101]={"𦠉"}
	a[75102]={"䯓"}
	a[75103]={"𢅣"}
	a[75105]={"𩥏"}
	a[75106]={"𩦘"}
	a[75107]={"𩥕"}
	a[75112]={"𡓗","𦢀","𩪄","𩪦"}
	a[75114]={"𩦽"}
	a[75142]={"𡍃"}
	a[75151]={"肚","𦙰"}
	a[75153]={"𠪜"}
	a[75162]={"胜","𢄍","𦛏"}
	a[75163]={"朑","𡏹"}
	a[75172]={"胿","𢃜","𦜣"}
	a[75175]={"𤦨"}
	a[75181]={"䐍","䐦","䦈"}
	a[75182]={"𦝧"}
	a[75184]={"𩣱"}
	a[75191]={"䐈","𥂠"}
	a[75192]={"鼪"}
	a[75193]={"𡐠"}
	a[75241]={"𦟬"}
	a[75261]={"䐒","𦝐"}
	a[75301]={"膸"}
	a[75302]={"臙"}
	a[75311]={"髄","髓","𦢪","𩪷"}
	a[75312]={"𩼐"}
	a[75313]={"𩦌"}
	a[75314]={"驠"}
	a[75315]={"𧕈"}
	a[75316]={"𦢔"}
	a[75317]={"𢅫","𦣘","𨳆"}
	a[75322]={"𦢬"}
	a[75331]={"䧀"}
	a[75332]={"瓞"}
	a[75341]={"肽","𤫸","𦞃"}
	a[75342]={"𢂴","𤫭","𦚒"}
	a[75343]={"𤫬"}
	a[75351]={"肱","𦚁","𦛘"}
	a[75353]={"駄"}
	a[75354]={"𣎨"}
	a[75361]={"䏯","慰","胠"}
	a[75362]={"䏝","","𤊯","𦜯"}
	a[75364]={"𩢕"}
	a[75365]={"𤬎"}
	a[75371]={"褽","𨲂"}
	a[75372]={"脿"}
	a[75373]={"䮃"}
	a[75376]={"𢄱"}
	a[75382]={"骵"}
	a[75383]={"螱","𦝏","𧏆"}
	a[75385]={"㿹"}
	a[75386]={"螴"}
	a[75392]={"𩻍"}
	a[75395]={"𦟪"}
	a[75396]={"𣎰"}
	a[75404]={"𩗼"}
	a[75407]={"𩘯"}
	a[75411]={"𠘰"}
	a[75413]={"膮","髐","𦠖","𩙇"}
	a[75414]={"䬞"}
	a[75415]={"驍","𩘤"}
	a[75417]={"𡳱","𩘹"}
	a[75418]={"𩘳"}
	a[75433]={"𢂢"}
	a[75441]={"𦘪"}
	a[75444]={""}
	a[75451]={"𦘳"}
	a[75452]={"𦚱","𩙭"}
	a[75453]={"䬊","屗","𩗆"}
	a[75454]={"𩖠","𩗉"}
	a[75455]={"𡳖","𩙧"}
	a[75462]={"䐠","肫","𦙛"}
	a[75463]={"䬉","𩖢"}
	a[75464]={"颫","𡲧","𦜽","𩖭","𩗄","𩢀"}
	a[75465]={"㡋","𩙯"}
	a[75473]={"駪","𡲨","𩘖"}
	a[75474]={"䬋","𡲥","𦞴","𩖤","𩖺"}
	a[75475]={"𣮳","𩗣"}
	a[75482]={"𦟩"}
	a[75483]={"飉","𩗊","𩘝"}
	a[75484]={"腌","𩗓"}
	a[75492]={"𪕅"}
	a[75493]={"𨱶","𩘧"}
	a[75494]={"臓"}
	a[75496]={"䬝","𩗷"}
	a[75497]={"𩗳","𩗴"}
	a[75503]={"臌"}
	a[75512]={"𠂔"}
	a[75515]={"𩩸"}
	a[75519]={"𦡐"}
	a[75522]={""}
	a[75523]={"𢂍","𦘽"}
	a[75532]={"𡊃","𢺼"}
	a[75533]={"𢁻"}
	a[75542]={"肗","胏"}
	a[75543]={"𢺾"}
	a[75544]={"帏","駁"}
	a[75552]={"肢","肺","𡜝","𦙓","𦚄","𦚬"}
	a[75553]={"脪"}
	a[75554]={"肼"}
	a[75562]={"䑔","𢻀","𣂊","𦣢","𦥥","𩨟"}
	a[75563]={"肨","膵","𡝪"}
	a[75564]={"䭽","䮮","馶","馷","𦛥","𦜭"}
	a[75566]={"𢃲"}
	a[75572]={"𨱜","𩨚"}
	a[75573]={"犚","𦝯"}
	a[75574]={"䮚"}
	a[75576]={"𩢲","𩣺"}
	a[75582]={"䐛","𩨝"}
	a[75583]={"𦞻","𨱺"}
	a[75584]={"𠁲","𩣡"}
	a[75585]={"䏾","䐙","䐭"}
	a[75586]={"𩣬"}
	a[75592]={"䐻","𩩃","𩩡"}
	a[75595]={"𨋺"}
	a[75602]={"𣎯","𨲘","𨲤"}
	a[75603]={"𤣘","𩥟"}
	a[75604]={"𦠛","𩥂"}
	a[75605]={"䮞","騞"}
	a[75606]={"䐬"}
	a[75613]={"𦢃","𩦇"}
	a[75651]={"𠷞"}
	a[75653]={"𤿛"}
	a[75661]={"𦙶"}
	a[75662]={"赌"}
	a[75663]={"帾","𢃟"}
	a[75671]={"㬶","𦛩"}
	a[75673]={"䞐","𩢪"}
	a[75674]={"𢄳","𤿸"}
	a[75681]={"𨼩","𪕖"}
	a[75682]={"䐗","腊"}
	a[75683]={"𩢴"}
	a[75687]={"㡟"}
	a[75691]={"骷","𨱻"}
	a[75692]={"𦞯","𦢁"}
	a[75693]={"䐏","𦠏"}
	a[75694]={"𩤈","𩤜"}
	a[75695]={"𢅯"}
	a[75698]={"𥀛"}
	a[75701]={"骻","𩩛"}
	a[75702]={"","𩪏"}
	a[75703]={"幬"}
	a[75704]={"𩩉"}
	a[75705]={"𡭐","𩦾"}
	a[75707]={"𢄣"}
	a[75711]={"䯝","𨲕","𩧜"}
	a[75712]={"鼱","𦡴","𦦰","𪕵"}
	a[75714]={"䮻"}
	a[75715]={"𩥫"}
	a[75718]={"𦪱"}
	a[75721]={"财"}
	a[75722]={"𢁜","𢂆"}
	a[75733]={"𤿋"}
	a[75741]={"肘","胕"}
	a[75743]={"𢂣"}
	a[75747]={"𡬥"}
	a[75749]={"𡬬"}
	a[75751]={"㷉","尀","尉","贿","𡬠","𡬡","𦝗"}
	a[75752]={"㡁","𣍫"}
	a[75753]={"駙"}
	a[75754]={"陦"}
	a[75755]={"帱"}
	a[75763]={"䐽","䮛","𦛨"}
	a[75765]={"䮎"}
	a[75771]={"䐀","胯","𦛒","𦜮"}
	a[75772]={"䞍","脖","腩","𣎙"}
	a[75773]={"𢃢","𢲴"}
	a[75774]={"𩢨"}
	a[75778]={"𢃶"}
	a[75779]={"㡚"}
	a[75782]={"𦡷","𨱫"}
	a[75783]={"騎","𩣋"}
	a[75791]={"𡬿","𦜤","𦝦"}
	a[75792]={"腈","鼭","𡭓"}
	a[75795]={"膞","𡦝","𡭍"}
	a[75798]={"䐟"}
	a[75801]={"贕"}
	a[75802]={"臜","𦟜"}
	a[75803]={"𥀲","𩥄"}
	a[75804]={"𪏍"}
	a[75811]={"𦢌","𦣶"}
	a[75812]={"臢","賾","𦣱","𨲪","𨳄"}
	a[75813]={"𩧈","𪖅"}
	a[75814]={"𦢤","𨲽"}
	a[75815]={"𩦥"}
	a[75822]={"𢁖","𢂿"}
	a[75833]={"㠸","帙","𢂔"}
	a[75841]={"脄","脥"}
	a[75842]={"赎","𡱛"}
	a[75843]={"㲳"}
	a[75851]={"熨"}
	a[75852]={"㬴","肤","胅","𣍰"}
	a[75853]={"帺","帻","馱"}
	a[75857]={"騻"}
	a[75861]={"𡬰","𦛣"}
	a[75864]={"䭿","𨺇"}
	a[75871]={"𩨿"}
	a[75872]={"镻","𦝁"}
	a[75873]={"𢅙"}
	a[75874]={"幩","胰","𦡛"}
	a[75876]={"䵊"}
	a[75877]={"𩧅"}
	a[75881]={"𨄯"}
	a[75882]={"赜","𣎧","𦣫","𩨰"}
	a[75883]={"幘"}
	a[75884]={"䐵","腠","騏"}
	a[75885]={"脻"}
	a[75886]={"䮊"}
	a[75891]={"䐜","𦢒"}
	a[75893]={"膹"}
	a[75894]={"𦦅","𪎼"}
	a[75895]={"䑖"}
	a[75896]={"䮲","𦟫"}
	a[75897]={"𩥲"}
	a[75901]={"𩪚"}
	a[75907]={"𦣌"}
	a[75914]={"驝","𦢭"}
	a[75916]={"𩧐"}
	a[75922]={"𤔅","𤔏"}
	a[75932]={"𦚜"}
	a[75933]={"帓"}
	a[75941]={"䏫","𣍿"}
	a[75942]={"脎"}
	a[75944]={"𢃿","𤿗"}
	a[75951]={"膝","𦡀"}
	a[75952]={"䏞","䏭","䑃","胨","𢄷"}
	a[75953]={"䮌","騋"}
	a[75954]={"𢃱"}
	a[75955]={"幉"}
	a[75961]={"𦝀"}
	a[75962]={"𦜔","𦥦"}
	a[75963]={"脨","𦜪"}
	a[75964]={"駯","𦢘","𩢖"}
	a[75965]={"𦜫"}
	a[75971]={"膫"}
	a[75972]={"𦡞"}
	a[75973]={"腜"}
	a[75974]={"䐑","腖"}
	a[75975]={"駷"}
	a[75982]={"膆"}
	a[75983]={"𩦚"}
	a[75985]={"䮪"}
	a[75986]={"䮜","𩣳"}
	a[75988]={"𢅿"}
	a[75991]={"镽"}
	a[75993]={"𩩥"}
	a[76012]={"𩪐"}
	a[76015]={"𣎫"}
	a[76032]={"䦿"}
	a[76041]={"𢁯"}
	a[76042]={"𢃠"}
	a[76050]={"𥄤"}
	a[76060]={"𦞢"}
	a[76061]={"㬷","䐃","胭"}
	a[76062]={"帼","𠺎"}
	a[76064]={"𦚼"}
	a[76070]={"䦉"}
	a[76071]={"𦝔"}
	a[76072]={"馹","駟"}
	a[76073]={"幗","駰","𩤁"}
	a[76074]={"駎"}
	a[76081]={"腘","𦛢"}
	a[76082]={"𩢱"}
	a[76090]={"𪕈"}
	a[76092]={"膕","鼬"}
	a[76104]={"𦡊","𩤵"}
	a[76110]={"䯠"}
	a[76112]={"臞","𢆀","𦣇","𪖏"}
	a[76113]={"𦡃"}
	a[76114]={"體","𩧘"}
	a[76117]={"𧖂"}
	a[76161]={"𧹓"}
	a[76164]={"𢃇"}
	a[76170]={"胆","膃"}
	a[76174]={"𧋗"}
	a[76180]={"腽"}
	a[76181]={"脭","𦛠"}
	a[76183]={"䤚"}
	a[76192]={"腥","𦢓","𩥈"}
	a[76193]={"𢅾","𧏔","𨑉"}
	a[76201]={"𩩚"}
	a[76271]={"𦜠"}
	a[76272]={"腗"}
	a[76292]={"𩤶"}
	a[76300]={"𦡹"}
	a[76301]={"𪕳"}
	a[76302]={"𩦮"}
	a[76304]={"膿"}
	a[76310]={"䯥","𤓑"}
	a[76311]={"𩪺"}
	a[76312]={"䑊","膙"}
	a[76331]={"𤔉"}
	a[76340]={"𤔑","𤫽","𤬒"}
	a[76341]={"䞏"}
	a[76352]={"𦜦"}
	a[76360]={"㼒"}
	a[76362]={"𤔩","𦚭"}
	a[76364]={"𧹗"}
	a[76370]={"𦡵"}
	a[76371]={"腮","𦞗"}
	a[76372]={"𢠬","𣎚","𪕕"}
	a[76373]={"𧏁"}
	a[76381]={"腲"}
	a[76382]={"㥸"}
	a[76383]={"騦"}
	a[76392]={"𦢺"}
	a[76394]={"𪑐"}
	a[76400]={"覭","𣬑","𧡎"}
	a[76401]={"𧡯"}
	a[76402]={"騉","𧡋"}
	a[76403]={"䬑"}
	a[76409]={"䬛"}
	a[76410]={"𧡸","𧢗"}
	a[76411]={"𣎔","𧢨"}
	a[76412]={"𦢮"}
	a[76413]={"𩙈"}
	a[76414]={"𩘺"}
	a[76415]={"𧡡","𧢝","𩘾"}
	a[76416]={"𩙎"}
	a[76430]={"𠩣","𦙿"}
	a[76440]={"贶","𠙂"}
	a[76442]={"𠙍"}
	a[76445]={"𢂝"}
	a[76450]={"𧠏","𧠙","𨻙"}
	a[76452]={"䙻","飔"}
	a[76453]={"𩙬"}
	a[76460]={"覛","𣍦"}
	a[76461]={"幌"}
	a[76470]={"𠖞","𦚢","𦜧"}
	a[76471]={"𢃚","𧠟"}
	a[76472]={"䫻","𡲉"}
	a[76474]={"𡲝"}
	a[76480]={"䏹","𦚽","𦛞","𧠿"}
	a[76482]={"𩖸","𩗗","𩙰"}
	a[76483]={"颸","𩗤","𩗨"}
	a[76484]={"覥","𨚉"}
	a[76486]={"𡲭"}
	a[76490]={"䐊","𧠢"}
	a[76491]={"𢅩","𧠠"}
	a[76492]={"䣖","颺","𠒰","𩗥"}
	a[76493]={"𩙊"}
	a[76500]={"䮫"}
	a[76502]={"𩩙","𪕤"}
	a[76504]={"驛"}
	a[76509]={"驆"}
	a[76511]={"𨲩"}
	a[76512]={"䑍","鼹","𦦣"}
	a[76513]={"䐷","𦣒"}
	a[76515]={"驒"}
	a[76517]={"𩪖"}
	a[76518]={"髏"}
	a[76552]={"肿"}
	a[76562]={"胛"}
	a[76563]={"胂"}
	a[76565]={"駛"}
	a[76566]={"𤱣"}
	a[76571]={"𦜄"}
	a[76572]={"幔","𥏏","𦜉","𦡇"}
	a[76576]={"𩢶"}
	a[76579]={"㡞"}
	a[76581]={"䏷","𨱮"}
	a[76583]={"㿸"}
	a[76591]={"䐕","𦠍"}
	a[76592]={"䐾","𩨹"}
	a[76593]={"駻","𢄸"}
	a[76594]={"幝","騴","𩦯"}
	a[76598]={"膢"}
	a[76600]={"𣎇"}
	a[76602]={"䮖"}
	a[76613]={"鼺","𦢏"}
	a[76614]={"𡂶"}
	a[76615]={"𣍔"}
	a[76670]={"䞎","𦛗"}
	a[76671]={"𢃑"}
	a[76685]={"𥀒"}
	a[76693]={"𥀜"}
	a[76694]={"𥀖"}
	a[76700]={"䯜","腭","𩨴","𪕩"}
	a[76702]={"𦦊"}
	a[76703]={"𩤸"}
	a[76704]={"䮷"}
	a[76710]={"㬽","𩩐","𩩲","𪕫","𪕭"}
	a[76712]={"䶇","髑","𩥑","𩦧","𩩍"}
	a[76713]={"髃"}
	a[76750]={"赐"}
	a[76751]={"𢃡"}
	a[76760]={"𦝲"}
	a[76761]={"幆","脶","𢂱"}
	a[76770]={"𣉠","𦚊"}
	a[76771]={"㡌","𦛭"}
	a[76772]={"斶","𠂄"}
	a[76780]={"腸","𣎅"}
	a[76781]={"㡢"}
	a[76782]={"𦥶"}
	a[76783]={"腢"}
	a[76790]={"䑗","𦝖","𨱭","𨲎"}
	a[76791]={"𦝩"}
	a[76792]={"臅","駽","騔","𩤟"}
	a[76794]={"騁"}
	a[76795]={"𩤛"}
	a[76800]={"鼰"}
	a[76801]={"𪕜"}
	a[76802]={"膭","贒"}
	a[76811]={"鼳","𣎱","𦣜"}
	a[76812]={"䯣"}
	a[76831]={"帜"}
	a[76840]={"咫"}
	a[76841]={"䟟"}
	a[76850]={"胑"}
	a[76852]={""}
	a[76861]={"𢃰"}
	a[76862]={"𩢢"}
	a[76863]={"𦚤"}
	a[76871]={"脵","𢄙","𦜃"}
	a[76880]={"䐎","𩨵"}
	a[76881]={"𦝳"}
	a[76890]={"䐣","𩩔","𪕝"}
	a[76892]={"騠"}
	a[76894]={"𥀠"}
	a[76901]={"臊"}
	a[76903]={"髁","𦣃"}
	a[76941]={"𨹦"}
	a[76954]={"𢃦"}
	a[76971]={"幜","𣎈"}
	a[76973]={"腂"}
	a[76981]={"䐯","𨲃"}
	a[76982]={"幧"}
	a[76983]={"𠪧"}
	a[76985]={"騍"}
	a[76992]={"𦢊"}
	a[76993]={"騾"}
	a[77000]={"𠚡","𩩅","𪕙"}
	a[77010]={"","𦑹","𪓞"}
	a[77011]={"膶","𪕱"}
	a[77017]={"𩧛"}
	a[77018]={"驧"}
	a[77020]={"","𠨖"}
	a[77021]={"㠴","劤","𠡲","𢁕","𢁞","𦥓","𧹑"}
	a[77022]={"𠠻","𢁩"}
	a[77030]={"购","","𠨝"}
	a[77032]={"𠠹","𠠿","𠣝","𢁶","𤿇","𤿉"}
	a[77033]={"𠡄","𤿒"}
	a[77034]={"册"}
	a[77040]={"䏛","凹","肑","肕","肳","胊","臼"}
	a[77041]={"励","劶","朒","肋","肭","","𢂁","𢂅","𢂶","𦛦","𦥔"}
	a[77042]={"𢂊","𦐴","𦑆"}
	a[77043]={"龾"}
	a[77048]={""}
	a[77050]={"⺽","𠝋","𦥑"}
	a[77051]={"㡄","助","胸","𠡗","𢂓","𦑫","𦝓"}
	a[77052]={"馰","𠡰","𠢭","𩡲"}
	a[77054]={"𦙱"}
	a[77060]={"朋","朐"}
	a[77061]={"赒","𦛪","𦛳"}
	a[77062]={"劻","𢃖","𦐢","𦙸","𦛴","𩢛"}
	a[77063]={"胟","𩣀","𩣽"}
	a[77064]={"䏥","𦙇","𦙽"}
	a[77068]={"𦚻"}
	a[77070]={"䏤","䶂","胴","𡳏","𢛀 ","𣎁","𦚧","𦛓","𪔹","𪔺","𪕺"}
	a[77071]={"䯇","䯐","","𠚖","𠡮"}
	a[77072]={"䮐","駉","駒","𦛕"}
	a[77073]={"𩢒"}
	a[77074]={"䎃","𦐎","𩤍"}
	a[77076]={"𩢡"}
	a[77078]={"𦣧"}
	a[77080]={"𠚜","𣇱","𦣩","𨱠","𨱸","𪔸"}
	a[77081]={"勖","𣍼","𨱧"}
	a[77082]={"駧","駨","𦑘","𩢹"}
	a[77083]={"𨱱"}
	a[77086]={"勵"}
	a[77090]={"鼩","𠚞","𪕍","𪕥"}
	a[77091]={"翢","𠢔"}
	a[77092]={"𠣆","𦑱","𦒝"}
	a[77093]={"騆"}
	a[77096]={"𦟯"}
	a[77101]={"朢","𡒊","𥂤"}
	a[77102]={"䪡","䪢","𦦦"}
	a[77103]={"瑿","𣱒"}
	a[77104]={"雤","𡑺","𤩱","𦡿","𩣿"}
	a[77105]={"𦦍"}
	a[77107]={"𢄶"}
	a[77110]={"舋","𠁠","𥃔","𥃘","𥃜","𦦭"}
	a[77111]={"㼂","䝂","璺","𡓵","𤪐","𥃖","𦦮","𨮆","𨮖","𨯜"}
	a[77112]={"䥣","𡓓","𤪭","𥃝","𦡱","𩁕"}
	a[77113]={"髉","𦦯"}
	a[77114]={"𣫫"}
	a[77116]={"䐸"}
	a[77131]={"𡊂"}
	a[77140]={"𢑏","𥁚"}
	a[77141]={"𡊎"}
	a[77142]={"𢂉"}
	a[77150]={"阻","","𥂼"}
	a[77151]={"𢂈"}
	a[77160]={"胫","","𥂻","𦚦"}
	a[77161]={"䏔"}
	a[77170]={"䏣","𦙠"}
	a[77171]={"堲","竪","𥁺 ","𦚲","𧖺"}
	a[77172]={"堅","幄","𥂞"}
	a[77180]={"盥","𠨣","𥂀"}
	a[77181]={"𦛑","𦝚","𨦴","𨲐"}
	a[77182]={"㻨","鋻","駔","𤦁","𦦛","𨿀"}
	a[77183]={"壆","𦞦"}
	a[77190]={"","𠁁","𦡪"}
	a[77191]={"腛","豎","𦞆","𦦋","𧗕","𨩁"}
	a[77192]={"䪠","毉","𦜻"}
	a[77193]={"㙠"}
	a[77194]={"壂"}
	a[77195]={"䮤"}
	a[77200]={"髎","","𦦞"}
	a[77210]={"𦦡"}
	a[77211]={"𨑁"}
	a[77212]={"𩮵","𩰪"}
	a[77215]={"䐹"}
	a[77217]={"驌"}
	a[77220]={"卬","卯","卵"}
	a[77230]={"印"}
	a[77231]={"㡅","𢄪"}
	a[77250]={"䏧","即",""}
	a[77252]={"𦛶"}
	a[77260]={"卿","腳",""}
	a[77261]={"𦡩"}
	a[77262]={"䭹","䮈","駠","","𩣍"}
	a[77270]={"膠",""}
	a[77271]={"脚","𠨥"}
	a[77272]={"𩢞"}
	a[77280]={"䐚","𠂼","𪕋"}
	a[77282]={"𩩨"}
	a[77283]={""}
	a[77287]={"𩥶"}
	a[77290]={""}
	a[77291]={"𦦼"}
	a[77300]={"𤕉"}
	a[77301]={"𢅱","𨲑","𩞺"}
	a[77303]={"鱟","𧎂"}
	a[77304]={"㼖","䗟","𧔱","𨲫"}
	a[77310]={"𢤀","𢤒","𤓲","𤓵","𤕊","𩝵"}
	a[77311]={"䢉","𦣴","𦦬","𦦶","𧞜","𩼹"}
	a[77312]={"𤬢","𤬣","𪒵"}
	a[77314]={"黳","𧓖","𧓟","𨲳","𩪌"}
	a[77315]={"𧔳","𧕧","𧖥"}
	a[77316]={"𦧀"}
	a[77320]={"瓝","𢜛","𤊑"}
	a[77321]={"𢙦","𤓶"}
	a[77322]={"㠽"}
	a[77323]={"𤔀"}
	a[77330]={"㤻","爬","赆","𢘴","𤫮"}
	a[77331]={"㼉","𢂻","𤓷"}
	a[77333]={"𢃭"}
	a[77340]={"𤔈","𦜩","𧰽"}
	a[77341]={"𢄐","𢞭","𦙭"}
	a[77343]={"𤔢"}
	a[77346]={"𤫰"}
	a[77350]={"䏰","瓟","𦥧","𧱃"}
	a[77351]={"惥","脓"}
	a[77352]={"𢝪","𦝰"}
	a[77360]={"煕","腞","𢞍","𦞪","𩛁"}
	a[77361]={"𢟬"}
	a[77362]={"𩵫"}
	a[77363]={"𢄟"}
	a[77364]={"騘"}
	a[77365]={"㡝"}
	a[77370]={"熙","褜","𤋮","𤍥","𦚣","𦠧"}
	a[77371]={"䐳","鼨","𢅗","𧛽"}
	a[77372]={"𦟌","𩥃"}
	a[77373]={"𦞣"}
	a[77380]={"䢅","腿","𢣟"}
	a[77381]={"𢝅","𤬟","𩶿"}
	a[77383]={"蜸","𦜎","𦦵","𧌘","𩥭"}
	a[77384]={"膖"}
	a[77385]={"騒","騷"}
	a[77390]={"㦛","膼","𢢎"}
	a[77391]={"𢣠","𧛣","𩜬"}
	a[77392]={"蜰","𧜤","𧝷"}
	a[77393]={"𦏗"}
	a[77394]={"驟","𩥇"}
	a[77400]={"骲","𦦁","𦦳","𩨾","𪕨"}
	a[77401]={"䯌","𦟭"}
	a[77402]={"㽇","𠨧","𩘇","𩘦","𪕴"}
	a[77403]={"𣮫"}
	a[77405]={"颹","𡦥"}
	a[77410]={"鼆","𠤫","𠨨","𣎜","𣩺","𩩢","𪓢","𪓬"}
	a[77411]={"𠨩","𦦩","𨳂","𪓸"}
	a[77412]={"㐦","覺","𥀨","𥀩","𧇜","𧢂","𩘿","𪓜"}
	a[77413]={"𦢗","𩙞"}
	a[77414]={"𪓘","𪓚"}
	a[77418]={"𩙡"}
	a[77420]={"乮","𠑼","𠘬"}
	a[77421]={"𠘫"}
	a[77423]={"𦘾"}
	a[77431]={"帆","飏","𢁒","𢁡"}
	a[77432]={"帎","𤑂"}
	a[77434]={"㿪"}
	a[77440]={"𠒂","𠨎"}
	a[77441]={"帊","觃","飑","𠙙","𦘮"}
	a[77442]={"肒","𠝈"}
	a[77444]={"觍"}
	a[77445]={"𩙨"}
	a[77450]={"䏎","兒","兕","屔","肊","肌","","𠑹"}
	a[77451]={"䏙","肍","𢂕","𦥙"}
	a[77452]={"㡈","㿬","䫸","肔","𩖚","𩖝","𩖡","𩖨"}
	a[77453]={"𠡨","𩖙","𩖯"}
	a[77454]={"𩙫"}
	a[77455]={"毑"}
	a[77460]={"兜","肥","胒","鼠","𠒅","𠙉","𦘺"}
	a[77461]={"飓","𠒍","𡥲","𦙉","𦥟"}
	a[77462]={"䒋","䬍","䭵","皰","飗","𦫗","𩖛","𩖴","𩗈"}
	a[77463]={"飕","馾","𡲋","𣫰","𩖜","𩖩","𩖪","𩡰"}
	a[77464]={"䫼","馳","𩖽"}
	a[77470]={"巸","胞","脃","脆","𠙧","𦡔","𨱙"}
	a[77471]={"脕","𦙷","𩨥","𪔽"}
	a[77472]={"䑕","䫿","骫","𡲊","𩖹","𩗅","𩘐"}
	a[77473]={"䬀","屘","𩣦"}
	a[77475]={"䬅"}
	a[77478]={"𩖼"}
	a[77480]={"腉","骪","𦜕","𨱤","𩨒"}
	a[77481]={"骩","𩨖"}
	a[77482]={"䮀","颮","飂","𩖾","𩗑","𩗜","𩘂"}
	a[77483]={"𡲪","𣱓","𩘋","𩣮"}
	a[77484]={"䬕","颿"}
	a[77485]={"颾"}
	a[77486]={"𩗲","𩘏"}
	a[77490]={"䒌","𠥷","𩨕","𩨜","𪕁"}
	a[77491]={"𤭠"}
	a[77492]={"䮘","颶","𩘻","𪕦"}
	a[77493]={"飀","𩗪","𩙔"}
	a[77494]={"颼","𩗘"}
	a[77501]={"腵"}
	a[77502]={"舉","𡕻","𢁅","𢍯"}
	a[77504]={"𩤣","𩤿","𩩟"}
	a[77506]={"肆","𣎤","𩋆","𩍂"}
	a[77507]={"䮝","腱"}
	a[77511]={"夓","毆","𣫏","𦗶","𦣯","𨏮","𩩱","𪕰"}
	a[77512]={"𥽳","𦏜","𪖃"}
	a[77513]={"騢","𦦙","𩧊"}
	a[77514]={"𠧑","𢍲","𢍹"}
	a[77515]={"轝","鼲","𦧁"}
	a[77519]={"騝"}
	a[77521]={"𠬨"}
	a[77531]={"𠬮"}
	a[77532]={"㠷","婴"}
	a[77533]={"㿭","帔","𤿏","𦚆"}
	a[77541]={"𢂗"}
	a[77542]={"㕞","𠚆"}
	a[77544]={"㿮","𤿔"}
	a[77547]={"𢂀"}
	a[77551]={"䏜","叞","帠","服","臤","𠭃","𡰻","𤈫","𦘿","𦙹","𦚂"}
	a[77552]={"㱽","䏢","叟","殴","舁","𣪂"}
	a[77553]={"幈","馭","𩢇"}
	a[77554]={"䧏"}
	a[77555]={"𥀙","𦜁"}
	a[77556]={"𤿶"}
	a[77561]={"㱼","股","𠵳","𦥠","𦥱"}
	a[77562]={"段","𡝨","𢃥","𤿚","𦙈","𦙨","𦥡"}
	a[77563]={"婜","胮","馺","𢃣","𣪵","𤿕","𦚀"}
	a[77564]={"駊","𢄌"}
	a[77565]={"皲"}
	a[77566]={"胇"}
	a[77571]={"㲀","叚","殷","𠭊","𢃵","𣪫","𦜼"}
	a[77572]={"殹","𡝑","𡝞","𢌴","𣆼","𦚪","𦝷","𨱣","𪌲"}
	a[77573]={"㹂","殿","𣍯","𤿳","𥀓"}
	a[77574]={"䏺","幃","腏","𡡼"}
	a[77576]={"㡓"}
	a[77581]={"𠭜","𠭭","𦜌","𨱚","𩨞"}
	a[77582]={"媐","毀","毇","毈","膄","骳","𡕯","𦜺","𦝒","𦥸","𦦒"}
	a[77583]={"𡢗","𢍱","𥀮"}
	a[77584]={"嫛","𢅝","𢍭","𤛱","𥀣"}
	a[77585]={"𥀊","𩦄"}
	a[77586]={"䮕","𡡋","𨱰"}
	a[77587]={"皸","皹"}
	a[77588]={"𦞘"}
	a[77591]={"毁","臎","骰","𣪍","𪕂"}
	a[77592]={"腶","𣪷"}
	a[77593]={"駸","𡣿","𦝛","𩤨","𩨫"}
	a[77594]={"騪","𡢕"}
	a[77595]={"腪","𩧞"}
	a[77598]={"䮇"}
	a[77600]={"䐲","膽"}
	a[77601]={"𦝮"}
	a[77602]={"䁷","䃜"}
	a[77603]={"嚳"}
	a[77605]={"𦦤"}
	a[77610]={"礜","譽","𥗑","𧭒"}
	a[77611]={"䶉"}
	a[77612]={"瞖","騽","𧫦"}
	a[77614]={"醫"}
	a[77641]={"赂","𢁾"}
	a[77642]={"𦛃"}
	a[77650]={"𣆾"}
	a[77651]={"留"}
	a[77660]={"脗","𦚔"}
	a[77661]={"胳","𤱚","𦛚","𧹕"}
	a[77662]={"𢄜"}
	a[77663]={"𢄰"}
	a[77664]={"𢂽","𣆑"}
	a[77670]={"䐇","𣆫","𣇀"}
	a[77671]={"𢃼","𦛵","𦞧"}
	a[77672]={"駋","𦥪"}
	a[77673]={"駱","𩢟"}
	a[77680]={"赗","赡"}
	a[77681]={"帽","幨","硻","腒","𢄭","𣉈","𦞞","𨱴"}
	a[77682]={"𠿟","𤲗","𥕭"}
	a[77683]={""}
	a[77690]={"鼦","𣎊"}
	a[77691]={"䁂","䶅","骼"}
	a[77692]={"㗨","礐"}
	a[77693]={"騮","𩤅"}
	a[77695]={"𦦠"}
	a[77696]={"𣎭"}
	a[77700]={"𦞩","𪃹","𪕾"}
	a[77701]={"𢄛","𢅂","𦠅","𦦝","𪂖"}
	a[77702]={"䮩","擧","鹥","𨟦"}
	a[77703]={"臀"}
	a[77704]={"䮸","觷"}
	a[77705]={"𥝊"}
	a[77710]={"䐞","䯞","朤","臖","鸒","𢑅","𦡌","𦦀","𦦟","𦦧","𦦸","𨺫","𩪆"}
	a[77711]={"𣎟","𦉝","𦢰"}
	a[77712]={"翳","釁","鷖","鷽","𢸁","𥝋","𩤫","𩦑","𩦡","𩱬"}
	a[77713]={"㩓","𥝇","𦦥","𦦻","𩪡"}
	a[77714]={"𦦷","𩥯"}
	a[77715]={"驏"}
	a[77717]={"𢹏"}
	a[77720]={"𨙮"}
	a[77732]={"䢷"}
	a[77740]={"𡶓"}
	a[77741]={"𢁠","𢃗"}
	a[77742]={"𡬻"}
	a[77744]={"𢂐"}
	a[77750]={"肠","舄","𡰺","𡵹","𤉡","𤬋","𦥗","𨝂"}
	a[77751]={"罂","𦥕","𦥘"}
	a[77754]={"㝀","𢂰"}
	a[77760]={"舃","𡷦","𤎡","𦜆","𦠈","𦥚"}
	a[77761]={"㡊","𡬯","𡹩","𤬙","𦜿","𦝾","𦥤"}
	a[77762]={"𢃃","𢃞"}
	a[77763]={"𢫪","𢮗","𨺳"}
	a[77764]={"𩢊"}
	a[77770]={"𨱢","𨱨"}
	a[77771]={"䐰","𢄚","𦜂","𦜇","𨜸"}
	a[77772]={"䐢","孯","嶨","𦛲","𦛸","𦦑","𨝇","𩣒"}
	a[77773]={"㬹","掔","𢲓","𩢆"}
	a[77774]={"𩣁"}
	a[77780]={"䏱","䐄","腡","𣎛","𦞚","𦣤","𦥩","𦥮"}
	a[77781]={"腎","𠢈","𦥳"}
	a[77782]={"舅","𡥷","𥝅","𩡿","𩣅"}
	a[77783]={"學","騊","𦥹","𩤓","𩤺"}
	a[77784]={"臋","騶","𩥎"}
	a[77790]={"䳔","𡽬","𤔼","𦞽","𦦂","𩨙"}
	a[77791]={"镼","𦜴","𦟓","𦡭","𪘦"}
	a[77792]={"㬾","䑁","駶","騧","驈","𥀤","𥝈","𦦎","𩤂"}
	a[77793]={"𡥸","𧤑","𨲌"}
	a[77794]={"𦦔"}
	a[77800]={"爂","興","𤓕","𦦚","𦦪"}
	a[77801]={"𦣁","𩩵","𩩽"}
	a[77802]={"𣥀"}
	a[77806]={"𦠻"}
	a[77810]={"䑂","𠔻","𥌏","𦢯","𦦫","𦦲","𦧅","𧸧","𩪢"}
	a[77811]={"臔","𩪹"}
	a[77812]={"㸑","贀","𢁌","𦠆","𦦴"}
	a[77813]={"爨","𦧂","𨲿","𩧙"}
	a[77815]={"輿"}
	a[77816]={"黌"}
	a[77820]={"欣","𣢀","𣢔","𣢚"}
	a[77821]={"𢁧"}
	a[77830]={"贸","𡰰","𣢁","𣢥","𣢬","𣢭"}
	a[77831]={"欧","𣢌","𣢎"}
	a[77833]={"𢁪"}
	a[77840]={"㰝","肷","𣢨","𦜡"}
	a[77841]={"㰼","䏮","臾","𣣃","𦛧"}
	a[77842]={"𥁍"}
	a[77844]={"𧹖"}
	a[77850]={"㰮","𣢞","𣢣","𣢮","𣣒","𣣪","𦙬","𦜓","𦥞"}
	a[77851]={"㷂","𠔜","𡘑"}
	a[77852]={"㰹","䏐","帿","胦","𣣣","𣤮"}
	a[77860]={"巺","歄","貿","镹","𠨠","𣣉","𣤀","𣤔","𤊏"}
	a[77861]={"幎","𡘩","𣣏","𦝝"}
	a[77862]={"燢","駅","𤓟"}
	a[77863]={"𣤇","𤌨"}
	a[77864]={"腆","駃","駚"}
	a[77870]={"䯉","𤌇","𪔼","𪕆"}
	a[77871]={"䐅","歋","腴","𦞈","𦞕"}
	a[77872]={"㰽","𢅟","𣤅","𣤭","𩀲"}
	a[77875]={"𣣞","𣣭"}
	a[77876]={"𩣲"}
	a[77880]={"㽰","與","𣤑","𣤒","𤌑","𨂢"}
	a[77881]={"㰺","䝿","𣣤","𤐫"}
	a[77882]={"巽","𦦉"}
	a[77884]={"𠔹","𦝜"}
	a[77890]={"歐","歟","𣎡","𣤆","𦥷","𪕠"}
	a[77891]={"賢","𤏿","𦡸","𧷈"}
	a[77892]={"𢅽"}
	a[77893]={"舆"}
	a[77894]={"𢅭","𩧁"}
	a[77895]={"𡚣"}
	a[77910]={"𤓱","𦈇"}
	a[77913]={"𣡈"}
	a[77916]={"𣟰","𣫥"}
	a[77930]={"爮"}
	a[77940]={"𣍨"}
	a[77942]={"𢄵"}
	a[77951]={"㡜","䊆","𦚩","𦜊"}
	a[77960]={"脲"}
	a[77961]={"䐖","腬"}
	a[77962]={"𣔚"}
	a[77963]={"𡮧","𩤞"}
	a[77970]={"䐂","𤂞","𦀥"}
	a[77971]={"緊","𦦆"}
	a[77972]={"䌠","䵖","澩"}
	a[77973]={"騥","𦦗","𩧋"}
	a[77974]={"𦟄","𩦅"}
	a[77975]={"𡳨"}
	a[77982]={"騄"}
	a[77983]={"𣘦"}
	a[77984]={"𣙰"}
	a[77985]={"𡳭"}
	a[77986]={"䮣","𠙲"}
	a[77990]={"𨲒"}
	a[77991]={"𣝑"}
	a[77992]={"繄"}
	a[77993]={"䐼","𥽂"}
	a[77994]={"𨽸"}
	a[78030]={"𣍞","𦘩","𦘲"}
	a[78040]={"臥"}
	a[78042]={"𩡩"}
	a[78100]={"𦡶"}
	a[78101]={"盬","鑒","鹽","𤪋"}
	a[78102]={"𨲠"}
	a[78110]={"𥃡"}
	a[78112]={"髊","𤪈","𩦹"}
	a[78131]={"𡉡"}
	a[78140]={"𠩧"}
	a[78141]={""}
	a[78142]={"𢂘"}
	a[78150]={"脸","𦙐","𦝤"}
	a[78151]={"脞"}
	a[78152]={"㕍"}
	a[78160]={"膉","𧗄"}
	a[78162]={"𩤀"}
	a[78170]={"㭀","監","𥪡"}
	a[78172]={"𩤼"}
	a[78173]={"駩"}
	a[78174]={"𡑘","𣱑"}
	a[78181]={"鍳","𢅡"}
	a[78182]={"䐤"}
	a[78183]={"𩣜"}
	a[78190]={"䜿","𥂭","𥃆","𪕶"}
	a[78191]={"𡒓","𥃉"}
	a[78192]={"䑘","𩐇"}
	a[78193]={"𦟤","𩐈"}
	a[78194]={"𩥙"}
	a[78211]={"㠹"}
	a[78221]={"𢁮"}
	a[78230]={"胗"}
	a[78240]={"肣"}
	a[78241]={"𢂃"}
	a[78242]={"駗","𩡺"}
	a[78260]={"胙","骱"}
	a[78270]={"䶃","𦥬"}
	a[78272]={"𩢐"}
	a[78300]={"𩩶"}
	a[78302]={"䑆"}
	a[78307]={"䯡","鼸"}
	a[78311]={"𩟨"}
	a[78312]={"𩪴"}
	a[78315]={"𩧗"}
	a[78321]={"𢁷"}
	a[78331]={"𢃧","𢅕","𢚓"}
	a[78332]={"𢃓"}
	a[78340]={"朎"}
	a[78342]={"㥖","𤫼"}
	a[78345]={"幠"}
	a[78350]={"䐋","腍"}
	a[78352]={"駖"}
	a[78357]={"㼓","赚"}
	a[78358]={"㡘"}
	a[78360]={"脍","𨱛"}
	a[78361]={"𦞮"}
	a[78362]={"䮉","愍","騐","𢅑","𦜱","𦞸","𩣭"}
	a[78364]={"膴"}
	a[78370]={"䯍","䯟","𦛰","𦜲","𪕌"}
	a[78373]={"𩥽"}
	a[78377]={"膁"}
	a[78380]={"𦝴","𩩦"}
	a[78382]={"𩥆"}
	a[78390]={"𩩈"}
	a[78400]={"覧"}
	a[78405]={"𩘭"}
	a[78410]={"㽉","覽"}
	a[78431]={"㡃"}
	a[78441]={"帨"}
	a[78450]={"脫"}
	a[78451]={"𦙋"}
	a[78452]={"𩖦","𩖵"}
	a[78453]={"𩗚"}
	a[78460]={"䏗","肐","脱"}
	a[78462]={"胣","𩢯"}
	a[78463]={"𢅶"}
	a[78471]={"𦞝"}
	a[78472]={"䬈","颴","駾"}
	a[78474]={"駞"}
	a[78482]={"䬔","𡳗","𩡹"}
	a[78483]={"𡳦","𩘞","𩥀"}
	a[78484]={"𩣾"}
	a[78485]={"𦡫"}
	a[78490]={"𩨘"}
	a[78492]={"𩘶","𩨺"}
	a[78493]={"𩘓"}
	a[78494]={"𣎮"}
	a[78502]={"𨲶"}
	a[78503]={"䦋"}
	a[78504]={"驐","𨲥"}
	a[78505]={"𦣵","𨍒"}
	a[78512]={"𢆃"}
	a[78513]={"𣀭","𩪕"}
	a[78514]={"𪖄"}
	a[78515]={"𨏊"}
	a[78521]={"败","𢻮","𨸩"}
	a[78522]={"𢼈"}
	a[78532]={"𢼕"}
	a[78533]={"帡"}
	a[78541]={"攺","肸","𢽷"}
	a[78542]={"𢽇"}
	a[78543]={"䭸"}
	a[78545]={"敟"}
	a[78551]={"㬳","敐","𢼑","𦚿"}
	a[78552]={"敃","胼"}
	a[78553]={"駇"}
	a[78561]={"𦜍","𨱝"}
	a[78562]={"羘","脌","𢼳","𢽹"}
	a[78563]={"𢼪"}
	a[78564]={"駢"}
	a[78571]={"𢽵","𦞀","𦞺","𪔻"}
	a[78572]={"䧩","𢅎","𦝡"}
	a[78573]={"𩣓","𩤝"}
	a[78574]={"𢄻"}
	a[78581]={"䯎","腹"}
	a[78582]={"骿","𢾞","𦟃","𦟔","𦣬","𪕒"}
	a[78586]={"𩥹"}
	a[78591]={"𢾺","𢿛","𣎣","𦠣"}
	a[78592]={"㬿","𦎨"}
	a[78593]={"䮡","𣀼","𦠐"}
	a[78594]={"斆"}
	a[78595]={"䮯","𣀣"}
	a[78596]={"𩥍"}
	a[78600]={"𧩾","𨲛","𨲯","𩈵"}
	a[78601]={"𩩗"}
	a[78602]={"𩦱"}
	a[78604]={"𩦐"}
	a[78610]={"䯤","臨","譼","𥊇"}
	a[78612]={"𨢒"}
	a[78613]={"𦣷"}
	a[78631]={"𢂲"}
	a[78641]={"帢"}
	a[78650]={"𦛱"}
	a[78652]={"𣇻"}
	a[78660]={"䏩","赠","𦛜","𦝵"}
	a[78661]={"𢅋"}
	a[78662]={"𩣥"}
	a[78670]={""}
	a[78672]={"𩠗"}
	a[78680]={"𦞛","𦠇","𦡮"}
	a[78682]={"暋","𦝱"}
	a[78683]={"騇"}
	a[78690]={"膾","𧨭","𩩂","𩩊","𪕛"}
	a[78692]={"睯","膳","驓"}
	a[78701]={"𦉞"}
	a[78703]={"𢅹"}
	a[78720]={"肦"}
	a[78721]={"帉"}
	a[78740]={"朌","𦙝"}
	a[78742]={"𨹥"}
	a[78750]={"䦇","肹","𦙕","𦣡"}
	a[78751]={"㡏","㡐","𣍮"}
	a[78752]={"䭻"}
	a[78754]={"𢂳"}
	a[78761]={"𦚥"}
	a[78762]={"㟩","䏲","腀"}
	a[78764]={"𢰞"}
	a[78765]={"𨲼"}
	a[78770]={"腧","鼢","𩨪"}
	a[78772]={"𡼐","𢱯","𦡬"}
	a[78773]={"脢","𩢿"}
	a[78780]={"䐥"}
	a[78782]={"騚","騟"}
	a[78790]={"膓"}
	a[78791]={"𡦋"}
	a[78792]={"擥","𣊽","𨲬","𪕧"}
	a[78803]={"𦢹","𦣍"}
	a[78805]={"𩦸"}
	a[78840]={"䐫"}
	a[78842]={"険"}
	a[78851]={"朕"}
	a[78852]={"𨺰"}
	a[78860]={"𦛔","𨲧"}
	a[78861]={"𢅐"}
	a[78870]={"𪖁"}
	a[78872]={"𦝺"}
	a[78873]={"𩥾"}
	a[78874]={"験"}
	a[78880]={"臉","𣎓"}
	a[78892]={"驗"}
	a[78893]={"𦢋"}
	a[78896]={"𩦙"}
	a[78910]={"𤂟","𤄈","𤓼"}
	a[78930]={"赊"}
	a[78940]={"𦙳"}
	a[78942]={"𩢜"}
	a[78950]={"䑐","𨱯"}
	a[78961]={"𣔿"}
	a[78963]={"駼"}
	a[78970]={"𦂳","𦃂"}
	a[78980]={"𤀩"}
	a[78981]={"㯺","𥽏"}
	a[78983]={"𥽐"}
	a[78992]={"𣠿"}
	a[79100]={"𩩆"}
	a[79102]={"𪖀"}
	a[79103]={"䲢",""}
	a[79110]={"𩪂"}
	a[79162]={"𣍺"}
	a[79171]={"𦡎"}
	a[79173]={"塍"}
	a[79180]={"䐩"}
	a[79181]={"膛"}
	a[79182]={"膗"}
	a[79184]={"𤰀"}
	a[79192]={"𩥉"}
	a[79193]={"𦨄"}
	a[79195]={"𦨃"}
	a[79211]={"㠺","𦙧"}
	a[79230]={"䏚"}
	a[79242]={"𩡾"}
	a[79260]={"𩨡"}
	a[79270]={"𡮻","𡮼"}
	a[79302]={"𣎲"}
	a[79304]={"𩻷"}
	a[79340]={"𤫾"}
	a[79350]={"𦜥"}
	a[79351]={"𦟂","𦡗"}
	a[79352]={"𠗲"}
	a[79361]={"𤔶"}
	a[79382]={"𦢜"}
	a[79383]={"𦞲","𦢅"}
	a[79384]={"螣"}
	a[79393]={"鰧"}
	a[79394]={"黱"}
	a[79411]={"飚","𩙪"}
	a[79412]={"𪓺"}
	a[79414]={"𠃈"}
	a[79441]={"𦚃"}
	a[79442]={"颷","飈","𩖥","𩖧"}
	a[79450]={"胱"}
	a[79452]={"𩖞"}
	a[79453]={"𡲸","𢃩","𦝘","𩗐","𩘌"}
	a[79460]={"𦥰 "}
	a[79462]={"駫"}
	a[79463]={"𩖷"}
	a[79470]={"𪕓"}
	a[79472]={"腃","颵","𩗵"}
	a[79480]={"䯑","𩨷"}
	a[79483]={"𩙆"}
	a[79490]={"𧡼"}
	a[79492]={"𨲏","𩘥"}
	a[79533]={"𦚓"}
	a[79541]={"𦛀"}
	a[79542]={"𣍹"}
	a[79544]={"𢄑","𦞊"}
	a[79552]={"胖","𦛎"}
	a[79553]={"隣","𣎌","𦝼"}
	a[79563]={"幐","𩥘"}
	a[79564]={"媵","𩢔"}
	a[79573]={"膦","𩣞"}
	a[79574]={"䮼"}
	a[79583]={"䮗","髅"}
	a[79585]={"騨","驎"}
	a[79591]={"𨲊"}
	a[79596]={"𩥪"}
	a[79600]={"𩩭"}
	a[79602]={"謄"}
	a[79671]={"𣃉"}
	a[79673]={"𥀋"}
	a[79683]={"𣎒","𥀑"}
	a[79690]={"𦠙","𨲓"}
	a[79691]={"𦡁"}
	a[79692]={"膡"}
	a[79702]={"𩦏"}
	a[79705]={"𩦜"}
	a[79706]={"驣"}
	a[79710]={"𨲲"}
	a[79712]={"𦢥","𦢿"}
	a[79714]={"驨","𩧎"}
	a[79731]={"胐"}
	a[79732]={"𡵕"}
	a[79740]={"𦘹"}
	a[79741]={"帩","脳"}
	a[79751]={"朏","朥"}
	a[79760]={"䏴","腨","𦓙","𦓚","𦝶"}
	a[79763]={"㬺","勝","幥","𩢎"}
	a[79770]={"膌","𦓝","𦦇"}
	a[79771]={"𨱦","𨲮"}
	a[79772]={"𩤚"}
	a[79780]={"𨲆"}
	a[79781]={"𩨸"}
	a[79782]={"腾"}
	a[79790]={"𩩓"}
	a[79794]={"騰"}
	a[79800]={"𩪈"}
	a[79810]={"赕"}
	a[79811]={"𢃔"}
	a[79822]={"𢃸"}
	a[79830]={"腅"}
	a[79831]={"𦛡"}
	a[79841]={"䐐"}
	a[79851]={"𣎐"}
	a[79852]={"","𣎎","𤑘"}
	a[79860]={"𩩧"}
	a[79862]={"","𩤧"}
	a[79870]={"䐝","𤑠"}
	a[79882]={"𨃗"}
	a[79892]={"賸","𩧟"}
	a[79941]={"脒"}
	a[79961]={"𣎝"}
	a[79962]={"滕"}
	a[79963]={"榺"}
	a[79972]={"縢"}
	a[79974]={"𩥱"}
	a[80000]={"丷","人","亻","入","八","𠑑"}
	a[80001]={"𧯋"}
	a[80010]={"们","","𠐩","𧯎","𧯓"}
	a[80011]={"䥨","鐗","鐧","𠑆","𨰏","𨰓"}
	a[80012]={"𧯘","𨬔","𨰎","𩰕"}
	a[80013]={"鐦"}
	a[80014]={"鑭"}
	a[80020]={"邠","邻","𨙽","𨚐"}
	a[80030]={"郤","𨜪"}
	a[80031]={"䣄","郑","𨛏"}
	a[80032]={"䣏","郱","𤕓"}
	a[80040]={"郃","郐","𨛣","𨜶"}
	a[80041]={"𨛈"}
	a[80042]={"㑚","𨚶","𨛁"}
	a[80044]={"鄦"}
	a[80050]={"鄃"}
	a[80051]={"䣃","倻","鄇","钔","𨛭"}
	a[80052]={"爺","𨝱"}
	a[80053]={"郸","𨜰","𨝈"}
	a[80060]={"們","鄫","𨜺","𨜾","𨞅"}
	a[80061]={"𨝕"}
	a[80062]={"鋣"}
	a[80065]={"䣡"}
	a[80070]={"鄶","𠑡"}
	a[80072]={"鄯","铘"}
	a[80073]={"鄭","锎"}
	a[80080]={"𨝫"}
	a[80081]={"鎯","锏"}
	a[80082]={"鎁"}
	a[80084]={"镧"}
	a[80090]={"僩","僴","𩝢"}
	a[80091]={"鍆"}
	a[80100]={"𩝑"}
	a[80102]={"盫"}
	a[80103]={"饚"}
	a[80110]={"䒑","亼","","𠓛","𠓿"}
	a[80112]={"𩟺"}
	a[80113]={"𥃣"}
	a[80114]={"𦏮"}
	a[80115]={"罐","鑵","𥐓","𨰑"}
	a[80120]={"㒰","並","仝","企","伫","佥","","","","","𠇯","𠓞","𠔄"}
	a[80121]={"𠉓","𠊍","𡉀","𨥄"}
	a[80130]={"仺","倥","兰","盆","益","𠅇","𠈔","𠓯","𣥝","𥁌"}
	a[80131]={"全","坌","玍","金","釒","釡","","𦍌"}
	a[80132]={"釜","𡌵","𤤎","𦚙","𨥏"}
	a[80134]={""}
	a[80140]={"㿽","佱","𧯚","𨤾"}
	a[80141]={"","𠆭","𣥳","𦈢"}
	a[80142]={"𠈘","𡌆"}
	a[80150]={"盒","谾","𠋪","𥁧","𩚃"}
	a[80151]={"盖","𠋤","𡋛"}
	a[80152]={"差","𠭳"}
	a[80153]={"𨦵"}
	a[80156]={"𤫆"}
	a[80160]={"⻞","𠐏","𠐰","𠑅"}
	a[80161]={"𡍽","𤥓"}
	a[80162]={"羫","𡌫","𥂝"}
	a[80163]={"羞","鋩"}
	a[80165]={"僿"}
	a[80172]={"𩛲"}
	a[80173]={"铓"}
	a[80174]={"𦎺"}
	a[80181]={"𥂜"}
	a[80182]={"盦","𨫐"}
	a[80183]={"鲝","𥂴"}
	a[80190]={"𩞜"}
	a[80191]={"鍹","𡓛"}
	a[80193]={"錱","鑫","𠓾","𦥈","𨫎"}
	a[80194]={"鑉"}
	a[80200]={"㐱","丫","介","𠌕","𢒃"}
	a[80210]={"㒱","今","兯","","","𠇏"}
	a[80211]={"斧","爷"}
	a[80220]={"","𠇎","𠓡","𠔅","𡰤","𢘈"}
	a[80221]={"爹"}
	a[80230]={"乍"}
	a[80231]={""}
	a[80232]={"养"}
	a[80234]={"𠋓"}
	a[80251]={"𨫂"}
	a[80252]={"儚"}
	a[80270]={"𠐉"}
	a[80271]={"𠌆 ","𨰆"}
	a[80281]={"𠓴"}
	a[80282]={"𩝨"}
	a[80283]={"𨮒"}
	a[80292]={"𩟞"}
	a[80300]={"亽","仒","","𠇍","𠐗","𠔇","𤆋"}
	a[80306]={"蠤","𧔭"}
	a[80310]={"㒸","令","公","","𠑳","𠓣","𠫥","𢗊","𤋌"}
	a[80311]={"𠍐"}
	a[80312]={"𦏬"}
	a[80315]={"𧕙"}
	a[80319]={"𧕶"}
	a[80320]={"傢","忩","念","忿","","𢗁","𢚒","𢝑"}
	a[80330]={"会","总","衾","飠","𠧦","𠫟","𢚱"}
	a[80331]={"悆","缹","羔","𡦈"}
	a[80332]={"㤣","𠏨","𢚖","𢜒","𢞥"}
	a[80333]={"𧉊"}
	a[80334]={"無"}
	a[80340]={"侌","兪","怎","煎","食","","","𠉽","𢖴","𢙅"}
	a[80341]={"恙","𣕙"}
	a[80342]={"蚠","𠐁"}
	a[80345]={"𠔥"}
	a[80347]={"兼"}
	a[80350]={"㥐","兹","愈","𢛪","𤎰","𧛯","𩚀","𩚜"}
	a[80351]={"鎵"}
	a[80352]={"𤋃","𥏕"}
	a[80353]={"𢙽"}
	a[80354]={"𤏹"}
	a[80360]={"慈"}
	a[80361]={"镓","𧜚","𨬃"}
	a[80362]={"鋐","𧊧"}
	a[80364]={"𢣍"}
	a[80372]={"養",""}
	a[80373]={"鮺","鯗","𧏨","𧓀"}
	a[80374]={"兿"}
	a[80382]={"饛","𩟘"}
	a[80388]={"𨮄"}
	a[80393]={"𩺃"}
	a[80396]={"𧒃"}
	a[80397]={"鑝"}
	a[80401]={"鑹","𠇃"}
	a[80403]={"鑧"}
	a[80405]={"𨭙"}
	a[80410]={"⺑","㐈","仑","龕","𠆹","𠑙","𪚕","𪚙","𪚡"}
	a[80411]={"𠆪"}
	a[80412]={"𪋨","𪓵"}
	a[80413]={"㲷"}
	a[80415]={"鑶","𣱮"}
	a[80416]={"𦏱"}
	a[80420]={"㖋","仓","佗","兊","兌","𠈑","𠙠","𡯂","𡯠"}
	a[80430]={"乞","兑","兺","气","氕","氘","氚","氮","𠒁","𠓟","𠤒","𢘔","𣱛"}
	a[80431]={"侘","気","爸","钅","𠉼"}
	a[80432]={"㐌","𠇜"}
	a[80434]={"𠎛"}
	a[80436]={"𠌾"}
	a[80440]={"俒","倇","忥","氙","氛","𠈢","𣱕","𣱖"}
	a[80441]={"氝","氡","氣"}
	a[80442]={"羌","𠎍","𠔲","𢀻","𣱘","𦍑"}
	a[80444]={"㒝"}
	a[80450]={"氖","氦","氩","瓫","瓮","𠉲","𠊊","𣱚","𣱞","𣱠","𩚁"}
	a[80451]={"氞","鉈","𣱗","𣱜","𣱥","𤕕"}
	a[80452]={"㲴","䍫","氨","羗","龛","𣱝"}
	a[80453]={"𠊋","𥠌"}
	a[80454]={"錵"}
	a[80455]={"義","𥠠"}
	a[80460]={"㲵","氜","氢","氫","𣱙","𣱦"}
	a[80461]={"㲶","氤","氪","铊","𣱟","𣱣","𦍛"}
	a[80462]={"䤩","氧","𧉁"}
	a[80463]={"氠"}
	a[80464]={"羲","𦏁"}
	a[80466]={"氟"}
	a[80470]={"氯","氳","𣱢","𧡟"}
	a[80471]={"鋎","鋺","𣱩"}
	a[80472]={"氥","羦","麄","𠐿","𣱫"}
	a[80474]={"氭","𠎾"}
	a[80475]={"鑖"}
	a[80476]={"𣯠"}
	a[80480]={"氱","氲","𩜌"}
	a[80482]={"䥉","𡢣","𦎶","𨫕"}
	a[80484]={"𦎻","𨝬"}
	a[80485]={"䥠"}
	a[80490]={"氬","甆"}
	a[80491]={"𩝜"}
	a[80492]={"氰"}
	a[80493]={"𨮼"}
	a[80494]={"𦏊","𦏣"}
	a[80495]={"䩩","𣱧"}
	a[80501]={"父","𩠮","𩠰"}
	a[80503]={"𨮰"}
	a[80505]={"𩟓"}
	a[80506]={"镬"}
	a[80507]={"䡨"}
	a[80511]={"仐","伞","傘","夔","攵","𠓝","𠦍","𠦎","𢁰","𣁁"}
	a[80512]={"𢌯"}
	a[80515]={"𠌂","𠓽"}
	a[80518]={"𨐃"}
	a[80521]={"午","屰","","𠇀","𠇨","𠇰","𠋢","𠍘","𠓠","𠬬","𠬰","𡴌","𢁥","𢂂","𢆉","𦍍"}
	a[80522]={"侒","并","弅","𠇋","𠊢","𠔈","𠔎","𡛑"}
	a[80523]={"𤕑"}
	a[80531]={"𠓥","𢁭","𢻶"}
	a[80532]={"年","弚","弟","羊","","𠇚","𠇭","𠈭","𠎃","𢄕","𤕘","𤘝","𦍐"}
	a[80540]={"命"}
	a[80541]={"𠈾","𦔯","𦔴","𦔵"}
	a[80542]={"弇","𢍋","𦍡"}
	a[80543]={"单","姜","𠔢"}
	a[80544]={"𠩖","𦍰"}
	a[80545]={"𢅊"}
	a[80551]={"复","𢃬"}
	a[80552]={"㿯","䜮","䤹","𠭦","𤕗","𨩵","𩚇"}
	a[80553]={"䓥","傇","銨","餀","𠌓","𠓰","𠔟","𤕖","𨥖"}
	a[80555]={"𦎕"}
	a[80562]={"𦍶"}
	a[80563]={"铵","𨦭"}
	a[80564]={"𠓼","𠭶","𢍜"}
	a[80565]={"𢄔","𨨭"}
	a[80566]={"䥈","舞","𣜈"}
	a[80567]={"羛"}
	a[80573]={"𠐎"}
	a[80574]={"𤛈","𨫽"}
	a[80581]={"𡕸","𩝪"}
	a[80582]={"𠏎","𩟒"}
	a[80583]={"𠑛"}
	a[80586]={"矱"}
	a[80587]={"𨌅"}
	a[80588]={"鏵"}
	a[80591]={"𣀚"}
	a[80594]={"𦏐"}
	a[80595]={"镩"}
	a[80596]={"羴","鑊"}
	a[80602]={"𧪰","𨣡","𨮱"}
	a[80603]={"𨮿","𩝛"}
	a[80604]={"𨢚"}
	a[80605]={"䦃"}
	a[80611]={"𧮟"}
	a[80612]={"譱","𦏯"}
	a[80613]={"𠑰","𨯠"}
	a[80620]={"㕣","谷","","𠔌","𠮦","𠲒","𧮫"}
	a[80621]={"𠔋","𤰒"}
	a[80630]={"㒲","㒶","傛","合","含","𠯨"}
	a[80631]={"","𠓦","𤳋"}
	a[80632]={"𠔍","𤱇"}
	a[80640]={"𠓤","𣅑","𥃦","𥃮"}
	a[80641]={"舍","舎","𠰥","𤰗"}
	a[80642]={"𠔪","𤱭","𤲞"}
	a[80643]={"㑤","偌"}
	a[80650]={"倉","普","曾","首","𠍹","𠓮","𠰞","𤽽","𥄘","𥄟","𥅍"}
	a[80651]={"畲","𡇤","𡇷"}
	a[80652]={"畬","酋","𠲘"}
	a[80653]={"㸙"}
	a[80660]={"會","𣌭"}
	a[80661]={"兽","曽","畣","鎔","𠐂","𡈤"}
	a[80662]={"善","酓","𠵊"}
	a[80663]={"僒","𠌣","𪉤"}
	a[80664]={"㒂"}
	a[80670]={"𠋑","𥅽"}
	a[80671]={"镕","𨧩"}
	a[80672]={"㑹","着","𨡣"}
	a[80673]={"鍣","鎝","𨪓","𪉬"}
	a[80674]={"錨","鍩","𠎲"}
	a[80676]={"𨭈"}
	a[80681]={"鏥","𠏇","𦎍","𧨁","𨧕"}
	a[80682]={"𠎏","𠐧","𦎩","𨠭"}
	a[80683]={"𧯆","𨱏","𪉵"}
	a[80684]={"锘","锚"}
	a[80694]={"鎋"}
	a[80695]={"鐯","𦎱"}
	a[80700]={"鶿"}
	a[80707]={"𩟛"}
	a[80708]={"鑮"}
	a[80710]={"仚","分","屳"}
	a[80711]={"㠳","肏","𠓧","𠛈","𤕏"}
	a[80713]={"𦏟"}
	a[80715]={"𤕨"}
	a[80716]={"𠑴"}
	a[80717]={"䭦"}
	a[80720]={"佇","兮","岔","𠔃","𠔆","𠔑","𥜼"}
	a[80721]={"㑏","㒴","","𠇮"}
	a[80722]={"𠋁","𠓢","𤕎"}
	a[80730]={"䏌","𠈛","𡶠","𢎦","𥫧","𥫮","𦏾"}
	a[80731]={"㑻","㸘","峹","缶","𡬦","𤕒"}
	a[80732]={"侖","𠌈","𠔕","𢪘","𢻯","𦛝"}
	a[80735]={"𠑂"}
	a[80740]={"俞","前","𪗖"}
	a[80741]={"㸗","侴","嵞","𦚷"}
	a[80742]={"儰","禽","𠋅"}
	a[80743]={"每"}
	a[80744]={"毎"}
	a[80746]={"𠉙"}
	a[80750]={"倌","儜","剪","翁","𠋔","𠔒","𦐈"}
	a[80751]={"䍆","𡬴","𡽚"}
	a[80752]={"拿","羜","𠎚","𠏸"}
	a[80753]={"𦍸"}
	a[80754]={"僃"}
	a[80760]={"","𠞽","𦚶","𩿈","𪘕"}
	a[80761]={"𠚗","𦥭","𦥴"}
	a[80762]={"𨩴"}
	a[80763]={"尊","𦍺"}
	a[80765]={"㒖","𠭻"}
	a[80766]={"𠏆","𠏯"}
	a[80770]={"翕","𠋒"}
	a[80771]={"孳","樖","𠎘","𠓳","𪀝"}
	a[80772]={"餝","𠎤","𦥽"}
	a[80773]={"𨩦"}
	a[80774]={"搻","铹"}
	a[80780]={"翦","𠍗"}
	a[80781]={"錧","鑏","𦥾","𦦓","𨭋","𩝒","𩱁","𩱋"}
	a[80782]={"𩰱"}
	a[80790]={"䭢","館"}
	a[80791]={"䥱","舘","𨬎"}
	a[80792]={"齹","龠"}
	a[80793]={"𨭛","𨯽"}
	a[80794]={"𩝳"}
	a[80795]={"䍎","𨰂"}
	a[80798]={"䥬"}
	a[80800]={"仌","众","","","𠊌","𠔁","𤆅","𧸋"}
	a[80801]={"𨮘"}
	a[80805]={"鑳"}
	a[80810]={"炃",""}
	a[80811]={"𠓵","𡙫"}
	a[80812]={"𨰦"}
	a[80815]={"𠓷"}
	a[80820]={"贪","贫","𠓫"}
	a[80821]={"关","矢","𠇄","𠊲","𡗯","𡗳","𡘔","𤇇"}
	a[80830]={"傧","𠈏","𠈮","𧾺"}
	a[80831]={"羙","𤈣","𤈩","𦎟"}
	a[80832]={"㑒",""}
	a[80834]={"偀"}
	a[80840]={"𤋎","𧿍"}
	a[80841]={"羑","𨬄"}
	a[80842]={"美","𠔯","𡙡"}
	a[80844]={"𤴘"}
	a[80850]={"僉","貧","貪","𠍺","𤎯","𨂝"}
	a[80851]={"羡","羨","𠓱","𦎅"}
	a[80852]={"㷢","𠔤","𨨷"}
	a[80853]={"兾","𠌉"}
	a[80854]={"𧯀"}
	a[80860]={"儐","𨂮"}
	a[80861]={"錠","𡙛","𡚈","𤕙"}
	a[80862]={"𩛛"}
	a[80863]={"奠","羮","𩜈"}
	a[80864]={"𨅐"}
	a[80865]={"鍈"}
	a[80870]={"𧷟","𩜦"}
	a[80871]={"锭","镔","𥐄","𦎙"}
	a[80873]={"羹","𣍄"}
	a[80874]={"䭊","𠐻"}
	a[80883]={"鏔"}
	a[80884]={"鏌"}
	a[80891]={"鑌"}
	a[80893]={"饃"}
	a[80894]={"镆","𩞶","𩟌"}
	a[80900]={"尒","","𡭗"}
	a[80910]={"㒪","尓","氽","汆","𠌺","𠑮","𠑱"}
	a[80911]={"籴"}
	a[80912]={"𨰭"}
	a[80914]={"𨰤"}
	a[80919]={"𣡰"}
	a[80920]={"佘","𠈒","𣲎","𥾈"}
	a[80921]={"余","俕","枀","𣏰"}
	a[80922]={"𠓭"}
	a[80930]={"倧","𠊺","𣴲"}
	a[80932]={"𦍎"}
	a[80941]={"淾","𣑠","𣴎","𥿅"}
	a[80942]={"𠎳"}
	a[80943]={"𠓲","𣔕"}
	a[80950]={"𣹅"}
	a[80951]={"㮍","羕"}
	a[80953]={"𣴴"}
	a[80954]={"𣒫"}
	a[80956]={"僷","橆"}
	a[80961]={"錝","𣛙"}
	a[80962]={"𠐙"}
	a[80964]={"𥣠"}
	a[80972]={"𪎨"}
	a[80973]={"鏼","𠓸"}
	a[80974]={"𨬘"}
	a[80976]={"𣞣"}
	a[80981]={"鑔"}
	a[80983]={"𨯓"}
	a[80984]={"𨾁"}
	a[80987]={"鐷"}
	a[80990]={"𩟔"}
	a[80991]={"镲","𩟩"}
	a[80996]={"䭟"}
	a[81100]={"𩜄"}
	a[81102]={"𩠯"}
	a[81103]={"𠐶","𨩽"}
	a[81110]={"饇"}
	a[81111]={"鏂","𦉒","𧯙","𨮮","𩟽"}
	a[81112]={"鑩"}
	a[81113]={"罏","鑎","鑪","𦏰","𩟯"}
	a[81114]={"𨯟"}
	a[81115]={"𣬁"}
	a[81116]={"𨮫"}
	a[81120]={"仁","仜","仩","伾","𠇈"}
	a[81121]={"伛"}
	a[81130]={"仨","佂","俓"}
	a[81131]={"仼","伍","𠇤"}
	a[81132]={"俇"}
	a[81140]={"䜫","仾","佢","侸","𠈄"}
	a[81141]={"侄","𠏂"}
	a[81150]={"𠈗","𠋧","𩚼"}
	a[81151]={"㑌","䤠","缸","釭","鉟"}
	a[81152]={"儮","𠊎","𠍝","𨦷"}
	a[81160]={"俹","𠋗"}
	a[81161]={"矩","短","鉦","鋞","铔","","𢿅","𦈮","𦈵","𨮷"}
	a[81162]={"偃","羥","鈺","鉔","𥎹","𨦖"}
	a[81170]={"㠮","𩚫"}
	a[81171]={"鉅","鉕","鋀","钜","钲","𠋿","𠔠","𨥛","𨱀"}
	a[81172]={"㒑","銍","钰","𠍾","𥂲","𦍞"}
	a[81174]={"𡟿"}
	a[81180]={"傴","餖","𥂾","𩚢","𩛉"}
	a[81181]={"䬹","钷","𥏝"}
	a[81182]={"铚","𦍼"}
	a[81183]={"䥶"}
	a[81184]={"䍽"}
	a[81185]={"𦎣"}
	a[81187]={"𨰡"}
	a[81190]={"𠼞","𩠛"}
	a[81191]={"錏","𨨙"}
	a[81192]={"僵","𠏺","𠐳"}
	a[81193]={"䤷"}
	a[81212]={"𨰳"}
	a[81213]={"䥮"}
	a[81220]={"俨","𠉡"}
	a[81250]={"𠌹","𠍩"}
	a[81251]={"䤮","𨥑","𨦄"}
	a[81260]={"俳"}
	a[81281]={"㒎","","𨦰"}
	a[81291]={"䤵"}
	a[81293]={"𨮭"}
	a[81310]={"𠍪","𠑚"}
	a[81311]={"𩟃"}
	a[81313]={"鑢"}
	a[81320]={"佧"}
	a[81325]={"𠑓"}
	a[81330]={"伝"}
	a[81340]={"侲","𢘢","𢚨"}
	a[81341]={"𧙾"}
	a[81342]={"𦎇","𧋚","𨧧"}
	a[81343]={"𦎜"}
	a[81346]={"𠏊"}
	a[81350]={"倀"}
	a[81351]={"鉲","𠎉"}
	a[81352]={"𠍴"}
	a[81353]={"𠍍"}
	a[81360]={"𩞈"}
	a[81362]={"𦍝"}
	a[81370]={"僫","𩚞"}
	a[81371]={"鋠","𠏡"}
	a[81372]={"𤑅"}
	a[81376]={"𧍻"}
	a[81381]={"鋹"}
	a[81382]={"儢","鐻","𨯂"}
	a[81390]={"餦"}
	a[81392]={""}
	a[81394]={"𧐉"}
	a[81400]={"𠐢"}
	a[81401]={"鐚"}
	a[81402]={"儷"}
	a[81403]={"㽀","𤮐"}
	a[81410]={"㽂","儱","豅","𩟭"}
	a[81411]={"鑨","𩞊"}
	a[81412]={"䥤","䵹","𤮬","𩞞"}
	a[81413]={"𨰣","𪛌"}
	a[81420]={"㐳","㐾","䝇"}
	a[81430]={"伌"}
	a[81440]={"佤"}
	a[81441]={"尩"}
	a[81442]={"𠌐"}
	a[81450]={"瓴","𤬰"}
	a[81451]={"㑙","鈨","鈪"}
	a[81452]={"䥻"}
	a[81460]={"𤭏"}
	a[81461]={"俿","𦈪","𨥵"}
	a[81462]={"瓶","𦍘","𦎄"}
	a[81470]={"㼨","䬧","𩚋","𩚚"}
	a[81471]={"缻","𠌰","𣱤","𧆺","𨦸"}
	a[81472]={"錿","𠌩","𠐚","𤭌","𦍭"}
	a[81473]={"僊","鐬"}
	a[81474]={"甒"}
	a[81480]={"㼶","𣍎"}
	a[81481]={"𧮽"}
	a[81482]={"銸","饖","𤮫","𩰤"}
	a[81483]={"𤭐"}
	a[81487]={"甉"}
	a[81490]={"甑"}
	a[81491]={"𤭬","𧆦"}
	a[81492]={"𣱪","𦏀","𧇍"}
	a[81493]={"𣱯","𦉐","𨪹"}
	a[81502]={"䥳","𨬜"}
	a[81504]={"罈","鐔","镊"}
	a[81507]={"𨪚"}
	a[81511]={"𠑍"}
	a[81513]={"㒤","𨰮","𩟴"}
	a[81514]={"鑷","镡"}
	a[81515]={"𠐡"}
	a[81521]={"仠","伻","𠆸"}
	a[81522]={"𠆻"}
	a[81531]={"㪁"}
	a[81532]={"佞","𠎋","𡛉"}
	a[81541]={"佴","𢼽"}
	a[81542]={"敍","𠈯","𠊳"}
	a[81543]={"㑝","𠉔","𢼩"}
	a[81544]={"便","偠","𠊼"}
	a[81551]={"㪂","倬","敆","𢼎"}
	a[81552]={"䍈","釬","鈙","銔","鋄","錽","𠋵","𨥚","𨥾","𨧴"}
	a[81553]={"䍬","鈃","𢼝","𦈨"}
	a[81555]={"𠏕"}
	a[81561]={"飦","𠌘"}
	a[81563]={"钘","𢽝"}
	a[81564]={"僲"}
	a[81568]={"㪠"}
	a[81571]={"優"}
	a[81572]={"鉺","𥏥"}
	a[81573]={"銒"}
	a[81575]={"𨩫","𨪁"}
	a[81581]={"餌"}
	a[81582]={"鋽","铒"}
	a[81583]={"㪨","𨨵"}
	a[81591]={"㪧","𦗼"}
	a[81594]={"𩝼"}
	a[81601]={"䥧","𩜰"}
	a[81611]={"𠑫","𩞷"}
	a[81612]={"䭙","鐂","𦉢","𨯻"}
	a[81613]={"鐕","鐳","镭","𦏪"}
	a[81614]={"䍼","𨢮"}
	a[81617]={"𠑵"}
	a[81630]={"佔","佦","俖","𠇅"}
	a[81631]={"𠈇","𠉦"}
	a[81632]={"価"}
	a[81640]={"佰","𠇙"}
	a[81650]={"偭"}
	a[81651]={"俉"}
	a[81661]={"䍄","偪","鉆","鉐","𠍚","𥏄","𦈶"}
	a[81662]={"鏀"}
	a[81670]={"䬯","𠏻"}
	a[81671]={"銆","钻"}
	a[81672]={"啎","𥏒"}
	a[81681]={"𨫌"}
	a[81682]={"鋙"}
	a[81690]={"𧯕","𧯖"}
	a[81692]={"僭","鍢","铻","𣉻"}
	a[81693]={"䥄"}
	a[81694]={"𦏩","𨣐"}
	a[81701]={"䥎","𥏼"}
	a[81702]={"𥐎"}
	a[81706]={"𨯅"}
	a[81710]={"仃"}
	a[81711]={"𥃋","𥐃"}
	a[81712]={"鑐","𦉏","𦏤","𨬆"}
	a[81713]={"羺","𪛍"}
	a[81714]={"鐪"}
	a[81720]={"侕","𠄖"}
	a[81721]={"㐵","㑂","伢","倆","𠆮","𠇆","𠉴"}
	a[81722]={"俩","𠇢"}
	a[81725]={"儞"}
	a[81730]={"何","俪","𠇐"}
	a[81731]={"𠆬"}
	a[81741]={"谺","釘"}
	a[81742]={"傌","𠋊"}
	a[81744]={"侢"}
	a[81750]={"傿","飣"}
	a[81751]={"傉","钉","𠋛","𥎵","𦈥"}
	a[81752]={"䍂","䥺","釪","釾","鈵","𦎂"}
	a[81753]={"𠎣","𦍠","𩢮"}
	a[81756]={"鑈"}
	a[81761]={"釫","鈣","鈳","𥏁"}
	a[81762]={"","𠍛","𥎿","𦈣"}
	a[81763]={"𥏽"}
	a[81770]={"餰"}
	a[81771]={"錒","鑡","钙","钶","𦉟"}
	a[81772]={"𦏌"}
	a[81773]={"鎷","𦈾"}
	a[81780]={"𩞪"}
	a[81781]={"儒","錹","鎘","锕"}
	a[81782]={"鎒"}
	a[81783]={"罅","鏬","𦉄","𦉑"}
	a[81784]={"𦉌"}
	a[81786]={"𨬀"}
	a[81791]={"鎶","镉","","𥏦"}
	a[81792]={"𥏾","𦉛","𨭀"}
	a[81793]={"𥏴"}
	a[81794]={"鎼","𢹁","𦉋"}
	a[81800]={"䭭","顩","𩔚"}
	a[81802]={"𩔕"}
	a[81803]={"𦏥","𨰥"}
	a[81811]={"𠑘","𠑯","𨯲"}
	a[81812]={"龥","𧯗","𩕊"}
	a[81815]={"𨯼"}
	a[81820]={"㑔","侦"}
	a[81821]={"𠎌"}
	a[81830]={"颁","颂","领"}
	a[81831]={"偄","𥏂"}
	a[81840]={"倾"}
	a[81841]={"𠊤","𠎮","𨪘"}
	a[81850]={"㑯","偵","颌","颔","𩒀","𩒉"}
	a[81851]={"偼","𨪳"}
	a[81852]={"𨭂"}
	a[81860]={"頌","頒","領","𧵰","𩑟","𩔀"}
	a[81861]={"𧺪","𩑭"}
	a[81862]={"𨨰"}
	a[81870]={"傾","𠐺"}
	a[81871]={"餪","𩑤","𩑿","𩒕","𩛫"}
	a[81872]={"價","鐝","頩","𩒭"}
	a[81873]={"𦏅"}
	a[81880]={"䫄","頜","頷","𩑔","𩔌","𩔝","𩔱"}
	a[81881]={"䫞","鍞","顉","𨬗"}
	a[81882]={"镢","𨩼","𨮗","𩓂"}
	a[81888]={"𧈁"}
	a[81890]={"𩑡","𩝗"}
	a[81891]={"䫛","𨫋"}
	a[81892]={"顀","顦","𠐾"}
	a[81897]={"䫡"}
	a[81910]={"伓"}
	a[81920]={"㑐","𠇣"}
	a[81940]={"傆"}
	a[81941]={"鈈","𠍞","𦈧"}
	a[81943]={"傈","僳"}
	a[81950]={"䬪"}
	a[81951]={"钚","𠋾"}
	a[81952]={"僄"}
	a[81960]={"𩚪"}
	a[81961]={"銢","銾","𠍲","𣛊"}
	a[81962]={"𠍙"}
	a[81964]={"𦏈"}
	a[81971]={"𨪛"}
	a[81972]={"榘","羱"}
	a[81974]={"䥔",""}
	a[81982]={"𨬡"}
	a[81983]={"鏢","𩞸"}
	a[81993]={"镖"}
	a[82000]={"","𠆯"}
	a[82030]={"𠇁"}
	a[82031]={"釧","銂"}
	a[82041]={"䤛","钏"}
	a[82051]={"矧"}
	a[82061]={"鈏"}
	a[82116]={"㒥"}
	a[82121]={"任","𠉰","𠍮"}
	a[82130]={"𠊦"}
	a[82131]={"𡐂"}
	a[82141]={"𠌠"}
	a[82145]={"倕"}
	a[82150]={"僜","𠉃"}
	a[82151]={"𠈺","𨧑"}
	a[82152]={"鈓","銋","𦉖","𨭇"}
	a[82160]={"𩚨"}
	a[82161]={"飪","餁"}
	a[82163]={"𨧓"}
	a[82165]={"偅","𨤨"}
	a[82176]={"䍋","錘"}
	a[82180]={"𠏪"}
	a[82181]={"鐙","𠎷","𨧥"}
	a[82185]={"𩜀"}
	a[82186]={"锤","𥏱"}
	a[82190]={"𩞬"}
	a[82191]={"镫"}
	a[82196]={"鍾","锺","𦉂"}
	a[82202]={"𪛊"}
	a[82205]={"𩞏"}
	a[82210]={"伒"}
	a[82211]={"侨","鐤","𨮕"}
	a[82213]={"𨰉"}
	a[82220]={"𠆺"}
	a[82221]={"𢒐","𢒑"}
	a[82231]={"釤"}
	a[82232]={"㑜","矫","羏"}
	a[82240]={"𣃀","𩚎"}
	a[82241]={"釿","钐"}
	a[82250]={"㣒","𣂮"}
	a[82251]={"","𠎎","𨥥","𨧗"}
	a[82252]={"㒋"}
	a[82253]={"䤯"}
	a[82263]={"𨦬"}
	a[82265]={"𠌲"}
	a[82271]={"䤺"}
	a[82273]={"𥐀"}
	a[82281]={"𨬅"}
	a[82282]={"𨭌"}
	a[82283]={"鐁"}
	a[82296]={"鏩","𨭠"}
	a[82300]={"䭡","𠇊"}
	a[82310]={"仏","仫","𠇗"}
	a[82320]={"𠇓","𤫫","𤫲"}
	a[82321]={"伥","俬","僁","𤫴","𦍖"}
	a[82322]={"𠌤"}
	a[82331]={"㶵","恁","釽"}
	a[82341]={"䍇","䤨","鈲","𧙨","𨥝","𨥧"}
	a[82342]={"𦍳"}
	a[82350]={"𩚮"}
	a[82351]={"鎃","𤬈","𨱃"}
	a[82352]={"鏭"}
	a[82353]={"𦍯"}
	a[82357]={"𤬓"}
	a[82360]={"㒚"}
	a[82361]={"𠎻","𥏩","𩜡"}
	a[82362]={"銩","","𩷀"}
	a[82371]={"𨥺"}
	a[82372]={"懖","铥"}
	a[82382]={"𢤌"}
	a[82385]={"鑂"}
	a[82391]={"𨮳"}
	a[82400]={"𩜆"}
	a[82402]={"𣰅"}
	a[82403]={"𩀗"}
	a[82413]={"䶵"}
	a[82414]={"𦏫"}
	a[82420]={"佻","𠈁","𡯑"}
	a[82421]={"仛","低"}
	a[82422]={"𠇔","𠋉"}
	a[82430]={"仳","佌","𠈊"}
	a[82431]={"罀"}
	a[82432]={"𢒘","𣬹"}
	a[82441]={"儠","凭","釓","","𠉗","𥎺","𨤽"}
	a[82442]={"𠃲","𣬩","𥏐"}
	a[82450]={"𠋃","𩚂"}
	a[82451]={"銚","钆","𠏢","𥎬","𨦂"}
	a[82452]={"䍮","毤","𣮧","𨥌","𨥼"}
	a[82453]={"僟","羝"}
	a[82460]={"㑷","餆","𠃽","𠉥"}
	a[82461]={"䜲","䬫","傂","鈚","鉳","铫","飥"}
	a[82462]={"鋵","𣮆","𨨜"}
	a[82463]={"𣯇","𦎞"}
	a[82472]={"毹","鑞","𨧰"}
	a[82474]={"㲬"}
	a[82482]={"镴","𣯽","𨡳"}
	a[82483]={"𧈛"}
	a[82484]={"鐖"}
	a[82485]={"𦏑"}
	a[82490]={"𩝹"}
	a[82491]={"𨮴"}
	a[82492]={"𡰡","𦎵","𨪉"}
	a[82493]={"饑"}
	a[82496]={"錷"}
	a[82502]={"鏺"}
	a[82503]={"𦗾"}
	a[82511]={"仟","仮","𩞽"}
	a[82512]={"俀"}
	a[82513]={"𦘉","𦘌"}
	a[82521]={"𠈩"}
	a[82522]={"儍"}
	a[82523]={"倭"}
	a[82531]={"僾","𧮮"}
	a[82532]={"𠋠","𥎮"}
	a[82533]={"𡜟"}
	a[82541]={"𠈰"}
	a[82542]={"侹","倂","僢","釺","鈑"}
	a[82543]={"鋖"}
	a[82544]={"矮"}
	a[82551]={"飯"}
	a[82552]={"钎","钣","餒","𩚿"}
	a[82553]={"鍐","鑁"}
	a[82554]={"錗"}
	a[82555]={"䍴"}
	a[82561]={"𠎆","𠐄"}
	a[82562]={"鑀","𡡚"}
	a[82563]={"鍰","餧","𥏎"}
	a[82565]={"𨪻"}
	a[82572]={"鋋","餠","𠍬","𨨻","𨫁"}
	a[82573]={"鋌","锾","𩝂"}
	a[82583]={"铤"}
	a[82593]={"𦗦"}
	a[82601]={"锴"}
	a[82612]={"龤"}
	a[82630]={"𠱧"}
	a[82631]={"佸"}
	a[82640]={"𠉤"}
	a[82641]={"𠈲","𦧎"}
	a[82642]={"僠"}
	a[82650]={"睂","𥇮","𧮶"}
	a[82651]={"偱","𠉣"}
	a[82660]={"偕"}
	a[82661]={"缿","銗"}
	a[82662]={"銛","錙","𨧐"}
	a[82671]={"錔","餂","𩛶","𩜊"}
	a[82672]={"銽","鍿","铦","锱","𨨱"}
	a[82673]={"䣸","鐇"}
	a[82674]={"羳"}
	a[82681]={"𥏪"}
	a[82682]={"錉","鍎"}
	a[82691]={"鍇"}
	a[82692]={"𦎥"}
	a[82700]={"𠋴"}
	a[82702]={"𨰜"}
	a[82703]={"䥷"}
	a[82710]={"㑎","侧","刢","𠊖","𠚼","𠛀","𠝮"}
	a[82711]={"俐","𠋙","𠛶"}
	a[82720]={"例","创","剑","𠜑"}
	a[82721]={"俘","剉"}
	a[82722]={"㐿","侀","𠛼","𢪽"}
	a[82730]={"㓣","㓧","僞","刉","刏","刽","𠛛","𠛢","𠛲","𠛷","𠟏"}
	a[82731]={"㓡","傜","釗","𠉑","𠊏","𠛮","𠜋","𠞼","𠟛"}
	a[82732]={"㑧","剃","剣","𦎋","𦚮"}
	a[82734]={"偁"}
	a[82740]={"㓱","側","𠋯"}
	a[82741]={"倒","钊","𠉳","𨦝"}
	a[82742]={"䤣","劁","鋓","鋝","𠋐","𠝢","𨥍"}
	a[82743]={"偊"}
	a[82744]={"𠌚"}
	a[82750]={"創","劍","𠐘","𠟂","𩛋"}
	a[82751]={"䥿","偛","铡","𨦙","𨦜","𩛝"}
	a[82752]={"㧱","鋢","锊","𠎼","𠞊","𠟚","𥏗","𦈤","𦈴","𨪺","𨬚"}
	a[82753]={"鉶","𨥋","𨧘"}
	a[82755]={"𨦕","𨪑"}
	a[82756]={"𨰛"}
	a[82760]={"偝","劊","𠟖","𠠆"}
	a[82761]={"僑","𨬞","𩛞"}
	a[82762]={"銹","鎐","𨉃"}
	a[82763]={"铏","𠎈","𠟃"}
	a[82770]={"𠞳","𠟊","𠠬"}
	a[82771]={"䤾","鍘","鵀"}
	a[82772]={"锈","𠟠","𨬭"}
	a[82776]={"𨪸"}
	a[82780]={"饀","𠠃"}
	a[82781]={"𨩈"}
	a[82782]={"矯","鍤","𨮸"}
	a[82783]={"𨭚"}
	a[82791]={"𩝟"}
	a[82792]={"鐈","锸"}
	a[82811]={"仸","𩕻"}
	a[82820]={"㑟"}
	a[82821]={"𤇲"}
	a[82831]={"傒","赁","𠊾","𠋳","𨪼"}
	a[82832]={"矨"}
	a[82842]={"僕","𨥜"}
	a[82851]={"㕗","豀","鋲","飫"}
	a[82860]={"儨"}
	a[82861]={"賃","𤏼"}
	a[82862]={"鍨","锧"}
	a[82863]={"𥐁"}
	a[82871]={"鎻"}
	a[82872]={"𨪾"}
	a[82873]={"鏷","𨮓"}
	a[82881]={"鎭","𨫞"}
	a[82883]={"镤"}
	a[82891]={"鑕"}
	a[82902]={"㶗"}
	a[82903]={"龢"}
	a[82910]={"㲻","𣲝"}
	a[82911]={"倸","𩟧"}
	a[82912]={"鑠"}
	a[82920]={"係","𠊥","𠌀"}
	a[82921]={"𠊻"}
	a[82931]={"𠍂"}
	a[82932]={"栠"}
	a[82941]={"䋕","偨","𥚘"}
	a[82942]={"㒒","鉌"}
	a[82943]={"㑿"}
	a[82951]={"㒡","銯","𩜓"}
	a[82952]={"铄"}
	a[82953]={"鏫"}
	a[82961]={"𥣂","𩜿"}
	a[82963]={"䋣","緐"}
	a[82970]={"𠐴"}
	a[82971]={"𩞛"}
	a[82973]={"𨭥"}
	a[82974]={"鏁"}
	a[82976]={"𨧺"}
	a[82977]={"𥣃"}
	a[82983]={"𥤖"}
	a[83000]={"仆"}
	a[83002]={"𨶊"}
	a[83010]={"伈"}
	a[83011]={"佖"}
	a[83013]={"𨷫"}
	a[83031]={"釙"}
	a[83032]={"剙"}
	a[83040]={"𩚅"}
	a[83041]={"鈊","钋"}
	a[83042]={"鉍"}
	a[83043]={"𠧩"}
	a[83051]={"飶"}
	a[83052]={"铋"}
	a[83060]={"𠟐"}
	a[83100]={"𠑠"}
	a[83104]={"䨄","鐘","雠"}
	a[83105]={"𦏆"}
	a[83108]={"儺"}
	a[83110]={"饘"}
	a[83111]={"𨭖"}
	a[83112]={"羶","𩟀"}
	a[83113]={"䭚"}
	a[83114]={"讎","𩁥"}
	a[83115]={"𩁗"}
	a[83116]={"雥","雦"}
	a[83120]={"位","𠇸"}
	a[83130]={"𠊔"}
	a[83131]={"住","𠉫"}
	a[83132]={"垈"}
	a[83133]={"垡"}
	a[83140]={"傡"}
	a[83142]={"倠","隹"}
	a[83143]={"𨾝"}
	a[83151]={"釯","鉝"}
	a[83152]={"雂","𨾠"}
	a[83153]={"䨀","傩","𨾪"}
	a[83162]={"鉒","𨿜"}
	a[83163]={"雉","雓","𨾟","𨿂"}
	a[83171]={"飳"}
	a[83172]={"㒕","䧻","𠍜","𩁆"}
	a[83173]={"僮","錐"}
	a[83174]={"𥃗","𨿝"}
	a[83175]={"𥃒"}
	a[83182]={"𩜑"}
	a[83183]={"䧾","鏟","锥"}
	a[83184]={"㒧","雔","𥃅","𩀂"}
	a[83190]={"儃"}
	a[83192]={"𩀕","𩀞"}
	a[83195]={"𨫻"}
	a[83211]={"侪"}
	a[83216]={"䨊","𩁵"}
	a[83220]={"偐"}
	a[83230]={"傪"}
	a[83231]={"㑪","𠎗"}
	a[83250]={"儕"}
	a[83251]={"𨩱"}
	a[83260]={"𩜽"}
	a[83261]={"鏒","铲","𥐌"}
	a[83270]={"𩞀"}
	a[83281]={"鑇"}
	a[83290]={"䭣"}
	a[83301]={"镱"}
	a[83310]={"㑊"}
	a[83314]={"饟"}
	a[83315]={"䥰","鑲","镶"}
	a[83316]={"𤓬","𧕲","𧖝"}
	a[83320]={"依"}
	a[83321]={"㒄","𢘋"}
	a[83330]={"㥋","伭"}
	a[83331]={"袋"}
	a[83335]={"𠎰"}
	a[83340]={"㒅","偯"}
	a[83342]={"僬","焦","𢛧"}
	a[83343]={"𧊇"}
	a[83350]={"儫","飰","𠐦"}
	a[83351]={"銥","𥎸"}
	a[83352]={"𠍡","𨿈"}
	a[83353]={"黛","𠍋"}
	a[83360]={"億","餏"}
	a[83361]={"鉉","铱","𠐝"}
	a[83362]={"㒟","𦍫"}
	a[83370]={"𩞼"}
	a[83371]={"䥋","鎄","铉"}
	a[83372]={"𠐤","𠐥","𨾜"}
	a[83373]={"鐎"}
	a[83380]={"𩟮"}
	a[83381]={"锿"}
	a[83382]={"𦏨"}
	a[83383]={"𨨸","𨱓"}
	a[83384]={"𤒏"}
	a[83387]={"𧔢"}
	a[83391]={"鐿","𨧻"}
	a[83392]={"𨮹","𩞿"}
	a[83394]={"儴"}
	a[83400]={"䭗"}
	a[83401]={"镜"}
	a[83405]={"鐵","𨮯","𩟙"}
	a[83406]={"𨯱"}
	a[83411]={"代","𨰊"}
	a[83412]={"㦰","䶳","伐","𡰟","𢦜","𩟶"}
	a[83413]={"鑯","𨯤","𨰠"}
	a[83414]={"𨯒","𨰸"}
	a[83421]={"优","𠈸"}
	a[83422]={"𠇘","𠈵","𠉛"}
	a[83423]={"𠈋","𠋰"}
	a[83424]={"㑘","俄","俴"}
	a[83430]={"伉"}
	a[83431]={"侙"}
	a[83432]={"傶","戗","𢦺"}
	a[83433]={"𢧅"}
	a[83434]={"𠈙","𠋘"}
	a[83441]={"㞃","倵"}
	a[83442]={"釴","","𠊭","𢦳","𢨈","𨥶"}
	a[83443]={"䤦","鈛","𨱆"}
	a[83444]={"𧮺"}
	a[83450]={"𡯷"}
	a[83451]={"僦","鈗","𠌗"}
	a[83452]={"䤞","鋱","𠏔"}
	a[83453]={"鉞","銊","鋮","𨠫"}
	a[83454]={"𢧐"}
	a[83455]={"羢","鋨","錢","𦈻"}
	a[83456]={"傤","𠏃","𦎗"}
	a[83459]={"𢧥"}
	a[83460]={"傹"}
	a[83461]={"鈧","銃","鋶","𠍎","𢎒","𦈷","𨥡"}
	a[83462]={"戧","鉽","铽","𠏞","𢨉","𢨔","𦎓","𧯃"}
	a[83463]={"鏚","钺","铖"}
	a[83464]={"钱","餓","餞","𡰙","𢨍"}
	a[83465]={"銭","锇","𨩆"}
	a[83471]={"㒃","钪","铳","锍","𠎂"}
	a[83472]={"錻"}
	a[83473]={"毓","鍼","𦈸","𨭟"}
	a[83474]={"䬻","羬","𦎘"}
	a[83475]={"𨪎"}
	a[83476]={"𠑀"}
	a[83478]={"儎"}
	a[83482]={"韱","𠎟","𩝈"}
	a[83483]={"","𡰕"}
	a[83484]={"鐡"}
	a[83489]={"𠔺"}
	a[83491]={"鏡"}
	a[83492]={"馘","𢨠","𩞡"}
	a[83494]={"䤋","𨫓","𩟦"}
	a[83495]={"𨬿","𨭓"}
	a[83496]={"䥫"}
	a[83502]={"鐴","𨫚"}
	a[83506]={"䨇","犨"}
	a[83511]={"伩","佼","𠇥","𠨉"}
	a[83512]={"𨯢"}
	a[83515]={"𠧐"}
	a[83516]={"犫"}
	a[83521]={"俊","倅"}
	a[83522]={"帒","𠇞"}
	a[83531]={"偙","𠉄"}
	a[83532]={"㑓","侔","侫","倿","𣁏"}
	a[83533]={"牮","𣁊"}
	a[83542]={"䍊","鈫","鉸","𢆏"}
	a[83543]={"𢆣","𥎱"}
	a[83551]={"餃","𠋩","𠌭"}
	a[83552]={"䤳","鈰","鋑","錊","铰","𥏔"}
	a[83553]={"羧","鈸","隻","隼","","𥏡","𨾏"}
	a[83554]={"𡠓","𦍱"}
	a[83561]={"傽","餕","𩜘"}
	a[83562]={"鋅","鍗","铈","𩚳"}
	a[83563]={"䥽","鉾","钹","𠍉"}
	a[83571]={"僻"}
	a[83572]={"锌","𩝘","𩠕"}
	a[83573]={"𨢅"}
	a[83582]={"𨫏"}
	a[83584]={"鎨","𠐲"}
	a[83592]={"鏱"}
	a[83593]={"𦗊"}
	a[83594]={"鏲"}
	a[83595]={"雙","𩀱"}
	a[83603]={"鑙","𨮀"}
	a[83612]={"韽","𩉕","𪛏"}
	a[83614]={"㘜","讐"}
	a[83630]={"佁","𠊑"}
	a[83631]={"倃","𠰰"}
	a[83640]={"倍"}
	a[83641]={"偺"}
	a[83642]={"𥑼"}
	a[83650]={"信","偣","𠋭"}
	a[83661]={"傗","鈶"}
	a[83662]={"售","𨿞"}
	a[83664]={"𨠰"}
	a[83670]={"飴"}
	a[83671]={"䍌","錇","𥏮"}
	a[83680]={"餢","𠏓"}
	a[83681]={"锫","𨦼"}
	a[83682]={"𠐜","𨬙"}
	a[83683]={"𨮺","𨯀"}
	a[83685]={"𥗛"}
	a[83692]={"𨪴"}
	a[83700]={"𩝝"}
	a[83701]={"镐"}
	a[83703]={"鐫","镌"}
	a[83704]={"𩀟"}
	a[83705]={"𪈇"}
	a[83713]={"𩱢"}
	a[83716]={"𧔰","𧕣"}
	a[83717]={"𩁴"}
	a[83720]={"仿","𠆼"}
	a[83721]={"岱"}
	a[83723]={"𠇇"}
	a[83732]={"𡥖"}
	a[83740]={"傍","𠊓","𠋣"}
	a[83741]={"𠉸","𦙯"}
	a[83742]={"𠌯"}
	a[83744]={"俌"}
	a[83750]={"俼","停"}
	a[83751]={"㒀","鈁"}
	a[83753]={"𨿇"}
	a[83755]={"傅"}
	a[83760]={"傐"}
	a[83761]={"钫"}
	a[83762]={"㑺","隽"}
	a[83764]={"𠌽"}
	a[83771]={"鎊","𨧤","𨫢"}
	a[83772]={"儁","雋"}
	a[83775]={"鋪"}
	a[83776]={"𦎎"}
	a[83780]={"𩝾"}
	a[83781]={"錥","镑","𥏹","𨪃"}
	a[83782]={"錞","鏑"}
	a[83784]={"餔"}
	a[83785]={"舖","舗","铺"}
	a[83786]={"鎛","𦉊"}
	a[83787]={"䍸"}
	a[83790]={"𩛭"}
	a[83791]={"鎬","𩝿"}
	a[83792]={"镝","","𪂣"}
	a[83793]={"鎸"}
	a[83794]={"𩠤"}
	a[83795]={"餺"}
	a[83796]={"镈"}
	a[83810]={"𠆾"}
	a[83811]={"伏"}
	a[83812]={"𤇰"}
	a[83813]={"钀"}
	a[83816]={"𤓪"}
	a[83820]={"侅"}
	a[83821]={"贷","𠋈"}
	a[83831]={"俟"}
	a[83842]={"𢛧","𤊙","𨦛"}
	a[83850]={"𠋏"}
	a[83851]={"䤤","貸","𦈲"}
	a[83852]={"䧶","𥏖"}
	a[83860]={"䬵"}
	a[83862]={"𨧚"}
	a[83863]={"猷","𨾎","𨾗"}
	a[83864]={"𤡽"}
	a[83870]={"𩠚"}
	a[83871]={"𧶣"}
	a[83884]={"㸈","𨬓","𨭹"}
	a[83911]={"𠇲"}
	a[83917]={"雧"}
	a[83920]={"𠎵"}
	a[83921]={"俅"}
	a[83922]={"柋"}
	a[83923]={"𣑡"}
	a[83930]={"倞"}
	a[83931]={"𠉪","𠋆","𥿝"}
	a[83942]={"鉥","𦈭"}
	a[83950]={"㒍"}
	a[83952]={"銶","","𨫟"}
	a[83953]={"集","𠍱"}
	a[83961]={"鍄","𨱉"}
	a[83962]={"𨧲","𨱇"}
	a[83971]={"𣚱"}
	a[83974]={"𣜫"}
	a[83981]={"𨮙"}
	a[83984]={"鏶"}
	a[84101]={"餭"}
	a[84102]={"锽","𨪽"}
	a[84115]={"𨮻"}
	a[84120]={"侐"}
	a[84150]={"𠊙"}
	a[84160]={"𠊿"}
	a[84161]={"偟"}
	a[84162]={"僱"}
	a[84192]={"鍠"}
	a[84210]={"𠆲"}
	a[84212]={"䭩"}
	a[84213]={"䶏","𨰞"}
	a[84220]={"𠌌"}
	a[84250]={"𩝯"}
	a[84281]={"𠏿"}
	a[84303]={"镳"}
	a[84310]={"𠍌"}
	a[84315]={"𪛖"}
	a[84320]={"𠍸"}
	a[84332]={"𠌮"}
	a[84340]={"俍"}
	a[84341]={"傯"}
	a[84343]={"𠏷"}
	a[84344]={"㒏"}
	a[84351]={"鉱"}
	a[84352]={"㒣"}
	a[84362]={"儦"}
	a[84363]={"鏣"}
	a[84371]={"鋃"}
	a[84372]={"䭖","羪","鏓","𧝛"}
	a[84380]={"𠑟","𩛡"}
	a[84381]={"鎚","鎴","锒"}
	a[84388]={"䥥","鐮"}
	a[84390]={"䭒","䭔"}
	a[84392]={"𩟠"}
	a[84393]={"鑣"}
	a[84397]={"䭠"}
	a[84398]={"镰"}
	a[84403]={"䥝"}
	a[84413]={"𨰅"}
	a[84414]={"𪛓"}
	a[84415]={"𪛕"}
	a[84420]={"𠉆"}
	a[84431]={"侂"}
	a[84440]={"𡯫"}
	a[84450]={"𡯱"}
	a[84451]={"𠌔"}
	a[84452]={"傀","𩲏"}
	a[84462]={"𠏁","𦎔"}
	a[84473]={"𣫼","𩲶"}
	a[84480]={"𩚬","𩛨"}
	a[84482]={"鎞"}
	a[84483]={"𨪈"}
	a[84490]={"𩛪"}
	a[84492]={"餽"}
	a[84493]={"鏕"}
	a[84503]={"朇","𧯔"}
	a[84521]={"𠊯"}
	a[84531]={"𠊒","𠊴"}
	a[84532]={"傻","𠉷"}
	a[84542]={"𢍑"}
	a[84543]={"俾"}
	a[84551]={"𩜯"}
	a[84552]={"𠌟","𨨿"}
	a[84553]={"鎫"}
	a[84562]={"𠌞"}
	a[84564]={"𥏠"}
	a[84572]={"䜰","錦"}
	a[84574]={"錍","鍍"}
	a[84581]={"𧯌"}
	a[84582]={"锦"}
	a[84583]={"𨫆"}
	a[84584]={"镀","𨯙"}
	a[84595]={"羻","𨭤"}
	a[84602]={"饝","𨬬"}
	a[84604]={"餹"}
	a[84621]={"𠈈"}
	a[84630]={"伯"}
	a[84640]={"㑑"}
	a[84650]={"𠍊"}
	a[84651]={"𥎷"}
	a[84661]={"鉑","𥏆"}
	a[84662]={"𨦱"}
	a[84664]={"傏"}
	a[84670]={"𩛇"}
	a[84671]={"铂"}
	a[84672]={"𦍾"}
	a[84673]={"𣫾"}
	a[84695]={"鎕"}
	a[84700]={"鶬","鶲","鷀","𪇇"}
	a[84701]={"䦂","𪃃"}
	a[84702]={"𪃬"}
	a[84703]={"鶽","𪅠"}
	a[84705]={"䴊"}
	a[84708]={"鏞"}
	a[84709]={"𩀬"}
	a[84710]={"𪅲"}
	a[84711]={"𪆷"}
	a[84712]={"䳺","鸙","𪈍"}
	a[84713]={"鷷","𪇝"}
	a[84717]={"𩞋"}
	a[84718]={"镛"}
	a[84721]={"俯"}
	a[84722]={"侜"}
	a[84730]={"𠆿"}
	a[84740]={"鸰","𠈆","𠉱","𠌥"}
	a[84741]={"㑗","鸺"}
	a[84742]={"偏"}
	a[84743]={"矪"}
	a[84750]={"䲸","鳰","鸧","鹆","𠊘","𠌵","𩿕"}
	a[84751]={"鈩","𠏅","𩾿"}
	a[84752]={"𠏛","𠏰","𪉊"}
	a[84753]={"𨦞"}
	a[84760]={"䲲","傓","鳹","鳻","鴒","鸽","鹢"}
	a[84761]={"㒙","銄","鵂","𩿧","𪀢","𪂥"}
	a[84762]={"鹈"}
	a[84763]={"𦢻"}
	a[84770]={"餉","鵒","𠏶","𠐈","𪂄"}
	a[84771]={"䳜","鎢","钨","鴙","","","𪀼"}
	a[84772]={"銵","鵧","鹪","𦈿"}
	a[84773]={"鍽"}
	a[84775]={"𪈕"}
	a[84777]={"傭","鹣"}
	a[84780]={"鴿","鷁","鹚","鹟","𩛍","𩝷","𩾥","𩿞","𪁑","𪁟","𪂽"}
	a[84781]={"䳰","鵭","𦉓","𨩮"}
	a[84782]={"鴹","鵇","鵜","𦉀","𨮁","𩿽","𪄇"}
	a[84783]={"𦉙"}
	a[84784]={"鷡"}
	a[84790]={"𩾻","𪂤","𪂾","𪃎"}
	a[84791]={"䥇","鵨","𪃶"}
	a[84792]={"䳡","鷦","𪂻","𪆅"}
	a[84797]={"鶼"}
	a[84801]={"𦒥"}
	a[84813]={"𨰰"}
	a[84830]={"𠉵"}
	a[84831]={"㑦"}
	a[84841]={"㑵"}
	a[84862]={"錑","𦎊","𩟇"}
	a[84863]={"鐭","𨩬"}
	a[84864]={"儣"}
	a[84865]={"𠌿"}
	a[84872]={"𨪏"}
	a[84883]={"䍹"}
	a[84891]={"𩝠"}
	a[84895]={"鑛"}
	a[84920]={"𠇟"}
	a[84932]={"𠍨"}
	a[84951]={"𠐟"}
	a[84952]={"𨧖"}
	a[84971]={"䤼"}
	a[84981]={""}
	a[84982]={"鎳"}
	a[84985]={"鏮"}
	a[84992]={"䭧","镍"}
	a[85001]={"仪"}
	a[85011]={"什","𠆱"}
	a[85012]={"㐼"}
	a[85032]={"斜","𥎧"}
	a[85041]={"𣁴"}
	a[85042]={"針","鈄","𨥪 "}
	a[85043]={"𣁵"}
	a[85051]={"𣁺"}
	a[85052]={"针","钭"}
	a[85062]={"𩜭"}
	a[85102]={"𡓉"}
	a[85111]={"饐","𩞵","𩟟","𩟣","𩟤"}
	a[85112]={"𡓷"}
	a[85116]={"饉"}
	a[85121]={"仕","𠇾"}
	a[85131]={"佐"}
	a[85132]={"𠇷","𠈚","𠉋"}
	a[85133]={"伳"}
	a[85142]={"佳"}
	a[85143]={"𡋚"}
	a[85151]={"𠊪"}
	a[85152]={"偡","釷"}
	a[85153]={"㙦","𠌱"}
	a[85161]={"値","值"}
	a[85162]={"钍","𤯤","𨫿"}
	a[85163]={"鉎","𤯹","𨧀"}
	a[85164]={"鉪"}
	a[85171]={"𠍼","𩝉"}
	a[85173]={"銈","錴","","𦈰"}
	a[85176]={"僅","𣫸"}
	a[85182]={"鎑","𡐏","𦉆","𨩨"}
	a[85183]={"㒗","鍖"}
	a[85184]={"鍷"}
	a[85191]={"餷","饁"}
	a[85192]={"䭍","儓","𩜱"}
	a[85194]={"䥓"}
	a[85212]={"𨯕"}
	a[85222]={"𠉾"}
	a[85231]={"偧"}
	a[85232]={"𠌅"}
	a[85302]={"䥦","𨯨"}
	a[85303]={"𩟐"}
	a[85304]={"鐽"}
	a[85305]={"𩞙"}
	a[85311]={"㑀","烋","𩟆"}
	a[85312]={"𨯝"}
	a[85317]={"儾","饢","𨯚"}
	a[85321]={"俧","怤","恷","𠆽","𠉂"}
	a[85322]={"体","𢘂"}
	a[85331]={"佉"}
	a[85332]={"传"}
	a[85341]={"谹"}
	a[85342]={"俵","鈦","錰","𠊁","𠏖"}
	a[85343]={"𧊆"}
	a[85351]={"𠎢"}
	a[85352]={"䤲","鈜","钛","𥎰"}
	a[85353]={"缽","鉢"}
	a[85354]={"㷶","𠎝"}
	a[85362]={"䬱","鉣","鋕","鍅"}
	a[85363]={"㒓","钵"}
	a[85364]={"僡","憊"}
	a[85365]={"僆","𠏽"}
	a[85371]={"𠏍","𩛣"}
	a[85372]={"𠐷"}
	a[85373]={"錶"}
	a[85374]={"𠎱"}
	a[85382]={"鎱","𩞱","𩸔"}
	a[85383]={"𩞍"}
	a[85384]={"链"}
	a[85385]={"䦄"}
	a[85392]={"𩝤"}
	a[85393]={"𨯧"}
	a[85395]={"鏸"}
	a[85396]={"鏈"}
	a[85404]={"𦉗"}
	a[85411]={"化"}
	a[85413]={"饒"}
	a[85414]={"䥵","鐃"}
	a[85431]={"㖚","侁","𠇳"}
	a[85432]={"伅","佬","侥","𡜎"}
	a[85441]={"㐛","𡯛"}
	a[85442]={"鈋"}
	a[85443]={"𡯸"}
	a[85444]={"𡝸"}
	a[85451]={"𩛔"}
	a[85452]={"𨱂"}
	a[85453]={"䤜","𨥃"}
	a[85454]={"俺","𢻐","𦍓"}
	a[85462]={"銑","鋴","𩚊"}
	a[85463]={"鈍","銠","𩲜"}
	a[85464]={"𦍣"}
	a[85472]={"铣","飩"}
	a[85473]={"钝","铑","铙"}
	a[85483]={"僥"}
	a[85484]={"𦎉","𦎽"}
	a[85485]={"䤶"}
	a[85494]={"餣"}
	a[85504]={"𨬕","𨭸"}
	a[85511]={"𠑭"}
	a[85512]={"㚢","仗"}
	a[85515]={"𨍻"}
	a[85522]={"件","伂","伎","伖","佈","华","𠍅"}
	a[85523]={"俙","姇"}
	a[85532]={"倰","𠈞","𢺹","𤘨"}
	a[85533]={"仹","伟","伡"}
	a[85534]={"使","倴"}
	a[85542]={"倖"}
	a[85543]={"釹","𠍑","𨥅","𨥦"}
	a[85544]={"銰","𠉕","𦍜"}
	a[85546]={"𠏒"}
	a[85552]={"𢻆","𤙖","𤙣"}
	a[85553]={"䥑","鈘","鈝","鈽","钕","𠋽","𠎹","𢻂","𥏢","𥏣","𨥳"}
	a[85554]={"䍨"}
	a[85555]={"俥","俸","僀","","𠌙","𨥙"}
	a[85556]={"𠉯"}
	a[85557]={"𠎑"}
	a[85562]={"𩚡","𩛑"}
	a[85563]={"䂔","錂","铧","餙","𨱋","𩚰","𩛌"}
	a[85564]={"𡞜","𩝃"}
	a[85565]={"錛","𨬁","𨿛"}
	a[85566]={"𠎔"}
	a[85572]={"𩜁"}
	a[85573]={"﨨","𩛏"}
	a[85574]={"餴","","𩞳"}
	a[85575]={"锛","𩞑"}
	a[85583]={"𨨹"}
	a[85584]={"䵾","","𩞔","𩞴"}
	a[85587]={"𨧬"}
	a[85593]={"𠐪","𨬟"}
	a[85602]={"儲","𨭎","𩝙"}
	a[85603]={"𦏔","𨯩"}
	a[85605]={"鐟"}
	a[85606]={"𦏋"}
	a[85607]={"鏪"}
	a[85611]={"饎"}
	a[85612]={""}
	a[85614]={"𩞲","𩼫"}
	a[85615]={"𩽫"}
	a[85616]={"𩞄"}
	a[85618]={"𠑤"}
	a[85631]={"估","佑","𠉉","𠯒"}
	a[85641]={"佶","俈","𥑧"}
	a[85643]={"㑬"}
	a[85651]={"傄","𠉊","𡱨","𧮴"}
	a[85652]={"借","偖"}
	a[85656]={"𠍔"}
	a[85661]={"𠎸"}
	a[85662]={"䂒","鈷"}
	a[85663]={"偆","𠍽","𦍩"}
	a[85671]={"僖","𡲞","𩚩"}
	a[85672]={"储","銡","鋯","钴","𧨻"}
	a[85673]={"𦎁"}
	a[85674]={"僣"}
	a[85676]={"傮"}
	a[85682]={"锆","𠏼"}
	a[85683]={"錯","鍺","𠑏","𨪲"}
	a[85692]={"鐑","𩜅","𩜼"}
	a[85693]={"锗","错","𨪌"}
	a[85695]={""}
	a[85701]={"䭉"}
	a[85702]={"𨬍","𩜎"}
	a[85703]={"锖"}
	a[85704]={"𠑦"}
	a[85707]={"䭄"}
	a[85711]={"付","𠆫","𩞢"}
	a[85712]={"𩟕"}
	a[85713]={"鑄","𨮩","𨯫"}
	a[85715]={"𨮾"}
	a[85716]={"钄"}
	a[85717]={"鏏",""}
	a[85722]={"𠇴","𠊠"}
	a[85723]={"𠍆"}
	a[85732]={"佄","侍","侟","偫","𦚘"}
	a[85733]={"𠊃"}
	a[85741]={"侉","侑","倚","𠉈","𠋚"}
	a[85742]={"㑲","侤","侼","倄","厁","釮","鉜","𨥇"}
	a[85743]={"𠋮"}
	a[85744]={"侾","俦"}
	a[85751]={"𩚭"}
	a[85752]={"𠏮","𥏤","𧮳"}
	a[85753]={"钸","𠍶","𨧼"}
	a[85754]={"䤭","備","𨧨"}
	a[85761]={"㑸","傠","𩛙","𩾹","𪀪"}
	a[85762]={"倩","𥏜"}
	a[85763]={"鉗","銌","錺","𠐆"}
	a[85764]={"鏋"}
	a[85765]={"傳"}
	a[85767]={"倳","𠉩"}
	a[85768]={"傋"}
	a[85771]={"𪘓"}
	a[85772]={"銙","銪","錡","𠍰","𨦘","𩚵"}
	a[85773]={"銬","鋍","钳","𠌴","𨩇","𩞘"}
	a[85774]={"𠎐"}
	a[85775]={"鋳","﨧"}
	a[85782]={"铕","锜","餑","餚"}
	a[85783]={"鑆","铐"}
	a[85784]={"𡡭","𨩥"}
	a[85785]={"铸","𨨲"}
	a[85788]={"鑻"}
	a[85791]={"𠑃","𪙄"}
	a[85792]={"䤻","儔"}
	a[85793]={"錆"}
	a[85794]={"𨮬"}
	a[85796]={"鏄","𨭬"}
	a[85798]={"𨧫","𨪇"}
	a[85799]={"𨪋"}
	a[85801]={"豄"}
	a[85802]={"儹","镇"}
	a[85803]={"䥊","饙"}
	a[85804]={"𦎸"}
	a[85811]={"㐲","俠","𤈢"}
	a[85812]={"鑟","饡"}
	a[85813]={"鑽","𦏢"}
	a[85814]={"𩟪","𩟲"}
	a[85815]={"傸","鑚"}
	a[85821]={"货"}
	a[85822]={"伕","佚","供","侠","𠉻"}
	a[85833]={"偾"}
	a[85841]={"𠏗"}
	a[85842]={"倛","债","儊","谼","釱","鋏","𨦗"}
	a[85844]={"侇"}
	a[85846]={"鏯"}
	a[85851]={"貨","𩛩"}
	a[85853]={"鈇","鉄","鉷","𨩅"}
	a[85854]={"僙"}
	a[85855]={"倢"}
	a[85861]={"傎","𠏱"}
	a[85862]={"𩛘"}
	a[85863]={"僨","铁","铗"}
	a[85865]={"锳"}
	a[85866]={"傼"}
	a[85872]={"債","𠏴","𠐑","𨭼"}
	a[85873]={"錤","𧷐","𨭣"}
	a[85875]={"銕","𨦶"}
	a[85876]={"羠"}
	a[85881]={"儥"}
	a[85883]={"𦎳"}
	a[85884]={"儧"}
	a[85885]={"鐄","𨨯"}
	a[85892]={"鎮"}
	a[85894]={"鐼","𩞩"}
	a[85895]={"羵","𨱑"}
	a[85911]={"休","倈"}
	a[85914]={"𩟰"}
	a[85922]={"㑈","㑣","佅","侏","俫","𠇱"}
	a[85931]={"倷"}
	a[85933]={"㑍","㑛","𠋖","𠎊"}
	a[85941]={"僚","𠋲"}
	a[85942]={"僸","鈢","銝","錸"}
	a[85943]={"傑","傣","𨦅"}
	a[85944]={"倲","偞","𠍷"}
	a[85952]={"傃","𠐐","𨭁"}
	a[85953]={"銖","铩","𠎀","𨦉"}
	a[85954]={"䍪","𠍀","𦎖"}
	a[85961]={"𣜟"}
	a[85962]={"䬴","錼"}
	a[85963]={"铢","铼"}
	a[85964]={"銇","鋉","鍊"}
	a[85965]={"𣔍","𥏭","𦎏"}
	a[85971]={"䭜"}
	a[85972]={"鎍","鐐","𨫜"}
	a[85973]={"餗","𨭺"}
	a[85974]={"𨱈","𩝀"}
	a[85975]={"錬","鍱","𦉃"}
	a[85976]={"䍶"}
	a[85982]={"镣"}
	a[85983]={"𩝇"}
	a[85984]={"䭎","𩜍"}
	a[85992]={"𩝥"}
	a[85995]={"䥡"}
	a[86001]={"𨯬","𩟍"}
	a[86011]={"𨭦"}
	a[86012]={"𩠲"}
	a[86020]={"㐰","𠇂"}
	a[86022]={"㑖"}
	a[86030]={"伵","𠉢"}
	a[86031]={"伽","佃","俰","𠉍"}
	a[86032]={"伷","侞"}
	a[86034]={"㑋"}
	a[86040]={"佪"}
	a[86041]={"倁","知"}
	a[86051]={"個","釦","𥎭"}
	a[86052]={"䜬","𥎴"}
	a[86061]={"鈤","𥎶"}
	a[86062]={"㒁","鈿","鉫","銦","𨨛"}
	a[86063]={"䍰","鈾","銣"}
	a[86070]={"𠌛","𠎡","𩚣"}
	a[86071]={"䤧","鉬","𠋼"}
	a[86072]={"钿","铟"}
	a[86073]={"铀","铷"}
	a[86081]={"钼"}
	a[86082]={"錮"}
	a[86091]={"䭅"}
	a[86092]={"锢"}
	a[86112]={"饠","𩟹"}
	a[86113]={"鑺","鑼","𩞯"}
	a[86114]={"㒦"}
	a[86115]={"鑸","𨰋"}
	a[86140]={"但","𠇝"}
	a[86151]={"侱"}
	a[86152]={"堡"}
	a[86153]={"俚"}
	a[86171]={"鉭"}
	a[86174]={"僼"}
	a[86180]={"饂"}
	a[86181]={"鎠","鎾","钽","𨩄"}
	a[86182]={"儸","鋥"}
	a[86184]={"鋰"}
	a[86185]={"𦎐"}
	a[86191]={"𩛦"}
	a[86192]={"锃","𠏄"}
	a[86193]={"鍟"}
	a[86194]={"锂","𦎬"}
	a[86195]={"𡒟"}
	a[86201]={"𨯴"}
	a[86230]={"㑩"}
	a[86241]={"㑭"}
	a[86250]={"𠉬"}
	a[86262]={"鎅"}
	a[86271]={"锣"}
	a[86290]={"𩜟"}
	a[86300]={"𩟁"}
	a[86301]={"䥪","镮","𨰄"}
	a[86311]={"𨰟"}
	a[86312]={"䭤","罎","𦉡","𩝽"}
	a[86313]={"鏹","鑓","镪"}
	a[86314]={"𩟊"}
	a[86317]={"𨰍"}
	a[86320]={"𠈉"}
	a[86322]={"𠊞"}
	a[86331]={"㷛"}
	a[86341]={"偲"}
	a[86350]={"𢞫"}
	a[86351]={"偎","𢜔"}
	a[86353]={"𠏋","𢠙","𨨩"}
	a[86354]={"𠌼"}
	a[86360]={"儇"}
	a[86362]={"𨪜"}
	a[86363]={"鉵"}
	a[86370]={"儑"}
	a[86371]={"𠐛"}
	a[86372]={"蝕","鍶"}
	a[86373]={"𧌲","𨭆"}
	a[86374]={"儂","𦏉"}
	a[86381]={"𢤁","𤒸","𨨴"}
	a[86382]={"儙","鍡","锶","𠎦","𠑌","𧔈"}
	a[86383]={""}
	a[86385]={"𨫑"}
	a[86386]={"䍺"}
	a[86391]={"鐶","餵"}
	a[86392]={"𦏖"}
	a[86400]={"餛","𧢐"}
	a[86401]={"矲","锟"}
	a[86410]={"𧢪","𨞡"}
	a[86411]={"䚐","䥯","鼅"}
	a[86412]={"儬","𧢢"}
	a[86413]={"観","𨞀"}
	a[86420]={"㑆"}
	a[86430]={"侃"}
	a[86434]={"𠈐"}
	a[86440]={"𡯒"}
	a[86441]={"𡰂"}
	a[86442]={"𧉇"}
	a[86450]={"俋","俔","𡯧","𧠝"}
	a[86451]={"𤭭"}
	a[86460]={"倱","𠋨","𧠚"}
	a[86462]={"𠊟"}
	a[86470]={"𩚶"}
	a[86471]={"䂓","𨦆"}
	a[86472]={"𨚽"}
	a[86473]={"㲛"}
	a[86480]={"䚊","𠐌"}
	a[86481]={"儭","鋧","鎤","𨧏"}
	a[86482]={"𧠡"}
	a[86490]={"䭂","覦"}
	a[86491]={"錕","𧡐"}
	a[86492]={"𧡞"}
	a[86501]={"饅"}
	a[86502]={"䭞","镘"}
	a[86507]={"饆"}
	a[86512]={"儼"}
	a[86513]={"𠑩","𥐑","𨰃","𨰫"}
	a[86514]={"䦆","钁","","𦉕","𨭐"}
	a[86522]={"仲"}
	a[86531]={"𠊗"}
	a[86532]={"𠇺"}
	a[86533]={"伸"}
	a[86541]={"𠉖","𠋍"}
	a[86542]={"𠈷","𠋻"}
	a[86543]={"𠉶"}
	a[86553]={"鈡"}
	a[86554]={"鉂"}
	a[86561]={"偮","僈"}
	a[86562]={"銱","𥏅"}
	a[86563]={"鉀","钟","𥏓"}
	a[86564]={"鉮"}
	a[86567]={"𠌫"}
	a[86568]={"僂"}
	a[86572]={"铞","𩚲"}
	a[86573]={"钾"}
	a[86574]={""}
	a[86575]={"鋛"}
	a[86581]={"䜱"}
	a[86582]={"聟","銲","𥏯"}
	a[86583]={"僤","𨪶"}
	a[86590]={"𦎹"}
	a[86591]={"𩛧"}
	a[86592]={"鍓","鏝"}
	a[86593]={"鐸"}
	a[86598]={"鏎"}
	a[86599]={"鏤"}
	a[86601]={"𠐠","𩞓"}
	a[86602]={"𩞒"}
	a[86610]={"𠐨","𠑪"}
	a[86612]={"𩞮","𪛋"}
	a[86614]={"鑘"}
	a[86640]={"侣","侶"}
	a[86660]={"倡","偘"}
	a[86670]={"𠌜","𧧹","𧨍"}
	a[86671]={"智","鋁"}
	a[86672]={"𦎑"}
	a[86680]={"諐","𠏘"}
	a[86681]={"铝","𨼓"}
	a[86691]={"錩","锠"}
	a[86693]={"䣽","儡"}
	a[86701]={"鍔","鎉","𨭜"}
	a[86702]={"𠏬","𦉅","𦎲","𨫘","𩞾"}
	a[86703]={"䥟","镯"}
	a[86711]={"锷","𨪒"}
	a[86712]={"𩝡","𩟉"}
	a[86714]={"𨢰"}
	a[86740]={"㑥"}
	a[86742]={"侽","𠌳"}
	a[86750]={"偈","偒","𠉌"}
	a[86752]={"俜"}
	a[86753]={"偶"}
	a[86760]={"𠎯","𠏑"}
	a[86762]={"㒔","䤢"}
	a[86770]={"偔","傝"}
	a[86771]={"錫","𠕧","𥏫"}
	a[86772]={"锅","𥏃","𧮹"}
	a[86780]={"儩","𩛿"}
	a[86781]={"鋗","鍚","鍻","锡","𨫖","𪃁"}
	a[86782]={"羯","鍀","𦎪"}
	a[86784]={"鍝"}
	a[86790]={"䬼","餲","餳"}
	a[86791]={"鐊","鐋"}
	a[86792]={"蠲","锝","𨩋"}
	a[86793]={"鐲"}
	a[86794]={"𦏕"}
	a[86803]={"鐀"}
	a[86804]={"罆","鏆"}
	a[86812]={"饋"}
	a[86820]={"伿"}
	a[86830]={"促"}
	a[86831]={"煲"}
	a[86841]={"㑨","俁","俣"}
	a[86850]={"倶","偍"}
	a[86851]={"䍉","鉙","𠋬"}
	a[86860]={"傊"}
	a[86861]={"鋜"}
	a[86862]={"𨦚"}
	a[86863]={"𦎀"}
	a[86864]={"𨦢"}
	a[86871]={"賲","鋇"}
	a[86872]={"僓","鋘"}
	a[86873]={"𠍿"}
	a[86881]={"䝷","鍉","𦉁"}
	a[86884]={"𨱌"}
	a[86886]={"𨭄"}
	a[86890]={"𧸑","𩝊"}
	a[86893]={"𩞫"}
	a[86900]={"䭘"}
	a[86901]={"𩟎"}
	a[86902]={"鐰"}
	a[86903]={"𦏛"}
	a[86913]={"儽"}
	a[86931]={"保"}
	a[86940]={"𣶚"}
	a[86943]={"倮"}
	a[86951]={"䤽","傫","𠋸"}
	a[86952]={"𣔇"}
	a[86960]={"𠎠"}
	a[86962]={"儤","𨩚"}
	a[86971]={"䭋","僺","𩛴"}
	a[86973]={"𠑔"}
	a[86974]={"錁"}
	a[86982]={"鏍","镙"}
	a[86983]={"餜"}
	a[86984]={"锞"}
	a[86991]={"鐛"}
	a[86993]={"鑤"}
	a[87000]={"𩜺"}
	a[87001]={"餬","","𦒟","𨪵"}
	a[87002]={"䥜","𦎿"}
	a[87005]={"𠑧"}
	a[87010]={"仞","仢","伆","𠇩","𧯑"}
	a[87011]={"㐻","仂","伪"}
	a[87012]={"仭","𠑨"}
	a[87020]={"伨","𠈀","𠈟"}
	a[87022]={"俲"}
	a[87030]={"仴","佝","𠇶"}
	a[87031]={"㑃"}
	a[87032]={"佣","剏"}
	a[87033]={"㑄","㔙"}
	a[87034]={"𠇦"}
	a[87040]={"㑡","伺","侗","侚","𠊉"}
	a[87041]={"㑢","㔕","䜯","䥼","釖","釣","釰","𠊐","𠍖","𠠶","𨦪","𩚛"}
	a[87042]={"剱","釛","鈉","𠉨","𦐵"}
	a[87043]={"劷","釼"}
	a[87050]={"䬢","翎","𩚈","𩚒"}
	a[87051]={"䦀","倜","朔","鈎","鈞","钓","𠛺","𦑒","𨦫"}
	a[87052]={"钠","钢","𦍨","𦑔","𨥸","𨨠"}
	a[87053]={"𠡬"}
	a[87054]={"勄","𥎳"}
	a[87060]={"倗","劎","劒","朆","𠎒","𠞴","𩚘","𩚱"}
	a[87061]={"勜","罁","鈅","鉤","鋼","钧","钩","𠡼","𥏊","𩛺"}
	a[87062]={"劔","𦍤","𦍵","𩛵"}
	a[87064]={"鉧","𠢄"}
	a[87065]={"䍭","䤡","銏"}
	a[87070]={"䎏","䬲","翖","𩛯"}
	a[87071]={"䬨","鉰","銁","銅","钥","𠎓","𧮻"}
	a[87072]={"翔","鋾","𠎞","𥏨","𦍻","𦍿","𨧶"}
	a[87073]={"𨦲"}
	a[87074]={"勧",""}
	a[87076]={"働"}
	a[87080]={"飼","餇","𠍒","𦑦"}
	a[87081]={"铜","𦑤","𩛽"}
	a[87082]={"鋤","錭","鎙","𦈺"}
	a[87083]={"㔦"}
	a[87090]={"䎖"}
	a[87091]={"䭇","錋","鍧","𦒂","𨧹"}
	a[87092]={"鍸","锄","𦑺","𦒈","𩜩"}
	a[87101]={"㒠"}
	a[87103]={"鏗"}
	a[87111]={"𨪐","𨮃"}
	a[87113]={"鑃"}
	a[87114]={"𦏍"}
	a[87130]={"𠇹"}
	a[87131]={"𡔟"}
	a[87132]={"㑠","𠈬"}
	a[87140]={"伹","俎"}
	a[87141]={"㸖","𥁙"}
	a[87151]={"㺱","㺸"}
	a[87153]={"傕","鎥","𢆗"}
	a[87157]={"𡌅"}
	a[87160]={"㒊","𠍈"}
	a[87161]={"偓","𡎬","𩛀"}
	a[87162]={"羟","鈕","𠊣"}
	a[87164]={"儘"}
	a[87171]={"㒘","鉏","𩚖"}
	a[87172]={"塑","錳","钮"}
	a[87173]={"铿","𨧵"}
	a[87180]={"飷","𩛐"}
	a[87181]={"鎺","𠏫"}
	a[87182]={"㒛","锰","𨩙"}
	a[87183]={"𠑝","𦎢"}
	a[87184]={"䥃","𨩰"}
	a[87190]={"𠍄"}
	a[87191]={"𠐊","𨭕"}
	a[87192]={"𨡡"}
	a[87193]={"糴"}
	a[87210]={"㐴"}
	a[87211]={"俢","修",""}
	a[87216]={"鏽"}
	a[87220]={"仰","侈"}
	a[87230]={"卻","𠊬"}
	a[87240]={"僇"}
	a[87241]={"缷","釸"}
	a[87242]={"鎀"}
	a[87251]={"䤝","卸","鉚","鉹","𠏣","𩝧"}
	a[87260]={"䬷","豂","飹","𩚺"}
	a[87261]={"铆"}
	a[87270]={"𠐋"}
	a[87271]={"鏐"}
	a[87281]={"镠"}
	a[87282]={"䥏","𨨶"}
	a[87285]={"𠏐"}
	a[87292]={"𡗍"}
	a[87300]={"𩟂"}
	a[87310]={"𩟄"}
	a[87311]={"佟"}
	a[87320]={"侭","您"}
	a[87321]={"侬","𢞣","𢟅"}
	a[87322]={"偬","𢟂"}
	a[87330]={"㑰"}
	a[87331]={"像","𠉘","𠋂"}
	a[87332]={"怹","𢜂"}
	a[87333]={"𢙠"}
	a[87340]={"佷","慾","𠋎"}
	a[87341]={"𢡮"}
	a[87342]={"鉖","𠌄","𢢑","𤌈"}
	a[87343]={"䖺","𠋺"}
	a[87351]={"鍃"}
	a[87352]={"燞","鯈","𠏭"}
	a[87353]={"儵","鍯","𠉹"}
	a[87360]={"𠏀","𩛓"}
	a[87361]={"䤸","䥂","愬","憌","锪","𠐃","𢣰"}
	a[87362]={"螸","鐌"}
	a[87365]={"𧊰"}
	a[87370]={"餯","𩝬"}
	a[87371]={"䭀","銀","𩞧"}
	a[87372]={"𠐯"}
	a[87374]={"𨪊"}
	a[87377]={"𧒦"}
	a[87380]={"䬶"}
	a[87381]={"银","𠏾","𩝎"}
	a[87382]={"𢤹"}
	a[87383]={"𨫀"}
	a[87385]={"鏠"}
	a[87391]={"鐹","𠑞"}
	a[87394]={"㒩"}
	a[87395]={"冁"}
	a[87400]={"僶"}
	a[87401]={"儳"}
	a[87402]={"𠑗","𪕪"}
	a[87405]={"𠑒"}
	a[87407]={"𪕼"}
	a[87410]={"𠆰","𠑣"}
	a[87411]={"㐽","饞","𨭘"}
	a[87412]={"㒨","鑱","镵","𩟖","𪓰"}
	a[87420]={"㐶","亿","仉","伔","伣","尦","𠆩"}
	a[87421]={"仇","𠆶"}
	a[87422]={"他"}
	a[87430]={"㑉","伲","𠈜"}
	a[87431]={"㖌","佩"}
	a[87432]={"𠌢","𤿑"}
	a[87440]={"佨","佹"}
	a[87441]={"䜪","俛","𠌋","𧮬"}
	a[87442]={"偑","𠒤","𧮭"}
	a[87443]={"釻"}
	a[87444]={"𠌁"}
	a[87450]={"倪","𡯚"}
	a[87451]={"釔","釠","釩","𨥈"}
	a[87452]={"釚","鈂","𠍠","𧮷","𨥐"}
	a[87453]={"釶"}
	a[87454]={"𠋞","𠌷","𦍔"}
	a[87460]={"䒊","俷","觎","飢","𠍃","𠏙","𡰊","𣩭","𩚑","𪗗"}
	a[87461]={"䤟","釲","鈀","鈮","钇","钒","铇","𥎾","𨥩"}
	a[87462]={"羓","艵","谻","𨦨","𩚉","𩚐"}
	a[87470]={"𠌑","𠏵","𩚗","𩚥","𩚯"}
	a[87471]={"䤥","鉋","銫","钯","铌","𨥹"}
	a[87472]={"䍯","䬇","鈱","鋔","𦫧"}
	a[87473]={"𩗩"}
	a[87480]={"飽","𩜮"}
	a[87481]={"铯","𨭾","𩛟"}
	a[87482]={"䍲","𨩶"}
	a[87483]={"𨩯"}
	a[87485]={"𨪅"}
	a[87490]={"䒏","𦫫"}
	a[87491]={"𨬫","𨭿","𩜧","𩝸"}
	a[87492]={"㐥","䬿"}
	a[87502]={"鍜","𨩷"}
	a[87503]={"锻","𦎮"}
	a[87505]={"餫","𨮂"}
	a[87506]={"𦏘"}
	a[87508]={"鍵","𨫡"}
	a[87511]={"仅","𠐽"}
	a[87512]={"𩝁"}
	a[87514]={"𦎾"}
	a[87515]={"𨱕"}
	a[87517]={"䭈"}
	a[87518]={"键"}
	a[87521]={"伋"}
	a[87522]={"佊"}
	a[87523]={"伮","𠈍"}
	a[87531]={"伇","俶","𠇛"}
	a[87532]={"伄","伜","叙"}
	a[87533]={"伊","佭"}
	a[87536]={"佛"}
	a[87542]={"偋","釵"}
	a[87544]={"𠉏"}
	a[87545]={"𠎕"}
	a[87551]={"侵","𠈧","𠈿","𩚄","𩚍"}
	a[87552]={"傁","鈒","钗","𠉧","𠌬","𤿫","𥀟"}
	a[87553]={"鈹"}
	a[87554]={"𦍷"}
	a[87556]={"侓"}
	a[87562]={"㑴","鈠","钑","𠌸","𨦯","𨧞","𨧷"}
	a[87563]={"偉","羖","鈟","铍","𢍥","𥀃","𨨏","𨩻"}
	a[87564]={"𦈫","𨥠","𨥻","𨦟"}
	a[87565]={"㑮","𥏞","𨍁"}
	a[87566]={"鞗"}
	a[87567]={"鉘"}
	a[87571]={"䬦","假","𠐖","𣫍","𩜂"}
	a[87572]={"𨱁","𩜤"}
	a[87573]={"","𦉇","𨬯"}
	a[87574]={"㿷","鎩","铎","𠎿"}
	a[87575]={"鋒","錣"}
	a[87576]={"䍳","𠍟"}
	a[87577]={"健","𦘗"}
	a[87582]={"鋟","𨧪","𨨘"}
	a[87583]={"鋷","鎪"}
	a[87584]={"餟"}
	a[87585]={"锋","𥀞"}
	a[87587]={"銉"}
	a[87592]={"锓","餿"}
	a[87593]={"鍛","锼"}
	a[87594]={"鍏"}
	a[87595]={"䍷"}
	a[87596]={"鍕"}
	a[87599]={"𩎵"}
	a[87601]={"镅","𥖹","𦉜","𧫋","𨩩"}
	a[87602]={"鍲","鏴","鑥"}
	a[87604]={"𨫛"}
	a[87610]={"𩟋"}
	a[87612]={"镥"}
	a[87616]={"𩟫"}
	a[87630]={"佋","佲"}
	a[87631]={"佫"}
	a[87641]={"㫦","𠌃"}
	a[87642]={"俻","偹"}
	a[87651]={"䂏","倨","𠌪"}
	a[87653]={"侰"}
	a[87660]={"㑾","𠋥"}
	a[87661]={"鉊","銘","𠊽"}
	a[87662]={"㑼","鉻","𨦳"}
	a[87670]={"䬰","儋"}
	a[87671]={"鉛","铭","餎","","𠐔","𨩲"}
	a[87672]={"铬","𥏵","𨡢"}
	a[87680]={"𩜴"}
	a[87681]={"铅"}
	a[87682]={"䥁","鋸","鎦","𦉉","𩜗"}
	a[87683]={"𦎠","𨧙"}
	a[87684]={"𨧡"}
	a[87691]={"鎇","餾"}
	a[87692]={"锯","镏","𦏂"}
	a[87693]={"𨪿"}
	a[87700]={"餶"}
	a[87710]={"𠆨","𩝣"}
	a[87711]={"𪅰"}
	a[87712]={"鐞"}
	a[87713]={"钃","𡦸"}
	a[87714]={"䥹","𨬖"}
	a[87720]={"仍","伃","𠈕"}
	a[87721]={"仔","𠋇"}
	a[87730]={"㐷","𠈥"}
	a[87731]={"偽","𠈡","𠉺"}
	a[87732]={"𠊇"}
	a[87740]={"㑇","佀","","𠈎","𠌇"}
	a[87741]={"倔","脩","釕"}
	a[87742]={"㑳","俑",""}
	a[87743]={"鿇"}
	a[87750]={"侷","偦","僪","𠊰","𠋱"}
	a[87751]={"翛","釢","钌","𨥤","𨥨"}
	a[87752]={"釨","𦍗","𨥂"}
	a[87753]={"𠋀","𠐕","𦎆"}
	a[87760]={"傦","𠋹"}
	a[87761]={"䤴","舒","钖","𠊫","𡥫","𨰾"}
	a[87762]={"𠏈","𥏘"}
	a[87763]={"𠊩","𢵡","𨦹"}
	a[87770]={"𨞤"}
	a[87771]={"䥾","鈻","铴","𨱍"}
	a[87772]={"䭏","鏅","鏘","锵","𨧱","𨫒"}
	a[87773]={"銿","𠁜","𨞿","𨨳","𨪕"}
	a[87774]={"䦁","錚","𦎈","𨧜"}
	a[87775]={"䍵","𦎚"}
	a[87776]={"𤕛"}
	a[87780]={"𨝙","𩝄"}
	a[87781]={"鋦","錎","鍋","鐍","𠎅","𩝴"}
	a[87782]={"𨱊","𨱐","𩛤"}
	a[87783]={"僝","𠐮"}
	a[87784]={"铮"}
	a[87790]={"餡","𠍻","𧯐","𩝔"}
	a[87791]={"锔","𨪷"}
	a[87792]={"𦎰"}
	a[87793]={"𩜳"}
	a[87796]={"䤿"}
	a[87801]={"𨩸"}
	a[87802]={"龡"}
	a[87807]={"鐨"}
	a[87810]={"㐸","㰡","𠇉","𠇧","𩜹"}
	a[87811]={"䥲","倐","𨮔","𨯵","𨯺","𨰷","𩟱"}
	a[87812]={"鑦","饌","𨰐"}
	a[87813]={"鐉","𦧸"}
	a[87814]={"䍻"}
	a[87820]={"伬","佽","俽","欦","𣢏","𣢝","𣢲","𣣈"}
	a[87822]={"佒","倏"}
	a[87830]={"欲","𠈳","𠈴","𣢉","𣢍"}
	a[87831]={"欮","𥎯"}
	a[87833]={"𠍫"}
	a[87834]={"倎"}
	a[87840]={"㰟","欱","𠊕","𠊸","𣢆","𣢺","𣣼"}
	a[87841]={"侯","候","欽","缼","𠉀","𠊱","𠋟","𠋫","𣤏","𨁀","𨨢","𩵑"}
	a[87842]={"㰸","𣢴","𣣵"}
	a[87850]={"俱","偩","歈","飲","𠋶","𣣔","𣣽"}
	a[87851]={"欫","鈬","鍁","钡","钦","𣣠"}
	a[87852]={"僛","𠋋","𣣫","𣤚","𩚟"}
	a[87853]={"缺","鈌","鉠"}
	a[87854]={"偰"}
	a[87857]={"歉"}
	a[87860]={"歛","飮","𠑁","𣣢","𣤉","𣤗","𤒡"}
	a[87861]={"儗","锨","𧯁","𧯂"}
	a[87862]={"䬬","𨩉"}
	a[87865]={"錪"}
	a[87870]={"𠊨","𠏩"}
	a[87871]={"𠐀","𨅠"}
	a[87872]={"㱃","歚","鍭","𨩀","𨫗"}
	a[87873]={"歓","𠏤"}
	a[87874]={"鏉","𠎇"}
	a[87880]={"㒜","歙"}
	a[87881]={"餱","𠑎","𩝍"}
	a[87882]={"䥗","僎","","𨮅"}
	a[87884]={"𨱒"}
	a[87885]={"鍥"}
	a[87887]={"镄"}
	a[87890]={"𧷴","𩜃"}
	a[87895]={"锲"}
	a[87902]={"𨯣"}
	a[87910]={"你","𠉎"}
	a[87912]={"龣"}
	a[87920]={"𠇡"}
	a[87921]={"𠈃","𣐗"}
	a[87922]={"條"}
	a[87931]={"㑱","絛"}
	a[87940]={"傺"}
	a[87941]={"鉨"}
	a[87942]={"儏","𠍇","𦍴"}
	a[87943]={"𠎖"}
	a[87951]={"𠋕","𠌖","𣗰"}
	a[87952]={"䤪","𨦃","𨨥"}
	a[87961]={"錄","𣺩"}
	a[87962]={"槊","鍒","鑗"}
	a[87963]={"𠎧","𦎤","𨬏"}
	a[87971]={"録","𦃗","𨨮","𩜷"}
	a[87973]={"𨮏"}
	a[87975]={"鎟"}
	a[87980]={"𩛼","𩠟"}
	a[87982]={"𣘟"}
	a[87984]={"𩛾"}
	a[87993]={"䌓"}
	a[87994]={"䥛"}
	a[88000]={"㐺","仈","从","𠆧","𠓜"}
	a[88010]={"似"}
	a[88031]={"釞","釟","𨥎"}
	a[88032]={"𦍏"}
	a[88040]={"飤"}
	a[88041]={"鉯"}
	a[88050]={"䬮","𩛮"}
	a[88101]={"鑑"}
	a[88103]={"饈"}
	a[88104]={"鳘"}
	a[88110]={"丛"}
	a[88111]={"𡔗"}
	a[88112]={"𨯿","𨰹"}
	a[88114]={"𨰻"}
	a[88120]={"俭","𠊧"}
	a[88121]={"侳","坐"}
	a[88130]={"㑅"}
	a[88131]={"佺","𠊄","𥁮"}
	a[88140]={"𠈝","𠈨"}
	a[88141]={"𨥷"}
	a[88142]={"矬","鋚"}
	a[88151]={""}
	a[88152]={"傞","銼"}
	a[88161]={"鎰","𩛠"}
	a[88162]={"銓","鍂","锉","","𥏧"}
	a[88170]={"儖"}
	a[88171]={"镒",""}
	a[88172]={"铨","𨩳"}
	a[88173]={"𥏺"}
	a[88182]={"𩝭"}
	a[88183]={"鎈"}
	a[88200]={"价","𠁥"}
	a[88210]={"仱"}
	a[88230]={"作","𧮰"}
	a[88231]={"鉁","𨱅"}
	a[88232]={"𦍪"}
	a[88240]={"飻"}
	a[88241]={"鈐"}
	a[88242]={"𨨞"}
	a[88250]={"𩚕"}
	a[88251]={"钤"}
	a[88261]={"鈼"}
	a[88270]={"飵"}
	a[88302]={"𩟳"}
	a[88310]={"㑫","伀","伶","怂"}
	a[88312]={"䭥","𣌞"}
	a[88320]={"倊"}
	a[88321]={"倯","悠"}
	a[88330]={"侩"}
	a[88331]={"𠌡","𢢱"}
	a[88334]={"㒇"}
	a[88340]={"㤰","偸","𠋡","𢠚"}
	a[88341]={"䍅","鈆","鈴"}
	a[88342]={"羚"}
	a[88343]={"𧌁"}
	a[88347]={"傔"}
	a[88350]={"𠏚","𩚹","𩝌"}
	a[88351]={"䥙","錜","鐩","铃","","𨨟","𨨡","𩛢"}
	a[88352]={"𩀨","𩥝"}
	a[88360]={"䭃","𠏧","𩜏"}
	a[88362]={"鎹","𠐒"}
	a[88363]={"𦎴"}
	a[88364]={"慜"}
	a[88371]={"餸","餻","𨩭","𩛕"}
	a[88372]={"𠐣","𧐂"}
	a[88378]={"鎌"}
	a[88381]={"䭐","鎡","𩛒"}
	a[88382]={"𨭝"}
	a[88387]={"䭑"}
	a[88390]={"𩝐"}
	a[88391]={"镃"}
	a[88394]={"鰵"}
	a[88410]={"伦","𡯗"}
	a[88411]={"鑬","𨰲"}
	a[88416]={"𩴨"}
	a[88420]={"伧","𠒃"}
	a[88430]={"㐹","仡","侻"}
	a[88432]={"𢼠"}
	a[88441]={"㑶"}
	a[88442]={"𠉒"}
	a[88451]={"銳","","𨦣"}
	a[88455]={"儀"}
	a[88457]={"𡰉"}
	a[88461]={"釳","鋭"}
	a[88463]={"鉇"}
	a[88464]={"𦍥"}
	a[88470]={"䬣","䬽","𩚤"}
	a[88471]={"锐","𠏌","𨥊","𨰿"}
	a[88472]={"鎎","𧇐","𩛆"}
	a[88473]={"錓","𨧯"}
	a[88480]={"𡰛","𩜐"}
	a[88481]={"餼"}
	a[88482]={"𨯥"}
	a[88483]={"鍦"}
	a[88491]={"𩛹"}
	a[88501]={"𠇑"}
	a[88502]={"䭛"}
	a[88503]={"镦","饊"}
	a[88505]={"𥍅"}
	a[88511]={"攸","𠦏","𡴤","𢻺"}
	a[88514]={"𦏭"}
	a[88521]={"仵","攽","𠈅","𠈹","𠈼","𢆑"}
	a[88522]={"併","傚","𠁮","𠍯"}
	a[88523]={"㛜"}
	a[88531]={"倣","敓","敛","敜","𠊮"}
	a[88532]={"佯","俤","夎","敘","𠇪","𠇫","𠈠","𢍩","𥎪"}
	a[88533]={"𠉿","𢼶"}
	a[88541]={"㩿","㪉","僘","敚","耸"}
	a[88542]={"做","𢽑","𨥞"}
	a[88543]={"㪘","䍩","","𠋄","𠌒","𢼏"}
	a[88544]={"敒","𠍏"}
	a[88551]={"𠊹","𠌝","𢾄"}
	a[88552]={"鉓","𠊷","𩛅"}
	a[88553]={"䥕","傲","儆","缾","鉼"}
	a[88554]={"敏","𠍁","𡠅"}
	a[88561]={"儌","斂","飾","𢿴"}
	a[88562]={"㒈","餅","𠎄","𨩺"}
	a[88563]={"銻","","","𠎭","𨦡"}
	a[88565]={"𨎯"}
	a[88566]={"䩦","僌","儛"}
	a[88572]={"䬺","䬾","𢅸"}
	a[88573]={"敾","锑"}
	a[88574]={"𨿘"}
	a[88575]={"𨫾"}
	a[88576]={"𤛎"}
	a[88579]={"𠐍"}
	a[88581]={"𩞥"}
	a[88582]={"䥩","豃","鍑","𥐊","𨨽"}
	a[88583]={"𦎭"}
	a[88584]={"𨫼"}
	a[88591]={"𩜲"}
	a[88592]={"䥞","𨫙","𨱖"}
	a[88593]={"鐓","𨬒"}
	a[88594]={"鏾"}
	a[88600]={"䭝","𠑐","𩠬"}
	a[88601]={"𥃙"}
	a[88602]={"饍"}
	a[88603]={"䦅"}
	a[88610]={"𠐼"}
	a[88614]={"𡆃"}
	a[88616]={"𩁰"}
	a[88620]={"俗","𠈻"}
	a[88630]={"㫺","佮","𠉐","𠎥"}
	a[88632]={"𠊆"}
	a[88641]={"倽"}
	a[88650]={"䁞","傖","僧","谽","𧮵"}
	a[88651]={"䀺","鋊"}
	a[88652]={"偤"}
	a[88660]={"儈","𣊦"}
	a[88661]={"䥘","鉿","鋡","𧮿"}
	a[88662]={"僐","𦎌"}
	a[88670]={"餄","𥊃","𧯒"}
	a[88671]={"矰","铪","𥏲","𥐅"}
	a[88672]={"𨨝"}
	a[88673]={"𨩊"}
	a[88680]={"𧭨","𩞰"}
	a[88681]={"鎗","鏳","鐠","𠏜","𩜉"}
	a[88682]={"𦏏"}
	a[88690]={"𩝞"}
	a[88691]={"镨","𨭗"}
	a[88693]={"鐥",""}
	a[88700]={"𩞃"}
	a[88703]={"𨯪","𪄴"}
	a[88704]={"𨱔"}
	a[88710]={"份","佡","𠉚"}
	a[88711]={"𨰝"}
	a[88712]={"𠑥"}
	a[88713]={"鑰"}
	a[88720]={"竹","𠆵"}
	a[88721]={"伤"}
	a[88730]={"佾","𠕞","𦠗","𧮱"}
	a[88732]={"倫"}
	a[88740]={"偂","偷","𠊈"}
	a[88741]={"鈖","𦠪"}
	a[88742]={"羒","𠍢"}
	a[88743]={"侮"}
	a[88746]={"𨯖"}
	a[88750]={"傟"}
	a[88751]={"𠷜","𦐻","𨥟","𩚝"}
	a[88752]={"𠎬"}
	a[88756]={"𨯡"}
	a[88760]={"㒐","傷","𥴒","𦠡"}
	a[88761]={"飭"}
	a[88762]={"𨪗"}
	a[88763]={"僔","錀"}
	a[88770]={"㒆"}
	a[88771]={"鍮","鎆","𠐵","𩛊"}
	a[88772]={"羭","𪘗"}
	a[88774]={"鋂"}
	a[88780]={"𥷹","𩜶"}
	a[88781]={"鎓","𠐫","𥏻","𨱎"}
	a[88783]={"鎿"}
	a[88791]={""}
	a[88792]={"㒢"}
	a[88793]={"镎"}
	a[88794]={"罇","鐏"}
	a[88800]={"𠇒","𠈌","𠉭","𠑲"}
	a[88810]={"傱","𩖐"}
	a[88811]={"焂","𠊅","𡚅"}
	a[88821]={"𠈪","𥏀"}
	a[88832]={"倹"}
	a[88841]={"跾","鏦"}
	a[88850]={"僋","儉","𩞆"}
	a[88852]={"鉃"}
	a[88860]={"餩"}
	a[88861]={"𤒥"}
	a[88862]={"𦏠"}
	a[88872]={"𨬢"}
	a[88873]={"鎂"}
	a[88881]={"鏇","鐱","镟"}
	a[88882]={"羷","鏃","𩝏"}
	a[88883]={"镁"}
	a[88884]={"𦏇"}
	a[88890]={"𩟅"}
	a[88892]={"镞"}
	a[88894]={"䥖"}
	a[88900]={"伱"}
	a[88920]={"𦃚","𦅪"}
	a[88921]={"俆"}
	a[88922]={"𣒼"}
	a[88931]={"鉩"}
	a[88941]={"𨪂"}
	a[88950]={"𩚸"}
	a[88951]={"𠍵"}
	a[88953]={"䍱"}
	a[88961]={"餘"}
	a[88972]={"𩜣"}
	a[88974]={"繁"}
	a[88991]={"𩞭"}
	a[88994]={"瀪"}
	a[89000]={"仦"}
	a[89031]={"釥"}
	a[89141]={"𠐓"}
	a[89144]={"𠍧"}
	a[89151]={"㑽"}
	a[89152]={"催"}
	a[89162]={"𠐹"}
	a[89171]={"𥏸"}
	a[89172]={"𨯗"}
	a[89173]={"𨫠"}
	a[89181]={"鎧","𠑜"}
	a[89182]={"鏜"}
	a[89183]={"鏙","𦉎"}
	a[89190]={"䭓"}
	a[89191]={"饄"}
	a[89192]={"镗","𩞅"}
	a[89200]={"仯"}
	a[89210]={"𠈱"}
	a[89220]={"㑕","侺"}
	a[89230]={"𠊵"}
	a[89231]={"鈔"}
	a[89240]={"𠋝","𩚙"}
	a[89241]={"䤬","钞"}
	a[89247]={"㝺"}
	a[89251]={"䤫","䤱"}
	a[89270]={"𩟑"}
	a[89274]={"𨫺"}
	a[89303]={"钂"}
	a[89311]={"𠌎"}
	a[89321]={"僽"}
	a[89340]={"偿"}
	a[89353]={"𠋷"}
	a[89361]={"𨬂"}
	a[89372]={"儻"}
	a[89373]={"𨩪"}
	a[89384]={"䥀"}
	a[89393]={"𩝚"}
	a[89410]={"𠇵","𠌻"}
	a[89420]={"侊"}
	a[89430]={"㒌","𠎽"}
	a[89440]={"傥"}
	a[89442]={"倦","𡯲"}
	a[89450]={"𠍕"}
	a[89451]={"銧"}
	a[89461]={"𨭊"}
	a[89462]={"𠎺"}
	a[89463]={"𥏙"}
	a[89471]={"鎲"}
	a[89473]={"錈"}
	a[89481]={"铠","镋","𨬌"}
	a[89482]={"𩜇"}
	a[89483]={"锩"}
	a[89504]={"𦏦"}
	a[89512]={"㑞","𠈤"}
	a[89521]={"𠈦","𠊂"}
	a[89522]={"伴"}
	a[89523]={"偻"}
	a[89531]={"𠈶"}
	a[89533]={"𠌍"}
	a[89534]={"𠊶"}
	a[89541]={"𠊀"}
	a[89542]={"𠌏"}
	a[89543]={"僯"}
	a[89552]={"銟","𠵵"}
	a[89553]={"鉡","𨪍","𨮽"}
	a[89561]={"𠑄"}
	a[89562]={"䬳"}
	a[89564]={"镂"}
	a[89572]={"錌","鏛"}
	a[89574]={"鏻"}
	a[89583]={"𩞻"}
	a[89584]={""}
	a[89585]={"鎽"}
	a[89601]={"𩟈"}
	a[89620]={"𠉇"}
	a[89640]={"偗"}
	a[89650]={"𠋜"}
	a[89661]={"儅"}
	a[89670]={"𩛎"}
	a[89680]={"𩜠"}
	a[89692]={"鐺"}
	a[89701]={"鏰"}
	a[89703]={"𨭽"}
	a[89710]={"仙"}
	a[89711]={"镚"}
	a[89712]={"䭨","𩟥"}
	a[89713]={"䥴","鑴"}
	a[89721]={"㑁","僗","𠉅"}
	a[89730]={"俏","倘","偳"}
	a[89732]={"𥏟"}
	a[89733]={"𠉮"}
	a[89741]={"𧯍","𨥉"}
	a[89742]={"䂐","𠍓"}
	a[89752]={"鈯","鐒"}
	a[89753]={"𦍦","𨾻"}
	a[89761]={"銷","鋿","鍴","飿"}
	a[89762]={"𨱄"}
	a[89764]={"儯"}
	a[89770]={"傰","𩜋","𩜵"}
	a[89771]={"铛","销"}
	a[89782]={"㒞","儶","𦉘","𨭃"}
	a[89783]={"罉","鐣"}
	a[89792]={"𩞦"}
	a[89795]={"𨭅"}
	a[89800]={"伙","倓"}
	a[89801]={"鑜"}
	a[89811]={"偢"}
	a[89820]={"𠋌"}
	a[89822]={"𠈖","𠈫"}
	a[89831]={"鈥","錟","𦈦","𨨚"}
	a[89840]={"餤"}
	a[89841]={"钬","锬"}
	a[89842]={"鍬","𥎽","𨧛"}
	a[89851]={"锁","𩝋"}
	a[89852]={"㷕","锹"}
	a[89853]={"羰"}
	a[89870]={"償"}
	a[89871]={"鎖"}
	a[89892]={"𠑇"}
	a[89911]={"侎"}
	a[89921]={"儝"}
	a[89941]={"㒉"}
	a[89942]={"銤"}
	a[89950]={"𧯈","𧯊"}
	a[89952]={"鑅"}
	a[89960]={"𩜖"}
	a[89972]={"鏿"}
	a[89980]={"𩞉"}
	a[89981]={"饓"}
	a[90000]={"⺍","个","忄","","","","𠆤","𡭔","𡼏","𢣻"}
	a[90001]={"㠈","𥼴"}
	a[90004]={"𥽭"}
	a[90005]={"爤"}
	a[90010]={"㦦","爓","邩","郯","𤒻","𨙹","𨞇"}
	a[90013]={"𠓖"}
	a[90014]={"𤑷"}
	a[90015]={"𥽼"}
	a[90016]={"糷"}
	a[90020]={"焖","邖"}
	a[90021]={"悯","𥸬","𨛂"}
	a[90031]={"䢺"}
	a[90040]={"䣊","𨛍"}
	a[90041]={"峫"}
	a[90042]={"𨞧"}
	a[90043]={"𨚦"}
	a[90050]={"䣔","𨜜","𨝡","𨞴"}
	a[90051]={"𨜿"}
	a[90052]={"𡷙"}
	a[90053]={"鄰"}
	a[90060]={"㥃","熌","𨟏"}
	a[90061]={"䣘"}
	a[90070]={"㦖","燜"}
	a[90071]={"憫","燘","𡻙","𢡿"}
	a[90080]={"䣙"}
	a[90082]={"䣣"}
	a[90090]={"憪","燗","𢢀"}
	a[90092]={"酅","𨟎"}
	a[90093]={"㦨","爛"}
	a[90102]={"𡿐"}
	a[90104]={"巏","𤒬"}
	a[90110]={"","","𤆂"}
	a[90111]={"𡾙","𡿡"}
	a[90112]={"𡾪"}
	a[90116]={"𡾿","𩁫"}
	a[90120]={""}
	a[90121]={"㞢","尘","烾","𤍢"}
	a[90130]={"㞬","亗","岦","峜","悾","焢","𡶍","𡶦","𡸃","𤆜"}
	a[90131]={"坣","𡭤","𡸄","𢚍"}
	a[90132]={"恾","𡴀","𤯓","𥹿"}
	a[90140]={"崆","𡶂","𡶽","𡹝","𤇙"}
	a[90141]={"埊","峑","崟","𡸌"}
	a[90142]={"㞷","㟐","峚","雀","𡉚","𡙅","𡴍","𥁠"}
	a[90143]={"𡔨"}
	a[90150]={"豈","𡶆","𡸈","𣥺","𦣟"}
	a[90151]={"堂","𡎨","𡷜","𧯛"}
	a[90152]={"崔","嵀","𡮝","𡷅"}
	a[90153]={"㷑","𦱺"}
	a[90154]={"𡴠"}
	a[90155]={"𥻎"}
	a[90160]={"㟵","愃","煊"}
	a[90161]={"鲎","𡹭","𡻜","𡼄"}
	a[90162]={"崖","嵟","嵳","嶳","𥁸","𧯦"}
	a[90163]={"𢣏","𤐩"}
	a[90164]={"糚"}
	a[90170]={"𡺟","𣦣"}
	a[90171]={"𡓚","𡴧","𡸽"}
	a[90172]={"嶉","𡽰"}
	a[90173]={"嶐","鲞","𡓪","𡺉"}
	a[90174]={"嶊"}
	a[90177]={"懂"}
	a[90182]={"𡽛"}
	a[90185]={"𢤦"}
	a[90186]={"𡽯"}
	a[90192]={"𡿏"}
	a[90194]={"懽","爟","𡿎","𤒽"}
	a[90200]={"少","𡭣","𡮏"}
	a[90210]={"岕","","","𡵯","𡷉"}
	a[90220]={"屵","岁","岑","𡴶","𡵱","𤆽"}
	a[90221]={"𠨲","𡸻"}
	a[90222]={"奍"}
	a[90230]={"岇","峁","𡵫"}
	a[90231]={"㟥","𠩃"}
	a[90240]={"岝","嵾","𡷧","𡼘","𢞲"}
	a[90241]={"𡻣","𢒮"}
	a[90246]={"𤎻"}
	a[90250]={"㗬","𡖹","𡻪"}
	a[90251]={"𡻼"}
	a[90252]={"懜"}
	a[90253]={"崭"}
	a[90260]={"𡸎","𡽐","𡽦"}
	a[90270]={"㦢","㸅"}
	a[90271]={"𡼅"}
	a[90275]={"嶄"}
	a[90285]={"𡽻"}
	a[90290]={"㠑"}
	a[90297]={"𤑳"}
	a[90300]={"尐"}
	a[90307]={"𡿋"}
	a[90310]={"㥕","𡭷","𢖿","𤆟"}
	a[90314]={"𧔮"}
	a[90316]={"𩏸"}
	a[90320]={"㞫","㞮","岺"}
	a[90321]={"𡶞","𢘻"}
	a[90330]={"𡵏","𡹢","𢚏"}
	a[90331]={"崧","𡴁","𡴒","𡵦"}
	a[90332]={"豢","𡴔","𡹸","𢘤","𧈨"}
	a[90334]={"憽","燪"}
	a[90340]={"尝","𡭿","𡷢","𡷰","𡼶"}
	a[90341]={"峵","𢡭","𩵮"}
	a[90342]={"懞","蛍","𤍳","𧙯"}
	a[90343]={"𡘶","𧈪"}
	a[90344]={"𢤄","𤑢"}
	a[90350]={"㷃","峎","崀","裳","𧚵"}
	a[90351]={"㦂","崽"}
	a[90352]={"㠓","嶣","𡼡","𡽮"}
	a[90353]={"蚩","𡴦","𢙌","𢠴"}
	a[90354]={"䖭","爑"}
	a[90355]={"𦱧"}
	a[90360]={"𡺒","𡾨"}
	a[90361]={"嵔","𡾳"}
	a[90362]={"飬","餋","𡾁","𡾢"}
	a[90363]={"鮝"}
	a[90364]={"𦻇"}
	a[90370]={"𡽸"}
	a[90372]={"黨"}
	a[90373]={"㦥"}
	a[90380]={"𡾯"}
	a[90382]={"㠢"}
	a[90384]={"𢥁"}
	a[90385]={"𡽅"}
	a[90392]={"嵹"}
	a[90393]={"𧒾"}
	a[90395]={"𤓦"}
	a[90397]={"爡"}
	a[90400]={""}
	a[90401]={"𡽷"}
	a[90402]={"嶏"}
	a[90403]={"𡽧"}
	a[90410]={"巃","灮"}
	a[90411]={"㶢","炛","","𡹽","𡿣","𢥼"}
	a[90412]={"𡿢"}
	a[90413]={"𪚯"}
	a[90415]={"𪛂"}
	a[90420]={"㕾","光","炨","𡭠"}
	a[90421]={"㐘","岚","𡳾","𡵈"}
	a[90422]={"毟","𡶔","𢦢"}
	a[90430]={"㞩","岮","觉","𠓉","𠤠","𡴯","𡴼","𡵂","𡵉","𡵧","𡶟"}
	a[90431]={"㤞","烢","𡭾","𡮑","𡵵","𢗍","𥹈"}
	a[90432]={"嵗","鼡","𡷫"}
	a[90434]={"峩","𡸚"}
	a[90440]={"㝸","党","岂","岜","惋","烷","焥","𠤝","𡭪","𡵋","𡶢"}
	a[90441]={"㝹","𡴄","𡶗","𥹆"}
	a[90442]={"㟡","卷","巻","慌","𡶰","𡸤","𡻕","𡻷"}
	a[90444]={"崴","懱","𡺄"}
	a[90445]={"嶘"}
	a[90450]={"䆪","峞","覍","𠨤","𡵷","𡷗","𡷹","𡸥","𨚒"}
	a[90451]={"𡷲","𡸊","𢟭","𥹳"}
	a[90452]={"㟟","嵅","嵐","𡷱"}
	a[90454]={"𣭮"}
	a[90455]={"𡽥","𥽘"}
	a[90460]={"覚","𡸢"}
	a[90461]={"㠇","𡷝","𢠠","𤬼"}
	a[90462]={"崺","嵬","𡸔"}
	a[90463]={"𡸾","𡾠","𦱢"}
	a[90464]={"巀","𡹛"}
	a[90465]={"㠖","𡸲"}
	a[90466]={"𤎣"}
	a[90470]={"崑","瓽"}
	a[90472]={"㠕"}
	a[90473]={"嶯","麊"}
	a[90474]={"𡼌"}
	a[90475]={"嶻"}
	a[90480]={"𡺮"}
	a[90482]={"𡒑","𡾻"}
	a[90484]={"𡾛","𡿆"}
	a[90485]={"巍"}
	a[90492]={"𡾖","𡾺"}
	a[90493]={"嶤","𡾾"}
	a[90494]={"𡿄"}
	a[90502]={"𡾸"}
	a[90506]={"𨎖","𪔫"}
	a[90511]={"屮","巋","","","𣁂","𤆌"}
	a[90512]={"巐","巖","灷","𡭛"}
	a[90513]={"𡿚"}
	a[90521]={"㞵","峳","𠦂","𠦖","𡶣","𡷁","𢜶"}
	a[90522]={"半","","𠬢","𡚴","𡴅","𢌲"}
	a[90523]={"娄","𥸭"}
	a[90531]={"岌","崒","𡵃","𢢒","𤈬","𤋬"}
	a[90532]={"㞿","㷠","举","峖","嵏","嵙","𡜈","𡜛","𡝷","𡴖","𡵄","𡼀","𢚄","𤉍"}
	a[90533]={"妛","崣","帣","𡴀","𡴑","𡷓","𥸶"}
	a[90534]={"𡭭","𢍊"}
	a[90535]={"𢟨"}
	a[90541]={"㟕","岸","峷","常","𡺲","𢠭","𦕉"}
	a[90542]={"㟉","𡜽","𡝣","𡹃","𤍚"}
	a[90543]={"単","粦","𡭼","𡮁","𡵞","𥼇"}
	a[90544]={"牶","𡴇","𥹻"}
	a[90545]={"㟿"}
	a[90546]={"岪"}
	a[90550]={"𥻔"}
	a[90551]={"嶶","𡷮","𡸅","𡺰","𡼦","𡽪"}
	a[90552]={"𠭆","𡴐","𡴙","𡴟","𡹉","𡺿","𡻶","𡻾","𥹢","𥻮"}
	a[90553]={"㟖","愺","𡹷","𡼵","𤌸","𧄣"}
	a[90554]={"峯","𠭏","𡮕","𡼃","𢍕","𢍨","𤙻"}
	a[90555]={"崋","𡴝","𡴨","𤒑"}
	a[90557]={"㦊","燁"}
	a[90561]={"㠅","𡸠","𡹨"}
	a[90562]={"㟬","𡸘","𢅢"}
	a[90563]={"㟼","㷹","𠮍","𡷠","𡺾"}
	a[90564]={"𢆤","𤏱"}
	a[90565]={"㦜","𡻺","𤐰"}
	a[90566]={"嵂","𡷏"}
	a[90567]={"㠏"}
	a[90571]={"𡽄"}
	a[90572]={"厳","𡼋"}
	a[90573]={"𡻛"}
	a[90574]={"𦸶"}
	a[90575]={"㟦","㠛"}
	a[90576]={"輋","𨋡"}
	a[90578]={"㟺"}
	a[90581]={"㠔","嶭","𡽕"}
	a[90582]={"巌"}
	a[90583]={"𡼒","𡽂"}
	a[90584]={"𡽖"}
	a[90585]={"韏","𡼬"}
	a[90586]={"𧁇","𨌗"}
	a[90587]={"𡺅"}
	a[90589]={"𡾄"}
	a[90592]={"𡾦","𤑧"}
	a[90593]={"𡼤","𡾲"}
	a[90594]={"𡿠"}
	a[90595]={"𡿑"}
	a[90600]={"𡾏"}
	a[90602]={"嶜","𡽞","𥋤"}
	a[90603]={"𡾋"}
	a[90610]={"𡾷"}
	a[90630]={"愹","熔","","𡮀","𡸋"}
	a[90631]={"畄"}
	a[90640]={"㞱","㟔","岧","岩","峇","嵱","省","","𡷂","𡸱","𣅱","𣆤","𤇁","𥃻"}
	a[90641]={"峉","愘","𠰕","𠰛","𡴏","𡴜","𡶥","𡸟","𡹤","𡽔"}
	a[90642]={"峀","畨","𡭵","𢞇","𢟉"}
	a[90643]={"𢜪","𤐞"}
	a[90650]={"営","峕","熍","𡶾","𡺊","𢞏","𤎭","𥅷"}
	a[90651]={"㟯","喾","旹","𡴗","𡹏"}
	a[90652]={"㟷","𤰫","𥻞"}
	a[90653]={"𤱵"}
	a[90660]={"訔","誉","𡷚","𡺞","𡻦","𡼳","𡾡"}
	a[90661]={"崮","當","𡻲","𥄾"}
	a[90662]={"眷","𡴡","𡷾","𡹍","𡺚","𤌻","𤯧"}
	a[90663]={"㟒","𡸼","𢞐","𣈤"}
	a[90664]={"𤏸"}
	a[90670]={"嘗","嵓","𠹉","𡮢","𡹼","𤍷"}
	a[90671]={"𡽜","𢠲"}
	a[90672]={"誊","𣋈"}
	a[90673]={"𣊨"}
	a[90680]={"㠄","𡾽","𧨲"}
	a[90681]={"𡻂","𡽘"}
	a[90682]={"懵","𡴩","𨡔"}
	a[90684]={"𡼫"}
	a[90690]={"𣋎"}
	a[90693]={"𥽴"}
	a[90701]={"𡼜"}
	a[90702]={"𡾤"}
	a[90704]={"𤓝"}
	a[90705]={"𩱵"}
	a[90710]={"㠋","山"}
	a[90711]={"㡀","劣","","𠠽"}
	a[90712]={"𡾧","𪈡"}
	a[90715]={"","𩱸"}
	a[90720]={"㤖","屶","岀","岃","峃","𡭙","𡵳","𡷀","𤆼"}
	a[90721]={"㞣","出","労","屴","岗","峲","𠢸","𡺵"}
	a[90722]={"烵"}
	a[90723]={"焫"}
	a[90730]={"㞧","尙","尚","峛","当","耑","肖","𡵤","𡷈","𦙊"}
	a[90731]={"学","𡥏","𡥐","𡵇","𡵥","𡷼","𡸐","𡸹","𢑐","𥹍"}
	a[90732]={"券","挙","𠝂","𡴚"}
	a[90733]={"劵","芔","𤋲"}
	a[90734]={"𥸻"}
	a[90740]={"岢","岿","崗","焪","脊","鸴","𡭸","𡶝","𡹺","𡼙","𢛙"}
	a[90741]={"𠕓","𡭮","𡴊","𡶻","𡷎","𡺃","𡺴","𤉐"}
	a[90742]={"崙","𡶤","𡹰"}
	a[90743]={"崂","𡸵","𥼈"}
	a[90744]={"拳","𡴋"}
	a[90748]={"𡷌"}
	a[90750]={"㞻","䲵","峝","崱","嵛","嵜","悺","懧","𡶫","𡸑","𡸕","𡸿","𡹗","𦏿","𩾟"}
	a[90751]={"㟢","峟","崫","嶈","牚","𡴎","𡸍"}
	a[90752]={"弮","掌","𡼁"}
	a[90753]={"𡴕","𡴥"}
	a[90754]={"𢟡"}
	a[90760]={"嵡","嶌","鴬","𡶹","𡹱","𡺇","𡺣","𡺩","𦞄"}
	a[90761]={"嶎","𡦙","𡮚","𡺕","𡼿","𡽲","𦈹","𦐉","𪂟"}
	a[90762]={"甞","齤","𡽵","𢢖"}
	a[90763]={"崶","𠻭","𦱡","𦴘"}
	a[90764]={"㟛","觠","駦"}
	a[90765]={"燤","𡴛","𡹆","𡾱","𥼓"}
	a[90766]={"𣫶"}
	a[90769]={"𦱶"}
	a[90770]={"崩","嵩","𡹌","𡼍"}
	a[90771]={"㠐"}
	a[90772]={"嵵","嶱","𡦣","𡸺","𡻎"}
	a[90773]={"𡽎","𢋱"}
	a[90775]={"𡽇"}
	a[90776]={"䊪"}
	a[90777]={"𡸪"}
	a[90779]={"𥻰"}
	a[90780]={"㟧","𡺺","𩨮"}
	a[90782]={"嶲","巂","𡽝"}
	a[90783]={"雟"}
	a[90786]={"巈"}
	a[90790]={"𡾈"}
	a[90791]={"𡿙"}
	a[90800]={"火","炎","焱","","𡭞","𡾣"}
	a[90801]={"𡿃"}
	a[90810]={"㞤","㞥","兴","巓","","𡵖","𡵝","𡹖","𡺛","𢠡","𤇑","𤈹"}
	a[90811]={"尖","巔","𡗩","𡭟","𡸓","𤉞","𥸪"}
	a[90812]={"巚"}
	a[90820]={"岤","嵸","𡷑"}
	a[90821]={"炭","𡴆","𢝀"}
	a[90822]={"烡","类","","𠔉","𤎫","𤐥"}
	a[90830]={"𡸛","𡽽","𤊟"}
	a[90831]={"㞺","㟮","𡭩","𡵗","𢝹","𢞖"}
	a[90832]={"𤑋"}
	a[90833]={"粪"}
	a[90834]={"愥","煐"}
	a[90840]={"䟫","赏","","𠔞","𡹦","𡼷","𤎚","𧴪"}
	a[90841]={"崁","𡺏"}
	a[90843]={"𡙪","𥏇"}
	a[90844]={"𤊖"}
	a[90845]={"䊔"}
	a[90850]={"𢟫"}
	a[90851]={"嶔","嶡"}
	a[90852]={"嵌"}
	a[90853]={"㷬","慔","𥻜"}
	a[90854]={"𡷳"}
	a[90855]={"𤴗"}
	a[90860]={"𡺋","𡻗","𡼽","𡽗","𢣐"}
	a[90861]={"嵚","𡸦","𡻬","𡼭","𧵠"}
	a[90862]={"㠌"}
	a[90863]={"𡴪","𡴫","𡻟"}
	a[90864]={"糞","糢","黉","𡾗"}
	a[90865]={"𡹈","𥻪"}
	a[90870]={"嵿","嶺","賞","𡻃","𡽙"}
	a[90871]={"嶷"}
	a[90872]={"嶽"}
	a[90873]={"𡼝","𧷵"}
	a[90881]={"䊴","𡽆","𧷓"}
	a[90882]={"𡽠"}
	a[90884]={"𡾰"}
	a[90890]={"㠘"}
	a[90891]={"巅","𡾆","𧷷"}
	a[90892]={"𡿍"}
	a[90900]={"尛","氺","","","𠁭","𠓪","𡭝","𡭯"}
	a[90902]={"𡿌"}
	a[90904]={"𡿗"}
	a[90910]={"𡶿","𣲱"}
	a[90911]={"尜","燊","米","𡭢","𡿈","𡿛","𣎵","𣏦"}
	a[90913]={"𡿜"}
	a[90920]={"㞸","汖","泶"}
	a[90921]={"栄","𡵬"}
	a[90922]={"𣳾"}
	a[90930]={"悰","𡭴","𡭽","𡮂","𥿟"}
	a[90931]={"𡸂"}
	a[90932]={"䊉","岽","粜","𡹇","𣐯","𥺋"}
	a[90933]={"䅈","桊","𠔗"}
	a[90940]={"崇","𡷷"}
	a[90941]={"棠","祟","粽","𡷵","𣖃"}
	a[90942]={"䄅","憡","絭"}
	a[90943]={"嵘","巣"}
	a[90944]={"𣕐"}
	a[90950]={"㟜","㟤","㟶","𡺙","𡻰","𡽋","𢣼"}
	a[90951]={"嶚","𡾚","𥚢"}
	a[90952]={"嶪"}
	a[90953]={"𡻝"}
	a[90954]={"崬","𡽼"}
	a[90960]={"𡼊","𡽭","𡽿","𥼢"}
	a[90961]={"𡺼","𡻭"}
	a[90963]={"㠍","𣙂"}
	a[90968]={"𥽒"}
	a[90970]={"𡼩","𡾍"}
	a[90971]={"𣞏"}
	a[90974]={"𡻚"}
	a[90980]={"𡾥"}
	a[90992]={"𡾹"}
	a[90993]={"𤓈"}
	a[91102]={"㠠"}
	a[91103]={"㸌"}
	a[91111]={"㦭","爧"}
	a[91112]={"𥾂"}
	a[91113]={"𡾜"}
	a[91114]={"𥽥"}
	a[91120]={"怌","灴","𢖷"}
	a[91121]={"怄",""}
	a[91130]={"屸","岯","怔","恆","炡","烴","𡷯","𢙼"}
	a[91131]={"䉺","岖","忹","愜","𢚬","𤆦","𥹂"}
	a[91132]={"𢚯"}
	a[91140]={"㤱","怇","炬","烥","𡷍","𡷨","𢗝"}
	a[91141]={"恎"}
	a[91142]={"惬","𢛢","𥺫"}
	a[91144]={"𤉁"}
	a[91150]={"岠","恒","烜","𡶅"}
	a[91151]={"峌","恇","憈","粔","𥺉"}
	a[91152]={"爏","𢛄","𢤩","𤏚"}
	a[91153]={"煙"}
	a[91160]={"峘","𢛟","𤉑","𤎠"}
	a[91161]={"㠊","𢝎","𥹚"}
	a[91162]={"㠣","崕","愝","𤎆"}
	a[91163]={"㥾"}
	a[91164]={"𥻛"}
	a[91170]={"𡹄"}
	a[91171]={"𡹪","𥺼","𧇺"}
	a[91172]={"𡹶"}
	a[91174]={"糎"}
	a[91180]={"㥱","慪","熰"}
	a[91181]={"𢟵","𧇲"}
	a[91190]={"嶇"}
	a[91192]={"爐","𤐀","𥽛"}
	a[91193]={"𡔇"}
	a[91202]={"𥾁"}
	a[91231]={"𥹴"}
	a[91260]={"悱"}
	a[91271]={"𥺘"}
	a[91291]={"𤓠"}
	a[91310]={"烼","𢗄"}
	a[91321]={"悿","𢝦"}
	a[91330]={"忶","𡶛","𢠟"}
	a[91340]={"峠","𡵮","𢛈"}
	a[91341]={"𢞋"}
	a[91342]={"𢝴"}
	a[91350]={"悵","𤊞"}
	a[91351]={"㷾","懅"}
	a[91352]={"𢡊"}
	a[91360]={"𢠕","𢡡","𢣁","𤐾"}
	a[91361]={"粻"}
	a[91371]={"燯","𥼞"}
	a[91382]={"爈","𢣿","𥼸"}
	a[91392]={"𡾅"}
	a[91401]={"㽆","㽊"}
	a[91410]={"巄","爖","𢤱"}
	a[91411]={"𡿕"}
	a[91412]={"𤮯","𤮰"}
	a[91421]={""}
	a[91430]={"屼","忨"}
	a[91431]={"怃"}
	a[91440]={"岏","𡵊","𤬬"}
	a[91441]={"𠒄","𠒝","𡵐"}
	a[91450]={"㼘"}
	a[91451]={"㤴","𤐊"}
	a[91454]={"𤐇"}
	a[91461]={"𤬷","𥚋"}
	a[91470]={"㼷"}
	a[91471]={"慨"}
	a[91472]={"𡼛"}
	a[91473]={"𡼟"}
	a[91480]={"㼳"}
	a[91481]={"𤭽"}
	a[91482]={"䖓","𢣒","𢥬","𤓧"}
	a[91483]={"甐"}
	a[91490]={"𤮶"}
	a[91491]={"虩","𧈅"}
	a[91501]={"𡾂"}
	a[91511]={"巎","𢥝"}
	a[91513]={"㸎","懾"}
	a[91514]={"𥽶"}
	a[91521]={"㶥","忓","怦","敥","𤆝","𤇊"}
	a[91531]={"屽","岼","𡵨"}
	a[91532]={"岍","𢝶","𥹒"}
	a[91533]={"𤈆"}
	a[91541]={"㟁","𢙘","𢝠","𢼯","𢾋"}
	a[91542]={"𢼍"}
	a[91543]={"𢙱","𦷻"}
	a[91544]={"𢙾"}
	a[91551]={"㪜","悼","焯","𢼼","𢿁"}
	a[91552]={"𢽾","𢾈"}
	a[91553]={"𡷟","𢽅"}
	a[91554]={"峺","崾"}
	a[91555]={"粳"}
	a[91561]={"𤌤"}
	a[91562]={"𢽃","𢾍","𢿆","𢿧"}
	a[91563]={"慑"}
	a[91564]={"𢼟"}
	a[91571]={"㥝","懮","敱","𡺷"}
	a[91573]={"憛","燂"}
	a[91574]={"𢾫"}
	a[91579]={"𣀰"}
	a[91582]={"𡼆","𥽟"}
	a[91583]={"𣀏"}
	a[91584]={"䊤"}
	a[91585]={"𣀲"}
	a[91603]={"糣"}
	a[91612]={"𢤓"}
	a[91630]={"㤳","怗","炶","炻","煔"}
	a[91631]={"𢙖","𢟧","𤌜"}
	a[91632]={"𤈇"}
	a[91640]={"岾","𡶌","𢘆"}
	a[91641]={"㶺","粘","𢚺"}
	a[91642]={"恓","𡶼"}
	a[91650]={"愐","𤋛"}
	a[91651]={"悟","焐","粨","𤒳"}
	a[91652]={"𨟽"}
	a[91653]={"粞","𥺗"}
	a[91660]={"𡺽"}
	a[91661]={"峿","愊","煏","糆"}
	a[91671]={"𪉻"}
	a[91672]={"𢡄","𥻅"}
	a[91682]={"𥽯"}
	a[91692]={"憯","熸"}
	a[91693]={"𥼦"}
	a[91701]={"嶀"}
	a[91710]={"忊","灯","𢥳"}
	a[91712]={"𥽮","𩪨"}
	a[91716]={"𢥻"}
	a[91720]={"㤚","烆","𡴵","𦓒"}
	a[91721]={"㤉","怲","炳","𢖳","𥸧"}
	a[91725]={"𢣚","𤐨"}
	a[91730]={"峏","炣","𢗃","𢗔","𢗙","𢗶","𤇃"}
	a[91731]={"岈","粫","","𤆏","𤈃","𥸯","𥸰"}
	a[91740]={"㞹","屿","𢡼","𤏙"}
	a[91741]={"粝","𥸴"}
	a[91742]={"𢰨","𤌬"}
	a[91750]={"㥼","𡹣","𡾐","𢡍","𤌦","𤎄"}
	a[91751]={"嶿","糥","𢛯","𢟹"}
	a[91752]={"㦆"}
	a[91754]={"𢟶"}
	a[91760]={"𢝒"}
	a[91761]={"㷞","𢡤","𥻥"}
	a[91762]={"𡻻"}
	a[91763]={"𤑣"}
	a[91770]={"𡹻"}
	a[91772]={"𢣵"}
	a[91775]={"爄","𢤆"}
	a[91781]={"懦","燸"}
	a[91783]={"𢢛"}
	a[91785]={"巁"}
	a[91786]={"糲"}
	a[91792]={"糯","𩧔"}
	a[91800]={"顗","顲","𩖋"}
	a[91802]={"𥽣","𩕣"}
	a[91811]={"𩕵"}
	a[91820]={"烦","𤌢","𩖖"}
	a[91821]={"恹"}
	a[91831]={"愞","煗"}
	a[91832]={"𤌪"}
	a[91842]={"𥻟"}
	a[91850]={"㥧","煩","顃","颛","𤋺"}
	a[91851]={"嶥","颣","𢞹"}
	a[91860]={"崸","愩","熕"}
	a[91861]={"頪","𩒪","𩓝","𩓮"}
	a[91870]={"䫈","𡺭","𡽹","𢠷","𩒚"}
	a[91871]={"䪼","𩔫"}
	a[91872]={"頖","類","𩒌","𩔖 "}
	a[91873]={"𩔗"}
	a[91880]={"顓","𡼔","𨆜"}
	a[91881]={"懨","纇","𥜛"}
	a[91882]={"𩕶"}
	a[91891]={"𡽣","𩓤"}
	a[91892]={"𩓫","𩓻","𩓼"}
	a[91893]={"𩕔"}
	a[91910]={"怀","炋"}
	a[91920]={"𤇋"}
	a[91930]={"㶹"}
	a[91940]={"㥳","㷧"}
	a[91941]={"𢢙"}
	a[91943]={"慄","憟","𤌣"}
	a[91950]={"㟲"}
	a[91951]={"㮡"}
	a[91952]={"慓","熛","𤍭"}
	a[91953]={"㟳"}
	a[91961]={"𤌓"}
	a[91962]={"㟽"}
	a[91971]={"𢡅"}
	a[91982]={"𥼠","𥽑"}
	a[92000]={"𣱱","𤆑"}
	a[92041]={"粌"}
	a[92100]={"𢣎"}
	a[92111]={"𥽖"}
	a[92116]={"㠦"}
	a[92121]={"㤛","𢗖"}
	a[92130]={"岴"}
	a[92140]={"𡾑"}
	a[92141]={"𡹑","𢝤"}
	a[92145]={"𢛉"}
	a[92150]={"憕","燈"}
	a[92151]={"悂"}
	a[92155]={"崜"}
	a[92160]={"嶝"}
	a[92161]={"𨨺"}
	a[92165]={"煄","𢝆"}
	a[92171]={"𧺄"}
	a[92175]={"𡺍"}
	a[92176]={"𥻝"}
	a[92193]={"𡿂"}
	a[92200]={"𢒆"}
	a[92201]={"𤒤"}
	a[92210]={"忻","炘"}
	a[92211]={"㤭"}
	a[92220]={"岓"}
	a[92221]={"䉼","峤"}
	a[92222]={"烿"}
	a[92231]={"𣂹","𥸺"}
	a[92232]={"㪿","𣂚","𥺚"}
	a[92240]={"𣂫"}
	a[92241]={"𣂟","𥼔"}
	a[92242]={"𣃌"}
	a[92243]={"惭","𥺈"}
	a[92251]={"憉"}
	a[92252]={"燍","𢠹","𣂲"}
	a[92253]={"斴"}
	a[92263]={"𥼤"}
	a[92265]={"慚","𤍖"}
	a[92275]={"嶃"}
	a[92312]={"𢦈"}
	a[92320]={"𡶉","𢜦"}
	a[92321]={"怅","𢝲"}
	a[92332]={"䊝","𤏞"}
	a[92340]={"𢘌"}
	a[92343]={"粼","𥻘"}
	a[92350]={"𢢥"}
	a[92354]={"燻","𢣤"}
	a[92360]={"懚"}
	a[92365]={"𢣥"}
	a[92370]={"㦩","嶾"}
	a[92371]={"㼕"}
	a[92381]={"𤑿"}
	a[92400]={"𤆇"}
	a[92403]={"𧰙"}
	a[92410]={"𢖪","𢖬"}
	a[92411]={"𤍡"}
	a[92420]={"乢","恌","烑"}
	a[92421]={"忯","怟","灹","𢖲","𤈯"}
	a[92431]={"㞴","㟅","岻","𢗵","𤭰"}
	a[92432]={"㲜","㲭","䉻","籷","𢗳"}
	a[92440]={"𤌶"}
	a[92441]={"爉","粃"}
	a[92442]={"𤎞"}
	a[92443]={"粍"}
	a[92444]={"𤊚"}
	a[92452]={"𦧿"}
	a[92453]={"亃","𢡧"}
	a[92461]={"㥴"}
	a[92462]={"㲖","𥽊"}
	a[92463]={"𡼠"}
	a[92464]={"𥼘"}
	a[92475]={"𡸗"}
	a[92484]={"𣯯"}
	a[92511]={"㤆","忏","炍"}
	a[92512]={"𢘛","𤇚"}
	a[92521]={"㟆","㥅","岅","𤊐"}
	a[92522]={"㟎","惾","粁","粄","𢣌"}
	a[92523]={"𢛊","𤉦"}
	a[92531]={"懓","燰"}
	a[92532]={"嵕","愋","煖","𡽀"}
	a[92533]={"叛","糉","糭","𡹜"}
	a[92541]={"烻","𢚀","𤇹"}
	a[92542]={"嵈","烶"}
	a[92545]={"𡞟"}
	a[92552]={"𡸫"}
	a[92561]={"𤏋"}
	a[92562]={"𤓡"}
	a[92571]={"𢠺"}
	a[92572]={"𤎙"}
	a[92583]={"爜"}
	a[92620]={"𤋠"}
	a[92621]={"惱","𤊲"}
	a[92630]={"㤧","㷔"}
	a[92631]={"恬","𤈏","𤉣","𦧡"}
	a[92640]={"恉"}
	a[92641]={"崰","𤋭"}
	a[92642]={"憣","燔"}
	a[92650]={"崉","𢞮"}
	a[92651]={"惛","焝","𢝺"}
	a[92652]={"嶓","𠺤","𢣊"}
	a[92653]={"䊩"}
	a[92660]={"煯","𡼴","𢝷"}
	a[92661]={"崏","𥅱"}
	a[92670]={"𡺓"}
	a[92671]={"𥻄"}
	a[92672]={"𡺗"}
	a[92674]={"𤏾"}
	a[92700]={"剡","灲","𠚺","𠟡","𠠓"}
	a[92702]={"𪛑"}
	a[92710]={"恻","𡿞","𢙉","𤇱"}
	a[92711]={"忷","悧","烀","𠝉","𢚃","𢚰"}
	a[92720]={"㤡","刿","𠛕","𠝦","𤈘","𤈰 ","𤌵"}
	a[92721]={"烰","𡸉"}
	a[92722]={"䉿","判","𥹽"}
	a[92730]={"㓥","削","剬","峢","𡹂","𤎶"}
	a[92731]={"㟊","愮","熎","𢝾"}
	a[92732]={"㓬","悸","粰","𡶭"}
	a[92733]={"𢱀","𤊶"}
	a[92734]={"𢜻","𤌁"}
	a[92740]={"㓽","剀","惻","慆","熖","𠜿","𠝀","𠝿","𡷘"}
	a[92741]={"𠟁","𠠜","𡺯"}
	a[92743]={"㔂","崢"}
	a[92744]={"𥺲","𥻃"}
	a[92750]={"剴","𡺢","𡺫"}
	a[92751]={"懰","𤊿"}
	a[92752]={"揱","𢢼"}
	a[92760]={"𡺖","𤊷"}
	a[92761]={"劏","憍","燆"}
	a[92762]={"㠒"}
	a[92770]={"剻"}
	a[92771]={"嶠","爝","𢥚"}
	a[92772]={"鵥"}
	a[92780]={"𪃅"}
	a[92782]={"㔒"}
	a[92811]={"㤇"}
	a[92821]={"岆"}
	a[92831]={"慀","𢜽","𤌳"}
	a[92841]={"嵠"}
	a[92850]={"愼"}
	a[92853]={"𤒊","𥼜"}
	a[92860]={"懫"}
	a[92883]={"懻"}
	a[92901]={"𥽸"}
	a[92910]={"𤆩"}
	a[92911]={"㥒","烁","秌","𤊕"}
	a[92920]={"𡵰"}
	a[92921]={"𡸯","𢝥","𤍝"}
	a[92933]={"𥼄"}
	a[92935]={"𢜼"}
	a[92941]={"𢟊","𣕇"}
	a[92942]={"㸁","𢢜"}
	a[92943]={"𤍒"}
	a[92945]={"𡹴","𤊔"}
	a[92950]={"𦂗"}
	a[92951]={"嵊"}
	a[92952]={"嶫","𦆰"}
	a[92981]={"㦡","爍"}
	a[92991]={"𡾒"}
	a[92992]={"𥽗"}
	a[93000]={"㣺","","𤆊"}
	a[93010]={"㤈"}
	a[93011]={"怭","烞"}
	a[93012]={"𥹅"}
	a[93101]={"𥼷"}
	a[93108]={"𤓌"}
	a[93120]={"忙"}
	a[93130]={"𡵀","𡶧"}
	a[93131]={"炷","粒","𢛛"}
	a[93142]={"惟","焳"}
	a[93144]={"𤐒"}
	a[93152]={"㦃","𡹐"}
	a[93153]={"䊒","𥼵"}
	a[93160]={"𢠊"}
	a[93161]={"𤍣"}
	a[93162]={"嵼"}
	a[93172]={"𢢓","𨿰","𨿻"}
	a[93173]={"憧","燑"}
	a[93174]={"𥽀"}
	a[93181]={"㸀"}
	a[93182]={"𩀙"}
	a[93183]={"㠉","𩀯"}
	a[93190]={"憻"}
	a[93192]={"𩀡"}
	a[93210]={"忭"}
	a[93221]={"惨"}
	a[93230]={"嵃","慘","𡶴","𤍜"}
	a[93232]={"糁"}
	a[93240]={"㠁"}
	a[93241]={"糝"}
	a[93250]={"㸄","懠","𤒱"}
	a[93260]={"𡽉"}
	a[93271]={"𪗊"}
	a[93305]={"𥽬"}
	a[93310]={"炞"}
	a[93314]={"蠥","𡗑"}
	a[93316]={"𩏷"}
	a[93318]={"蠽"}
	a[93320]={"𢙇","𢚚","𢟰"}
	a[93321]={"㦓","燃"}
	a[93330]={"怰","炫","𢡖","𤏟"}
	a[93340]={"𢜺","𢟦","𢡏"}
	a[93342]={"憔","燋","𤐉"}
	a[93350]={"懐","懷","𡻨","𢜚"}
	a[93351]={"𤏂"}
	a[93352]={"嶕","憾","𤏘"}
	a[93353]={"𥼚"}
	a[93360]={"㠙","惤","憶","燱","𡾝"}
	a[93361]={"𤑦"}
	a[93367]={"𤒄"}
	a[93372]={"㠡","𢠌"}
	a[93383]={"𢤤"}
	a[93386]={"𧓷"}
	a[93394]={"㠤","懹","爙"}
	a[93397]={"𥾀"}
	a[93403]={"巇"}
	a[93411]={"𢖺"}
	a[93412]={"㤜"}
	a[93421]={"忧"}
	a[93422]={"㤶","怴","𡶙","𢘙","𤇭","𤇳"}
	a[93423]={"𤇽"}
	a[93424]={"㥇","悈","𤈪"}
	a[93430]={"㤝","㤺","忼","炕"}
	a[93431]={"恜","烒","𡵔"}
	a[93432]={"㞽","㟌","峸","慽","𢜾"}
	a[93433]={"𤉫","𤍬"}
	a[93434]={"㟞","峨","𢚕"}
	a[93440]={"𡵻"}
	a[93441]={"粇","𡹕","𡻏","𥹷"}
	a[93442]={"惐","煘","𡹿","𢜩","𥹨"}
	a[93443]={"𥼀"}
	a[93444]={"𢣝"}
	a[93451]={"憱"}
	a[93452]={"熾","𢡠","𢧾"}
	a[93453]={"𡴞","𥻇"}
	a[93454]={"𢧵"}
	a[93455]={"戦"}
	a[93460]={"煷","𢝋"}
	a[93463]={"𥽇"}
	a[93464]={"𡰚","𡾃"}
	a[93471]={"㦐","糡"}
	a[93473]={"𡾟"}
	a[93474]={"𢨄"}
	a[93475]={"𡽱","𢤚"}
	a[93480]={"𤒀"}
	a[93482]={"懺","𡽴","𤒯"}
	a[93493]={"㸍","䊱","懴"}
	a[93501]={"𤑴"}
	a[93505]={"𡾼"}
	a[93506]={"𢥵"}
	a[93511]={"忟","恔","炆","烄","𡾘"}
	a[93521]={"㞶","峧","悛","悴","焌","焠","焲","𢘥"}
	a[93522]={"炦","𡶖","𢘀","𥸹","𥹜"}
	a[93531]={"峻","崪","𢜙","𣁗","𤈼"}
	a[93532]={"峅","恈","粹","𢙗"}
	a[93533]={"𥹇","𥹔"}
	a[93541]={"崹","𡸝"}
	a[93551]={"𢟳"}
	a[93552]={"𦓗"}
	a[93553]={"愯"}
	a[93554]={"𣁣"}
	a[93561]={"慞","𢡐","𤍤"}
	a[93562]={"𥼁"}
	a[93564]={"𥻬"}
	a[93571]={"嶂","𤐙"}
	a[93582]={"辥"}
	a[93593]={"𢤈"}
	a[93595]={"𢥠"}
	a[93630]={"怡","炲","𤉮"}
	a[93631]={"悋","𢜥","𥹋"}
	a[93640]={"㥉","焙"}
	a[93641]={"𢚜"}
	a[93642]={"𥻀"}
	a[93650]={"㟝","愔","𢚘"}
	a[93652]={"糌"}
	a[93660]={"㥫","𡺈"}
	a[93661]={"慉","𥻚"}
	a[93680]={"𡻫"}
	a[93702]={"𡦯"}
	a[93703]={"孼"}
	a[93720]={"㤃"}
	a[93721]={"恼"}
	a[93730]={"𤇖"}
	a[93732]={"𢚙"}
	a[93733]={"𢰣"}
	a[93740]={"㥬","悙","熵","𤈽"}
	a[93742]={"㷰","𢟢"}
	a[93744]={"悑","烳"}
	a[93750]={"㥔","㷚","嵭","焴","﨑"}
	a[93751]={"惇","焞","𥺪","𥻭"}
	a[93753]={"𥻿"}
	a[93754]={"峬"}
	a[93755]={"䊇","愽","煿"}
	a[93760]={"嵉","熇","𢞟"}
	a[93761]={"㠃","崞","𥺞"}
	a[93762]={"㷪","䊞"}
	a[93766]={"糐","𣫿"}
	a[93770]={"嵪"}
	a[93771]={"𠒿"}
	a[93772]={"懏","𤎱"}
	a[93774]={"𦓞"}
	a[93775]={"𤒔"}
	a[93782]={"𡼕"}
	a[93791]={"𩱙"}
	a[93792]={"㔎"}
	a[93811]={"𢗗"}
	a[93812]={"巘"}
	a[93816]={"𩏶"}
	a[93820]={"㤥","烗"}
	a[93821]={"㷜","𤋋"}
	a[93830]={"峐"}
	a[93831]={"㶼","𢚝"}
	a[93841]={"𤟮","𥹼"}
	a[93853]={"𤝶"}
	a[93854]={"𤡩"}
	a[93860]={"𢡝"}
	a[93861]={"獃"}
	a[93863]={"𢢕"}
	a[93872]={"獣"}
	a[93911]={"怵","炢"}
	a[93921]={"㤹"}
	a[93930]={"惊"}
	a[93931]={"㟈","𢛐","𤉬"}
	a[93941]={"㷘"}
	a[93950]={"𤐶"}
	a[93961]={"懍","燣"}
	a[93963]={"㠎"}
	a[93970]={"懔","燷"}
	a[93971]={"燺"}
	a[93992]={"櫱"}
	a[93993]={"糱"}
	a[94120]={"恤","烅"}
	a[94142]={"粧","𥺁"}
	a[94150]={"𤊃"}
	a[94152]={"𢟴"}
	a[94161]={"惶","煌","𥺥"}
	a[94163]={"𤐷"}
	a[94164]={"𢡒"}
	a[94171]={"崲","𤌼","𤾗"}
	a[94172]={"䊗"}
	a[94173]={"𤓍"}
	a[94202]={"㠧"}
	a[94203]={"䊳"}
	a[94210]={"𤆓"}
	a[94220]={"炉"}
	a[94230]={"𡵘"}
	a[94260]={"𡽟"}
	a[94281]={"𢣦"}
	a[94291]={"𡽶"}
	a[94292]={"戂","𤓒"}
	a[94310]={"𢠋"}
	a[94320]={"𢜿"}
	a[94330]={"𢤪"}
	a[94331]={"𤈻"}
	a[94332]={"熫","𢠫"}
	a[94340]={"悢","烺"}
	a[94341]={"憁","熜"}
	a[94342]={"懡","𡻠"}
	a[94343]={"𥼌"}
	a[94350]={"㟍","㷟","熄","𢟋"}
	a[94351]={"粮"}
	a[94352]={"𢣗"}
	a[94353]={"𥽓"}
	a[94355]={"𤑙"}
	a[94357]={"燫"}
	a[94361]={"䊚"}
	a[94362]={"爊","𡾶"}
	a[94372]={"𡾌"}
	a[94377]={"𠓌"}
	a[94380]={"𤓋"}
	a[94410]={"𢖾"}
	a[94413]={"𤒅","𪚱"}
	a[94421]={"𥸱"}
	a[94431]={"䊌"}
	a[94440]={"𢚋","𤈥"}
	a[94450]={"𡶃"}
	a[94451]={"𢞗"}
	a[94452]={"愧","𤌋"}
	a[94462]={"㟴","㦇","熝"}
	a[94470]={"熩"}
	a[94472]={"𡼂","𤏶","𩳁"}
	a[94480]={"𡻮"}
	a[94481]={"𥽃"}
	a[94484]={"兤"}
	a[94492]={"䰪"}
	a[94522]={"𤇼"}
	a[94543]={"焷","𢛞","𢜬"}
	a[94551]={"㷆"}
	a[94553]={"崥"}
	a[94554]={"粺"}
	a[94561]={"𡻆","𢡋"}
	a[94562]={"㟸"}
	a[94563]={"𥻷"}
	a[94564]={"𥼊","𥽅","𥽝"}
	a[94571]={"𡼗"}
	a[94581]={"𡽁"}
	a[94582]={"𥼺"}
	a[94583]={"𡻇"}
	a[94630]={"怕","𤇢"}
	a[94631]={"𡶯"}
	a[94640]={"岶","惦","𢙆"}
	a[94641]={"粕"}
	a[94651]={"𡺀","𥺦"}
	a[94652]={"𥺨"}
	a[94661]={"𥼍"}
	a[94664]={"煻"}
	a[94673]={"𥽨"}
	a[94674]={"嵣"}
	a[94675]={"糖"}
	a[94700]={"𪂓"}
	a[94702]={"䳽"}
	a[94704]={"𪇲"}
	a[94711]={"𪇁","𪈖"}
	a[94712]={"𪈥"}
	a[94713]={"𪇒"}
	a[94721]={"𤈁"}
	a[94722]={"炿","烐"}
	a[94730]={"恦","𤆡","𤈍"}
	a[94731]={"粐"}
	a[94740]={"熓","𢛷","𢞬"}
	a[94741]={"𤏓","𥹝"}
	a[94742]={"惼","煸"}
	a[94750]={"䲴","嵨","𡸰","𪂈"}
	a[94752]={"𡺂","𢢘"}
	a[94753]={"糄"}
	a[94754]={"𢣾"}
	a[94760]={"嶋","煽","𡹫"}
	a[94761]={"䳤","𪀿"}
	a[94764]={"𡾉"}
	a[94770]={"䳥","鹡","𡸬","𡻅","𢣔","𤍦","𪁏"}
	a[94771]={"𩿩"}
	a[94777]={"慵"}
	a[94780]={"䳪","𪁎","𪁺"}
	a[94781]={"𩿭"}
	a[94787]={"㟾"}
	a[94790]={"鶺","𪅁"}
	a[94791]={"䳳","𪂢","𪄹"}
	a[94793]={"𪆞"}
	a[94821]={"㷝"}
	a[94830]={"𢛸"}
	a[94831]={"悷"}
	a[94832]={"懊","燠"}
	a[94841]={"愱","𡸒","𤌿"}
	a[94842]={"㠗"}
	a[94844]={"焿"}
	a[94851]={"𤋡"}
	a[94855]={"𥺧"}
	a[94862]={"糗"}
	a[94864]={"懭","爌"}
	a[94874]={"𡾇"}
	a[94875]={"䊯"}
	a[94893]={"𥽙"}
	a[94894]={"𦓣"}
	a[94920]={"怺"}
	a[94921]={"𢚗"}
	a[94930]={"𤉳"}
	a[94931]={"糘"}
	a[94940]={"𡸶","𢝓"}
	a[94942]={"𡻥"}
	a[94944]={"𤎖"}
	a[94950]={"㟫"}
	a[94951]={"爎"}
	a[94954]={"慷","𥽰"}
	a[94961]={"嵲","𥽕"}
	a[94964]={"嵻"}
	a[94965]={"糠"}
	a[94971]={"𢤭","𤒢"}
	a[94973]={"𢥄","𢥐"}
	a[95011]={"炓","𡵌"}
	a[95012]={"𢗢","𤆭"}
	a[95021]={"㞳"}
	a[95022]={"料","籵"}
	a[95033]={"㪵"}
	a[95101]={"㸆"}
	a[95102]={"𡽩"}
	a[95121]={"灶","𤆧"}
	a[95132]={"性","恠","𢘪"}
	a[95133]={"怈"}
	a[95141]={"𢙳"}
	a[95142]={"㤬","烓"}
	a[95143]={"𡊽"}
	a[95144]={"𥹑"}
	a[95151]={"㥺","熆","𢜳"}
	a[95152]={"䊋","愖","煁"}
	a[95153]={"煃","𢟠"}
	a[95154]={"𤍞"}
	a[95161]={"㥀","嵖","𡻊"}
	a[95162]={"嵁","","𢞑","𤋨","𥻗"}
	a[95163]={"糂","𤋑"}
	a[95165]={"𤑆"}
	a[95171]={"㦉","𡸜","𤏈"}
	a[95173]={"𡻸"}
	a[95176]={"慬"}
	a[95182]={"䊦","墯"}
	a[95184]={"𤏎"}
	a[95186]={"𡓧"}
	a[95192]={"懛","𤐽"}
	a[95204]={"𡿥"}
	a[95212]={"𤊍"}
	a[95232]={"𢟼"}
	a[95294]={"爩"}
	a[95305]={"𧓔"}
	a[95306]={"𤑡"}
	a[95311]={"忲"}
	a[95317]={"𡿝"}
	a[95321]={"㤸","焃","𢗞","𤆠"}
	a[95322]={"㤓","㶱","恡","粏","𢞺"}
	a[95331]={"怯","𡵓","𢙺"}
	a[95332]={"𡶱","𥺃"}
	a[95341]={"𢝍"}
	a[95342]={"懗","爀","𥹓"}
	a[95351]={"慥"}
	a[95352]={"𤌷"}
	a[95354]={"𢤼"}
	a[95362]={"糙","𢢮","𤒈"}
	a[95363]={"燵"}
	a[95364]={"憓"}
	a[95365]={"慩"}
	a[95366]={"𢤺","𤓂"}
	a[95372]={"𢣖"}
	a[95377]={"𤑞"}
	a[95384]={"𤒋"}
	a[95396]={"懳"}
	a[95421]={"𢗟","𢙝"}
	a[95422]={"𤆚"}
	a[95424]={"糀"}
	a[95431]={"烍","𢙧","𢚛"}
	a[95432]={"忳","恅","炖","烧","𢙒"}
	a[95433]={"焼","粩"}
	a[95442]={"䊁","峔","峣"}
	a[95443]={"𢡨","𥸵"}
	a[95444]={"𢞷","𤌥"}
	a[95451]={"𡭶"}
	a[95454]={"㤿","㷈"}
	a[95462]={"㞊"}
	a[95464]={"崦"}
	a[95474]={"黋","𢟾"}
	a[95483]={"憢","燒"}
	a[95493]={"嶢"}
	a[95500]={"𠣇"}
	a[95502]={"㤊"}
	a[95512]={"𢖵","𢗛"}
	a[95513]={"𡿟","𥜱"}
	a[95522]={"㤄","㤒","忮","怖","烨","𢻑"}
	a[95523]={"悕","烯","籹","粀"}
	a[95532]={"㥄","岐","𡵜","𤊥"}
	a[95533]={"㟓","炐","炜","𢗒","𥸳"}
	a[95534]={"㤦","𢜘"}
	a[95542]={"崚","悻"}
	a[95543]={"𥺙"}
	a[95544]={"","𤉻","𤑁"}
	a[95552]={"𡻴","𢝉","𢻒","𤋓","𪌨"}
	a[95555]={"㦅","愅","煂","𢜗","𤉖"}
	a[95556]={"悽"}
	a[95562]={"𢡇"}
	a[95563]={"𤓄"}
	a[95565]={"嵽","𡷖"}
	a[95566]={"𡻹"}
	a[95567]={"㒯"}
	a[95576]={"㷯"}
	a[95579]={"𤏑"}
	a[95587]={"𤒃"}
	a[95588]={"𥼏"}
	a[95602]={"𢥃"}
	a[95613]={"䊰"}
	a[95618]={"𢥱","𤓗"}
	a[95619]={"𥽾"}
	a[95631]={"㤑","怙","𤇌"}
	a[95632]={"𢙵"}
	a[95641]={"岵","恄","悎","焅","𤈄"}
	a[95642]={"䊀"}
	a[95643]={"𤋙"}
	a[95651]={"峼"}
	a[95652]={"㥩","惜","焟","𤌚","𥺊"}
	a[95661]={"懎","𢠁","𢢂","𤌫"}
	a[95662]={"㟙","愭","𡺐","𤌕"}
	a[95663]={"㦋","𢝇","𢝣","𤊴","𥺮"}
	a[95671]={"憘","熺","𤏔"}
	a[95672]={"𡺸","𤎃"}
	a[95674]={"𢡚","𤏖"}
	a[95676]={"㷮","慒"}
	a[95681]={"𡼎"}
	a[95682]={"糦","𤐵"}
	a[95684]={"𢤬"}
	a[95686]={"嶆","𢢺"}
	a[95687]={"糟"}
	a[95692]={"㦧"}
	a[95702]={"嶹"}
	a[95703]={"䊭"}
	a[95705]={"㠨"}
	a[95711]={"㤔","忖"}
	a[95714]={"𡿒"}
	a[95715]={"𠓚"}
	a[95722]={"籿","𤊈","𥹃"}
	a[95732]={"㤌","㶰","恃","𢙨","𤈊","𤊊","𤊼"}
	a[95733]={"慲","𥺯"}
	a[95741]={"㤢","㥓","恗","烠"}
	a[95742]={"㶿","峙","崻","悖","烤","煵","𡶑","𢛘","𤉶"}
	a[95743]={"粓","𥹩"}
	a[95744]={"㤽","䊟","","","𢞻"}
	a[95751]={"崎","𢠢"}
	a[95752]={"㟑","㦠","崤","𢛻","𥺭"}
	a[95753]={"䊖","𢠍","𥹬","𥹸"}
	a[95754]={"𡷸","𢞎"}
	a[95755]={"𥺄"}
	a[95761]={"惰","𤌃"}
	a[95762]={"㠚","情","𢞧"}
	a[95764]={"𥼥"}
	a[95765]={"慱","糒","𤍿"}
	a[95767]={"𢝂","𥼉"}
	a[95768]={"煹","𢞡"}
	a[95771]={"憜","𤐟","𦑑"}
	a[95772]={"崝","𡻄","𢥓"}
	a[95773]={"精","𥻵"}
	a[95776]={"䊜"}
	a[95778]={"𡻉"}
	a[95783]={"𤓣"}
	a[95792]={"懤","燽"}
	a[95795]={"𤓭"}
	a[95796]={"𢟩","𤐭"}
	a[95801]={"𢤋","𢥎"}
	a[95802]={"㦫"}
	a[95811]={"忕","恢","悏","烣"}
	a[95812]={"巑"}
	a[95813]={"𥽷"}
	a[95815]={"慡"}
	a[95821]={"峽"}
	a[95822]={"㤨","怢","烘","𢗲","𤆮"}
	a[95825]={"𡻯"}
	a[95832]={"峡","𡶵"}
	a[95833]={"愤","粠"}
	a[95841]={"𤐗"}
	a[95842]={"㥍","憷","𤊄"}
	a[95844]={"恞","𤈙"}
	a[95852]={"𡸷"}
	a[95853]={"粸"}
	a[95854]={"峓","熿","𤎺","𤏛"}
	a[95855]={"𢜀"}
	a[95861]={"慎","𤌭"}
	a[95862]={"𢢻"}
	a[95863]={"憤","燌"}
	a[95865]={"䊣","崨","𢣜"}
	a[95866]={"熯"}
	a[95871]={"嵮"}
	a[95872]={"㥽","懥"}
	a[95882]={"𤓎"}
	a[95883]={"𡮴","𥼃"}
	a[95884]={"㸇"}
	a[95891]={"𢢰"}
	a[95892]={"𧹍"}
	a[95894]={"㠝","𠓒"}
	a[95911]={"恘","炑","烌"}
	a[95912]={"𢘹"}
	a[95921]={"崍"}
	a[95922]={"㶬","怽","惏","𢗿","𢙀","𤈐"}
	a[95932]={"崃","崊","𡶎"}
	a[95933]={"䊂","悚","炼","煉","粖","𤏗"}
	a[95941]={"憭","燎","𤌘"}
	a[95942]={"㦗","𤐖"}
	a[95943]={"㥭","煤","𡷽","𡼨","𢜮","𢞼","𤌴"}
	a[95944]={"惵","煠","𢛔","𥹵","𥻂"}
	a[95951]={"嶛"}
	a[95952]={"愫","𥻨"}
	a[95953]={"嵥","𠒵"}
	a[95954]={"崠","𡺑","𡻈","𥼨"}
	a[95955]={"𥻈"}
	a[95956]={"𢢲","𤐌"}
	a[95966]={"𥼧"}
	a[95983]={"𤒶"}
	a[96020]={"𢘄"}
	a[96030]={"㥵","怬"}
	a[96031]={"悃","烟","焑","畑","𢛕","𢛾"}
	a[96032]={"怞","𢘉","𢘾"}
	a[96040]={"恛"}
	a[96041]={"𡶐","𡶚","𡸙","𢛍","𥹊"}
	a[96042]={"岫","","𥹉"}
	a[96043]={"粙","𠒗"}
	a[96045]={"粬"}
	a[96051]={"𢛅","𤊎"}
	a[96061]={"崓","𡻽"}
	a[96062]={"慖"}
	a[96063]={""}
	a[96070]={"𡹎"}
	a[96072]={"𡻢"}
	a[96093]={"𡼱"}
	a[96096]={"糰"}
	a[96104]={"糧"}
	a[96112]={"懼","爠"}
	a[96114]={"㠥"}
	a[96116]={"𢦃"}
	a[96140]={"怛","慍","炟","熅"}
	a[96142]={"𢝈"}
	a[96150]={"愠","煜","煴","𤉊","𤌗"}
	a[96151]={"悜"}
	a[96153]={"悝","𨤢"}
	a[96162]={"惺","煋","𤌒","𥺆"}
	a[96163]={"爅"}
	a[96164]={"粴"}
	a[96174]={"𢢪","𥽞"}
	a[96182]={"㦬","𤓓"}
	a[96184]={"𡽍"}
	a[96185]={"𥽈"}
	a[96192]={"𡿇"}
	a[96193]={"𢢳","𤎲","𥽺"}
	a[96194]={"𤑻"}
	a[96220]={"𢚻"}
	a[96280]={"𤐣"}
	a[96290]={"嶵"}
	a[96291]={"䊫"}
	a[96322]={"㥙"}
	a[96330]={"𢟿"}
	a[96331]={"𢞴","𤋘"}
	a[96332]={"烛","𢘷"}
	a[96341]={"愢","煾"}
	a[96342]={"㷵","𢡀"}
	a[96343]={"𧊾"}
	a[96344]={"𤍲"}
	a[96351]={"愄","煨"}
	a[96352]={"𥻏"}
	a[96353]={"㦙","𥼯"}
	a[96360]={"懁","𤋉","𤍴"}
	a[96361]={"㟪","𤏏"}
	a[96362]={"𤒁"}
	a[96363]={"𢡎","𪐽"}
	a[96364]={"燶"}
	a[96370]={"𤐴"}
	a[96371]={"糫"}
	a[96374]={"憹"}
	a[96384]={"嶩"}
	a[96393]={"糨"}
	a[96396]={"爞","𢥞"}
	a[96400]={"覬"}
	a[96401]={"𨝦"}
	a[96403]={"𠓊"}
	a[96412]={"𧢧"}
	a[96430]={"怳","炾"}
	a[96434]={"𢘽"}
	a[96440]={"岲","𢙃","𣆥","𤈋","𤈑"}
	a[96444]={"𤉈"}
	a[96445]={"𥹞"}
	a[96450]={"䙺","尡","悒","悓","愰","熀","覢","𠒼","𢚉","𨚈","𨚊"}
	a[96460]={"峴","惃","焜"}
	a[96461]={"粯"}
	a[96470]={"崐"}
	a[96471]={"䊐"}
	a[96472]={"𨚚"}
	a[96480]={"𨜂"}
	a[96481]={"𧡁"}
	a[96490]={"䚇"}
	a[96493]={"䚏","𨞁"}
	a[96494]={"𨛝"}
	a[96502]={"巊"}
	a[96512]={"巗","𢥴"}
	a[96513]={"戄"}
	a[96522]={"忡"}
	a[96532]={"㞲","炠"}
	a[96533]={"𡶈","𢘊"}
	a[96534]={"㤤"}
	a[96541]={"㥗"}
	a[96542]={"岬","焺","𢛿"}
	a[96551]={"悍","焊","𡹋"}
	a[96552]={"𤏵"}
	a[96553]={"𥺛"}
	a[96561]={"㦍","慢","熳","𡷛","𢜱"}
	a[96562]={"懌","燡"}
	a[96563]={"𤌰","𥽉"}
	a[96565]={"𢡌"}
	a[96567]={"熚"}
	a[96568]={"慺","熡"}
	a[96571]={"𡹯","𡻩"}
	a[96572]={"䊡","嶧"}
	a[96573]={"𥼶"}
	a[96575]={"㷸"}
	a[96577]={"𡻞"}
	a[96578]={"嶁"}
	a[96582]={"熶","𠓋","𥻯"}
	a[96583]={"憚","燀"}
	a[96584]={"𤑥"}
	a[96587]={"爗"}
	a[96588]={"𤒹"}
	a[96593]={"㠆"}
	a[96602]={"𢥑"}
	a[96603]={"𡾊"}
	a[96612]={"𤓊"}
	a[96640]={"焒","𢙲"}
	a[96650]={"𤈵"}
	a[96660]={"焻","煰","𢛽"}
	a[96670]={"㦒"}
	a[96673]={"𥻍"}
	a[96683]={"糬"}
	a[96700]={"𡼑"}
	a[96731]={"㶽"}
	a[96740]={"惕","愣","焬","𤉆"}
	a[96741]={"𤐋"}
	a[96750]={"㷎","悁","愒","愓","焆","煬","𤌙"}
	a[96751]={"㥂","𤋪"}
	a[96753]={"㥥","㷒","𢝟"}
	a[96754]={"𢞙"}
	a[96760]={"崵","嵑","𡷡","𢛡","𤑼","𤒫"}
	a[96761]={"㥜","煟","糃","𡹾","𥻉"}
	a[96762]={"燭","𠲑","𢢗","𢤇"}
	a[96763]={"嵎","𤌖"}
	a[96764]={"𥻑"}
	a[96770]={"愕","𢞠","𢢔"}
	a[96771]={"𥺳"}
	a[96773]={"䊘"}
	a[96774]={"𤐲"}
	a[96780]={"崿"}
	a[96782]={"𤒌"}
	a[96820]={"怾","炽"}
	a[96830]={"𤈶"}
	a[96840]={"𡷿","𤊋"}
	a[96841]={"悞","悮","𤉇"}
	a[96842]={"愦"}
	a[96843]={"惯"}
	a[96850]={"惿","煶"}
	a[96851]={"𡷤","𤋀"}
	a[96852]={"𤌱"}
	a[96853]={"熼"}
	a[96860]={"崼","愪","熉","𢠼"}
	a[96861]={"䊓","𡹊"}
	a[96871]={"𥻱"}
	a[96872]={"憒","𤏳"}
	a[96873]={"慣","𤎽"}
	a[96883]={"𥼩"}
	a[96913]={"𡿔"}
	a[96931]={"𥼟"}
	a[96943]={"㷄","惈"}
	a[96951]={"𡻱","𤍶"}
	a[96952]={"𥺰"}
	a[96953]={"𠒪","𡸖","𥼑"}
	a[96954]={"粿","𢠮"}
	a[96960]={"憬","燝"}
	a[96962]={"懪","爆"}
	a[96970]={"𡼮"}
	a[96971]={"懆","燥","𥼐"}
	a[96973]={"𢥟","𤒺"}
	a[96982]={"𥼾"}
	a[97000]={"𡼥","𤓁"}
	a[97010]={"㣼","㣿","忉","灱","灼","𢗘","𤆞","𤆥","𤇄"}
	a[97011]={"㶧","忇","𢗉"}
	a[97013]={"𤓙"}
	a[97020]={"屻","岉","𡴮","𢗋","𢗕","𦐶"}
	a[97021]={"㥌","恟","籾","粅","𡴽","𢗠","𤆳"}
	a[97023]={"𥸼"}
	a[97030]={"㤯","怐","炯","烱","焵","𡵺","𢜟","𤋢"}
	a[97031]={"㶭","怮"}
	a[97032]={"㔘","㶲","粷"}
	a[97033]={"𢘃"}
	a[97034]={"𤇒"}
	a[97040]={"㟠","㶷","岄","岣","恂","恫","惘","烔","焹","翙","𡵿","𡸀","𢘜","𤈎"}
	a[97041]={"㥘","岰","恸","𥺂"}
	a[97042]={"㤼","𤈸","𥹱"}
	a[97043]={"㟂","𠢁"}
	a[97044]={"𠡶"}
	a[97045]={"粣","𥹣"}
	a[97049]={"𥹤"}
	a[97050]={"㟃","峋","峒","𡷃","𤊵"}
	a[97051]={"惆","粡","𠡱","𡷄","𢚆","𣍧"}
	a[97053]={"勌","勬","𤊹"}
	a[97060]={"㥊","焩","𢝁","𤊉","𤎜"}
	a[97061]={"㟘","煳"}
	a[97062]={"𥺝"}
	a[97065]={"爋"}
	a[97070]={"𠒫","𡹔","𦐺"}
	a[97072]={"糊","𦒪"}
	a[97073]={"𠢚"}
	a[97076]={"㷲","慟"}
	a[97083]={"翷"}
	a[97084]={"𢣛"}
	a[97087]={"懄"}
	a[97090]={"𤏐","𦒀"}
	a[97091]={"𢡞"}
	a[97092]={"𡼼"}
	a[97101]={"𢤯"}
	a[97102]={"耀","𥜺"}
	a[97114]={"糶"}
	a[97130]={"㷥","烃","𤇶"}
	a[97131]={"忸","炄"}
	a[97132]={"怪","悭","𤇂"}
	a[97140]={"怚","𤆾","𤇅"}
	a[97141]={"𢛴"}
	a[97142]={"粈"}
	a[97150]={"岨"}
	a[97151]={"㥛","粗","𡹥","𤈓"}
	a[97152]={"𢞕","𥺬"}
	a[97153]={"𤌍"}
	a[97160]={"熤","𢡉"}
	a[97161]={"㷐","𡺡","𤌆"}
	a[97162]={"𢣷","𤊛"}
	a[97163]={"㦕"}
	a[97164]={"燼","𢣺"}
	a[97171]={"𢄄"}
	a[97172]={"慳","熞","𡺻"}
	a[97173]={"𤏯","𥺣"}
	a[97175]={"𢟸"}
	a[97182]={"燿"}
	a[97192]={"𡽢"}
	a[97193]={"䊮"}
	a[97196]={"㦎"}
	a[97210]={"㶤","𢗇"}
	a[97220]={"㶯","㶴","恀","𡴹","𤇔"}
	a[97230]={"𠓂","𡵙","𢜭"}
	a[97231]={"熪","𥸾","𥹠"}
	a[97232]={"𢛠"}
	a[97240]={"憀","熮"}
	a[97250]={"嵺"}
	a[97271]={"㟹"}
	a[97285]={"熽"}
	a[97290]={"𤑺"}
	a[97295]={"𡼣"}
	a[97296]={"䊥"}
	a[97310]={"𤉃"}
	a[97311]={"㤏","㶶","炵","𢥯"}
	a[97320]={"惚","烬"}
	a[97321]={"峂","𢙐"}
	a[97322]={"㷓","愡"}
	a[97330]={"㥟","𢝧","𤊂","𤊺"}
	a[97331]={"𡻑","𢠽"}
	a[97340]={"恨","𡺪","𢚁","𢢽"}
	a[97341]={"嶑","龽","𡺎","𢠐","𢠒"}
	a[97343]={"慅"}
	a[97350]={"煺","𡷐","𡷞","𢟈"}
	a[97351]={"𥼙"}
	a[97352]={"熥"}
	a[97354]={"㦀","熢","糔","𢠻"}
	a[97360]={"燳"}
	a[97361]={"𢣩"}
	a[97362]={"𢡈"}
	a[97365]={"𤑕"}
	a[97370]={"𤐤"}
	a[97371]={"爘"}
	a[97375]={"𢥕"}
	a[97376]={"𤑛"}
	a[97382]={"𢦇"}
	a[97384]={"𧑎"}
	a[97394]={"𢥾"}
	a[97400]={"憴"}
	a[97403]={"𩙜"}
	a[97410]={"𡽑","𢖯","𤆘"}
	a[97411]={"㶩","巉","𢘚","𢥋","𤒰"}
	a[97420]={"忆","忛","𢖭","𤆤"}
	a[97421]={"忱"}
	a[97422]={"忚","灺","𡴿","𤇉"}
	a[97430]={"㞦","岘","忋","怩","𡴭","𡴱","𡴾","𡵆","𡵟","𢗌","𢗑","𢙚","𤆵","𦫟"}
	a[97431]={"籶","𢙜"}
	a[97432]={"籸"}
	a[97440]={"㞾","屺","怉","恑","炮","𤊓"}
	a[97441]={"怋","悗","粑","𡶺","𤇜"}
	a[97442]={"䊃","煈","飊","𢞁","𤇛","𩗹"}
	a[97443]={"𥹗"}
	a[97450]={"峗","𡶄","𢞌"}
	a[97451]={"岷","𡶋","𡷭"}
	a[97452]={"𡶮","𡺤","𢛺","𤈦"}
	a[97460]={"凯","觊","𡸣"}
	a[97462]={"𡷕","𤑑"}
	a[97463]={"䊊","𥼡"}
	a[97464]={"𦧾"}
	a[97470]={"凱","𦫢"}
	a[97471]={"䄐","𡽏","𥛁"}
	a[97473]={"𠄈","𥼗"}
	a[97480]={"𪕗"}
	a[97483]={"韑","𩘽"}
	a[97492]={"颽","𡽡"}
	a[97502]={"𢤫"}
	a[97505]={"𤑱"}
	a[97507]={"𩏗"}
	a[97511]={"㣾"}
	a[97521]={"忣","𤆣"}
	a[97522]={"怶","𠬵","𥸩"}
	a[97523]={"怓"}
	a[97531]={"岋","炈","𢗎","𢘎","𢚌","𢛼","𤈧"}
	a[97532]={"岥","忰"}
	a[97533]={"怿","𢘦","𢘸","𤆿","𤇺","𥹖"}
	a[97536]={"怫","炥"}
	a[97541]={"𡹧"}
	a[97542]={"𤋊","𤎈","𥺍","𥺱"}
	a[97543]={"峄","恽","粋","𡶶","𢞸","𢟌"}
	a[97544]={"惙","烽","𡢏","𥹪"}
	a[97546]={"𡶒"}
	a[97552]={"㥰","𠭥","𡼧","𢛏","𤿨","𤿼"}
	a[97553]={"𤿣"}
	a[97554]={"䊛","峰"}
	a[97555]={"𥹾"}
	a[97556]={"𢘶"}
	a[97561]={"㲂","𡹙"}
	a[97562]={"煅","𡸨","𡻁","𤎋"}
	a[97563]={"愇","煒","辉"}
	a[97565]={"惲","煇","𤐕"}
	a[97566]={"峍"}
	a[97567]={"𥹧"}
	a[97571]={"煆","𢝄","𢟝","𤊳","𤐘"}
	a[97572]={"𣪿"}
	a[97573]={"𡺨","𤐢"}
	a[97574]={"懈","𤐃"}
	a[97575]={"𡺠"}
	a[97577]={"煡"}
	a[97581]={"𡺁","𣪱"}
	a[97582]={"𣪼"}
	a[97584]={"嶰"}
	a[97585]={"輝"}
	a[97588]={"䊕"}
	a[97591]={"燬"}
	a[97593]={"𥼹"}
	a[97630]={"怊","炤","𢙛"}
	a[97631]={"恪","烙"}
	a[97640]={"岹","焔"}
	a[97641]={"䊅","峈"}
	a[97650]={"𢝻","𤉝"}
	a[97651]={"熘","𢞓","𤉴","𤉸","𤌐","𥻓"}
	a[97653]={"𤉙","𥺢"}
	a[97660]={"煝","𢝌","𦒉"}
	a[97661]={"崌","嵧"}
	a[97663]={"峮"}
	a[97670]={"嵋","慴","憺","熠","𢞦","𤊻","𤐐"}
	a[97671]={"惽","𤑟","𥺸"}
	a[97680]={"嶍","嶦","𡾓"}
	a[97681]={"㟭"}
	a[97702]={"䶴"}
	a[97713]={"𪛐"}
	a[97720]={"㶦","忬","炀","𢘕","𤆈"}
	a[97723]={"𤇎"}
	a[97730]={"屷","𡴰","𢖸"}
	a[97731]={"㞨","𢠿"}
	a[97732]={"籽","𢘘"}
	a[97733]={"㶸","恊"}
	a[97740]={"㤘","崡","","𢡓","𤍎"}
	a[97741]={"煀","","𢘩","𥸲"}
	a[97742]={"㥮","㷁","悀","煼","","𧣌"}
	a[97743]={"𢛵"}
	a[97744]={"𨛟"}
	a[97745]={"𢜲"}
	a[97750]={"㥠","惂","憰","焗","焰","煱","燏","𢝸","𢞜","𤏭"}
	a[97751]={"㷌","崛","𡥯","𡸆","𢝞","𢞊","𢞳"}
	a[97752]={"崅","𡺱","𥺷","𨜋"}
	a[97753]={"峥","愑","𤑲","𥻤"}
	a[97760]={"愲","焨","𡸞","𡹬","𡹲","𢞛"}
	a[97761]={"惸","糈","糏","𡦐","𡽈","𤍪"}
	a[97763]={"愶","熁"}
	a[97765]={"𤌂"}
	a[97770]={"嵶","𡻋","𦥿"}
	a[97771]={"𡻳","𢝼"}
	a[97772]={"𥺵"}
	a[97776]={"𤌛"}
	a[97780]={"愵"}
	a[97781]={"憳","燖","𩨳"}
	a[97783]={"𢢁","𢤾","𤒎"}
	a[97791]={"糑","𡼢"}
	a[97792]={"爥"}
	a[97793]={"𡿖"}
	a[97800]={"𢤽"}
	a[97810]={"忺","欻","歘","炊","𢜁","𣢒"}
	a[97812]={"𢦅"}
	a[97820]={"㰞","惞","焮","𢗜","𢘧","𢙊"}
	a[97821]={"𢙑","𥸷"}
	a[97822]={"快","怏","炔","炴"}
	a[97830]={"𣢽"}
	a[97831]={"愌","欪","焕","煥","粎","𢚾","𣢑"}
	a[97832]={"岟"}
	a[97834]={"㥏"}
	a[97840]={"歂","𣣗"}
	a[97841]={"㥚","𡺌","𢜴","𢜵"}
	a[97845]={"𠢣"}
	a[97850]={"惧","慏","熐"}
	a[97851]={"㱁","𡹵","𡺝","𡼲","𢝢","𢡜"}
	a[97852]={"糇","𤏌","𥺶"}
	a[97853]={"懒","𣢫"}
	a[97860]={"㟰","𢢚","𢢾"}
	a[97861]={"懝","𥻩","𥽁"}
	a[97863]={"𣣷","𣤹"}
	a[97870]={"𡾴","𤏉"}
	a[97871]={"㠜","𥼻"}
	a[97873]={"燲","𤒩"}
	a[97880]={"懙"}
	a[97881]={"𢤳","𢥡","𤒾"}
	a[97882]={"㦏","㷷"}
	a[97883]={"㸊","懶"}
	a[97887]={"䊧"}
	a[97890]={"嶼"}
	a[97892]={"𧸆"}
	a[97910]={"𢘝"}
	a[97921]={"㤾","𤉾"}
	a[97930]={"𤊒"}
	a[97931]={"煣","𡷔","𢜸","𣒓"}
	a[97940]={"憏","𡸮","𢞶","𢟺"}
	a[97941]={"㠟","㥡","𡶲"}
	a[97942]={"燦","糅","𥻐"}
	a[97944]={"㥆","𤌧"}
	a[97951]={"粶"}
	a[97953]={"𥽆"}
	a[97962]={"𡽨"}
	a[97964]={"𠒽"}
	a[97985]={"𨾀"}
	a[98043]={"𥻋"}
	a[98110]={"𢗅"}
	a[98120]={"𢘐","𢛰","𤈷"}
	a[98121]={"𢚂"}
	a[98130]={"崄","烂"}
	a[98131]={"㟇","恮","惍","烇"}
	a[98140]={"𡺬"}
	a[98141]={"崯"}
	a[98143]={"𡐞"}
	a[98150]={"𢠏"}
	a[98151]={"㦈","𢚮"}
	a[98153]={"鐅"}
	a[98162]={"嵯","𡻘"}
	a[98164]={"䨆"}
	a[98170]={"懢","爁"}
	a[98173]={"鳖"}
	a[98180]={"𡽳"}
	a[98181]={"糮"}
	a[98190]={"𢥸"}
	a[98200]={"忦","炌"}
	a[98210]={"忴","𡵚"}
	a[98220]={"岒"}
	a[98230]={"怍","炸"}
	a[98240]={"岞"}
	a[98241]={"𥹁"}
	a[98310]={"㥞","忪","怜","炂","炩","焾","煫"}
	a[98320]={"岭","惗","焧","燧","𡵴","𢛌","𢛨","𢢝","𤉪"}
	a[98321]={"𢛒","𥹕","𥻖"}
	a[98322]={"𢞽"}
	a[98330]={"烩","𡹓","𢙓","𢤸"}
	a[98331]={"㟣","㥹","𥺴"}
	a[98332]={"憋"}
	a[98334]={"㷻","憮"}
	a[98340]={"𤐄","𤐹"}
	a[98341]={"㟱","𥺩"}
	a[98342]={"糕","𧝬"}
	a[98347]={"慊","熑"}
	a[98350]={"𤍏"}
	a[98351]={"𢢌","𢢴","𤐑","𧝟"}
	a[98352]={"𤏺"}
	a[98354]={"蟞"}
	a[98357]={"嵰"}
	a[98358]={"𥻧"}
	a[98360]={"嵫"}
	a[98361]={"糍"}
	a[98362]={"𢢡"}
	a[98363]={"鱉","𥼎"}
	a[98364]={"𤓚"}
	a[98372]={"懩"}
	a[98381]={"𤒪"}
	a[98384]={"𧒥"}
	a[98393]={"𩼡"}
	a[98400]={"𤆢","𤑸"}
	a[98410]={"爦"}
	a[98411]={"𣀴"}
	a[98412]={"鼈","𪓶","𪓾","𪔀"}
	a[98415]={"龞"}
	a[98420]={"怆","恱","悅","炝"}
	a[98430]={"忔","忾","悦","𡷋","𢛹"}
	a[98432]={"炧","𠒳"}
	a[98440]={"㟋","屹"}
	a[98441]={"愾","熂","籺","𥹲"}
	a[98442]={"𡶊"}
	a[98443]={"粚","𣱔"}
	a[98444]={"𣰉"}
	a[98451]={"𥸽"}
	a[98452]={"斃"}
	a[98453]={"𥺡"}
	a[98455]={"燨"}
	a[98460]={"𡹳","𡺜"}
	a[98461]={"𡰇"}
	a[98462]={"𤮕"}
	a[98464]={"爔","𢤻"}
	a[98465]={"嶬"}
	a[98472]={"鄨","𤍯","𧢍"}
	a[98473]={"氅"}
	a[98474]={"𡾞"}
	a[98480]={"𤑓"}
	a[98490]={"𢥊"}
	a[98494]={"𣀽"}
	a[98503]={"巕"}
	a[98511]={"巙","炇","𡵛","𢗡","𢙋","𢽻"}
	a[98521]={"忤","𠒡","𡵲","𢚔"}
	a[98522]={"恲","敉","敝","𢠳","𤏰"}
	a[98531]={"㞰","𡹀","𢝽","𢼴","𣁋"}
	a[98532]={"悌","烊","焍","𢾡","𥹎","𨻖"}
	a[98533]={"幣","𢄞","𢾗","𣁢"}
	a[98534]={"嫳","弊","数"}
	a[98541]={"敞","𢠵","𢽐","𢽗","𤏮"}
	a[98542]={"㟄","敩","𢜰"}
	a[98543]={"惮",""}
	a[98544]={"𢠂"}
	a[98551]={"愎","𢼸","𢽡","𢾰","𤋟"}
	a[98552]={"幤","𡹮","𢽘","𢽠","𢾕","𢿵","𤋖"}
	a[98553]={"㢢","㷣","慠","𢢩","𢽸","𢿗","𤍗"}
	a[98554]={"𢿻"}
	a[98561]={"憿","敳","燩","𤒦"}
	a[98562]={"㦑","憞","燉","𢾷","𢿦","𢿽","𦗥"}
	a[98563]={"㠂","𤏽"}
	a[98569]={"𣀱"}
	a[98573]={"𢥌","𪑛"}
	a[98574]={"糤","𪍾"}
	a[98583]={"𡾮"}
	a[98585]={"𤐆"}
	a[98586]={"𥼼"}
	a[98593]={"𦗷"}
	a[98620]={"焀"}
	a[98630]={"㤷","峪","恰","烚","焓","𢡽","𤎳"}
	a[98640]={"㟏","峆","𡹒"}
	a[98641]={"粭","𥼪"}
	a[98650]={"愴","憎","熗","熷","𢢏"}
	a[98652]={"㥢","暼","煪"}
	a[98660]={"嵢","嶒","懀","燴","𡼪"}
	a[98661]={"𥻲"}
	a[98662]={"㷽","崷","瞥"}
	a[98670]={"𡼾","𢠑","𤍸"}
	a[98671]={"糩"}
	a[98672]={"𡻡","𤏲"}
	a[98680]={"𡻵","𩠦"}
	a[98682]={"𧭁"}
	a[98701]={"𠓓"}
	a[98704]={"𤓀"}
	a[98710]={"㤋","𤆶","𤓃"}
	a[98720]={"岎","𢗴","𤍺"}
	a[98721]={"粉"}
	a[98731]={"𤈒"}
	a[98732]={"㷍","惀","𠟈"}
	a[98733]={"𠢪"}
	a[98740]={"㷙","愉"}
	a[98742]={"崘"}
	a[98743]={"悔","烸","𥺀"}
	a[98744]={"撆"}
	a[98750]={"崳","慃","𤌏"}
	a[98751]={"糋","𢝡"}
	a[98752]={"彆","𢡩","𤍼","𦠞"}
	a[98753]={"𥼝"}
	a[98754]={"䊈"}
	a[98755]={"𡦤"}
	a[98760]={"慯","𡻐","𤐎"}
	a[98763]={"燇"}
	a[98764]={"𩦉"}
	a[98770]={"熻","𢡁"}
	a[98772]={"鷩","𤐯"}
	a[98773]={"嶟"}
	a[98774]={"𢶗","𦪰"}
	a[98780]={"嶖"}
	a[98781]={"𦦢"}
	a[98791]={"𪅶"}
	a[98792]={"爚"}
	a[98810]={"𢠰"}
	a[98820]={"嵷"}
	a[98821]={"烪"}
	a[98822]={"𤎨"}
	a[98832]={"𡙢"}
	a[98833]={"獘","𡚁"}
	a[98850]={"㷿","憸"}
	a[98851]={"𤌯"}
	a[98852]={"嵄","蹩","𢣴"}
	a[98853]={"𥻙"}
	a[98860]={"嶮"}
	a[98861]={"𥽋"}
	a[98862]={"𧷍","𧸁"}
	a[98863]={"𠔷","𤢝"}
	a[98873]={"𡼓"}
	a[98892]={"𧸟"}
	a[98921]={"悇"}
	a[98931]={"𡷣"}
	a[98932]={"𥺌"}
	a[98942]={"䌘"}
	a[98951]={"𢟣"}
	a[98955]={"𤏆"}
	a[98973]={"𡼺"}
	a[99000]={"","𢖹"}
	a[99130]={"𤍩"}
	a[99131]={"塋"}
	a[99132]={"𥺇"}
	a[99141]={"瑩","鎣","𢣙","𤑚"}
	a[99142]={"熦","𢚇","𤯵"}
	a[99143]={"𤐻"}
	a[99150]={"䝁","愷","𤍈"}
	a[99151]={"憆","𤎌"}
	a[99152]={"慛","熣","𠓃","𦭠","𦭫"}
	a[99154]={"𤐼"}
	a[99160]={"嵦"}
	a[99161]={"𥻶"}
	a[99162]={"糛"}
	a[99163]={"𥼂"}
	a[99172]={"𡽓","𦯥"}
	a[99182]={"𥫋"}
	a[99200]={"炒"}
	a[99210]={"","𤇾"}
	a[99211]={"粆"}
	a[99220]={"𢙿"}
	a[99221]={"𤎤"}
	a[99230]={"𡷴"}
	a[99242]={"𦬟"}
	a[99263]={"𦯤"}
	a[99320]={"𤬐"}
	a[99321]={"𢞞"}
	a[99330]={"褮"}
	a[99331]={"憥","𢥒"}
	a[99332]={"𢘿"}
	a[99342]={"螢","𢤨"}
	a[99353]={"𢠞"}
	a[99360]={"𡻌"}
	a[99362]={"𧛬","𨑆"}
	a[99364]={"𡽒"}
	a[99372]={"戃","爣"}
	a[99382]={"𡿓"}
	a[99383]={"𥽻"}
	a[99401]={"𩟜"}
	a[99410]={"𤈛","𤈺"}
	a[99420]={"恍","𠙦","𢙙"}
	a[99421]={"㷀"}
	a[99430]={"焭"}
	a[99431]={"煢"}
	a[99432]={"𡴂","𤉼"}
	a[99440]={"恺"}
	a[99442]={"惓"}
	a[99444]={"𡻍","𦲬"}
	a[99450]={"甇","𡮡","𢁃","𢠎"}
	a[99452]={"𡸩"}
	a[99453]={"䊎"}
	a[99460]={"覮"}
	a[99462]={"𦯦"}
	a[99470]={"熴"}
	a[99474]={"𢅇"}
	a[99504]={"𦿑","𧂥"}
	a[99521]={"𢄋","𣂈","𤋩"}
	a[99522]={"嫈","怑","艸","𡠺"}
	a[99523]={"㥪","𤋏"}
	a[99531]={"𡷶"}
	a[99532]={"犖","𢣶","𤌠","𤍛","𤎬","𤐪"}
	a[99533]={"䉽","嵝"}
	a[99534]={"𤌌","𤍧"}
	a[99542]={"𡽤","𢃷","𤏻"}
	a[99543]={"憐","燐","𥻾"}
	a[99544]={"茻","𦫹","𦬧"}
	a[99545]={"𦱹"}
	a[99551]={"𦖽"}
	a[99552]={"𡮖"}
	a[99553]={"嶙","𢄆"}
	a[99554]={"㷨","𥼭"}
	a[99555]={"𦷶"}
	a[99556]={"𦱴"}
	a[99561]={"㦪","夑","燮","𣀢","𣁧"}
	a[99564]={"𠙢","𡻀"}
	a[99565]={"𨍶"}
	a[99574]={"𦶛"}
	a[99584]={"𦽱"}
	a[99593]={"𩇿"}
	a[99640]={"䃕","𢜫"}
	a[99641]={"㽦","𤑝"}
	a[99642]={"𠱭","𢟷"}
	a[99650]={"䁝","營","𢡾","𢥏","𤒨"}
	a[99651]={"𢡦"}
	a[99660]={"䪯","巆","謍"}
	a[99662]={"慻","醟"}
	a[99671]={"𡽊"}
	a[99672]={"𥼽"}
	a[99690]={"𡿘"}
	a[99710]={"灿"}
	a[99711]={"悩","𢛎","𤉤"}
	a[99713]={"𧀍"}
	a[99720]={"屾","嵤"}
	a[99721]={"㤕","勞","憦","炪","籼","𤏪"}
	a[99730]={"悄","惝","惴","焇","煓","𢘏","𤇻","𤋫","𤍀"}
	a[99731]={"嶗","𡦃","𡶏","𡷻","𤊀","𦟴"}
	a[99732]={"𠣁"}
	a[99733]={"𢛗"}
	a[99740]={"㟨","峭","膋","𡷬","𤍔 "}
	a[99741]={"䊑","罃","𤏃","𥹶","𥻁"}
	a[99750]={"䎕","嵴","鶑","𡀸","𡾀"}
	a[99751]={"𡻿"}
	a[99754]={"𡺹","𦮅"}
	a[99755]={"𢢟","𥺅","𦱠"}
	a[99760]={"鶯"}
	a[99764]={"𢥂"}
	a[99770]={"𡾕"}
	a[99772]={"𦺂"}
	a[99782]={"𢤮","𢥘"}
	a[99790]={"𡼰"}
	a[99792]={"𡿀"}
	a[99800]={"㷋","惔","炏","燚"}
	a[99801]={"𢙹"}
	a[99810]={"熒","𡵼","𤐺"}
	a[99811]={"䊏","愀","煍","𤓔"}
	a[99821]={"𡺘","𤌡"}
	a[99822]={"𤋍"}
	a[99825]={"𢣨"}
	a[99831]={"㸉"}
	a[99832]={"𠔖"}
	a[99833]={"𦬦"}
	a[99841]={"𡷪"}
	a[99850]={"爕","𢥥","𤐔"}
	a[99852]={"𦹼"}
	a[99863]={"𦽣"}
	a[99870]={"𢤗"}
	a[99900]={"𡮐"}
	a[99911]={"𢘨","𢘺","𣓳","𤇿","𤌟","𤒇"}
	a[99920]={"滎","𢚭","𥚡"}
	a[99921]={"榮","爃"}
	a[99922]={"𣑼","𥹫"}
	a[99930]={"禜","縈"}
	a[99931]={"嶸"}
	a[99932]={"檾","𢟱","𥣻","𥻒"}
	a[99933]={"𤎊","𥻕","𥼬"}
	a[99942]={"𥼫","𥼮"}
	a[99955]={"𣞆"}
end

-------------------------------------------------------------------------------
-- 汉字拼音表共6157个汉字，缺少拼音汉字14745个(见pinyin-lost.txt)

do
	local b = pinyin_table
	b["彳"]="彳 [00000]"
	b["蕑"]="蕑 [00002]"
	b["蘭"]="蘭 [00005]"
	b["宀"]="宀 [00010]"
	b["簡"]="簡 [00010]"
	b["闁"]="闁 [00010]"
	b["门"]="门 [00010]"
	b["阝"]="阝 [00010]"
end

-------------------------------------------------------------------------------

-- 初始化通配符表
generateIm4cExtTable()

-------------------------------------------------------------------------------

